/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(wb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function ub(vb){var s=vb.a;var t=s.a;var u=t.buffer;t.grow=sb;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=s.va;var gb=s.wa;var hb=528960;var ib=0;var jb=0;var kb=0;var lb=0;
// EMSCRIPTEN_START_FUNCS
function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,U=0,V=0,W=E(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0),ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=E(0),La=0;Y=hb-32|0;hb=Y;la=a+24604|0;f=la;a:{if(!x[f+16>>2]){break a}g=x[f+20>>2];if(g>>>0>4|!(1<<g&22)){break a}f=x[f+28>>2];if(f>>>0>4){break a}e=23>>>f&1}if(!e){g=Y+16|0;KM(g,5104,8871,207);e=hb-112|0;hb=e;f=Vb(e+84|0,13603);x[114409]=0;T(6,e+72|0,1,13195);h=x[114409];x[114409]=0;b:{c:{d:{e:{f:{if((h|0)!=1){x[114409]=0;T(3,e+96|0,f|0,e+72|0);h=x[114409];x[114409]=0;if((h|0)==1){break f}x[114409]=0;ba(2240,e+60|0,g|0,1,9458,e+96|0);g=x[114409];x[114409]=0;if((g|0)==1){break e}xb(e+96|0);xb(e+72|0);break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;xb(e+96|0)}xb(e+72|0)}xb(f);Q(a|0);p()}xb(f);hb=e+112|0}e=x[a+480208>>2];g:{if(!b|e&512){break g}ma=a+8204|0;va=a+1074332|0;K=a+393352|0;$=a+12|0;na=a+1304392|0;g=x[a+1074380>>2];while(1){h:{if(g){break h}ia=a;f=e|512;i:{if(e&256){break i}t=hb-32|0;hb=t;P=hb-16|0;hb=P;f=a+1074392|0;e=x[f>>2]+1|0;x[f>>2]=e;j:{k:{if(Tl(a)>>>0>e>>>0){break k}j=a+1074984|0;l=a+1074312|0;g=a+1304360|0;m=a+484344|0;n=a+484360|0;i=a+1074438|0;r=a+1074424|0;q=a+480210|0;while(1){k=0;l:{if(!x[a+1074396>>2]){break l}k=0;if(!(y[q|0]&8)){break l}k=x[a+480180>>2]==1}m:{if(x[a+480180>>2]!=2|(y[q|0]&8?0:x[a+1074428>>2])){break m}f=0;if(!z[a+480188>>1]){break m}while(1){x[(D(f,896)+a|0)+1075788>>2]=0;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}x[a+1074400>>2]=0;x[a+1074392>>2]=0;x[a+1074396>>2]=0;x[a+1074424>>2]=x[a+1074428>>2];f=z[a+1074440>>1];w[a+1074438>>1]=f;n:{o:{p:{if(!(y[a+480208|0]&32)){q:{if(rc(Wb(n))>>>0>f>>>0){f=z[vc(Wb(n),z[i>>1])>>1];break q}f=65535}w[a+1074436>>1]=f;r:{if(Ne(m)>>>0<=(f&65535)>>>0){break r}if(Ah(Zb(m,z[a+1074436>>1]))){break r}w[a+1074436>>1]=65534}if(z[a+1074436>>1]>=Ne(m)>>>0){while(1){s:{t:{u:{v:{if(z[a+1074436>>1]!=65535){e=z[i>>1];if(rc(Wb(n))>>>0>e>>>0){break v}}f=z[Wb(n)+28>>1];if(f){break t}e=z[i>>1];if(rc(Wb(n))>>>0<e>>>0){break u}e=z[i>>1];if(!e){break u}h=e;while(1){f=e;h=h-1|0;u=h&65535;if(!u){break u}e=f-1|0;if(z[vc(Wb(n),u)>>1]!=65535){continue}break}break t}f=z[i>>1]+1|0;w[i>>1]=f;break s}f=0}w[a+1074438>>1]=f;x[a+480208>>2]=x[a+480208>>2]&-524289;w:{if(rc(Wb(n))>>>0<=(f&65535)>>>0){break w}while(1){if(z[vc(Wb(n),z[i>>1])>>1]!=65534){break w}e=z[i>>1]+1|0;w[i>>1]=e;if(rc(Wb(n))>>>0>(e&65535)>>>0){continue}break}}e=z[i>>1];x:{if(rc(Wb(n))>>>0<=e>>>0){break x}if(!dq(Wb(n),z[i>>1])){break x}f=z[i>>1];break s}Nk(g,1);break p}y:{if(rc(Wb(n))>>>0>(f&65535)>>>0){f=z[vc(Wb(n),z[i>>1])>>1];break y}f=65535}w[a+1074436>>1]=f;z:{if(Ne(m)>>>0<=(f&65535)>>>0){break z}if(Ah(Zb(m,z[a+1074436>>1]))){break z}w[a+1074436>>1]=65534}if(z[a+1074436>>1]>=Ne(m)>>>0){continue}break}}w[a+1074440>>1]=z[a+1074438>>1]}e=0;if(!pg(m,z[a+1074436>>1])){break j}if(A[a+1074424>>2]>=A[Zb(m,z[a+1074436>>1])+12>>2]){x[r>>2]=0}h=(y[a+480208|0]&32)>>>5&x[a+480272>>2]!=-1;if(k){f=g+12|0;if(kd(f)){f=-1}else{f=x[Fj(f)>>2]}f=(f|0)==x[r>>2]}else{f=1}if(h|!f){break n}if(!cO(g,z[i>>1],x[r>>2],1)){break n}f=x[a+480272>>2];if(f){if((f|0)>0){x[a+480272>>2]=f-1}Nk(g,1);dM(g,z[i>>1],x[r>>2]);break n}if(!(y[q|0]&64)){break o}if(!bO(g,i,r,1)){x[a+1074424>>2]=0;x[a+1074428>>2]=0;w[a+1074438>>1]=0;w[a+1074440>>1]=0;f=y[n+16|0];if((f|0)>=(ai(n)-1|0)){cq(n,0);Nk(g,1);break j}cq(n,y[n+16|0]+1&255);Nk(g,1)}f=0;while(1){Qn((D(f,896)+a|0)+1074984|0,7,a,f&65535,1024);f=f+1|0;if((f|0)!=256){continue}break}CM(a);x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+1074444>>2]=x[a+480200>>2];w[a+1074440>>1]=z[a+1074438>>1];x[a+1074428>>2]=x[a+1074424>>2];f=rc(Wb(n));e=z[a+1074438>>1];if(f>>>0>e>>>0){Ia=a,Ja=z[vc(Wb(n),z[a+1074438>>1])>>1],w[Ia+1074436>>1]=Ja;e=z[a+1074438>>1]}dM(g,e&65535,x[a+1074424>>2]);if(pg(m,z[a+1074436>>1])){break n}}e=0;break j}Nk(g,1);break j}e=x[a+1074424>>2]+1|0;x[a+1074428>>2]=e;A:{if(e>>>0<A[Zb(m,z[a+1074436>>1])+12>>2]){break A}if(!(y[a+480208|0]&32)){w[a+1074440>>1]=z[a+1074438>>1]+1}x[a+1074428>>2]=0;e=P+8|0;Kb(e,l,63);if(!Ib(e)){break A}e=x[a+1074432>>2];x[a+1074432>>2]=0;x[a+1074428>>2]=e}e=Hf(Zb(m,z[a+1074436>>1]),x[a+1074424>>2],0);f=z[a+480188>>1];if(f){u=j+D(f,896)|0;f=j;while(1){h=P+8|0;Kb(h,l,82);B:{if(!Ib(h)|y[f+827|0]!=1){break B}h=y[e+3|0];if((h|0)!=2&(h|0)!=3){break B}Ia=f,Ja=jg(a,y[f+822|0],x[f+768>>2],x[f+704>>2]),x[Ia+700>>2]=Ja}h=P+8|0;Kb(h,l,91);C:{if(!Ib(h)){break C}if(Ff(e)){break C}if(!Ff(f+810|0)|y[f+813|0]!=19){break C}h=y[f+815|0];if((h&240)!=208|A[a+1074416>>2]>(h&15)>>>0){break C}Ia=f,Ja=jg(a,y[f+810|0],x[f+768>>2],0),x[Ia+700>>2]=Ja}h=P+8|0;Kb(h,l,92);D:{if(!Ib(h)){break D}Kb(P,l,5);if(Ib(P)|x[a+1074416>>2]!=1|y[f+813|0]!=17){break D}v[P+8|0]=1;Ia=a,Ja=D(y[ah(P+8|0,f+815|0)|0],1e4),x[Ia+1074420>>2]=Ja}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[f+810|0]=h;v[f+811|0]=h>>>8;v[f+812|0]=h>>>16;v[f+813|0]=h>>>24;h=y[e+4|0]|y[e+5|0]<<8;v[f+814|0]=h;v[f+815|0]=h>>>8;h=x[f+676>>2];x[f+20>>2]=x[f+672>>2];x[f+24>>2]=h;x[f+88>>2]=x[f+88>>2]&-393217;h=P+8|0;Kb(h,l,21);if(!Ib(h)){v[f+851|0]=0}x[f+884>>2]=0;v[f+827|0]=0;e=e+6|0;f=f+896|0;if((u|0)!=(f|0)){continue}break}}f=a+1074412|0;E:{F:{e=a+484344|0;if(so(e,z[a+1074436>>1])){if(IN(Zb(e,z[a+1074436>>1]))){break F}}x[a+1074408>>2]=x[a+480216>>2];e=x[a+480220>>2];break E}Ia=a+1074408|0,Ja=x[Zb(e,z[a+1074436>>1])+16>>2],x[Ia>>2]=Ja;e=x[Zb(e,z[a+1074436>>1])+20>>2]}x[f>>2]=e;if(!k){break k}e=x[a+1074416>>2]+1|0;x[a+1074392>>2]=e;if(Tl(a)>>>0<=e>>>0){continue}break}}if(!x[a+1074416>>2]){x[a+1074416>>2]=1}f=x[a+480208>>2];G:{H:{if(x[a+1074392>>2]){x[a+480208>>2]=f&-4097;if(x[a+480180>>2]&1048580|!(y[a+480210|0]&32)&x[a+480180>>2]==1){break G}if(A[a+1074392>>2]>=Tl(a)>>>0|A[a+1074392>>2]%(x[a+1074400>>2]+x[a+1074416>>2]>>>0)){break G}e=x[a+480208>>2];break H}e=f&-528385}x[a+480208>>2]=e|4096}C=0;o=hb-32|0;hb=o;I:{if(!z[a+480188>>1]){m=-1;U=65535;l=-1;break I}ca=a+1075821|0;O=a+1304392|0;G=a+1074312|0;aa=a+1074376|0;J=a+480209|0;da=a+480210|0;l=-1;m=-1;U=65535;while(1){s=D(C,896)+a|0;n=s+1075799|0;g=y[n|0];i=s+1075797|0;L=y[i|0];u=s+1075798|0;I=y[u|0];S=s+1075796|0;r=y[S|0];X=s+1075795|0;k=y[X|0];f=x[a+1074392>>2];j=x[a+1074400>>2];q=x[a+1074416>>2];R=s+1075794|0;e=tt(R);h=s+1075856|0;v[h|0]=x[a+480208>>2]>>>12&1|y[h|0]&254;q=(f>>>0)%(j+q>>>0)|0;f=y[R|0];if((f|0)==252){f=y[X|0];j=Zy(R);H=rt(R);J:{if((f-1&255)>>>0>249){break J}f=x[(D(f,160)+a|0)+906140>>2];if(!f){break J}mb[x[x[f>>2]+44>>2]](f,j,E(E(H>>>0)*E(.0010010009864345193)))}f=y[R|0]}K:{if(B[s+1075868>>2]==E(0)|L?(f&255)!=251:0){break K}f=x[a+480208>>2]&4096;L:{if(!f){j=y[s+1075878|0];break L}j=y[X|0];v[s+1075878|0]=j}if((j-1&255)>>>0>249){break K}j=(D(j&255,160)+a|0)+906140|0;if(!x[j>>2]){break K}M:{if(!f){f=z[s+1075876>>1];break M}f=ot(y[S|0],y[u|0]);w[s+1075876>>1]=f;W=E(E(ot(y[i|0],y[n|0])>>>0)*E(.0010010009864345193));B[s+1075872>>2]=W;n=x[j>>2];Ia=s+1075868|0,Ka=E(E(W-E(mb[x[x[n>>2]+48>>2]](n,f)))/E(Tl(a)>>>0)),B[Ia>>2]=Ka}n=x[a+1074392>>2];i=Tl(a);j=x[j>>2];u=f;f=(i|0)==(n+1|0);mb[x[x[j>>2]+(f?44:100)>>2]](j,u,B[(f?s+1075872|0:s+1075868|0)>>2])}n=s+1074984|0;N:{O:{P:{Q:{R:{if(!DN(y[R|0])){if(y[J|0]&16){break R}break Q}f=hb-16|0;hb=f;w[f+12>>1]=0;x[f+8>>2]=0;e=ei(f+8|0);g=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[n+810|0]=g;v[n+811|0]=g>>>8;v[n+812|0]=g>>>16;v[n+813|0]=g>>>24;e=y[e+4|0]|y[e+5|0]<<8;v[n+814|0]=e;v[n+815|0]=e>>>8;hb=f+16|0;k=0;r=0;I=0;L=0;g=0;e=0;if(!(y[J|0]&16)){break Q}j=0;break O}if(!k){k=0;break P}x[s+1075768>>2]=0;break P}vN(a,n)}if((L|0)==33){f=o+24|0;Kb(f,G,30);j=g>>>4|0;Uy(a,C&65535,j+(g&15)|0,Ib(f));L=33;break O}j=0;if((L-19&255)>>>0>1){break O}S:{if(!(!(x[a+480180>>2]&16777250)|g)){g=y[s+1075837|0];break S}v[s+1075837|0]=g}f=g&240;if((f|0)==208){f=g&15;if(!f){if(x[a+480180>>2]&16777248){j=1;break O}if(x[a+480180>>2]!=2){break O}break N}T:{if(f>>>0<x[a+1074400>>2]+x[a+1074416>>2]>>>0){break T}j=o+24|0;Kb(j,G,14);if(!Ib(j)){break T}if(!k){break N}v[s+1075809|0]=k;break N}j=f;break O}if(!(y[J|0]&16)){break O}U:{if((L|0)==19&(f|0)==96|(L|0)==20&(f|0)==176){f=o+24|0;Kb(f,G,77);if(Ia=Ib(f),Ja=0,La=x[((C<<5)+a|0)+480280>>2]&1024,La?Ia:Ja){break O}u=0;i=hb-16|0;hb=i;H=g&15;V:{W:{if(H){f=y[n+861|0];X:{if(f){f=f-1|0;v[n+861|0]=f;if(f&255){break X}f=i+8|0;Kb(f,a+1074312|0,16);if(!Ib(f)){f=-1;if(x[a+480180>>2]!=2){break V}}x[n+804>>2]=x[a+1074424>>2]+1;break W}f=i+8|0;Kb(f,a+1074312|0,17);if(!(Ib(f)|x[a+480180>>2]&3|!z[a+480188>>1])){f=a+1074984|0;while(1){if(y[f+861|0]?(f|0)!=(n|0):0){break W}f=f+896|0;u=u+1|0;if(z[a+480188>>1]>(u&65535)>>>0){continue}break}}v[n+861|0]=H}f=x[n+804>>2];x[a+1074432>>2]=f;break V}x[n+804>>2]=x[a+1074424>>2]}f=-1}hb=i+16|0;Y:{if((f|0)==-1){f=m;break Y}Z:{if((l|0)!=-1){i=o+24|0;Kb(i,G,68);l=Ib(i)?f:l;break Z}l=-1}i=o+24|0;Kb(i,G,103);U=Ib(i)?-1:U}if(!z[a+480188>>1]|x[a+480180>>2]!=2){break U}m=s+1075845|0;u=s+1075788|0;i=0;while(1){H=D(i,896)+a|0;x[H+1075788>>2]=x[u>>2];v[H+1075845|0]=y[m|0];i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}break U}if((f|0)!=224|(x[a+1074396>>2]?x[a+480180>>2]&16777250:0)){break O}f=g&15;if(!(x[a+480180>>2]&2?f:1)){break O}x[a+1074396>>2]=f+1;break O}m=f}f=j;j=(L|0)==19&x[a+480180>>2]==16&(g&240)==208;M=j?0:f;_:{if(!M|y[R|0]!=255|y[S|0]!=2){break _}f=o+24|0;Kb(f,G,74);if(!Ib(f)){break _}v[S|0]=0}_=g&15;f=x[a+1074392>>2];i=o+24|0;Kb(i,G,72);$:{if(Ib(i)){u=0;if(M>>>0>=A[a+1074416>>2]){break $}}i=o+24|0;Kb(i,G,88);u=(q|0)==(M|0)|(f|0)==(M|0);if(!(!M|!Ib(i))){break $}u=(f|0)==(M|0)}f=o+24|0;Kb(f,G,44);i=j?_|144:g;aa:{if(!Ib(f)){f=y[h|0];break aa}f=y[h|0]&-2|(q|0)==(M|0)}v[h|0]=f&253|(u?2:0);f=o+24|0;Kb(f,G,66);j=(!M|Ib(f)^1)&e;ba:{ca:{da:{if(!(x[a+1074392>>2]|(!(y[da|0]&32)|!k))){x[s+1075644>>2]=0;if(u){g=y[R|0];break da}if(!Zh(n)){break ba}v[s+1075809|0]=k;if(z[a+480190>>1]<k>>>0){break ba}e=D(k,104)+a|0;x[s+1075672>>2]=z[e+484410>>1];x[s+1075752>>2]=v[e+484417|0];break ba}if(!u){break ba}g=y[R|0];if(!k){break ca}}v[s+1075809|0]=k}ea:{fa:{e=g&255;if(!be(e)){break fa}f=o+24|0;Kb(f,G,67);if(!Ib(f)){break fa}f=x[s+1075756>>2];ga:{if(!k|j){break ga}ha:{if(z[a+480192>>1]){h=65535;if(z[a+480192>>1]<k>>>0){break ha}q=x[((k<<2)+a|0)+900380>>2];if(!q){break ha}h=z[fd(q+236|0,e-1|0)>>1];break ha}h=k}h=h&65535;if(h>>>0>z[a+480190>>1]){break ga}f=v[mq(a,h)+36|0]}g=(e+f|0)-132>>>0>=4294967176?g:0;break ea}if(!(x[a+480180>>2]&25165856)|!z[a+480192>>1]){break ea}if(e){e=be(e)}else{e=1}if(!e){break ea}e=k;if(!e){e=y[s+1075810|0]}if(!e|(x[((e<<2)+a|0)+900380>>2]?z[a+480192>>1]>=e>>>0:0)){break ea}g=0;k=0}if(!((L|0)!=25|i)){e=o+24|0;Kb(e,G,55);e=Ib(e);k=e?0:k;g=e?0:g}h=o+24|0;Kb(h,G,65);f=(k|0)!=0;e=g&255;q=!e;h=Ib(h);V=1;ia:{if(x[a+480180>>2]&16777248){break ia}H=o+24|0;Kb(H,G,107);if(Ib(H)){break ia}H=o+16|0;Kb(H,G,85);V=0;if(!Ib(H)){break ia}if(Zh(n)){break ia}V=1;H=x[s+1075088>>2];if(!H){break ia}V=He(H)^1}q=f&q;H=f&h;ja:{ka:{la:{ma:{na:{oa:{if(!(x[a+480180>>2]&1048580)){break oa}pa:{if((e|0)!=255){break pa}if(!(!((L|0)==13|k)&(r|0)!=1)){f=o+24|0;Kb(f,G,55);if(Ib(f)){break pa}}f=x[s+1075640>>2];if(v[f+60|0]&1?f:0){break pa}x[s+1075672>>2]=0;e=s+1075072|0;x[e>>2]=x[e>>2]|2097152;qa:{if(!(x[a+480208>>2]&4096)){break qa}f=o+24|0;Kb(f,G,86);if(!Ib(f)){break qa}x[e>>2]=x[e>>2]|4096}k=0;g=0;f=0;e=0;h=0;q=1;if(H){break ka}break ja}f=o+24|0;Kb(f,G,59);if(!Ib(f)|x[a+480208>>2]&4096){break oa}ra:{if(!e){g=y[s+1075803|0]-y[s+1075756|0]|0;break ra}if(e>>>0>250){V=0;H=1;g=0;break ra}sa:{if(k){break sa}e=o+24|0;Kb(e,G,98);if(!Ib(e)){break sa}k=0;break ra}V=1;H=1}f=g;j=0;break na}f=0;if(!q){break ma}}e=o+24|0;Kb(e,G,65);if(!Ib(e)){break la}g=f;f=1}e=g;h=f;q=1;if(H){break ka}break ja}g=f;f=1;q=H}ta:{ua:{if(!z[a+480192>>1]){if(z[a+480190>>1]<k>>>0){break ta}e=(D(k,104)+a|0)+484380|0;break ua}e=x[s+1075088>>2];if(!e){break ta}}va:{if(w[e+34>>1]<0){break va}if(x[a+480180>>2]==2){if(!He(e)){break va}}x[s+1075672>>2]=z[e+30>>1]}if(!q){break ta}Nt(n,z[e+28>>1],a)}e=g;h=f}f=o+24|0;Kb(f,G,71);if(!(!Ib(f)|!k)){v[s+1075843|0]=32}wa:{if(!z[a+480192>>1]){break wa}f=o+24|0;Kb(f,G,100);if(!Ib(f)|!k){break wa}if(be(e&255)){break wa}f=x[a+480208>>2];xa:{if(j){if(f&8){break xa}break wa}if(!(f&4)){break wa}}Wl(n);x[s+1075680>>2]=65536;f=s+1075072|0;x[f>>2]=x[f>>2]|2097152}if(h){f=o+24|0;Kb(f,G,11);ya:{if(!Ib(f)&x[a+480180>>2]!=268435456){break ya}f=o+24|0;Kb(f,G,87);g=0;if(Ib(f)){g=Zh(n)^1}za:{if(z[a+480192>>1]){if(z[a+480192>>1]<k>>>0){break ya}if(x[s+1075640>>2]!=x[((k<<2)+a|0)+900380>>2]|g){break za}break ya}if((g^-1)&x[s+1075088>>2]==((D(k,104)+a|0)+484380|0)){break ya}}e=y[s+1075803|0]}Aa:{if(!z[a+480192>>1]|!(x[a+480180>>2]&1048588)){break Aa}Wl(n);v[s+1075822|0]=0;x[s+1075764>>2]=0;x[s+1075680>>2]=65536;f=s+1075072|0;x[f>>2]=x[f>>2]&-2101249|2097152;g=o+24|0;Kb(g,G,86);if(!Ib(g)){break Aa}x[f>>2]=x[f>>2]&-2049}k=V?k:0}g=e&255;Ba:{if(g>>>0<251){break Ba}f=o+24|0;Kb(f,G,50);Ca:{if(!Ib(f)|!k){break Ca}if(z[a+480192>>1]){if(z[a+480192>>1]<k>>>0){break Ca}f=((k<<2)+a|0)+900380|0;if(!x[f>>2]){break Ca}h=s+1075805|0;if(!be(y[h|0])){break Ca}f=z[fd(x[f>>2]+236|0,y[h|0]-1|0)>>1]}else{f=k}f=f&65535;if(!f|f>>>0>z[a+480190>>1]){break Ca}f=D(f,104)+a|0;if(w[f+484414>>1]<0){break Ca}x[s+1075672>>2]=z[f+484410>>1]}f=o+24|0;Kb(f,G,100);if(Ia=Ib(f),Ja=0,La=x[a+480208>>2]&4,La?Ia:Ja){break Ba}k=0}if(be(g)){v[s+1075808|0]=e;v[s+1075805|0]=e;if(!j){yN(a,C&65535,k,g,0)}iP(n)}Da:{Ea:{Fa:{Ga:{Ha:{if(k){f=s+1075088|0;h=x[f>>2];Up(a,n,k,j,1,1);e=x[f>>2];Ia:{if(!e|!(y[e+35|0]&2)){break Ia}if(!yd(O)){break Ia}lz(x[O>>2],C&65535,x[f>>2]+68|0)}Ja:{Ka:{if(x[a+480180>>2]==1){if(!j){break Ka}e=o+24|0;Kb(e,G,85);if(!Ib(e)){break Ka}break Ja}e=o+24|0;Kb(e,G,50);if(!Ib(e)){break Ka}if(!be(g)){break Ja}}v[s+1075809|0]=0}e=o+24|0;Kb(e,G,42);if(Ib(e)){if(!be(g)|(h|0)==x[f>>2]){break Ga}break Ha}if(!(!(x[a+480180>>2]&16777248)|(h|0)==x[f>>2])){e=0;if(be(g)){break Fa}}e=o+24|0;Kb(e,G,107);La:{if(!Ib(e)|(h|0)==x[f>>2]){break La}if(!j){if(be(g)){break La}}e=s+1075060|0;if(A[e>>2]>=A[n+4>>2]){break La}x[e>>2]=0;break Ga}e=o+24|0;Kb(e,G,85);if(!Ib(e)){break Ga}if(!Zh(n)){break Ha}break Ga}if(!g){e=j;break Da}f=0;h=s+1075809|0;Ma:{if(!y[h|0]){break Ma}if(!be(g)){break Ma}Up(a,n,y[h|0],j,!(x[s+1075088>>2]?1:x[s+1075640>>2]),!(x[a+480180>>2]&1048580));v[h|0]=0;f=1}e=j;break Ea}x[n>>2]=0;x[n+4>>2]=0}e=j}f=0;if(!g){break Da}}h=s+1075088|0;j=x[h>>2];Na:{if(!j|!(y[j+35|0]&2)){break Na}if(!yd(O)){break Na}if(!f){if(zN(x[O>>2],C&65535)){break Na}}lz(x[O>>2],C&65535,x[h>>2]+68|0)}f=C&65535;qt(a,n,g,e,!(x[a+480180>>2]&1048580),0,f);if(!(!e|(!k|!(x[a+480180>>2]&1048580)))){h=s+1075072|0;x[h>>2]=x[h>>2]|2097152;Wl(n);v[s+1075822|0]=0;x[s+1075764>>2]=0}if(!(x[s+1075072>>2]&512)){break Da}if(!yd(O)){break Da}if(g>>>0<=253){if((g|0)!=253){break Da}g=o+24|0;Kb(g,G,99);if(Ib(g)){break Da}}Ok(x[O>>2],f)}Oa:{Pa:{switch(r-1|0){case 0:I=I>>>0>=64?64:I;x[s+1075672>>2]=I<<2;f=s+1075072|0;x[f>>2]=x[f>>2]|2097152;break Oa;case 1:break Pa;default:break Oa}}Xl(a,n,I,6)}if(z[a+480192>>1]){aM(a,C&65535)}j=e}e=o+24|0;Kb(e,G,77);if(Ia=Ib(e),Ja=0,La=x[((C<<5)+a|0)+480280>>2]&1024,La?Ia:Ja){break N}e=x[a+1074392>>2];f=o+24|0;Kb(f,G,75);g=e>>>0>=M>>>0;Qa:{Ra:{Sa:{if(!M|!Ib(f)){break Sa}f=x[a+1074392>>2];if(!f){break Ra}g=1;if((f|0)!=(M|0)){break Sa}g=!y[X|0]&(r|0)!=11}e=r;if(!g|e>>>0<3){break Ra}if((e|0)==11){e=o+24|0;Yy(e,a,R,M);f=y[mc(e)|0];Dn(a,n,x[e>>2]);if(f){break Qa}r=11;break Ra}f=o+24|0;Kb(f,G,62);Ta:{Ua:{Va:{Wa:{Xa:{Ya:{if(!(!Ib(f)|I)){I=0;r=0;Za:{switch(e-8|0){case 0:break Ya;case 1:break Za;default:break Ra}}if(y[J|0]&16){break Ra}x[s+1075676>>2]=0;break Ra}f=o+24|0;Kb(f,G,41);_a:{if(Ib(f)){break _a}if(I){v[s+1075838|0]=I;break _a}I=y[s+1075838|0]}$a:{switch(e-3|0){case 0:case 1:ab:{bb:{if(I){break bb}f=o+24|0;Kb(f,G,41);if(!Ib(f)){break bb}I=y[s+1075838|0];if(I){break ab}I=0;break Ra}v[s+1075838|0]=I}Gn(a,n,((e|0)==3?I<<4:I)&255);break Ra;case 2:if((M|0)!=x[a+1074392>>2]){e=o+24|0;Kb(e,G,41);r=5;if(Ib(e)){break Ra}}e=o+24|0;Kb(e,G,41);Sp(a,n,I,Ib(e));r=5;break Ra;case 3:if((M|0)!=x[a+1074392>>2]){e=o+24|0;Kb(e,G,41);r=6;if(Ib(e)){break Ra}}e=o+24|0;Kb(e,G,41);Rp(a,n,I,Ib(e));r=6;break Ra;case 12:break Ta;case 10:break Ua;case 9:break Va;case 7:break Wa;case 6:break Xa;case 5:break Ya;case 4:break $a;default:break Ra}}e=o+24|0;Kb(e,G,53);if(Ib(e)){v[s+1075827|0]=I&15;r=7;break Ra}Kk(n,I<<4);r=7;break Ra}Kk(n,I);r=8;break Ra}e=o+24|0;Kb(e,G,62);Ty(a,n,I,Ib(e)^1);r=9;break Ra}e=o+24|0;Kb(e,G,62);Ty(a,n,I<<4&240,Ib(e)^1);r=10;break Ra}r=12;e=o+24|0;Kb(e,G,12);uN(a,C&65535,I<<2&252,Ib(e));break Ra}e=o+24|0;Kb(e,G,12);tN(a,C&65535,I<<2&252,Ib(e));r=13;break Ra}r=15;if(!u){break Ra}e=x[s+1075088>>2];if(!e|I>>>0>9){break Ra}cb:{if(!I){k=x[s+1075648>>2];break cb}k=x[(e+(I<<2)|0)- -64>>2];x[s+1075648>>2]=k}Tp(a,n,k)}db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{switch(L-1|0){case 12:if(!(y[a+480209|0]&16)){break Qa}e=D(C,896)+a|0;x[e+1075672>>2]=i>>>0>=64?256:i<<2;e=e+1075072|0;x[e>>2]=x[e>>2]|2097152;break Qa;case 1:if(!i&(x[a+480180>>2]&1)){break Ab}uN(a,C&65535,i,0);break Qa;case 2:if(!i&(x[a+480180>>2]&1)){break Ab}tN(a,C&65535,i,0);break Qa;case 10:if(!i&x[a+480180>>2]==1){break Ab}Gn(a,n,i);break Qa;case 3:Dn(a,n,i);break Qa;case 5:if(!(!i&x[a+480180>>2]==1)){Gn(a,n,i)}Dn(a,n,0);break Qa;case 4:Kk(n,i);break Qa;case 6:if(!(!i&x[a+480180>>2]==1)){Gn(a,n,i)}Kk(n,0);break Qa;case 15:if(!(y[a+480209|0]&16)){break Qa}break db;case 16:e=o+24|0;Kb(e,G,5);if(Ib(e)){if(!(y[a+480209|0]&16)){break Qa}if(i){break db}break Qa}i=Vp(a,z[a+1074436>>1],x[a+1074424>>2],C&65535,0);Cb:{if(!(x[a+480180>>2]&16777250)){break Cb}if(i){v[(D(C,896)+a|0)+1075839|0]=i;break Cb}i=y[(D(C,896)+a|0)+1075839|0]}x[o+24>>2]=D(i,1e4);zc(o+24|0,D(x[x[a+8>>2]+24>>2],1e4));e=hb-16|0;hb=e;g=x[o+24>>2];x[e+12>>2]=g;f=x[a+8>>2];Db:{if(g>>>0>=(x[a+480180>>2]&16392?1e4:32e4)>>>0){g=x[a+480208>>2];h=e+4|0;Kb(h,a+1074312|0,92);if((Ib(h)|0)==((g&4096)>>>12|0)){break Db}x[e+4>>2]=D(x[f+24>>2],1e4);Ia=a+1074420|0,Ja=x[Mb(e+12|0,e+4|0)>>2],x[Ia>>2]=Ja;break Db}if(y[a+480209|0]&16){break Db}h=a+1074420|0;g=(g>>>0)/1e4|0;j=D(g&15,1e4);x[h>>2]=x[h>>2]+((g&240)==16?j:0-j|0);g=x[f+20>>2];f=x[f+24>>2];j=e+4|0;Kb(j,a+1074312|0,8);Jo(h,D(g,1e4),Ib(j)?255e4:D(f,1e4))}hb=e+16|0;break Qa;case 9:if(!u|(x[a+480180>>2]==4?j:0)){break Qa}v[o+24|0]=0;e=Vp(a,z[a+1074436>>1],x[a+1074424>>2],C&65535,o+24|0);f=a;if(!y[o+24|0]){g=(D(C,896)+a|0)+1075648|0;k=e<<8;Eb:{if(k){x[g>>2]=k;break Eb}k=x[g>>2]}e=(y[(D(C,896)+a|0)+1075840|0]<<16)+k|0}Tp(f,n,e);break Qa;case 40:if(!u){break Qa}f=sqa(x[(D(C,896)+a|0)+1075060>>2],0,i,0);e=lb;j=e>>>8|0;Tp(a,n,id((e&255)<<24|f>>>8,j));break Qa;case 0:if(x[a+1074392>>2]){break Qa}e=D(C,896)+a|0;Fb:{if(y[e+1075803|0]?x[e+1075684>>2]:0){break Fb}e=x[e+1075640>>2];if(e){if(Ri(e)){break Fb}}e=o+24|0;Kb(e,G,13);if(Ib(e)){break Fb}if(x[a+480180>>2]&16777248){break Qa}}if(!i){i=0;if(x[a+480180>>2]&5){break Qa}v[(D(C,896)+a|0)+1075811|0]=1;break Qa}e=D(C,896)+a|0;v[e+1075812|0]=i;v[e+1075811|0]=1;break Qa;case 14:if(x[a+480180>>2]&1048580){i=i&240?i:z[(D(C,896)+a|0)+1075784>>1]&240|i;if(!(i&15)){i=z[(D(C,896)+a|0)+1075784>>1]&15|i}i=i|256}e=o+24|0;Kb(e,G,23);if(Ib(e)){Gb:{if(!i){k=z[(D(C,896)+a|0)+1075784>>1];break Gb}k=i&255;w[(D(C,896)+a|0)+1075784>>1]=k}Sy(a,C&65535,k<<16>>16,(r|0)==15?I+1|0:0);break Qa}Hb:{if(i){w[(D(C,896)+a|0)+1075784>>1]=i&255;break Hb}i=w[(D(C,896)+a|0)+1075784>>1]}Sy(a,C&65535,i,(r|0)==15?I+1|0:0);break Qa;case 39:break gb;case 38:break hb;case 34:case 35:case 36:case 37:break ib;case 13:break jb;case 11:break kb;case 29:break lb;case 26:break mb;case 21:break nb;case 20:break ob;case 27:break pb;case 24:break qb;case 19:break rb;case 18:break sb;case 25:break tb;case 7:break ub;case 28:break vb;case 8:break wb;case 23:break xb;case 22:break yb;case 17:break Bb;default:break Qa}}if(!(y[a+480209|0]&16)){break Qa}e=o+24|0;Kb(e,G,22);Ib:{Jb:{if(Ib(e)){if(!i){i=0;break Jb}if(y[a+480208|0]&4){break Jb}e=i&240?i-16|0:i;i=e-((e&15)!=0)|0;v[(D(C,896)+a|0)+1075844|0]=i;break Jb}e=o+24|0;Kb(e,G,71);if(!Ib(e)){break Ib}}e=(D(C,896)+a|0)+1075843|0;v[e|0]=y[e|0]|128}e=D(C,896)+a|0;v[e+1075811|0]=18;if(i){break zb}}i=0;break Qa}v[e+1075844|0]=i;break Qa}if(!(y[a+480209|0]&16)){break Qa}i=i<<!(x[a+480180>>2]&59593760);if(i>>>0<=128){x[a+1074444>>2]=i<<1;break Qa}if(x[a+480180>>2]&16777250){break Qa}x[a+1074444>>2]=256;break Qa}e=o+24|0;Kb(e,G,9);if(Ib(e)){sN(a,i,(D(C,896)+a|0)+1075821|0);break Qa}sN(a,i,ca);break Qa}if(!(y[a+480209|0]&16)){break Qa}Xl(a,n,i,8);break Qa}Ty(a,n,i,1);break Qa}LN(n,i);break Qa}MN(a,n,i);break Qa}e=i&15;f=C&65535;h=D(f,896)+a|0;g=h+1074984|0;Kb:{Lb:{switch(i>>>4|0){case 0:if(!z[a+480188>>1]){break Kb}f=(i&1)<<14;e=0;while(1){g=(D(e,896)+a|0)+1075072|0;x[g>>2]=(f|x[g>>2]&-16385)^16384;e=e+1|0;if(e>>>0<z[a+480188>>1]){continue}break};break Kb;case 1:if(!(e|x[a+480180>>2]&1048580)){break Kb}kN(a,g,e);break Kb;case 2:if(!(e|x[a+480180>>2]&1048580)){break Kb}iN(a,g,e);break Kb;case 3:f=h+1075072|0;x[f>>2]=x[f>>2]&-1048577|((e|0)!=0)<<20;break Kb;case 4:v[h+1075826|0]=i&7;break Kb;case 5:if(!(y[a+480209|0]&16)){break Kb}if(x[a+480180>>2]&69206025){g=D(f,896)+a|0;h=g+1075752|0;x[h>>2]=e<<28>>24;e=g+1075684|0;if(!x[e>>2]){break Kb}if(!Ff(g+1075794|0)){break Kb}g=e;e=D(f,896)+a|0;Ia=g,Ja=jg(a,y[e+1075803|0],x[h>>2],x[e+1075688>>2]),x[Ia>>2]=Ja;break Kb}h=x[a+480180>>2];g=Ff((D(f,896)+a|0)+1075794|0);if((h|0)==16){if(!g){break Kb}g=D(f,896)+a|0;h=x[g+1075088>>2];if(!h){break Kb}v[h+37|0]=e;x[g+1075752>>2]=e;g=g+1075684|0;if(!x[g>>2]){break Kb}f=D(f,896)+a|0;Ia=g,Ja=jg(a,y[f+1075803|0],e,x[f+1075688>>2]),x[Ia>>2]=Ja;break Kb}if(!g){break Kb}e=D(f,896)+a|0;f=(i<<4^128)<<24>>24;x[e+1075752>>2]=f;g=e+1075684|0;if(!x[g>>2]){break Kb}Ia=g,Ja=jg(a,y[e+1075803|0],f,x[e+1075688>>2]),x[Ia>>2]=Ja;break Kb;case 7:v[h+1075829|0]=i&7;break Kb;case 8:if(!(y[a+480209|0]&16)){break Kb}Xl(a,g,e,4);break Kb;case 9:Sy(a,f,e,0);break Kb;case 10:if(!(e|x[a+480180>>2]&1048580)){break Kb}Sp(a,g,e,0);break Kb;case 11:if(!(e|x[a+480180>>2]&1048580)){break Kb}Rp(a,g,e,0);break Kb;case 12:Uy(a,f,e,0);break Kb;case 15:break Lb;default:break Kb}}if(x[a+480180>>2]==1){v[(D(f,896)+a|0)+1075850|0]=e;if(!(y[a+480209|0]&16)){break Kb}vN(a,g);break Kb}v[(D(f,896)+a|0)+1075848|0]=e}break Qa}rN(a,C&65535,i);break Qa}e=o+24|0;Kb(e,G,55);if(Ib(e)){if(x[a+1074392>>2]!=(i|0)){break Qa}e=x[(D(C,896)+a|0)+1075640>>2];if(v[e+60|0]&1?e:0){break eb}if(!(!(y[X|0]|y[S|0])|i)){e=(D(C,896)+a|0)+1075072|0;x[e>>2]=x[e>>2]|4096;break eb}e=D(C,896)+a|0;x[e+1075672>>2]=0;e=e+1075072|0;x[e>>2]=x[e>>2]|2097152;break eb}if(y[a+480209|0]&16){break eb}break Qa}e=(i&240)-16>>>4|0;if(e>>>0>9){break Qa}if(!(1<<e&880)){if(!e){break fb}if((e|0)!=1){break Qa}qN(a,n,i&15);break Qa}e=o+24|0;Kb(e,G,58);if(Ib(e)){break Qa}rN(a,C&65535,i);break Qa}if(!(y[a+480209|0]&16)|i>>>0>64){break Qa}e=D(C,896)+a|0;x[e+1075744>>2]=i;e=e+1075072|0;x[e>>2]=x[e>>2]|2097152;break Qa}e=i;Mb:{if(e){v[n+836|0]=e;break Mb}e=y[n+836|0]}f=e&15;g=e&255;Nb:{Ob:{if(!((f|0)!=15|g>>>0<16)){if(!(y[a+480209|0]&16)){break Nb}e=g>>>4|0;break Ob}h=x[a+480208>>2]&4096;j=g&240;if(!(!f|(j|0)!=240)){if(!h){break Nb}e=0-f|0;break Ob}if(h){break Nb}if(f){e=0-f|0;if(!j|!(x[a+480180>>2]&25690144)){break Ob}break Nb}if((e&255)>>>0<16){break Nb}e=g>>>4|0}Ia=n,Ja=Yb(e+x[n+760>>2]|0,0,64),x[Ia+760>>2]=Ja}break Qa}KN(n,i);break Qa}if(!(y[a+480209|0]&16)){break Qa}e=D(C,896)+a|0;x[e+1075712>>2]=i;f=o+24|0;Kb(f,G,60);if(Ia=0,Ja=Ib(f),La=y[e+1075708|0]&4,La?Ia:Ja){break Qa}e=D(C,896)+a|0;x[e+1075736>>2]=i;x[e+1075724>>2]=i;break Qa}x[a+1074432>>2]=0;U=Vp(a,z[a+1074436>>1],x[a+1074424>>2],C&65535,0);l=x[a+480180>>2]&5?(l|0)==-1?l:0:l;break Qa}e=NN(a,aa,C&65535,i);if((e|0)==-1){break Qa}U=y[a+480208|0]&32?z[a+1074438>>1]:U;l=e;break Qa}if(y[a+480209|0]&16){e=i&240;if(e){v[n+869|0]=e>>>4}e=i&15;if(e){v[n+870|0]=e}v[n+868|0]=y[n+869|0]}g=(L|0)==35|(L|0)==37;h=(L-37&255)>>>0<2;Pb:{Qb:{if(x[a+480180>>2]==32768){f=y[n+869|0];e=16;if((f|0)==16){break Qb}e=f;if(y[a+480209|0]&16){break Qb}break Pb}if(y[a+480209|0]&16){break Pb}e=y[n+868|0]-1|0;v[n+868|0]=e;if(e&255){break Pb}e=y[n+869|0]}v[n+868|0]=e;e=y[n+870|0];e=g?e:0-e|0;Rb:{if(Lj(n)){x[n+876>>2]=x[n+876>>2]+D(e,x[x[x[n+656>>2]+44>>2]+36>>2]);break Rb}Ia=n,Ja=jg(a,kt(a,x[n+700>>2],0,x[n+704>>2])+e|0,0,x[n+704>>2]),x[Ia+700>>2]=Ja}if(!h){break Pb}x[n>>2]=0;x[n+4>>2]=0}break Qa}HN(o,n,i);break Qa}if(x[a+1074392>>2]|_>>>0>1|i>>>0>47){break Qa}e=(i&240)==16;k=e?0:C;f=e?z[a+480188>>1]-1|0:C;if((k&65535)>>>0>(f&65535)>>>0){break Qa}e=((_|0)==1)<<26;while(1){g=k&65535;h=((g<<5)+a|0)+480280|0;x[h>>2]=e|x[h>>2]&-67108865;g=(D(g,896)+a|0)+1075072|0;x[g>>2]=e|x[g>>2]&-67108865;k=k+1|0;if((k&65535)>>>0<=(f&65535)>>>0){continue}break}break Qa}pN(a,n,i&15);break Qa}Fn(a,n);break Qa}ON(a,aa,i)}e=o+24|0;Kb(e,G,78);if(!(!Ib(e)|!i)){JN(n,i&255)}e=y[X|0];if(!e){break N}v[s+1075810|0]=e}C=C+1|0;if(C>>>0<z[a+480188>>1]){continue}break}}Sb:{if(!(y[a+480209|0]&16)){break Sb}Tb:{if(!((l|0)==-1&(U&65535)==65535)){Ub:{if((m|0)==-1){break Ub}f=o+24|0;e=a+1074312|0;Kb(f,e,68);if(Ib(f)){break Ub}f=o+16|0;Kb(f,e,103);if(Ia=Ib(f),Ja=0,La=(U&65535)!=65535,La?Ia:Ja){break Ub}f=o+8|0;Kb(f,e,49);if(!Ib(f)|(U&65535)==65535){break Tb}}x[a+480208>>2]=x[a+480208>>2]|524288;f=(U&65535)!=65535?U:z[a+1074438>>1]+1|0;e=a+484360|0;if(rc(Wb(e))>>>0<=(f&65535)>>>0){f=z[Wb(e)+28>>1]}g=(l|0)!=-1?l:0;Vb:{if(z[a+1074438>>1]==(f&65535)){break Vb}e=o+24|0;h=a+1074312|0;Kb(e,h,26);if(Ib(e)){break Vb}e=o+16|0;Kb(e,h,68);if(Ib(e)|x[a+480180>>2]==1|!z[a+480188>>1]){break Vb}e=0;while(1){v[(D(e,896)+a|0)+1075845|0]=0;e=e+1|0;if(e>>>0<z[a+480188>>1]){continue}break}}x[a+1074428>>2]=g;if(y[a+480208|0]&32){break Sb}w[a+1074440>>1]=f;break Sb}if((m|0)==-1){break Sb}}x[a+1074428>>2]=m;w[a+1074440>>1]=z[a+1074438>>1];Wb:{if(!x[a+1074396>>2]){break Wb}if(x[a+480180>>2]==32){e=o+24|0;Kb(e,a+1074312|0,103);if(Ib(e)){break Wb}}if(x[a+480180>>2]==2){break Wb}x[a+1074428>>2]=x[a+1074428>>2]+1}if(A[Zb(a+484344|0,z[a+1074436>>1])+12>>2]<=m>>>0){x[a+1074428>>2]=0;w[a+1074440>>1]=z[a+1074440>>1]+1}j=z[a+1074438>>1];e=hb-16|0;hb=e;k=a+1304360|0;g=k+12|0;Ia=e,Ja=PO(g),x[Ia+12>>2]=Ja;Ia=e,Ja=tz(g),x[Ia+8>>2]=Ja;Xb:{if(!Kt(e+12|0,e+8|0)|(m|0)==-1){break Xb}while(1){f=hb-16|0;hb=f;h=e+12|0;x[f+12>>2]=x[h>>2];n=x[hg(f+12|0)>>2];hb=f+16|0;f=x[n>>2];hz(k,j,f,0);hg(h);Ia=e,Ja=tz(g),x[Ia+8>>2]=Ja;h=Kt(h,e+8|0);if((f|0)==(m|0)){break Xb}if(h){continue}break}}hb=e+16|0}hb=o+32|0;e=1}hb=P+16|0;X=x[a+1074420>>2]!=0&e;Yb:{if(!X){break Yb}e=xM(a,a+1074376|0);x[a+1074380>>2]=e;x[a+1074404>>2]=e;f=Md(z[a+480188>>1],1,31);L=a+1074332|0;Zb:{if(y[L+37|0]){e=x[a+24628>>2];if((e|0)>=129){e=((D(e-128|0,f+4|0)|0)/16|0)+128|0}u=D(x[a+480228>>2],e)>>>6|0;break Zb}u=x[a+480228>>2]}u=y[L+37|0]?(u<<7>>>0)/y[(f>>>1|0)+25856|0]|0:u;w[a+480212>>1]=0;G=a+1304392|0;s=a+1074312|0;U=a+480210|0;V=a+480209|0;q=0;while(1){l=D(q,896)+a|0;H=l+1075072|0;_b:{if(!(x[H>>2]&4096)|(x[l+1075008>>2]|(x[l+1075004>>2]|x[l+1075680>>2]))){break _b}e=t+24|0;Kb(e,s,64);if(Ib(e)){break _b}x[l+1075060>>2]=0;e=l+1075076|0;x[e>>2]=0;x[e+4>>2]=0}f=z[a+480188>>1];e=x[H>>2];$b:{if(x[l+1075060>>2]|f>>>0>q>>>0?e&1024:1){if(f>>>0>q>>>0){kM(a,q&65535)}w[l+1075846>>1]=0;break $b}m=0;R=l+1075704|0;x[R>>2]=0;C=l+1075664|0;x[C>>2]=0;n=l+1074992|0;g=n;x[g>>2]=0;x[g+4>>2]=0;x[l+1075084>>2]=0;x[t+20>>2]=1065353216;w[t+18>>1]=0;r=0;I=l+1075684|0;r=x[I>>2]?x[l+1075060>>2]!=0:r;k=l+1074984|0;P=l+1075640|0;M=x[P>>2];ac:{bc:{cc:{if(f>>>0<=q>>>0){break cc}if(y[((q<<5)+a|0)+480288|0]){break bc}if(!M){break cc}m=y[M+34|0]!=0}if((m|r)!=1){break ac}}x[t+8>>2]=x[l+1075672>>2];x[t+4>>2]=x[l+1075748>>2];f=t+24|0;Kb(f,s,28);e=t+8|0;f=Ib(f)?t+4|0:e;g=a+1074312|0;dc:{if($b(g,28)){x[f>>2]=x[f>>2]+w[k+788>>1];ce(f,0,64);break dc}h=$b(g,1);g=w[k+788>>1];if(h){x[f>>2]=g+x[f>>2];ce(f,0,256);break dc}x[k+688>>2]=g+x[k+688>>2];ce(k+688|0,0,256);x[f>>2]=x[k+688>>2];w[k+788>>1]=0}ec:{fc:{f=a+1074312|0;if(!$b(f,28)){if(!$b(f,1)){break fc}}x[k+684>>2]=x[k+692>>2]+w[k+790>>1];ce(k+684|0,0,256);break ec}x[k+692>>2]=x[k+692>>2]+w[k+790>>1];ce(k+692|0,0,256);w[k+790>>1]=0;x[k+684>>2]=x[k+692>>2]}gc:{if(!(y[k+90|0]&4)|(x[a+480208>>2]&2101248)==2101248){break gc}hc:{if(x[e>>2]<=0){if(!$b(a+1074312|0,21)){break hc}}h=5;if(!(x[a+480180>>2]&5)){h=$b(a+1074312|0,21)?5:6}f=xy(a,y[k+845|0],y[k+840|0]);ic:{if((y[k+845|0]&3)!=1){break ic}if(!$b(a+1074312|0,89)){break ic}f=y[k+839|0];j=y[k+840|0];g=j<<2&124;f=(!(y[k+90|0]&2)|y[a+480209|0]&16?f:y[k+843|0]+f|0)&32?g^127:g;f=j&32?0-f|0:f}if(x[a+480180>>2]!=131072){f=x[e>>2]+((D(y[k+847|0],f)|0)/(1<<h)|0)|0}else{g=64-f|0;f=x[e>>2];f=((D(y[k+847|0],D(g,f))|0)/-8192|0)+f|0}x[e>>2]=f}if(!(x[a+480180>>2]&16777248)|y[a+480208|0]&4?y[a+480209|0]&16:0){break gc}f=$b(a+1074312|0,21);g=y[k+846|0];h=y[k+840|0];v[k+840|0]=(f?g<<2:h)+(f?h:g)}f=q&65535;j=hb-16|0;hb=j;g=j+8|0;h=a+1074312|0;Kb(g,h,71);jc:{if(Ib(g)){g=(D(f,896)+a|0)+1075843|0;h=v[g|0];if((h|0)>=0){break jc}if(!(y[a+480209|0]&16|y[(D(f,896)+a|0)+1075811|0]!=18)){kc:{lc:{if((h&-33)!=-64){h=h&223;if((h|0)!=128){break lc}h=y[(D(f,896)+a|0)+1075844|0]>>>4|-64;break kc}h=y[(D(f,896)+a|0)+1075844|0]&15|-128;break kc}h=h-1|0}v[g|0]=h;g=(D(f,896)+a|0)+1075072|0;x[g>>2]=x[g>>2]|2097152}if((h&224)!=128){break jc}x[e>>2]=0;break jc}if(y[(D(f,896)+a|0)+1075811|0]!=18){break jc}g=j+8|0;Kb(g,h,22);mc:{if(Ib(g)){m=D(f,896)+a|0;g=m+1075843|0;i=y[g|0];h=i<<24>>24;if(!((h|0)>=0|!x[m+1075060>>2])){nc:{oc:{if((i|0)!=192){if((i|0)!=128){break oc}h=y[(D(f,896)+a|0)+1075844|0]>>>4|-64;break nc}h=y[(D(f,896)+a|0)+1075844|0]&15|-128;break nc}h=h-1|0}v[g|0]=h}if((h&192)!=128){break mc}x[e>>2]=0;break mc}g=y[(D(f,896)+a|0)+1075844|0];h=g>>>4|0;m=h+(g&15)|0;if(!(y[a+480208|0]&4?0:x[a+480180>>2]&16777248)){m=m+2|0;h=h+1|0}i=(D(f,896)+a|0)+1075843|0;g=y[i|0];if(!(x[a+480180>>2]&4)){g=(g&255)>>>0<m>>>0?g:0;if((g&255)>>>0>=h>>>0){x[e>>2]=0}v[i|0]=g+1;break mc}pc:{if(y[a+480209|0]&16){g=g&255;i=g-1|0;g=g>>>0>=i>>>0?i:0;break pc}v[i|0]=g+1}if(((g&255)>>>0)%(m>>>0)>>>0<h>>>0){break mc}x[e>>2]=0}g=(D(f,896)+a|0)+1075072|0;x[g>>2]=x[g>>2]|2097152}g=D(f,896)+a|0;qc:{if(y[g+1075811|0]!=18){break qc}i=g+1075640|0;g=x[i>>2];if(!g|!y[g+34|0]|y[g+15|0]&2){break qc}g=D(f,896)+a|0;if(x[g+1075072>>2]&134218752){break qc}h=g+1075805|0;if(!be(y[h|0])){break qc}i=x[i>>2];g=x[(D(y[i+34|0],160)+a|0)+906140>>2];if(!g){break qc}m=mb[x[x[g>>2]+96>>2]](g,y[h|0],f)|0;o=x[e>>2];if(!(!m|o)){mb[x[x[g>>2]+88>>2]](g,i,y[h|0]+255|0,0,f);break qc}if(m|!o){break qc}mb[x[x[g>>2]+88>>2]](g,i,y[h|0],z[(D(f,896)+a|0)+1075672>>1],f)}hb=j+16|0;ce(e,0,256);e=x[t+8>>2]<<6;x[t+8>>2]=e;rc:{sc:{if(M){e=t+24|0;Kb(e,s,31);if(Ib(e)){et(a,k)}g=t+8|0;tc:{if(!wy(a,k,0)){break tc}h=x[k+656>>2];j=a+1074312|0;m=$b(j,31);e=x[k+728>>2];if(e?0:m){break tc}i=h+48|0;O=e-$b(j,31)|0;e=gq(i,O,256,64);o=y[h+65|0];uc:{if((o|0)==255){break uc}m=x[k+732>>2];if((m|0)==-1){break uc}J=y[Pb(i,o)+2|0];o=J<<2;e=(O|0)==z[Pb(i,y[h+65|0])>>1]?o:e;if($b(j,94)){e=m+(e-o<<1)|0;break uc}if(!J){e=0;break uc}e=(D(e,m)|0)/(o|0)|0}Ia=g,Ja=(D(x[g>>2],Yb(e,0,512))|0)/256|0,x[Ia>>2]=Ja}jM(k,g);vc:{if(!wy(a,k,1)){break vc}e=x[k+656>>2];g=a+1074312|0;j=$b(g,31);h=x[k+740>>2];if(h?0:j){break vc}g=gq(e+68|0,h-$b(g,31)|0,64,64)-32|0;e=x[k+684>>2];Ia=k,Ja=Yb(((D(g,(e|0)>127?256-e|0:e)|0)/32|0)+e|0,0,256),x[Ia+684>>2]=Ja}e=x[k+656>>2];g=y[e+26|0];wc:{if(!g){break wc}h=y[k+819|0];if(!h){break wc}Ia=k,Ja=Yb(x[k+684>>2]+((D(g<<24>>24,h+(y[e+27|0]^-1)|0)<<16>>16)/2<<16>>16)|0,0,256),x[Ia+684>>2]=Ja}e=x[t+8>>2];break sc}if(!(y[H+1|0]&16)){break sc}x[l+1075680>>2]=0;x[t+8>>2]=0;break rc}if(!e){break rc}if(y[H+3|0]&8){x[C>>2]=0;break rc}e=x[t+8>>2];if(y[L+36|0]){g=D(x[t+4>>2],x[l+1075744>>2]);e=e<<8;Ia=C,Ja=Ec(tqa(sqa(g,g>>31,e,e>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;break rc}g=D(x[t+4>>2],x[l+1075744>>2]);e=D(e,x[a+1074444>>2]);Ia=C,Ja=Ec(tqa(sqa(g,g>>31,e,e>>31),lb,1048576,0),lb),x[Ia>>2]=Ja}x[R>>2]=x[t+8>>2];xc:{if(x[a+480180>>2]==2|x[I>>2]>=x[a+480260>>2]){break xc}if(Op(a)){break xc}x[I>>2]=x[a+480260>>2]}e=t+24|0;Kb(e,s,73);if(Ib(e)){Yb(x[I>>2],1,31999)}e=x[I>>2];x[t+12>>2]=e;yc:{if((x[H>>2]&1572864)!=1572864){break yc}if(y[U|0]&32){if(!tt(l+1075794|0)|y[V|0]&16){break yc}e=x[t+12>>2]}g=l+1075696|0;zc:{if(x[g>>2]==(e|0)){e=x[l+1075700>>2];break zc}x[g>>2]=e;j=e;e=l+1075752|0;g=l+1075688|0;e=jg(a,kt(a,j,x[e>>2],x[g>>2]),x[e>>2],x[g>>2]);x[l+1075700>>2]=e}x[t+12>>2]=e}o=hb-16|0;hb=o;e=f;m=D(e,896)+a|0;g=x[m+1075640>>2];Ac:{if(!g){break Ac}f=y[g+34|0];if(!f|y[g+15|0]&2|(!x[(D(f,160)+a|0)+906140>>2]|x[(D(e,896)+a|0)+1075072>>2]&134218752)){break Ac}h=D(e,896)+a|0;J=h+1075797|0;O=y[J|0];f=0;j=h+1075805|0;if(be(y[j|0])){f=y[fc(g+108|0,y[j|0]-1|0)|0]}i=h+1075794|0;Bc:{Cc:{if((O|0)==1){g=0;Dc:{Ec:{switch((A[a+1074392>>2]%3|0)-1|0){case 0:g=y[(D(e,896)+a|0)+1075812|0]>>>4|0;break Dc;case 1:break Ec;default:break Dc}}g=y[(D(e,896)+a|0)+1075812|0]&15}h=D(e,896)+a|0;v[h+1075807|0]=f;if(y[h+1075806|0]==(f+g|0)){break Bc}if(!(y[a+480209|0]&16)){break Cc}if(!Ff(i)){break Cc}break Bc}g=0;if(y[i|0]|!y[(D(e,896)+a|0)+1075806|0]){break Bc}}h=D(e,896)+a|0;Vl(a,e,y[h+1075807|0]+g|0,z[h+1075672>>1])}j=(D(e,896)+a|0)+1075806|0;h=y[j|0];Fc:{if(!h){if(!(y[a+480209|0]&16)|(O|0)!=1){break Fc}if(Ff(i)){break Fc}h=f;if(!be(f)){break Fc}}Vl(a,e,(h&255)+255|0,0)}v[j|0]=y[J|0]==1?y[(D(e,896)+a|0)+1075807|0]+g|0:0}Gc:{if(y[m+1075811|0]!=1){break Gc}if(Lj(m+1074984|0)){f=0;Hc:{Ic:{Jc:{switch(A[a+1074392>>2]%3|0){case 1:f=y[(D(e,896)+a|0)+1075812|0]>>>4|0;break Ic;case 0:break Ic;case 2:break Jc;default:break Hc}}f=y[(D(e,896)+a|0)+1075812|0]&15}w[t+18>>1]=f}e=(D(e,896)+a|0)+1075856|0;v[e|0]=y[e|0]|24;break Gc}if(!(!(y[a+480209|0]&16)|x[a+480180>>2]!=1048576)){f=D(e,896)+a|0;g=jg(a,y[f+1075803|0],x[f+1075752>>2],x[f+1075688>>2]);x[t+12>>2]=g;x[f+1075684>>2]=g}g=o+8|0;f=a+1074312|0;Kb(g,f,13);if(Ib(g)){f=y[(D(e,896)+a|0)+1075812|0];if(!f){break Gc}e=65536;Kc:{switch(((A[a+1074392>>2]%(x[a+1074400>>2]+x[a+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:f=f<<4;case 0:e=x[((f&240)<<2)+30400>>2];break;default:break Kc}}h=Op(a);f=x[t+12>>2];g=f>>31;if(h){e=sqa(f,g,e,e>>31);m=lb;e=e+32768|0;m=e>>>0<32768?m+1|0:m;e=tqa(e,m,65536,0);f=lb}else{h=(e|0)/2|0;j=h>>31;i=g<<16|f>>>16;g=f<<16;f=g+h|0;i=i+j|0;e=tqa(f,f>>>0<g>>>0?i+1|0:i,e,e>>31);f=lb}Ia=t,Ja=Ec(e,f),x[Ia+12>>2]=Ja;break Gc}g=o+8|0;Kb(g,f,51);if(Ib(g)){if(y[a+480209|0]&16){break Gc}Lc:{Mc:{f=x[a+1074416>>2];f=f-(A[a+1074392>>2]%(f>>>0)|0)|0;if((f|0)>16){break Mc}if((f|0)==16){break Gc}g=0;Nc:{switch((f|0)%3|0){case 0:break Gc;case 2:break Mc;case 1:break Nc;default:break Lc}}g=y[(D(e,896)+a|0)+1075812|0]>>>4|0;break Lc}g=y[(D(e,896)+a|0)+1075812|0]&15}e=D(e,896)+a|0;f=e+1075752|0;e=e+1075688|0;g=kt(a,x[t+12>>2],x[f>>2],x[e>>2])+g|0;f=jg(a,g,x[f>>2],x[e>>2]);x[t+12>>2]=f;if(g>>>0<109){break Gc}x[o+8>>2]=f;Ia=o,Ja=jg(a,109,0,x[e>>2]),x[Ia+4>>2]=Ja;Ia=t,Ja=x[$c(o+8|0,o+4|0)>>2],x[Ia+12>>2]=Ja;break Gc}h=x[a+1074392>>2];if(x[a+480180>>2]!=1){g=y[(D(e,896)+a|0)+1075803|0]}else{g=D(e,896)+a|0;g=kt(a,x[t+12>>2],x[g+1075752>>2],x[g+1075688>>2])}Oc:{Pc:{switch((((x[a+480180>>2]&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:g=(y[(D(e,896)+a|0)+1075812|0]>>>4|0)+g|0;break Oc;case 1:break Pc;default:break Oc}}g=(y[(D(e,896)+a|0)+1075812|0]&15)+g|0}if(!(x[a+480180>>2]&67633408|y[(D(e,896)+a|0)+1075803|0]!=(g&255))){h=o+8|0;Kb(h,f,82);if(!Ib(h)){break Gc}}if(y[a+480210|0]&32){h=g&255;if((h|0)==85){x[t+12>>2]=2147483647;break Gc}g=h>>>0>85?g-37|0:g}h=D(e,896)+a|0;Ia=t,Ja=jg(a,g&255,x[h+1075752>>2],x[h+1075688>>2]),x[Ia+12>>2]=Ja;if(x[a+480180>>2]&71827712){x[h+1075684>>2]=x[t+12>>2];break Gc}h=o+8|0;Kb(h,f,82);if(!Ib(h)){break Gc}v[(D(e,896)+a|0)+1075806|0]=g}hb=o+16|0;if(!(!(y[U|0]&33)|x[t+12>>2]==2147483647)){Qc:{if(x[a+480180>>2]==2){e=452;f=3424;break Qc}f=D(x[l+1075752>>2]>>>4&15,24)+26112|0;e=z[f+22>>1]>>>1|0;e=e>>>0<=452?452:e;f=z[f>>1]<<1}ce(t+12|0,e,f);ce(I,e,f)}iM(a,k);e=x[H>>2]}Rc:{if(!(e&256)|y[V|0]&64){break Rc}e=t+24|0;Kb(e,s,37);if(!Ib(e)){break Rc}x[l+1075668>>2]=128}h=q&65535;kM(a,h);Sc:{if(!r){break Sc}e=gM(a,k,t+12|0);if((e|0)<0|!(y[H+1|0]&2)){break Sc}if(!yd(G)){break Sc}bq(x[G>>2],h,e>>>2&255,1)}Tc:{if(y[l+1075796|0]!=8){break Tc}Uc:{Vc:{e=y[l+1075797|0];switch(e-5|0){case 1:break Tc;case 0:case 2:break Uc;default:break Vc}}if((e|0)!=26){break Tc}}if(x[a+480180>>2]==4){if(y[V|0]&16){break Tc}e=l+1075823|0;v[e|0]=y[e|0]+y[l+1075827|0];break Tc}if(!(x[a+480180>>2]&16777248)){break Tc}Kk(k,y[l+1075798|0]);fM(a,h,t+12|0,t+20|0)}fM(a,h,t+12|0,t+20|0);if(r){x[t+8>>2]=0;f=t+12|0;m=hb-16|0;hb=m;i=x[k+104>>2];Wc:{if(!i|!y[i+40|0]){break Wc}O=Lj(k);o=Op(a);e=o?31424:30400;j=o?30400:31424;if(!(O|!$b(a+1074312|0,21)|x[a+480180>>2]==1048576)){if(!y[i+41|0]){break Wc}g=y[k+838|0];x[m+12>>2]=x[k+780>>2]+y[i+39|0];Fh(m+12|0,y[i+40|0]<<8);r=x[m+12>>2];x[k+780>>2]=r;r=(r|0)/256|0;x[m+12>>2]=r;v[k+838|0]=y[k+838|0]+y[i+41|0];Xc:{Yc:{switch(y[i+38|0]-1|0){case 3:g=cM(En(a))+-64|0;r=x[m+12>>2];break Xc;case 2:g=64-(g+1>>>1|0)|0;break Xc;case 1:g=(g+1>>>1|0)+-64|0;break Xc;case 0:g=(g^-1)>>>1&64;break Xc;default:break Yc}}g=v[g+26704|0]}Fh(f,8388607);i=x[f>>2]<<8;x[f>>2]=i;J=D(g,r);r=(J|0)/64|0;g=r>>31;g=(g^r)-g|0;r=g&3;O=g>>>2|0;g=i;i=g>>31;Zc:{if((J|0)<=-64){e=x[(O<<2)+e>>2];g=Ec(tqa(sqa(e,e>>31,g,i),lb,65536,0),lb);e=x[f>>2];g=g-e|0;if(!r){break Zc}j=x[(r<<2)+(o?30336:30272)>>2];g=Ec(tqa(sqa(j,j>>31,e,e>>31),lb,65536,0),lb)+g|0;e=x[f>>2];g=g-e|0;break Zc}e=x[j+(O<<2)>>2];g=Ec(tqa(sqa(e,e>>31,g,i),lb,65536,0),lb);e=x[f>>2];g=g-e|0;if(!r){break Zc}j=x[(r<<2)+(o?30272:30336)>>2];g=Ec(tqa(sqa(j,j>>31,e,e>>31),lb,65536,0),lb)+g|0;e=x[f>>2];g=g-e|0}x[f>>2]=(e+g|0)/256;x[t+8>>2]=g&255;break Wc}_c:{if(!(y[i+39|0]|x[a+480180>>2]&16777248)){x[k+780>>2]=y[i+40|0]<<8;break _c}$c:{ad:{if(x[a+480180>>2]&16777248){r=y[i+39|0]<<1;o=k+780|0;g=x[k+780>>2];break ad}if(y[k+89|0]&8){break $c}r=x[k+780>>2];o=k+780|0;g=((y[i+40|0]<<8&65280)>>>0)/y[i+39|0]|0}x[o>>2]=g+r}Fh(k+780|0,y[i+40|0]<<8)}g=y[k+838|0]+y[i+41|0]|0;v[k+838|0]=g;g=g<<24>>24;bd:{cd:{switch(y[i+38|0]-1|0){case 3:v[k+838|0]=g+1;r=v[(g&63)+26640|0];break bd;case 2:r=(64-(g>>>1|0)&127)+-64|0;break bd;case 1:r=((g>>>1|0)- -64&127)+-64|0;break bd;case 0:r=(g|0)>=0?-64:64;break bd;default:break cd}}g=y[k+838|0];r=0-v[g+26704|0]|0;if(x[a+480180>>2]!=1048576){break bd}r=(64-v[(g+-64&255)+26704|0]|0)/2<<16>>16}g=r;o=D(g,x[k+780>>2]);r=(o|0)/256|0;if(O){B[t+20>>2]=E(E(E(g|0)*E(1220703143189894e-20))*E(y[i+40|0]))+B[t+20>>2];v[k+872|0]=y[k+872|0]|16;break Wc}if(x[a+480180>>2]!=4){dd:{if((o|0)<=-256){r=0-r|0;g=r>>>8|0;j=(g<<2)+e|0;break dd}e=j;g=r>>>8|0;j=e+(g<<2)|0}i=x[f>>2];g=x[((g<<2)+e|0)+4>>2];e=x[j>>2];e=((D(g-e|0,r>>>2&63)|0)/64|0)+e|0;e=Ec(tqa(sqa(i,i>>31,e,e>>31),lb,256,0),lb);x[f>>2]=e;x[t+8>>2]=e&255;x[f>>2]=x[f>>2]/256;break Wc}x[f>>2]=x[f>>2]+((o|0)/16384|0)}hb=m+16|0;if(x[t+12>>2]<=x[a+480260>>2]){e=t+24|0;Kb(e,s,81);if(Ib(e)){x[l+1075060>>2]=0}x[t+12>>2]=x[a+480260>>2]}f=Lj(k);ed:{if(!f){break ed}e=l+1075856|0;g=y[e|0];if(!(x[a+1074392>>2]|!(g&8)?g&16:1)){break ed}hP(k,B[t+20>>2],w[t+18>>1],a);g=e;e=y[e|0];v[g|0]=(e&16?-17:-9)&e}fd:{if((x[H>>2]&134219264)!=512){break fd}if(!yd(G)){break fd}e=t+24|0;Kb(e,s,99);if(!(!(Ib(e)|!(y[H+1|0]&16))&x[a+480180>>2]!=2)){if(!(y[H+1|0]&8?x[a+480180>>2]==2:0)){if(f){e=x[I>>2]}else{e=eN(a,x[t+12>>2],x[l+1075688>>2],x[t+8>>2])}e=sqa(e,0,261625,0);j=lb;e=e+66904|0;j=e>>>0<66904?j+1|0:j;e=id(vqa(e,j,133808,0),lb);e=sqa(x[a+480240>>2],0,e,0);i=lb;e=e+32768|0;i=e>>>0<32768?i+1|0:i;e=id((i&65535)<<16|e>>>16,i>>>16|0);g=x[H>>2];f=1;gd:{if(g&2048){break gd}f=0;if(!(g&4096)){break gd}f=!x[l+1075680>>2]}g=x[G>>2];j=t+24|0;Kb(j,s,95);I=Ib(j);m=hb-16|0;hb=m;o=Pk(g,h);hd:{if((o|0)==255){break hd}if(Ij(g)){break hd}id:{if(e>>>0>6208431){j=7;e=1023;break id}j=7;jd:{if(e>>>0>3104215){break jd}j=6;if(e>>>0>1552107){break jd}j=5;if(e>>>0>776053){break jd}j=4;if(e>>>0>388026){break jd}j=3;if(e>>>0>194013){break jd}j=2;if(e>>>0>97006){break jd}j=e>>>0>48503}i=20-j|0;r=i&31;if((i&63)>>>0>=32){i=e<<r;e=0}else{i=(1<<r)-1&e>>>32-r;e=e<<r}e=e+24858e3|0;if(e>>>0<24858e3){i=i+1|0}e=id(vqa(e,i,49716e3,0),lb)}if(I){w[m+14>>1]=(h&3)+e;w[m+12>>1]=1023;e=z[Gf(m+14|0,m+12|0)>>1]}i=Ft(o);r=g+4|0;Ia=fc(r,o),Ja=(j<<10|e)>>>8|(f?0:32),v[Ia|0]=Ja;th(x[g>>2],i|160,e&255);th(x[g>>2],i|176,y[fc(r,o)|0]);v[g+530|0]=1}hb=m+16|0}e=x[G>>2];f=sqa(D(x[l+1075748>>2],D(x[l+1075744>>2],x[R>>2])),0,63,0);j=lb;f=f+33554432|0;j=f>>>0<33554432?j+1|0:j;bq(e,h,id((j&67108863)<<6|f>>>26,j>>>26|0)&255,0);e=l+1075668|0;i=e;f=x[e>>2];g=0;e=x[G>>2];j=Pk(e,h);kd:{if((j|0)==255){break kd}if(Ij(e)){break kd}g=y[fc(Ui(e+314|0,j),10)|0];m=x[e>>2];e=g&-49;e=(f|0)<171?e|16:e;e=(f|0)>84?e|32:e;th(m,Ft(j)|192,e&255);g=(e>>>5&1)+(e<<27>>31)|0}x[i>>2]=(g<<7)+128}ld:{e=x[P>>2];if(!e|(y[e+60|0]&7)!=1){break ld}e=e+48|0;if(kd(e)){break ld}if(A[eM(k,0)+4>>2]<z[Fj(e)>>1]){break ld}if(y[Fj(e)+2|0]){break ld}Pi(x[G>>2],h,1);e=t+24|0;Kb(e,s,109);e=Ib(e);f=x[H>>2];x[H>>2]=(e?f:f&-4609)|4096;x[l+1075680>>2]=0;break fd}e=t+24|0;Kb(e,s,99);if(!Ib(e)|!(y[H+1|0]&16)|x[l+1075680>>2]){break fd}Pi(x[G>>2],h,1);x[H>>2]=x[H>>2]&-513}e=sqa(yy(a,k,x[t+12>>2],x[t+8>>2]),lb,x[a+480240>>2],0);i=lb;f=tqa(e,i,65536,0);g=lb;e=e+65535|0;e=!(e>>>0<65535?i+1|0:i)&e>>>0<131071;x[n>>2]=e?1:f;x[n+4>>2]=e?0:g}md:{if(!M){break md}e=t+24|0;Kb(e,s,31);if(Ib(e)){break md}et(a,k)}f=x[H>>2];e=f&-65537;i=l+1075004|0;o=l+1075008|0;x[H>>2]=x[i>>2]|(x[o>>2]|x[C>>2])?(e|f<<7&65536)^65536:e;f=l+1075656|0;e=f;x[e>>2]=0;x[e+4>>2]=0;h=l+1075846|0;g=y[h|0];e=g-4|0;v[h|0]=e>>>0<=g>>>0?e:0;j=l+1075847|0;g=y[j|0];e=g-4|0;v[j|0]=e>>>0<=g>>>0?e:0;nd:{od:{pd:{qd:{rd:{sd:{e=l+1075088|0;g=x[e>>2];td:{if(!g){break td}if(!He(g)|!x[l+1075060>>2]){break td}if(Zh(k)){break sd}}m=l+1075e3|0;x[m>>2]=0;break rd}m=l+1075e3|0;e=x[x[e>>2]+20>>2];x[m>>2]=e;if(e){break qd}}if(!Ej(k)|y[H+1|0]&24){break pd}}I=x[C>>2];r=x[l+1075668>>2];e=(D(I,256-r|0)|0)/16384|0;g=e>>>0>=127?127:e;e=v[h|0];if((e|0)<0){v[h|0]=g;Z=g}else{Z=e}e=g>>>1|0;if((Z&255)>>>0<e>>>0){v[h|0]=e}e=(D(r,I)|0)/16384|0;e=e>>>0>=127?127:e;r=e>>>1|0;h=r;g=v[j|0];if((g|0)<0){v[j|0]=e}else{e=g}if((e&255)>>>0<h>>>0){break od}break nd}if(y[h|0]>=129){v[h|0]=0}r=0;if(y[j|0]<129){break nd}}v[j|0]=r}ud:{vd:{if(x[m>>2]){e=l+1075660|0;wd:{if(A[a+24624>>2]>=2){x[t+24>>2]=x[l+1075668>>2];ce(t+24|0,0,256);g=D(x[C>>2],u)>>>(y[L+37|0]?7:8)|0;xd:{yd:{zd:{switch(x[L+32>>2]){case 0:if(!(y[a+24616|0]&16)){break yd}case 1:h=x[t+24>>2];if((h|0)<=127){x[f>>2]=g>>>1;g=(D(g,h)|0)/256|0;break xd}x[f>>2]=(D(g,256-h|0)|0)/256;g=g>>>1|0;break xd;case 3:break zd;default:break yd}}Fh(t+24|0,255);h=x[t+24>>2];if((h|0)<=0){j=65536}else{j=z[(0-h<<1)+32960>>1]}x[f>>2]=D(j,g)>>>16;g=D(g,z[(h<<1)+32448>>1])>>>16|0;break xd}h=x[t+24>>2];x[f>>2]=(D(g,256-h|0)|0)/256;g=(D(g,h)|0)/256|0}x[e>>2]=g;break wd}g=D(x[C>>2],u)>>>8|0;x[f>>2]=g;x[e>>2]=g}h=l+1075800|0;Ad:{Bd:{g=x[P>>2];if(!g){break Bd}if(!xo(y[g+14|0])){break Bd}g=y[x[P>>2]+14|0];break Ad}if(xo(y[a+480268|0])){g=y[a+480268|0];break Ad}g=y[a+24648|0];g=y[U|0]&128?x[a+24668>>2]?-1:g:g}v[h|0]=g;if(!(y[H+2|0]&2|(x[n>>2]!=0|x[n+4>>2]!=1)|(x[l+1075764>>2]|(g&255)==255))){v[h|0]=0}g=f;j=x[f>>2];f=1<<x[L+28>>2];x[g>>2]=(j|0)/(f|0);f=x[e>>2]/(f|0)|0;x[e>>2]=f;g=x[H>>2];if(!(!(g&256)|x[a+24624>>2]!=2)){x[e>>2]=0-f}if(g&128){e=x[n>>2];f=0-e|0;e=0-(x[n+4>>2]+((e|0)!=0)|0)|0;x[n>>2]=f;x[n+4>>2]=e}r=0;j=hb-16|0;hb=j;x[k+28>>2]=0;x[k+32>>2]=0;Fh(k+672|0,524287);Fh(k+676|0,524287);Cd:{Dd:{g=x[k+88>>2];if(!(g&65536)){h=x[k+676>>2];e=x[k+672>>2];break Dd}e=x[k+20>>2];n=x[k+672>>2];Ed:{if((e|0)!=(n|0)){h=x[k+24>>2];f=x[k+676>>2];break Ed}f=x[k+676>>2];h=x[k+24>>2];if((f|0)==(h|0)){break Dd}}g=a+24604|0;h=(f|0)<=(h|0)&(e|0)>=(n|0);Fd:{if(!h){e=mP(g);break Fd}e=lP(g)}if(!(!$b(a+1074312|0,4)|!(x[a+480180>>2]&4))){e=x[a+24620>>2];e=sqa(e,e>>31,5,0);i=lb;e=e+500|0;i=e>>>0<500?i+1|0:i;e=Ec(tqa(e,i,1e3,0),lb)}f=e;g=x[k+656>>2];Gd:{if(h|!g){break Gd}g=z[g+12>>1];r=(g|0)!=0;if(!g){break Gd}f=(D(g,x[a+24620>>2])>>>0)/1e5|0}m=f>>>0<=1?1:f;g=x[k+676>>2];h=x[k+24>>2];n=g-h<<12;f=x[k+672>>2];i=x[k+20>>2];o=f-i<<12;if(!(y[k+90|0]&32|(!(f|g)|(!(h|i)|r)))){x[j+12>>2]=x[a+1074380>>2];ce(j+12|0,e,2048);g=x[k+676>>2];m=x[j+12>>2];f=x[k+672>>2]}n=(n|0)/(m|0)|0;x[k+32>>2]=n;i=(o|0)/(m|0)|0;x[k+28>>2]=i;h=((D(n,m)|0)/-4096|0)+g|0;x[k+24>>2]=h;e=((D(i,m)|0)/-4096|0)+f|0;x[k+20>>2]=e;if(i|n){x[k+100>>2]=m;f=x[k+88>>2];break Cd}x[k+24>>2]=g;x[k+20>>2]=f;h=g;e=f;f=x[k+88>>2]&-65537;break Cd}x[k+24>>2]=h;x[k+20>>2]=e;f=g&-65537}x[k+88>>2]=f&-2097153;x[k+40>>2]=h<<12;x[k+36>>2]=e<<12;hb=j+16|0;if(!(y[H+1|0]&2)){break vd}break ud}x[i>>2]=0;x[o>>2]=0;x[l+1075060>>2]=0;if(x[l+1075080>>2]){break vd}if(!x[l+1075076>>2]){break ud}}e=z[a+480212>>1];w[a+480212>>1]=e+1;w[((e<<1)+a|0)+1074466>>1]=q}x[l+1075652>>2]=x[H>>2]}q=q+1|0;if((q|0)!=256){continue}break}if(A[a+24608>>2]>z[a+480212>>1]){break Yb}g=a+1074466|0;e=g+(x[a+24608>>2]<<1)|0;j=(z[a+480212>>1]<<1)+g|0;r=hb-16|0;hb=r;x[r+12>>2]=a;if((e|0)!=(g|0)){n=r+12|0;h=hb-16|0;hb=h;x[h+12>>2]=g;if((e|0)!=(g|0)){f=e-g|0;if((f|0)>=3){i=f>>1;f=i-2>>>1|0;while(1){k=f;_L(g,n,i,(f<<1)+g|0);f=f-1|0;if(k){continue}break}}x[h+8>>2]=e;if((e|0)!=(j|0)){f=e-g>>1;g=e;while(1){if(Hk(n,z[g>>1],z[x[h+12>>2]>>1])){g=x[h+8>>2];k=z[g>>1];m=g;g=x[h+12>>2];w[m>>1]=z[g>>1];w[g>>1]=k;g=x[h+12>>2];_L(g,n,f,g);g=x[h+8>>2]}g=g+2|0;x[h+8>>2]=g;if((g|0)!=(j|0)){continue}break}g=x[h+12>>2]}f=e-g|0;if((f|0)>=3){m=f>>>1|0;while(1){f=0;k=hb-16|0;hb=k;x[k+12>>2]=g;u=z[x[k+12>>2]>>1];i=x[k+12>>2];l=hb-16|0;hb=l;H=m-2>>>1|0;while(1){f=f<<1;j=f+2|0;q=j+i|0;x[l+12>>2]=q;f=f|1;Hd:{if((j|0)>=(m|0)){break Hd}if(!Hk(n,z[q>>1],z[q+2>>1])){break Hd}x[l+12>>2]=q+2;f=j}w[i>>1]=z[x[l+12>>2]>>1];i=x[l+12>>2];if((f|0)<=(H|0)){continue}break}hb=l+16|0;f=e-2|0;x[k+8>>2]=f;Id:{if((f|0)==(i|0)){w[i>>1]=u;break Id}w[i>>1]=z[x[k+8>>2]>>1];w[x[k+8>>2]>>1]=u;f=x[k+12>>2];l=f;j=hb-16|0;hb=j;i=i+2|0;f=i-f>>1;Jd:{if((f|0)<2){break Jd}f=f-2|0;q=l+(f&-2)|0;x[j+8>>2]=q;q=z[q>>1];i=i-2|0;x[j+12>>2]=i;if(!Hk(n,q,z[i>>1])){break Jd}f=f>>>1|0;i=z[x[j+12>>2]>>1];while(1){Kd:{w[x[j+12>>2]>>1]=z[x[j+8>>2]>>1];q=x[j+8>>2];x[j+12>>2]=q;if(!f){break Kd}u=f-1|0;f=u>>>1|0;u=l+(u&-2)|0;x[j+8>>2]=u;if(Hk(n,z[u>>1],i)){continue}}break}w[q>>1]=i}hb=j+16|0}hb=k+16|0;e=e-2|0;f=m>>>0>2;m=m-1|0;if(f){continue}break}}}hb=h+16|0}hb=r+16|0}hb=t+32|0;if(X){e=x[a+480208>>2];break h}f=x[a+480208>>2]|512;if(y[a+1304512|0]){break i}h=0;e=x[a+24620>>2];g=Ec(tqa(sqa(e,e>>31,100,0),lb,1e3,0),lb);Ld:{if(!g){break Ld}f=g>>>0>=1048576?1048576:g;x[a+1074380>>2]=f;k=z[a+480212>>1];if(!k){break Ld}j=a+1074376|0;while(1){e=j+D(z[(j+(h<<1)|0)+90>>1],896)|0;n=e+1280|0;x[n>>2]=0;x[n+4>>2]=0;x[e+708>>2]=f;n=x[e+632>>2]<<12;x[e+648>>2]=n;i=x[e+628>>2]<<12;x[e+644>>2]=i;x[e+696>>2]=x[e+696>>2]|65536;x[e+636>>2]=(0-i|0)/(f|0);x[e+640>>2]=(0-n|0)/(f|0);h=h+1|0;if((k|0)!=(h|0)){continue}break}}e=x[a+480208>>2];f=e|256;if(g){break i}f=e|512}e=f;x[ia+480208>>2]=e}if(e&512){Ia=a+1074392|0,Ja=Tl(a),x[Ia>>2]=Ja;break g}x[Y+16>>2]=512;e=x[a+1074380>>2];x[Y+12>>2]=3;x[Y+24>>2]=b;x[Y+20>>2]=e;x[Y+8>>2]=Y+16;e=x[Y+12>>2];x[Y>>2]=x[Y+8>>2];x[Y+4>>2]=e;n=ZT(Y);if(x[a+24632>>2]){f=0;e=hb-16|0;hb=e;g=n<<2;while(1){x[e>>2]=0;h=((f<<11)+a|0)+16396|0;LK(h,g+h|0,e);f=f+1|0;if((f|0)!=4){continue}break}f=0;while(1){x[e+(f<<2)>>2]=((f<<11)+a|0)+16396;f=f+1|0;if((f|0)!=4){continue}break}mb[x[x[d>>2]+8>>2]](d,e,x[a+24632>>2],n);hb=e+16|0}r=0;ea=0;g=hb-112|0;hb=g;if(n){s=a+12|0;o=a+24592|0;G=a+24588|0;Sn(s,n,o,G);if(A[a+24624>>2]>=3){Sn(a+8204|0,n,a+24600|0,a+24596|0)}w[g+30>>1]=0;e=g+12|0;ja=a+1074312|0;Kb(e,ja,33);e=Ib(e);h=z[a+480212>>1];if(h){wa=e?2:1;xa=a+24648|0;ia=a+24596|0;ya=a+24600|0;za=a+8204|0;C=a+397460|0;I=a+397456|0;P=a+393352|0;oa=a+1074376|0;while(1){i=oa+(r<<1)|0;e=D(z[i+90>>1],896);k=e+oa|0;U=k;Md:{Nd:{if(x[k+624>>2]){break Nd}f=a+e|0;if(x[f+1075080>>2]){break Nd}if(!x[f+1075076>>2]){break Md}}j=a+e|0;e=y[j+1075800|0]+1|0;if((e&255)>>>0<=5){e=x[(e<<24>>24<<2)+24328>>2]}else{e=0}u=j+1075072|0;q=x[u>>2];l=e|q&1;t=q>>>5&2;L=q>>>12|0;k=k+608|0;Z=ia;Od:{if(!(!(q&16777216)&y[a+24612|0]>>>5)){f=s;h=o;m=G;if(!(q&8388608)){break Od}}if(!x[P+4116>>2]){Sn(P+8|0,n,P+4104|0,P+4108|0)}x[P+4116>>2]=1;f=P+8|0;q=x[u>>2];h=I;m=C}e=q>>>8&A[a+24624>>2]>2;aa=e?Z:m;ca=e?ya:h;h=e?za:f;ka=Ul(a,z[i+90>>1],2,1);pa=(ka-1&255)>>>0>249;Pd:{if(pa){break Pd}f=x[(D(ka,160)+a|0)+906140>>2];if(!f){break Pd}e=x[f+24>>2];if(!e){break Pd}aa=f+36|0;ca=f+40|0;if(!(v[f+28|0]&1)){Sn(e,n,ca,aa);x[f+28>>2]=x[f+28>>2]|1}h=e}V=0;H=g+12|0;e=H;x[e>>2]=0;x[e+4>>2]=0;x[e+8>>2]=0;x[e+12>>2]=0;if(x[k+16>>2]){OC(H,k);e=x[k+12>>2];f=e>>31;m=f^x[k+8>>2];e=(e^f)-((f>>>0>m>>>0)+f|0)|0;x[H+12>>2]=e>>>0>8191?2:16384/(e+1>>>0)|0}Aa=L&8|(l|t);Ba=ea&65535;qa=j+1075809|0;Ca=j+1075792|0;Da=j+1075680|0;Ea=j+1075016|0;Fa=j+1075012|0;Ga=j+1075660|0;Ha=j+1075656|0;R=j+1075080|0;O=j+1075076|0;ra=j+1075008|0;sa=j+1075004|0;da=j+1075088|0;_=j+1075068|0;L=j+1075060|0;M=j+1074992|0;fa=j+1075064|0;X=j+1075084|0;f=n;while(1){Qd:{e=x[X>>2];ha=e?e>>>0<f>>>0?e:f:f;x[g+68>>2]=ha;ga=x[fa>>2];S=x[u>>2];e=x[M+4>>2];q=e;m=x[M>>2];x[g+56>>2]=m;x[g+60>>2]=e;Rd:{Sd:{if(!ha|!(e|m)){break Sd}J=x[L>>2];if(!J){break Sd}e=x[H>>2];if(!e){break Sd}x[U+624>>2]=e;e=x[k>>2];Td:{Ud:{t=ga&S<<30>>31;i=x[k+4>>2];Vd:{if((t|0)>(i|0)){if((q|0)<0){x[g+104>>2]=0;x[g+108>>2]=t<<1;e=ug(g+104|0,k);j=lb;i=j;x[k>>2]=e;x[k+4>>2]=i;if(!(i>>>0<t+x[L>>2]>>>1>>>0&(i|0)>=(t|0))){e=0;x[k>>2]=e;i=t;x[k+4>>2]=i}j=0-m|0;x[g+56>>2]=j;l=0-(((m|0)!=0)+q|0)|0;x[g+60>>2]=l;x[M>>2]=j;x[M+4>>2]=l;J=x[u>>2];Wd:{if(J&4){m=J&-129;break Wd}i=x[L>>2]-1|0;x[k>>2]=e;x[k+4>>2]=i;x[M>>2]=m;x[M+4>>2]=q;m=J|128}x[u>>2]=m;Xd:{if(!(m&2)){q=x[L>>2];break Xd}q=x[L>>2];if(i>>>0<q>>>0){break Td}}x[k>>2]=0;x[k+4>>2]=q;break Sd}if((i|0)>0|(i|0)>=0){break Vd}j=0;i=j;x[k>>2]=e;x[k+4>>2]=i;break Vd}if(i>>>0>=J>>>0){break Ud}}j=m;l=q;break Td}if(!(S&2)){break Sd}if(S&4){Yd:{if(!m&(q|0)<=0|(q|0)<0){j=m;l=q;break Yd}j=0-m|0;m=0-(((m|0)!=0)+q|0)|0;l=m;x[g+56>>2]=j;x[g+60>>2]=l;x[M>>2]=j;x[M+4>>2]=l}x[u>>2]=S|128;q=0-e|0;m=(J<<1)-((1-((e|0)!=0)|0)+i|0)|0;e=q;x[k>>2]=e;i=m;x[k+4>>2]=i;if(i>>>0<J>>>0&i>>>0>ga>>>0){break Td}x[g+104>>2]=wa;m=J-x[Mb(L,g+104|0)>>2]|0;e=x[k>>2];x[k>>2]=e;i=m;x[k+4>>2]=i;break Td}Zd:{if((q|0)>0|(q|0)>=0){j=m;l=q;break Zd}e=0-(((m|0)!=0)+q|0)|0;l=e;j=0-m|0;x[g+56>>2]=j;x[g+60>>2]=e;x[M>>2]=j;x[M+4>>2]=e}x[g+104>>2]=0;x[g+108>>2]=t-J;Tb(k,g+104|0);x[u>>2]=x[u>>2]|8192;e=x[k>>2];i=x[k+4>>2]}x[g+48>>2]=e;x[g+52>>2]=i;_d:{if((i|0)<(t|0)){if((i|0)<0){break Sd}if((l|0)>0|(l|0)>=0){break _d}break Sd}if((i|0)<0){break Sd}}if(i>>>0>=A[L>>2]){break Sd}x[g+44>>2]=ha;zc(g+68|0,x[g+24>>2]);Ia=g,Ja=Ze(g+56|0,x[g+68>>2]-1|0),x[Ia+32>>2]=Ja;x[g+36>>2]=lb;yf(g+48|0,g+32|0);e=lb;m=x[g+48>>2];q=x[g+52>>2];J=q;i=x[fa>>2];ga=q>>>0<i>>>0|q>>>0>=i+16>>>0;if(ga){x[u>>2]=x[u>>2]&-8193}Z=l;i=l>>31;S=j^i;l=S-i|0;S=(i^Z)-((i>>>0>S>>>0)+i|0)|0;j=e;$d:{ae:{be:{if(!x[g+16>>2]){i=x[g+60>>2];break be}e=x[g+20>>2];if(e>>>0<=q>>>0){ce:{if(x[g+60>>2]<0){x[g+96>>2]=m;x[g+100>>2]=J;x[g+104>>2]=0;x[g+108>>2]=e;Ia=g,Ja=ug(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=ug(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;e=Bm(g+88|0,l,S);break ce}e=x[_>>2];x[g+104>>2]=m;x[g+108>>2]=J;x[g+96>>2]=0;x[g+100>>2]=e;Ia=g,Ja=ug(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=ug(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;e=Bm(g+88|0,l,S)}x[g+44>>2]=e+1;x[U+624>>2]=x[g+16>>2];break $d}if(!(ga|!(y[u+1|0]&32))){x[g+104>>2]=m;x[g+108>>2]=J;x[g+96>>2]=0;x[g+100>>2]=t+16;Ia=g,Ja=ug(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=ug(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=Bm(g+88|0,l,S)+1|0,x[Ia+44>>2]=Ja;Ia=U,Ja=x[g+16>>2]+D(x[_>>2]-t|0,Ko(x[da>>2]))|0,x[Ia+624>>2]=Ja;break $d}i=x[g+60>>2];if(!x[g+56>>2]&(i|0)<=0|(i|0)<0){break be}if(ha>>>0<2|e>>>0>j>>>0){break ae}x[g+104>>2]=m;x[g+108>>2]=J;x[g+96>>2]=0;x[g+100>>2]=e;Ia=g,Ja=ug(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=ug(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=Bm(g+88|0,l,S)+1|0,x[Ia+44>>2]=Ja;break $d}if((i|0)>0|(i|0)>=0){break ae}if((j|0)>=(t|0)){break $d}x[g+96>>2]=m;x[g+100>>2]=J;x[g+104>>2]=0;x[g+108>>2]=t;Ia=g,Ja=ug(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=ug(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=Bm(g+88|0,l,S)+1|0,x[Ia+44>>2]=Ja;break $d}e=j;j=x[L>>2];if((e|0)<(j|0)){break $d}x[g+104>>2]=m;x[g+108>>2]=J;x[g+96>>2]=0;x[g+100>>2]=j;Ia=g,Ja=ug(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=ug(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=Bm(g+88|0,l,S)+1|0,x[Ia+44>>2]=Ja}Jo(g+44|0,1,x[g+68>>2]);j=x[g+44>>2];if((j|0)>0){break Rd}}x[U+624>>2]=0;x[L>>2]=0;x[k>>2]=0;x[k+4>>2]=0;x[X>>2]=0;t=0;e=x[k+92>>2];q=x[k+96>>2];if(e|q){if(f){while(1){j=(t<<3)+h|0;e=e-(((-2147483648-e>>>31|0)-1&255)+e>>8)|0;x[j>>2]=e+x[j>>2];q=q-(((-2147483648-q>>>31|0)-1&255)+q>>8)|0;x[j+4>>2]=q+x[j+4>>2];t=t+1|0;if((t|0)!=(f|0)){continue}break}}x[k+96>>2]=q;x[k+92>>2]=e}x[ca>>2]=x[ca>>2]+x[O>>2];x[aa>>2]=x[aa>>2]+x[R>>2];x[R>>2]=0;x[O>>2]=0;x[u>>2]=x[u>>2]&-129;break Qd}de:{ee:{if(A[a+24608>>2]>Ba>>>0){q=4;if(x[X>>2]){break ee}q=0;if(x[ra>>2]|x[sa>>2]){break ee}}Ia=g,Ja=sqa(x[M>>2],x[M+4>>2],j,j>>31),x[Ia+104>>2]=Ja;x[g+108>>2]=lb;Tb(k,g+104|0);V=0;x[R>>2]=0;x[O>>2]=0;e=(j<<3)+h|0;break de}e=(j<<3)+h|0;i=e-8|0;x[O>>2]=0-x[i>>2];m=e-4|0;x[R>>2]=0-x[m>>2];mb[x[((q|Aa)<<2)+76336>>2]](k,xa,h,j);x[O>>2]=x[O>>2]+x[i>>2];x[R>>2]=x[R>>2]+x[m>>2];V=1}h=e;e=x[X>>2];fe:{if(!e){break fe}if(e>>>0<=j>>>0){x[X>>2]=0;x[sa>>2]=x[Ha>>2];x[ra>>2]=x[Ga>>2];x[Fa>>2]=0;x[Ea>>2]=0;if(x[Da>>2]|!(y[u+1|0]&16)){break fe}x[L>>2]=0;x[U+624>>2]=0;break fe}x[X>>2]=e-j}i=0;e=0;m=x[k+4>>2];e=m>>>0>=A[_>>2]?(y[u|0]&2)>>>1|0:e;l=m;m=x[L>>2];i=x[u>>2]&2|(l>>>0<m>>>0|!m)?i:!z[Ca>>1];f=f-j|0;j=g+104|0;Kb(j,ja,85);ge:{he:{ie:{if(!Ib(j)){break ie}j=y[qa|0];if(!j){break ie}if(j>>>0<=z[a+480190>>1]){break he}}q=0;break ge}l=x[da>>2];j=D(y[qa|0],104)+a|0;m=j+484380|0;q=(l|0)!=(m|0);if((l|0)==(m|0)|(e|i)!=1){break ge}x[da>>2]=m;x[U+624>>2]=x[j+484400>>2];e=z[j+484414>>1];x[u>>2]=e|x[u>>2]&-768;m=e<<30>>31;e=x[j+484388>>2];x[L>>2]=m&e;j=x[j+484384>>2];x[fa>>2]=j;x[_>>2]=e;x[k+4>>2]=j;OC(H,k);if(!x[U+624>>2]){break Qd}if((f|0)>0){continue}break Qd}je:{if(!e|q){break je}e=g+104|0;Kb(e,ja,83);if(!Ib(e)|x[fa>>2]){break je}x[k>>2]=x[k>>2];x[k+4>>2]=0;e=x[x[da>>2]+8>>2];x[L>>2]=e;x[_>>2]=e}if((f|0)>0){continue}}break}x[U+624>>2]=x[H>>2];ea=V+ea|0;w[g+30>>1]=ea;ke:{if(!V|pa){break ke}e=x[(D(ka,160)+a|0)+906140>>2];if(!e){break ke}mb[x[x[e>>2]+144>>2]](e)}h=z[a+480212>>1]}r=r+1|0;if(r>>>0<h>>>0){continue}break}}Ia=a,Ja=z[jj(a+480214|0,g+30|0)>>1],w[Ia+480214>>1]=Ja}hb=g+112|0;if(yd(na)){e=$;g=n;f=(D(x[a+480232>>2],x[a+480236>>2])>>>0)/48|0;i=hb-16|0;hb=i;o=x[na>>2];le:{if(!y[o+530|0]){break le}h=sqa(f,0,6169,0);f=lb;j=f>>>16|0;H=id((f&65535)<<16|h>>>16,j);if(!g){break le}while(1){k=x[o>>2];r=x[k>>2];h=x[k+4>>2];if((r|0)<=(h|0)){while(1){x[k+8>>2]=x[k+12>>2];r=0;m=0;t=0;f=hb-16|0;hb=f;while(1){j=k+D(t,44)|0;me:{if(!y[j+56|0]){w[f+12>>1]=0;w[f+14>>1]=0;break me}l=x[j+32>>2];h=z[l+3840>>1];if(h&3){l=(z[j+36>>1]>>>7&7)>>>!y[l+3844|0]>>>(h&1)<<z[j+38>>1];h=h&4?0-l|0:l}else{h=0}l=x[j+52>>2];ne:{if(l){G=z[l+32>>1];s=z[j+48>>1];h=h<<16>>16;l=Uf(x[j+16>>2],x[j+40>>2],h,0,w[j+46>>1]);q=x[j+40>>2];u=x[j+20>>2];if(!G){if(!s){l=Uf(u,q,h,l,0);l=Uf(x[j+24>>2],x[j+40>>2],h,l,0);h=Uf(x[j+28>>2],x[j+40>>2],h,l,0);break ne}q=Uf(u,q,h,0,0);q=Uf(x[j+24>>2],x[j+40>>2],h,q,0);h=Uf(x[j+28>>2],x[j+40>>2],h,q,0)+l|0;break ne}if(!s){l=Uf(u,q,h,l,0);q=Uf(x[j+24>>2],x[j+40>>2],h,0,0);h=Uf(x[j+28>>2],x[j+40>>2],h,q,0)+l|0;break ne}q=Uf(u,q,h,0,0);h=(Uf(x[j+24>>2],x[j+40>>2],h,q,0)+l|0)+Uf(x[j+28>>2],x[j+40>>2],h,0,0)|0;break ne}s=z[j+48>>1];h=h<<16>>16;l=Uf(x[j+16>>2],x[j+40>>2],h,0,w[j+46>>1]);q=x[j+40>>2];u=x[j+20>>2];if(!s){h=Uf(u,q,h,l,0);break ne}h=Uf(u,q,h,0,0)+l|0}w[f+14>>1]=y[j+57|0]?h:0;w[f+12>>1]=y[j+58|0]?h:0}r=w[f+12>>1]+r|0;m=w[f+14>>1]+m|0;t=t+1|0;if((t|0)!=18){continue}break}h=(m|0)>=32767?32767:m;w[k+12>>1]=(h|0)<=-32768?-32768:h;h=(r|0)>=32767?32767:r;w[k+14>>1]=(h|0)<=-32768?-32768:h;w[k+3832>>1]=z[k+3832>>1]+1;h=(z[k+3834>>1]+1>>>0)%13440|0;w[k+3834>>1]=h;h=h>>>0<6720?h:13440-h|0;w[k+3836>>1]=h>>>8;if(!y[k+3843|0]){w[k+3836>>1]=h>>>10}h=z[k+3838>>1]+1|0;w[k+3838>>1]=h;if((h&65535)>>>0>=1024){w[k+3838>>1]=0;w[k+3840>>1]=z[k+3840>>1]+1&7}hb=f+16|0;r=x[k>>2];h=x[k+4>>2]-r|0;x[k+4>>2]=h;if((h|0)>=(r|0)){continue}break}}f=r-h|0;w[i+14>>1]=(D(w[k+12>>1],h)+D(f,w[k+8>>1])|0)/(r|0);w[i+12>>1]=(D(w[k+14>>1],h)+D(f,w[k+10>>1])|0)/(r|0);x[k+4>>2]=h+49716;x[e>>2]=x[e>>2]+D(H,w[i+14>>1]);x[e+4>>2]=x[e+4>>2]+D(H,w[i+12>>1]);e=e+8|0;g=g-1|0;if(g){continue}break}}hb=i+16|0}e=x[K+4116>>2];if(e|x[K+4120>>2]){if(!e){Sn(K+8|0,n,K+4104|0,K+4108|0)}e=x[K>>2];g=x[K+4184>>2];f=D(e,g)>>>4|0;f=f>>>0>=32767?32767:f;w[K+4202>>1]=f;w[K+4200>>1]=f;h=x[K+54052>>2];f=D(h,e)>>>4|0;f=f>>>0>=65536?65536:f;j=f+127>>>3|0;w[K+54050>>1]=j;f=f+255>>>4|0;w[K+54048>>1]=f;w[K+54046>>1]=f;w[K+54044>>1]=j;f=K+8|0;g=(g|0)>(h|0)?g:h;e=36-e>>>1|0;e=16-(e>>>0<=8?8:e)|0;g=16-(D((g|0)>=32768?32768:g,e>>>0<=16?e:0)>>15)|0;e=0;if(n){while(1){h=e<<3;j=h+$|0;x[j>>2]=x[j>>2]+D(g,x[f+h>>2]>>4);h=h|4;j=h+$|0;x[j>>2]=x[j>>2]+D(g,x[f+h>>2]>>4);e=e+1|0;if((n|0)!=(e|0)){continue}break}}e=0;h=x[K+4144>>2];g=x[K+4140>>2];if(n){k=w[K+4188>>1];while(1){j=(e<<3)+f|0;i=x[j>>2]>>12;g=(D(k,i-g|0)>>15)+i|0;x[j>>2]=g;m=j;j=x[j+4>>2]>>12;h=(D(k,j-h|0)>>15)+j|0;x[m+4>>2]=h;e=e+1|0;if((n|0)!=(e|0)){continue}break}}q=K+4172|0;x[K+4144>>2]=h;x[K+4140>>2]=g;oe:{if(!n){k=x[q>>2]&8191;break oe}e=f;k=z[q+22>>1];h=z[q+20>>1];t=x[q+4>>2];g=n;if(g){j=w[q+26>>1];i=w[q+24>>1];u=w[q+18>>1];s=w[q+16>>1];H=x[q>>2]-1|0;m=q+32928|0;while(1){l=Uc(x[e>>2]);r=Uc(x[e+4>>2]);h=Uc((h<<16>>16)-l|0);k=Uc((k<<16>>16)-r|0);h=Wc(Uc((D(h,s)|0)/65536<<1)+l|0);k=Wc(Uc((D(k,u)|0)/65536<<1)+r|0);r=m+(t<<2)|0;l=w[r+2>>1];o=w[r>>1];r=Wc(((D(o,i)|0)/-65536|0)+h|0);t=t+1&127;G=m+(t<<2)|0;C=Wc(((D(j,l)|0)/-65536|0)+k|0);w[G+2>>1]=C;w[G>>1]=r;H=H+1&8191;G=q+(H<<2)|0;Ia=G,Ja=Wc(o+((D(i,r)|0)/65536|0)|0),w[Ia+160>>1]=Ja;Ia=G,Ja=Wc(l+((D(j,C)|0)/65536|0)|0),w[Ia+162>>1]=Ja;e=e+8|0;g=g-1|0;if(g){continue}break}}l=K+53996|0;w[q+22>>1]=k;w[q+20>>1]=h;x[q+4>>2]=t;h=x[K+4180>>2];I=K+37612|0;e=f;g=n;while(1){j=h&4095;u=I+(j<<2)|0;k=e;j=4096-j|0;G=h-x[K+53996>>2]&4095;h=4096-G|0;h=h>>>0>j>>>0?j:h;h=g>>>0<h>>>0?g:h;m=h>>>0>=64?64:h;r=m;h=0;H=hb-32|0;hb=H;j=x[q>>2];while(1){x[H+(h<<2)>>2]=j+(x[(q+(h<<4)|0)+32>>2]^-1);h=h+1|0;if((h|0)!=7){continue}break}if(r){s=w[q+28>>1]/8<<16>>16;while(1){i=0;j=0;h=0;while(1){t=H+(h<<2)|0;o=x[t>>2]+1&8191;x[t>>2]=o;Z=j;j=q+(o<<2)|0;o=w[j+160>>1];t=q+(h<<4)|0;C=w[j+162>>1];j=(Z+D(o,w[t+44>>1])|0)+D(C,w[t+46>>1])|0;i=(D(o,w[t+40>>1])+i|0)+D(C,w[t+42>>1])|0;h=h+1|0;if((h|0)!=4){continue}break}t=0;h=4;C=Wc((i|0)/32768|0);L=Wc((j|0)/32768|0);i=0;while(1){j=H+(h<<2)|0;o=x[j>>2]+1&8191;x[j>>2]=o;Z=i;i=q+(o<<2)|0;o=w[i+160>>1];j=q+(h<<4)|0;M=w[i+162>>1];i=(Z+D(o,w[j+44>>1])|0)+D(M,w[j+46>>1])|0;t=(D(o,w[j+40>>1])+t|0)+D(M,w[j+42>>1])|0;h=h+1|0;if((h|0)!=7){continue}break}h=Wc(C+((t|0)/32768|0)|0);w[u>>1]=h;x[k>>2]=D(h,s);h=Wc(L+((i|0)/32768|0)|0);w[u+2>>1]=h;x[k+4>>2]=D(h,s);k=k+8|0;u=u+4|0;r=r-1|0;if(r){continue}break}}hb=H+32|0;H=I+(G<<2)|0;h=e;u=x[l+4>>2];r=u&2047;i=m;if(i){L=l+2|0;j=z[l+32>>1];k=l+24640|0;t=l+16448|0;while(1){X=l+8256|0;M=w[X+((u+1206&2047)<<2)>>1];J=l- -64|0;C=w[J+((u+1750&2047)<<2)>>1];o=k+((u+22&2047)<<2)|0;s=w[o+2>>1];o=w[o>>1];P=k+((u+502&2047)<<2)|0;G=w[P+2>>1];U=w[(L+((u+754&2047)<<2)|0)+8256>>1];V=w[(L+((u+1602&2047)<<2)|0)- -64>>1];R=w[H>>1];O=w[H+2>>1];Z=j<<16>>16;j=w[P>>1];P=Uc(Z-j|0);S=w[l+24>>1];_=Uc(w[l+34>>1]-G|0);aa=w[l+26>>1];ca=Uc(w[l+36>>1]-o|0);da=w[l+28>>1];fa=Uc(w[l+38>>1]-s|0);ea=w[l+30>>1];j=Wc(Uc((D(P,S)|0)/65536<<1)+j|0);w[l+32>>1]=j;Ia=l,Ja=Wc(Uc((D(_,aa)|0)/65536<<1)+G|0),w[Ia+34>>1]=Ja;Ia=l,Ja=Wc(Uc((D(ca,da)|0)/65536<<1)+o|0),w[Ia+36>>1]=Ja;s=Wc(Uc((D(fa,ea)|0)/65536<<1)+s|0);w[l+38>>1]=s;o=Uc((D(w[l+16>>1],j)|0)/32768|0);s=Uc((D(s,w[l+22>>1])|0)/32768|0);P=Uc(o+((R|0)/4<<16>>16)|0);R=Uc(s+((O|0)/4<<16>>16)|0);s=w[l+8>>1];O=Uc(P+((D(s,C)|0)/-65536|0)|0);o=r<<2;J=o+J|0;G=w[l+10>>1];S=Uc(R+((D(G,V)|0)/-65536|0)|0);w[J+2>>1]=S;w[J>>1]=O;C=Uc(C+((D(s,O)|0)/65536|0)|0);O=o+t|0;J=Uc(V+((D(G,S)|0)/65536|0)|0);w[O+2>>1]=J;w[O>>1]=C;V=Uc(C+P|0);P=Uc(J+R|0);C=t+((u+426&2047)<<2)|0;R=w[C+2>>1];O=w[C>>1];u=t+((u+682&2047)<<2)|0;J=w[u+2>>1];S=w[u>>1];u=Uc((D(J,w[l+42>>1])+D(S,w[l+40>>1])|0)/32768|0);C=Uc((D(R,w[l+46>>1])+D(O,w[l+44>>1])|0)/32768|0);S=Uc(Uc(S+V|0)-u|0);J=Uc(Uc(J+P|0)-C|0);V=Uc(Uc(O+V|0)-u|0);P=Uc(Uc(P+R|0)-C|0);u=Uc(u+((D(s,M)|0)/-65536|0)|0);R=o+X|0;C=Uc(C+((D(G,U)|0)/-65536|0)|0);w[R+2>>1]=C;w[R>>1]=u;s=(D(s,u)|0)/65536|0;u=Uc(s+M|0);o=k+o|0;G=(D(C,G)|0)/65536|0;C=Uc(G+U|0);w[o+2>>1]=C;w[o>>1]=u;u=Uc(u+S|0);o=w[l+48>>1];C=Uc(C+J|0);x[h>>2]=(x[h>>2]+D(o,u)|0)+D(C,w[l+50>>1]);u=Uc(Uc(s)+V|0);s=w[l+52>>1];o=Uc(Uc(G)+P|0);x[h+4>>2]=(x[h+4>>2]+D(s,u)|0)+D(o,w[l+54>>1]);h=h+8|0;H=H+4|0;u=r+1|0;r=u&2047;i=i-1|0;if(i){continue}break}}x[l+4>>2]=r;h=m+x[K+4180>>2]&4095;x[K+4180>>2]=h;k=m+x[K+4172>>2]&8191;x[K+4172>>2]=k;e=(m<<3)+e|0;g=g-m|0;if(g){continue}break}}x[K+4172>>2]=k;e=$;g=0;h=0;t=x[K+4160>>2];i=x[K+4156>>2];m=n;if(n){k=x[K+4164>>2];h=x[K+4168>>2];while(1){g=x[f>>2];j=h;h=x[f+4>>2];j=j-h|0;j=(((j|0)/1024|0)-j|0)+t|0;x[e+4>>2]=j+x[e+4>>2];k=k-g|0;k=(((k|0)/1024|0)-k|0)+i|0;x[e>>2]=k+x[e>>2];t=j+((j|0)/-512|0)|0;i=k+((k|0)/-512|0)|0;e=e+8|0;f=f+8|0;k=g;m=m-1|0;if(m){continue}break}}x[K+4168>>2]=h;x[K+4164>>2]=g;x[K+4160>>2]=t;x[K+4156>>2]=i;e=x[K+4124>>2];pe:{if(x[K+4116>>2]){break pe}e=x[K+4120>>2];if(e>>>0>n>>>0){e=e-n|0;break pe}FJ(K);e=0}x[K+4116>>2]=0;x[K+4120>>2]=e}if(x[a+946300>>2]){i=0;t=0;h=n<<2;H=z[a+480214>>1]!=0;e=a+1074332|0;W=B[e>>2];ta=B[e+4>>2];while(1){j=(D(i,160)+a|0)+906300|0;e=x[j>>2];qe:{if(!e|!x[e+24>>2]){break qe}if(!Eh(e+44|0)){break qe}e=x[j>>2];if(!(mb[x[x[e>>2]+108>>2]](e)|0)){mb[x[x[e>>2]+104>>2]](e,1);mb[x[x[e>>2]+116>>2]](e)}g=e+44|0;f=Qd(g,0);g=Qd(g,1);re:{if(v[e+28|0]&1){Az(x[e+24>>2],f,g,n,W);break re}k=e+40|0;if(x[k>>2]|x[e+36>>2]){Sn(x[e+24>>2],n,k,e+36|0);Az(x[e+24>>2],f,g,n,W);break re}Sb(f,0,h);Sb(g,0,h)}x[e+28>>2]=x[e+28>>2]&-2;if(vv(j)){break qe}H=!(y[e+28|0]&4)|H}i=i+1|0;if((i|0)!=250){continue}break}r=a+12|0;j=a+12300|0;k=a+14348|0;Az(r,j,k,n,W);e=a+1074464|0;G=y[e|0];v[e|0]=0;e=j;g=k;while(1){m=(D(t,160)+a|0)+906300|0;f=x[m>>2];se:{if(!f|!x[f+24>>2]){break se}if(!Eh(f+44|0)){break se}q=x[m>>2];te:{if(vv(m)){break te}f=x[m>>2];if(mb[x[x[f>>2]+140>>2]](f)|y[x[m>>2]+28|0]&2){break te}i=0;if(!t){break se}while(1){if((Xj((D(i,160)+a|0)+906300|0)|0)==(t|0)){break te}i=i+1|0;if((t|0)!=(i|0)){continue}break}break se}f=q+44|0;u=Qd(f,0);o=Qd(f,1);l=x[m>>2];s=(e|0)==(u|0);e=s?j:e;f=e;g=s?k:g;h=g;ue:{if(!(y[m+28|0]|y[m+29|0]<<8|(y[m+30|0]<<16|y[m+31|0]<<24))){break ue}i=Xj(m);h=g;if(i>>>0<=t>>>0){break ue}h=g;if(i>>>0>249){break ue}i=x[(D(i,160)+a|0)+906300>>2];h=g;if(!i){break ue}if(!(y[l+28|0]&4)){mb[x[x[i>>2]+144>>2]](i)}i=i+44|0;h=g;if(!Eh(i)){break ue}f=Qd(i,0);h=Qd(i,1)}ve:{if(!vv(m)){break ve}we:{if(s){break we}i=0;if(!n){break we}while(1){s=i<<2;C=s+u|0;Z=C;W=B[C>>2];C=e+s|0;B[Z>>2]=W+B[C>>2];I=o+s|0;s=g+s|0;B[I>>2]=B[I>>2]+B[s>>2];x[C>>2]=0;x[s>>2]=0;i=i+1|0;if((n|0)!=(i|0)){continue}break}}g=h;e=f;if(!(H&1)){break ve}e=x[m>>2];if(e){mb[x[x[e>>2]+144>>2]](e)}e=f;i=Xj(m);if(i>>>0>249|i>>>0<=t>>>0){break ve}while(1){g=i&255;e=(D(g,160)+a|0)+906300|0;i=Xj(e);e=x[e>>2];if(e){mb[x[x[e>>2]+144>>2]](e)}if(g>>>0<i>>>0&i>>>0<=249){continue}break}g=h;e=f}xe:{ye:{if(!((y[m+24|0]&2)>>>1|0)){if(!MC(m)|!(y[l+28|0]&4)){break ye}}i=0;if(!n){break xe}while(1){m=i<<2;q=m+f|0;B[q>>2]=B[q>>2]+B[m+u>>2];q=h+m|0;B[q>>2]=B[q>>2]+B[m+o>>2];i=i+1|0;if((n|0)!=(i|0)){continue}break}break xe}if(G){mb[x[x[q>>2]+124>>2]](q)}mb[x[x[q>>2]+60>>2]](q,f,h,n);x[l+32>>2]=n+x[l+32>>2];if(!MC(m)){break xe}if((mb[x[x[q>>2]+152>>2]](q)|0)<=0|A[l+32>>2]<x[a+24620>>2]<<2>>>0){break xe}i=0;ze:{if(!n){break ze}while(1){Ae:{m=i<<2;W=B[m+f>>2];if(W>=E(1.1920928955078125e-7)|W<=E(-1.1920928955078125e-7)){break Ae}W=B[h+m>>2];if(W>=E(1.1920928955078125e-7)|!(W>E(-1.1920928955078125e-7))){break Ae}i=i+1|0;if((n|0)!=(i|0)){continue}break ze}break}x[l+32>>2]=0;break xe}x[l+28>>2]=x[l+28>>2]|4}x[l+28>>2]=x[l+28>>2]&-3}t=t+1|0;if((t|0)!=250){continue}break}f=0;if(n){while(1){W=E(B[e>>2]*ta);Be:{if(E(F(W))<E(2147483648)){j=~~W;break Be}j=-2147483648}x[r>>2]=j;W=E(B[g>>2]*ta);Ce:{if(E(F(W))<E(2147483648)){j=~~W;break Ce}j=-2147483648}x[r+4>>2]=j;r=r+8|0;g=g+4|0;e=e+4|0;f=f+1|0;if((n|0)!=(f|0)){continue}break}}}if(x[a+24624>>2]==1){e=0;if(n){while(1){f=(e<<3)+$|0;x[(e<<2)+$>>2]=(x[f+4>>2]+x[f>>2]|0)/2;e=e+1|0;if((n|0)!=(e|0)){continue}break}}}if(y[va+36|0]){j=hb-16|0;hb=j;De:{Ee:{Fe:{if(!x[a+1074376>>2]){k=a+1074448|0;e=k;x[e>>2]=0;x[e+4>>2]=0;x[a+1074456>>2]=x[a+1074444>>2];break Fe}g=x[a+1074456>>2];e=x[a+1074444>>2];Ge:{if((g|0)==(e|0)){e=x[a+1074448>>2];break Ge}x[a+1074456>>2]=e;f=a+24604|0;h=a+1074448|0;He:{if((e|0)>(g|0)){e=mP(f);break He}e=lP(f)}x[h>>2]=e;x[a+1074452>>2]=e}k=a+1074448|0;if((e|0)>0){break Ee}}h=0;break De}g=(x[a+1074456>>2]<<12)-x[a+1074460>>2]|0;h=(g|0)/(e|0)|0;if(x[a+1074372>>2]!=2){break De}x[j+12>>2]=50;x[j+8>>2]=1e4/(x[a+1074452>>2]+1|0);i=x[Yf(j+12|0,j+8|0)>>2];e=h>>31;if((i|0)>=((e^h)-e|0)){break De}m=x[a+1074452>>2];e=x[a+1074448>>2];while(1){e=e+m|0;h=(g|0)/(e|0)|0;f=h>>31;if((i|0)<((f^h)-f|0)){continue}break}x[k>>2]=e}Ie:{Je:{switch(x[a+24624>>2]-1|0){case 0:if((n|0)<=0){break Ie}e=a+12|0;f=x[a+1074444>>2];m=f<<12;g=f;l=g>>31;f=0;while(1){Ke:{if(x[k>>2]>0){i=x[a+1074460>>2]+h|0;x[a+1074460>>2]=i;r=x[e>>2];Ia=e,Ja=Ec(tqa(sqa(r,r>>31,i,i>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;x[a+1074448>>2]=x[a+1074448>>2]-1;break Ke}i=x[e>>2];Ia=e,Ja=Ec(tqa(sqa(i,i>>31,g,l),lb,256,0),lb),x[Ia>>2]=Ja;x[a+1074460>>2]=m}e=e+4|0;f=f+1|0;if((n|0)!=(f|0)){continue}break};break Ie;case 1:if((n|0)<=0){break Ie}e=a+12|0;g=x[a+1074444>>2];l=g<<12;i=g>>31;f=0;while(1){Le:{if(x[k>>2]>0){m=x[a+1074460>>2]+h|0;x[a+1074460>>2]=m;r=x[e>>2];Ia=e,Ja=Ec(tqa(sqa(r,r>>31,m,m>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;m=x[a+1074460>>2];q=m;r=m>>31;m=x[e+4>>2];Ia=e,Ja=Ec(tqa(sqa(q,r,m,m>>31),lb,1048576,0),lb),x[Ia+4>>2]=Ja;x[a+1074448>>2]=x[a+1074448>>2]-1;break Le}m=x[e>>2];Ia=e,Ja=Ec(tqa(sqa(m,m>>31,g,i),lb,256,0),lb),x[Ia>>2]=Ja;m=x[e+4>>2];Ia=e,Ja=Ec(tqa(sqa(m,m>>31,g,i),lb,256,0),lb),x[Ia+4>>2]=Ja;x[a+1074460>>2]=l}e=e+8|0;f=f+1|0;if((n|0)!=(f|0)){continue}break};break Ie;case 3:break Je;default:break Ie}}if((n|0)<=0){break Ie}e=a+12|0;f=a+8204|0;g=x[a+1074444>>2];r=g<<12;i=g>>31;m=0;while(1){Me:{if(x[k>>2]>0){l=x[a+1074460>>2]+h|0;x[a+1074460>>2]=l;q=x[e>>2];Ia=e,Ja=Ec(tqa(sqa(q,q>>31,l,l>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;l=x[a+1074460>>2];q=l;u=l>>31;l=x[e+4>>2];Ia=e,Ja=Ec(tqa(sqa(q,u,l,l>>31),lb,1048576,0),lb),x[Ia+4>>2]=Ja;l=x[a+1074460>>2];q=l;u=l>>31;l=x[f>>2];Ia=f,Ja=Ec(tqa(sqa(q,u,l,l>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;l=x[a+1074460>>2];q=l;u=l>>31;l=x[f+4>>2];Ia=f,Ja=Ec(tqa(sqa(q,u,l,l>>31),lb,1048576,0),lb),x[Ia+4>>2]=Ja;x[a+1074448>>2]=x[a+1074448>>2]-1;break Me}l=x[e>>2];Ia=e,Ja=Ec(tqa(sqa(l,l>>31,g,i),lb,256,0),lb),x[Ia>>2]=Ja;l=x[e+4>>2];Ia=e,Ja=Ec(tqa(sqa(l,l>>31,g,i),lb,256,0),lb),x[Ia+4>>2]=Ja;l=x[f>>2];Ia=f,Ja=Ec(tqa(sqa(l,l>>31,g,i),lb,256,0),lb),x[Ia>>2]=Ja;l=x[f+4>>2];Ia=f,Ja=Ec(tqa(sqa(l,l>>31,g,i),lb,256,0),lb),x[Ia+4>>2]=Ja;x[a+1074460>>2]=r}f=f+8|0;e=e+8|0;m=m+1|0;if((n|0)!=(m|0)){continue}break}}hb=j+16|0}if(x[la>>2]!=128){f=a+12|0;g=a+8204|0;e=x[a+24604>>2];h=x[a+24624>>2];Ne:{if((e|0)==128|h>>>0<2){break Ne}$L(f,n,e);if(h>>>0<4){break Ne}$L(g,n,e)}}e=x[a+24624>>2];if((e|0)==4){f=n-1|0;if((f|0)>=0){while(1){e=f;g=(e<<4)+$|0;h=e<<3;j=h|4;x[g+12>>2]=x[j+ma>>2];x[g+8>>2]=x[h+ma>>2];x[g+4>>2]=x[j+$>>2];x[g>>2]=x[h+$>>2];f=e-1|0;if(e){continue}break}}e=x[a+24624>>2]}mb[x[x[c>>2]+8>>2]](c,$,e,n);g=x[a+1074380>>2]-n|0;x[a+1074380>>2]=g;x[a+1074376>>2]=n+x[a+1074376>>2];ua=n+ua|0;e=x[a+480208>>2];if(e&512){break g}b=b-n|0;if(b){continue}break}}hb=Y+32|0;return ua|0}function loa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;d=hb-688|0;hb=d;Nc(b);e=hb-16|0;hb=e;i=e+8|0;g=d+496|0;Su(i,g);h=Fb(i);i=nc(b,ac(e,i));if((h|0)==(i|0)){cc(b,Fb(e+8|0))}hb=e+16|0;e=(h|0)==(i|0);if(!e){ZS(g)}a:{b:{c:{if(!e){break c}if(!zT(d+496|0)){break c}if(!Qb(b,id(yT(d+496|0),lb))){break c}if(!c){f=1;break c}Pd(a,32);v[d+495|0]=0;i=gd(d+480|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if((y[d+496|0]|y[d+497|0]<<8|(y[d+498|0]<<16|y[d+499|0]<<24))==778924148){x[114409]=0;P(631,a|0,16777216);e=x[114409];x[114409]=0;if((e|0)==1){break b}x[114409]=0;e=S(228,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;O(229,b|0,e-4|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}x[114409]=0;s=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break H}break b}I:{J:{K:{L:{M:{e=y[d+536|0]|y[d+537|0]<<8;N:{if(e>>>0<2185|e>>>0>4095){break N}x[114409]=0;e=S(228,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;O(229,b|0,e-4|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}x[114409]=0;s=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(s>>>0<256){break N}x[114409]=0;e=S(228,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break N}x[114409]=0;e=O(229,b|0,s|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!e){break N}x[114409]=0;e=O(632,b|0,10285)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!e){break N}x[114409]=0;P(631,a|0,16777216);e=x[114409];x[114409]=0;if((e|0)==1){break b}if((y[d+536|0]|y[d+537|0]<<8)>>>0>=4096){x[114409]=0;b=O(633,d+264|0,12369)|0;c=x[114409];x[114409]=0;if((c|0)==1){break G}x[114409]=0;P(634,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b);f=0;break d}f=N()|0;xb(b);break a}if((y[d+536|0]|y[d+537|0]<<8)>>>0<2194){break N}x[114409]=0;e=O(633,d+468|0,11921)|0;f=x[114409];x[114409]=0;if((f|0)==1){break M}x[114409]=0;P(634,a|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break L}xb(e)}if(x[a+480180>>2]!=32){break H}if(((y[d+536|0]|y[d+537|0]<<8)&61440)!=20480){break I}e=(y[d+536|0]|y[d+537|0]<<8)&4095;f=e<<16;if((y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=1414548815){break K}v[d+495|0]=1;break J}f=N()|0;break a}f=N()|0;xb(e);break a}if(e>>>0<297){break J}f=y[d+556|0]|y[d+557|0]<<8|f}x[a+1074308>>2]=f;break H}if(!((y[d+538|0]|y[d+539|0]<<8)!=2184&(y[d+536|0]|y[d+537|0]<<8)!=2184)){v[d+495|0]=1;x[a+1074308>>2]=18284544;break H}if(!((y[d+536|0]|y[d+537|0]<<8)!=535|(y[d+538|0]|y[d+539|0]<<8)!=512|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)))){O:{if(Yq(d+560|0,255,64)){x[a+1074308>>2]=18219008;x[114409]=0;e=O(2,d+456|0,10342)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break O}f=N()|0;break a}x[a+1074308>>2]=18284544;x[114409]=0;e=O(2,d+456|0,12742)|0;f=x[114409];x[114409]=0;if((f|0)==1){break F}}Eb(i,e);xb(e);v[d+495|0]=1;break H}if(!((y[d+536|0]|y[d+537|0]<<8)!=532|(y[d+538|0]|y[d+539|0]<<8)!=514|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)))){x[a+1074308>>2]=17367040;x[114409]=0;e=O(2,d+456|0,10252)|0;f=x[114409];x[114409]=0;if((f|0)!=1){Eb(i,e);xb(e);v[d+495|0]=1;break H}f=N()|0;break a}if((y[d+536|0]|y[d+537|0]<<8)!=768|(y[d+538|0]|y[d+539|0]<<8)!=768|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)|(y[d+528|0]|y[d+529|0]<<8)!=256)){break H}if(y[d+549|0]|y[d+548|0]!=128){break H}x[a+1074308>>2]=18285088;v[d+495|0]=1}x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+540|0]|y[d+541|0]<<8)<<1&16;x[a+480208>>2]=x[a+480208>>2]&-5|(y[d+540|0]|y[d+541|0]<<8)>>>2&4;x[a+480208>>2]=x[a+480208>>2]&-9|(y[d+540|0]|y[d+541|0]<<8)>>>2&8;x[a+480208>>2]=x[a+480208>>2]&-32769|(y[d+540|0]|y[d+541|0]<<8)<<3&32768;x[114409]=0;T(635,d+364|0,3,d+500|0);e=x[114409];x[114409]=0;if((e|0)==1){break E}x[114409]=0;P(370,d+264|0,d+364|0);e=x[114409];x[114409]=0;if((e|0)==1){break E}e=d+264|0;Eb(a+1304400|0,e);xb(e);if(!(!(y[d+542|0]&4)|(A[a+1074308>>2]<18285314?x[a+1074308>>2]:0))){x[a+480216>>2]=y[d+526|0];x[a+480220>>2]=y[d+527|0]}e=y[d+544|0];x[a+480200>>2]=e>>>0>128?256:e<<1;if(y[d+546|0]){x[a+480196>>2]=y[d+546|0]}v[d+264|0]=31;e=y[d+547|0];x[114409]=0;v[d+364|0]=e;e=O(426,d+264|0,d+364|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}x[a+480204>>2]=D(y[e|0],1e4);e=y[d+545|0];x[114409]=0;v[d+264|0]=e;v[d+364|0]=128;e=O(431,d+264|0,d+364|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}x[a+480228>>2]=y[e|0];f=0;while(1){j=(d+496|0)+f|0;g=j- -64|0;P:{if(y[g|0]==255){break P}x[114409]=0;h=(f<<5)+a|0;e=h+480280|0;V(403,e|0);l=x[114409];x[114409]=0;if((l|0)==1){break D}C=h+480286|0,E=Md(y[j+128|0],0,64),w[C>>1]=E;if(v[g|0]<0){x[e>>2]=x[e>>2]|1024}g=y[g|0]&127;if(g>>>0<=64){w[h+480284>>1]=g<<2;break P}if((g|0)!=100){break P}x[e>>2]=x[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}x[114409]=0;O(229,b|0,192)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}Q:{if(!(x[a+480180>>2]!=16777216|(y[d+536|0]|y[d+537|0]<<8)>>>0<2187|(y[d+536|0]|y[d+537|0]<<8)>>>0>2189)){f=0;x[114409]=0;e=S(335,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break C}if(e){break d}x[114409]=0;e=S(413,b|0)|0;g=x[114409];x[114409]=0;R:{if((g|0)==1){break R}if(e>>>0>z[x[19555]+12>>1]){break d}g=Wb(a+484360|0);x[114409]=0;e=aa(636,g|0,b|0,e|0,65535,65535)|0;g=x[114409];x[114409]=0;if((g|0)==1){break R}if(!e){break d}break Q}f=N()|0;break a}e=Wb(a+484360|0);f=y[d+528|0]|y[d+529|0]<<8;x[114409]=0;aa(580,e|0,b|0,f|0,255,254)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}}r=Aq(d+444|0);o=Aq(d+432|0);l=Aq(d+420|0);e=y[d+530|0]|y[d+531|0]<<8;f=0;x[114409]=0;e=U(637,b|0,r|0,e|0)|0;g=x[114409];x[114409]=0;S:{if((g|0)==1){break S}if(!e){break A}e=y[d+532|0]|y[d+533|0]<<8;x[114409]=0;e=U(637,b|0,o|0,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break S}if(!e){break A}e=y[d+534|0]|y[d+535|0]<<8;x[114409]=0;e=U(637,b|0,l|0,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break S}if(!e){break A}x[d+416>>2]=-1;C=d,E=bc(r),x[C+264>>2]=E;C=d,E=dc(r),x[C+364>>2]=E;if(!Hb(d+264|0,d+364|0)){break B}while(1){e=x[d+264>>2];e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|e>>>0>=A[d+416>>2])){x[d+416>>2]=e}e=d+264|0;je(e);if(Hb(e,d+364|0)){continue}break}break B}f=N()|0;break g}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}C=d,E=bc(o),x[C+264>>2]=E;C=d,E=dc(o),x[C+364>>2]=E;if(Hb(d+264|0,d+364|0)){while(1){e=x[d+264>>2];e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|e>>>0>=A[d+416>>2])){x[d+416>>2]=e}e=d+264|0;je(e);if(Hb(e,d+364|0)){continue}break}}C=d,E=bc(l),x[C+264>>2]=E;C=d,E=dc(l),x[C+364>>2]=E;if(Hb(d+264|0,d+364|0)){while(1){e=x[d+264>>2];e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|e>>>0>=A[d+416>>2])){x[d+416>>2]=e}e=d+264|0;je(e);if(Hb(e,d+364|0)){continue}break}}T:{U:{if(v[d+542|0]&1){e=y[d+552|0]|y[d+553|0]<<8|(y[d+554|0]<<16|y[d+555|0]<<24);x[114409]=0;x[d+264>>2]=e;e=O(306,d+416|0,d+264|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break U}x[d+416>>2]=x[e>>2]}f=0;V:{W:{X:{e=y[d+536|0]|y[d+537|0]<<8;Y:{if((y[d+538|0]|y[d+539|0]<<8)!=532|(e?(e|0)!=532:0)|(y[d+527|0]|y[d+526|0])){break Y}if(y[d+540|0]&192|(y[d+549|0]|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)))){break Y}Z:{if(!(y[d+532|0]|y[d+533|0]<<8)|(y[d+530|0]|y[d+531|0]<<8)){break Z}if((x[b+8>>2]+(Lb(o)<<2)|0)+2>>>0>A[d+416>>2]){break Z}if(y[d+532|0]|y[d+533|0]<<8){e=0;while(1){x[114409]=0;f=S(413,b|0)|0;g=x[114409];x[114409]=0;_:{if((g|0)!=1){if(!f){break _}rg(b,((e&65535)<<2)+4|0);break Z}f=N()|0;break g}e=e+1|0;if((e&65535)>>>0<(y[d+532|0]|y[d+533|0]<<8)>>>0){continue}break}}x[114409]=0;e=O(2,d+404|0,10554)|0;f=x[114409];x[114409]=0;if((f|0)==1){break W}Eb(i,e);xb(e)}f=1;if(y[d+536|0]|y[d+537|0]<<8){break Y}x[114409]=0;e=O(2,d+392|0,11243)|0;g=x[114409];x[114409]=0;if((g|0)==1){break X}Eb(i,e);xb(e)}$:{aa:{ba:{if(y[d+542|0]&2){x[114409]=0;e=S(335,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break $}x[114409]=0;g=e<<3;h=O(231,b|0,g|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break $}if(!(!h|A[d+416>>2]<g+x[b+8>>2]>>>0)){x[114409]=0;g=a+1304500|0;P(638,g|0,e|0);h=x[114409];x[114409]=0;if((h|0)==1){break $}C=d,E=bc(g),x[C+364>>2]=E;C=d,E=dc(g),x[C+348>>2]=E;if(Hb(d+364|0,d+348|0)){while(1){g=x[d+364>>2];x[114409]=0;O(639,b|0,d+264|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break aa}x[114409]=0;P(640,d+264|0,g|0);g=x[114409];x[114409]=0;if((g|0)==1){break aa}g=d+364|0;x[g>>2]=x[g>>2]+48;if(Hb(g,d+348|0)){continue}break}}if(!(!e&f)){break ba}if(y[d+542|0]&4){x[114409]=0;e=O(2,d+380|0,11276)|0;f=x[114409];x[114409]=0;if((f|0)!=1){Eb(i,e);xb(e);break ba}f=N()|0;break g}x[114409]=0;e=O(2,d+380|0,10588)|0;f=x[114409];x[114409]=0;if((f|0)!=1){Eb(i,e);xb(e);break ba}f=N()|0;break g}rg(b,2);break ba}if(!f|(y[d+542|0]|y[d+543|0]<<8)>>>0>1){break ba}x[114409]=0;e=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break V}if(!e){x[114409]=0;e=O(2,d+380|0,10554)|0;f=x[114409];x[114409]=0;if((f|0)!=1){Eb(i,e);xb(e);break ba}f=N()|0;break g}rg(b,2)}ca:{if(!(y[d+540|0]&128|y[d+542|0]&8)){break ca}x[114409]=0;e=a+901404|0;f=O(641,b|0,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break h}if(!f){break ca}x[114409]=0;V(642,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break h}}if((y[d+536|0]|y[d+537|0]<<8)>>>0<=531){x[114409]=0;V(643,a+901404|0);e=x[114409];x[114409]=0;if((e|0)==1){break h}}x[114409]=0;t=S(247,d+364|0)|0;e=x[114409];x[114409]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){x[114409]=0;e=O(628,b|0,9651)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ja}if(e){x[114409]=0;e=S(413,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ia}x[114409]=0;T(316,d+264|0,b|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break ia}e=d+264|0;Zd(t,e);Ab(e)}w[a+480188>>1]=1;x[114409]=0;e=O(628,b|0,9656)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ja}if(e){x[114409]=0;e=S(413,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ha}x[114409]=0;T(316,d+264|0,b|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break ha}x[114409]=0;e=S(228,d+264|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ga}x[114409]=0;w[d+348>>1]=(e>>>0)/20;e=O(457,23700,d+348|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ga}e=z[e>>1];w[a+480188>>1]=e;if(e){f=0;while(1){x[114409]=0;U(644,d+264|0,((f<<5)+a|0)+480289|0,20)|0;g=x[114409];x[114409]=0;if((g|0)==1){break ga}f=f+1|0;if((e|0)!=(f|0)){continue}break}}Ab(d+264|0)}if(A[b+8>>2]>A[d+416>>2]){break fa}g=x[d+416>>2]-x[b+8>>2]|0;break ea}f=N()|0;break g}f=N()|0;break i}f=N()|0;break i}f=N()|0;break i}f=N()|0;Ab(d+264|0);break i}x[114409]=0;g=S(305,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break da}}x[114409]=0;T(316,d+348|0,b|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break da}x[114409]=0;u=O(645,a|0,d+348|0)|0;e=x[114409];x[114409]=0;ka:{la:{if((e|0)==1){break la}if(!(v[d+542|0]&1)|!(y[d+550|0]|y[d+551|0]<<8)){break ka}e=y[d+552|0]|y[d+553|0]<<8|(y[d+554|0]<<16|y[d+555|0]<<24);x[114409]=0;e=O(229,b|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break la}if(!e){break ka}e=y[d+550|0]|y[d+551|0]<<8;x[114409]=0;Z(584,a+1304424|0,b|0,e|0,4)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break ka}}f=N()|0;break j}w[a+480192>>1]=0;ma:{if(y[d+540|0]&4){e=y[d+530|0]|y[d+531|0]<<8;x[114409]=0;w[d+264>>1]=e;w[d+252>>1]=255;e=O(457,d+264|0,d+252|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ma}w[a+480192>>1]=z[e>>1]}na:{oa:{if(z[a+480192>>1]){f=0;while(1){e=Pb(r,f);pa:{if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break pa}e=Pb(r,f);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;e=O(229,b|0,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break na}if(!e){break pa}x[114409]=0;e=O(231,b|0,554)|0;g=x[114409];x[114409]=0;if((g|0)==1){break na}if(!e){break pa}x[114409]=0;e=U(427,a|0,f+1&65535,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break oa}if(!e){break pa}g=y[d+538|0]|y[d+539|0]<<8;x[114409]=0;Z(646,a|0,b|0,e|0,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break oa}v[e+33|0]=y[d+549|0]}f=f+1|0;if(f>>>0<z[a+480192>>1]){continue}break}}x[d+344>>2]=0;if(y[d+532|0]|y[d+533|0]<<8){e=Pb(o,(y[d+532|0]|y[d+533|0]<<8)-1|0);x[d+344>>2]=(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))+80}e=y[d+532|0]|y[d+533|0]<<8;x[114409]=0;w[d+264>>1]=e;w[d+252>>1]=3999;e=O(457,d+264|0,d+252|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){w[a+480190>>1]=z[e>>1];g=0;qa:{if(z[a+480190>>1]){j=c&2;q=d+284|0;f=0;while(1){e=Pb(o,f);ra:{if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break ra}e=Pb(o,f);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;e=O(229,b|0,e|0)|0;h=x[114409];x[114409]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{if((h|0)==1){break ya}if(!e){break ra}x[114409]=0;e=O(647,b|0,d+264|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ya}if(!e){break ra}x[114409]=0;k=f+1|0;e=D(k,104)+a|0;h=e+484380|0;n=O(648,d+264|0,h|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break xa}x[114409]=0;T(635,d+240|0,3,q|0);m=x[114409];x[114409]=0;if((m|0)==1){break wa}x[114409]=0;P(370,d+252|0,d+240|0);m=x[114409];x[114409]=0;if((m|0)==1){break wa}x[114409]=0;O(348,((k<<5)+a|0)+946304|0,d+252|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break va}xb(d+252|0);x[114409]=0;n=O(229,b|0,n|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break xa}if(!n){break ra}e=z[e+484414>>1];if(!(e&512)){break ua}x[114409]=0;e=O(649,b|0,d+252|0)|0;k=x[114409];x[114409]=0;if((k|0)!=1){if(!e){break ta}x[114409]=0;x[d+16>>2]=y[d+260|0]|y[d+261|0]<<8|(y[d+262|0]<<16|y[d+263|0]<<24);e=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[d+8>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);x[d+12>>2]=e;T(650,h|0,1,d+8|0);e=x[114409];x[114409]=0;if((e|0)!=1){break ta}}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;xb(d+252|0);break j}if(!(e&16384)){e=y[d+536|0]|y[d+537|0]<<8;x[114409]=0;T(651,d+252|0,d+264|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break k}za:{if(j){e=0;x[114409]=0;U(376,d+252|0,h|0,b|0)|0;k=x[114409];x[114409]=0;if((k|0)!=1){break za}break k}e=1;k=y[d+255|0];if(k>>>0>18){break za}k=1<<k;Aa:{if(!(k&126991)){if(k&396800){break Aa}break za}if(!y[d+252|0]){break za}}e=x[h>>2];x[114409]=0;k=O(652,d+252|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}e=0;x[114409]=0;O(313,b|0,k|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break k}}if(y[d+255|0]!=1){break sa}g=x[h>>2]!=0|g;break sa}x[114409]=0;O(653,b|0,d+164|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}e=x[d+164>>2];if(!(!j|!e)){e=Xb(d+252|0);x[114409]=0;U(461,b|0,e|0,x[d+164>>2])|0;h=x[114409];x[114409]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((h|0)!=1){x[114409]=0;h=O(2,d+216|0,12291)|0;n=x[114409];x[114409]=0;if((n|0)==1){break Ja}x[114409]=0;P(192,d+228|0,h|0);n=x[114409];x[114409]=0;if((n|0)==1){break Ia}x[114409]=0;x[d+152>>2]=k;T(13,d+204|0,0,e|0);k=x[114409];x[114409]=0;if((k|0)==1){break Ha}x[114409]=0;W(654,d+240|0,d+228|0,d+152|0,d+204|0);k=x[114409];x[114409]=0;if((k|0)==1){break Ga}x[114409]=0;T(655,a|0,2,d+240|0);k=x[114409];x[114409]=0;if((k|0)==1){break Fa}xb(d+240|0);xb(d+204|0);Gb(d+228|0);xb(h);xb(e);break ta}f=N()|0;break Ba}f=N()|0;break Ba}f=N()|0;break Ca}f=N()|0;break Da}f=N()|0;break Ea}f=N()|0;xb(d+240|0)}xb(d+204|0)}Gb(d+228|0)}xb(h)}xb(e);break j}x[114409]=0;O(313,b|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}}e=0}h=x[b+8>>2];x[114409]=0;x[d+252>>2]=h;h=O(656,d+344|0,d+252|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break qa}x[d+344>>2]=x[h>>2];B=(e|0)!=0}f=f+1|0;if(f>>>0<z[a+480190>>1]){continue}break}}w[d+264>>1]=1;e=z[a+480190>>1];x[114409]=0;w[d+252>>1]=e;e=O(424,d+264|0,d+252|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){w[a+480190>>1]=z[e>>1];Ka:{La:{if(!(g&1)|(y[d+536|0]|y[d+537|0]<<8)!=516|(y[d+542|0]|y[d+543|0]<<8|(y[d+538|0]|y[d+539|0]<<8)!=512)){break La}if(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)|((y[d+540|0]|y[d+541|0]<<8)&65527)!=21|(y[d+544|0]!=128|y[d+545|0]!=48)){break La}if(y[d+549|0]|y[d+548|0]!=128|(y[d+550|0]|y[d+551|0]<<8)){break La}g=d+624|0;e=d+560|0;f=1;while(1){f=(y[e|0]&127)==32&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=d+688|0;while(1){f=y[g|0]==64&f;g=g+1|0;if((e|0)!=(g|0)){continue}break}g=20;while(1){f=!y[(d+g|0)+500|0]&f;g=g+1|0;if(g>>>0<26){continue}break}if(!f){break La}x[114409]=0;e=O(2,d+252|0,5841)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ka}Eb(i,e);xb(e)}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;C=d,E=Lb(l),w[C+264>>1]=E;e=x[a+8>>2];x[114409]=0;e=O(457,d+264|0,e+10|0)|0;f=x[114409];x[114409]=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((f|0)!=1){e=z[e>>1];w[d+202>>1]=e;if((Lb(l)|0)!=(e|0)){x[114409]=0;P(489,d+264|0,12067);e=x[114409];x[114409]=0;if((e|0)==1){break Ua}e=Lb(l);x[114409]=0;x[d+228>>2]=e;W(657,d+188|0,d+264|0,d+228|0,d+202|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ta}x[114409]=0;e=O(658,d+240|0,d+188|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Sa}x[114409]=0;P(634,a|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ra}xb(e);xb(d+188|0);Gb(d+264|0)}if(c&1){break Oa}w[d+202>>1]=0;break Na}f=N()|0;break j}f=N()|0;break j}f=N()|0;break Pa}f=N()|0;break Qa}f=N()|0;xb(e)}xb(d+188|0)}Gb(d+264|0);break j}if(!z[d+202>>1]){break Na}e=0;while(1){c=Pb(l,e);Va:{if(!(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))){break Va}c=Pb(l,e);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114409]=0;c=O(229,b|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ma}if(!c){break Va}x[114409]=0;c=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break m}x[114409]=0;h=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break n}if((h-1025&65535)>>>0<64512){break Va}x[114409]=0;f=O(313,b|0,4)|0;g=x[114409];x[114409]=0;if((g|0)==1){break n}if(!f){break Va}x[114409]=0;T(316,d+264|0,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break o}c=0;f=z[a+480188>>1];x[114409]=0;g=O(659,d+228|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break q}while(1){Wa:{x[114409]=0;f=O(231,d+264|0,1)|0;j=x[114409];x[114409]=0;Xa:{Ya:{if((j|0)!=1){if(!f){break Wa}x[114409]=0;f=S(425,d+264|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break r}j=f<<24>>24;if(j){break Ya}c=c+1|0;break Xa}break r}Za:{f=j&127;k=f?f-1|0:0;f=k&65535;if(xc(g)>>>0>f>>>0){break Za}x[114409]=0;v[d+204|0]=0;T(660,g|0,f+1|0,d+204|0);q=x[114409];x[114409]=0;if((q|0)!=1){break Za}break r}if((j|0)<0){x[114409]=0;j=S(425,d+264|0)|0;q=x[114409];x[114409]=0;if((q|0)==1){break r}C=Cc(g,f),E=j,v[C|0]=E}if(!(!(y[Cc(g,f)|0]&15)|f>>>0<z[a+480188>>1])){w[a+480188>>1]=k+1}if(v[Cc(g,f)|0]&1){x[114409]=0;O(313,d+264|0,1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break r}}if(y[Cc(g,f)|0]&2){x[114409]=0;O(313,d+264|0,1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break r}}if(y[Cc(g,f)|0]&4){x[114409]=0;O(313,d+264|0,1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break r}}if(!(y[Cc(g,f)|0]&8)){break Xa}x[114409]=0;O(313,d+264|0,2)|0;f=x[114409];x[114409]=0;if((f|0)==1){break r}}if(c>>>0<h>>>0){continue}}break}c=x[b+8>>2];x[114409]=0;x[d+204>>2]=c;c=O(656,d+344|0,d+204|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break r}x[d+344>>2]=x[c>>2];de(g);Ab(d+264|0)}e=e+1|0;if(e>>>0<z[d+202>>1]){continue}break}}_a:{$a:{c=x[d+344>>2];if(!c){break $a}x[114409]=0;O(229,b|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break s}if(!B){break $a}while(1){ab:{x[114409]=0;c=O(231,b|0,4)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ab}if(!c){break $a}x[114409]=0;c=O(628,b|0,9630)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ab}bb:{if(!c){x[114409]=0;c=O(628,b|0,9635)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ab}if(!c){break bb}}x[114409]=0;c=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break _a}rg(b,8);if(c&-2139062144){break bb}if(c&1616928864){break $a}}x[114409]=0;c=S(335,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ab}x[114409]=0;O(313,b|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){continue}}break}f=N()|0;break j}x[114409]=0;c=O(661,a|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}c=c|y[d+495|0];v[d+495|0]=c;if(!(!(c&255)|u)){zu(a+1074312|0);x[a+1074372>>2]=0}x[114409]=0;W(662,a|0,b|0,0,d+495|0);c=x[114409];x[114409]=0;if((c|0)==1){break s}x[114409]=0;k=a+484344|0;P(377,k|0,z[d+202>>1]);c=x[114409];x[114409]=0;if((c|0)==1){break s}w[d+128>>1]=0;if(!z[d+202>>1]){break T}f=0;while(1){cb:{db:{c=Pb(l,f&65535);eb:{if(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)){c=Pb(l,z[d+128>>1]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114409]=0;c=O(229,b|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break eb}if(c){break db}}x[114409]=0;c=U(378,k|0,z[d+128>>1],64)|0;e=x[114409];x[114409]=0;if((e|0)==1){break eb}if(!c){x[114409]=0;P(489,d+264|0,11508);c=x[114409];x[114409]=0;fb:{gb:{hb:{ib:{jb:{if((c|0)!=1){x[114409]=0;T(663,d+176|0,d+264|0,d+128|0);c=x[114409];x[114409]=0;if((c|0)==1){break jb}x[114409]=0;c=O(658,d+204|0,d+176|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ib}x[114409]=0;P(634,a|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break hb}xb(c);xb(d+176|0);Gb(d+264|0);break T}f=N()|0;break j}f=N()|0;break fb}f=N()|0;break gb}f=N()|0;xb(c)}xb(d+176|0)}Gb(d+264|0);break j}c=Zb(k,z[d+128>>1]);x[114409]=0;P(664,c|0,t|0);c=x[114409];x[114409]=0;if((c|0)!=1){break cb}}f=N()|0;break j}x[114409]=0;c=S(335,b|0)|0;e=x[114409];x[114409]=0;kb:{lb:{if((e|0)!=1){x[114409]=0;q=S(335,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break lb}x[114409]=0;e=O(313,b|0,4)|0;f=x[114409];x[114409]=0;if((f|0)==1){break lb}if(!e){break cb}x[114409]=0;e=U(378,k|0,z[d+128>>1],q|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break lb}if(e){break kb}break cb}f=N()|0;break j}f=N()|0;break j}x[114409]=0;T(316,d+264|0,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=Zb(k,z[d+128>>1]);x[114409]=0;P(664,c|0,t|0);c=x[114409];x[114409]=0;mb:{if((c|0)!=1){c=z[a+480188>>1];x[114409]=0;j=O(659,d+164|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){c=z[a+480188>>1];e=d+204|0;di(e);x[114409]=0;h=U(665,d+152|0,c|0,e|0)|0;c=x[114409];x[114409]=0;nb:{if((c|0)!=1){C=d,E=bc(Zb(k,z[d+128>>1])),x[C+140>>2]=E;n=0;ob:{if(!q){break ob}while(1){x[114409]=0;c=O(231,d+264|0,1)|0;e=x[114409];x[114409]=0;pb:{if((e|0)!=1){qb:{if(!c){break ob}x[114409]=0;c=S(425,d+264|0)|0;e=x[114409];x[114409]=0;rb:{if((e|0)!=1){c=c<<24>>24;if(c){break rb}uT(d+140|0,z[a+480188>>1]);n=n+1|0;break pb}break qb}sb:{e=c&127;g=e?e-1&65535:0;if(xc(j)>>>0>g>>>0){break sb}x[114409]=0;v[d+204|0]=0;e=g+1|0;T(660,j|0,e|0,d+204|0);f=x[114409];x[114409]=0;if((f|0)==1){break qb}f=d+204|0;di(f);x[114409]=0;T(666,h|0,e|0,f|0);e=x[114409];x[114409]=0;if((e|0)!=1){break sb}break qb}if((c|0)<0){x[114409]=0;c=S(425,d+264|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break qb}C=Cc(j,g),E=c,v[C|0]=E}e=d+204|0;di(e);if(g>>>0<z[a+480188>>1]){e=Sc(d+140|0,g)}if(y[Cc(j,g)|0]&16){C=e,E=y[Sc(h,g)|0],v[C|0]=E}if(y[Cc(j,g)|0]&32){C=e,E=y[Sc(h,g)+1|0],v[C+1|0]=E}if(y[Cc(j,g)|0]&64){C=e,E=y[Sc(h,g)+2|0],v[C+2|0]=E;C=e,E=y[Sc(h,g)+4|0],v[C+4|0]=E}if(v[Cc(j,g)|0]<0){C=e,E=y[Sc(h,g)+3|0],v[C+3|0]=E;C=e,E=y[Sc(h,g)+5|0],v[C+5|0]=E}if(v[Cc(j,g)|0]&1){x[114409]=0;c=S(425,d+264|0)|0;f=x[114409];x[114409]=0;tb:{ub:{if((f|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(x[a+480180>>2]&16777216)){break ub}f=c;break tb}break qb}f=253;if((c-121&255)>>>0<132){break tb}f=(c&255)!=253?c:0}v[e|0]=f;C=Sc(h,g),E=f,v[C|0]=E}if(y[Cc(j,g)|0]&2){x[114409]=0;c=S(425,d+264|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break qb}v[e+1|0]=c;C=Sc(h,g),E=c,v[C+1|0]=E}if(y[Cc(j,g)|0]&4){x[114409]=0;c=S(425,d+264|0)|0;f=x[114409];x[114409]=0;vb:{wb:{if((f|0)!=1){if(c>>>0>64){break wb}v[e+4|0]=c;v[e+2|0]=1;break vb}break qb}if(c<<24>>24<=-64){v[e+2|0]=2;v[e+4|0]=c^128;break vb}if(c>>>0<=74){v[e+2|0]=5;v[e+4|0]=c-65;break vb}if(c>>>0<=84){v[e+2|0]=6;v[e+4|0]=c-75;break vb}if(c>>>0<=94){v[e+2|0]=3;v[e+4|0]=c-85;break vb}if(c>>>0<=104){v[e+2|0]=4;v[e+4|0]=c-95;break vb}if(c>>>0<=114){v[e+2|0]=13;v[e+4|0]=c-105;break vb}if(c>>>0<=124){v[e+2|0]=12;v[e+4|0]=c-115;break vb}f=c+63|0;if((f&255)>>>0<=9){v[e+4|0]=f;v[e+2|0]=11;break vb}f=c+53|0;m=f&255;if(m>>>0<=9){v[e+4|0]=f;v[e+2|0]=8;if(!m|!x[a+1074308>>2]|A[a+1074308>>2]>18285140){break vb}v[e+2|0]=7;break vb}c=c+33|0;if((c&255)>>>0>9){break vb}v[e+4|0]=c;v[e+2|0]=15}c=y[e+2|0];C=Sc(h,g),E=c,v[C+2|0]=E;c=y[e+4|0];C=Sc(h,g),E=c,v[C+4|0]=E}if(!(y[Cc(j,g)|0]&8)){break pb}x[114409]=0;P(452,d+92|0,d+264|0);c=x[114409];x[114409]=0;if((c|0)!=1){xb:{c=ed(d+92|0);v[e+3|0]=y[d+92|0];v[e+5|0]=y[c|0];x[114409]=0;P(667,e|0,1);c=x[114409];x[114409]=0;if((c|0)==1){break xb}c=y[e+3|0];C=Sc(h,g),E=c,v[C+3|0]=E;c=y[e+5|0];C=Sc(h,g),E=c,v[C+5|0]=E;break pb}}}}f=N()|0;hm(h);break nb}if(n>>>0<q>>>0){continue}break}}hm(h);de(j);Ab(d+264|0);break cb}f=N()|0}de(j);break mb}f=N()|0;break mb}f=N()|0}Ab(d+264|0);break j}f=N()|0;break j}f=z[d+128>>1]+1|0;w[d+128>>1]=f;if(z[d+202>>1]>(f&65535)>>>0){continue}break}break T}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break i}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}c=a+1074308|0;yb:{zb:{if(!x[a+1074308>>2]){Ab:{if((y[d+536|0]|y[d+537|0]<<8)==2184){x[c>>2]=18284544;f=18284544;break Ab}f=x[c>>2]}if(!f){break zb}}if(!Yc(i)){break zb}x[114409]=0;e=O(2,d+140|0,13386)|0;f=x[114409];x[114409]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{if((f|0)!=1){x[114409]=0;P(215,d+128|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break Gb}x[114409]=0;T(3,d+264|0,e|0,d+128|0);f=x[114409];x[114409]=0;if((f|0)==1){break Fb}f=d+264|0;Eb(i,f);xb(f);xb(d+128|0);xb(e);if((y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))==1414548815|((y[d+536|0]|y[d+537|0]<<8)&61440)!=20480){break Bb}x[114409]=0;c=O(2,d+264|0,12754)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Db}x[114409]=0;O(164,i|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Cb}xb(c);break yb}f=N()|0;break j}f=N()|0;break Eb}f=N()|0;xb(d+128|0)}xb(e);break j}f=N()|0;break j}f=N()|0;xb(c);break j}if(!OD(c)){break yb}x[114409]=0;c=O(2,d+264|0,12990)|0;e=x[114409];x[114409]=0;Hb:{if((e|0)!=1){x[114409]=0;O(164,i|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Hb}xb(c);break yb}f=N()|0;break j}f=N()|0;xb(c);break j}Ib:{Jb:{Kb:{Lb:{switch((y[d+536|0]|y[d+537|0]<<8)>>>12|0){case 0:if(u){x[114409]=0;c=O(2,d+264|0,4545)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break yb}f=N()|0;break j}Mb:{if((y[d+536|0]|y[d+537|0]<<8)!=532|(y[d+538|0]|y[d+539|0]<<8)!=512|(y[d+542|0]|y[d+543|0]<<8|(y[d+540|0]|y[d+541|0]<<8)!=9)){break Mb}if(y[d+527|0]|y[d+526|0]|(y[d+530|0]|y[d+531|0]<<8|((y[d+534|0]|y[d+535|0]<<8)+1|0)!=(y[d+528|0]|y[d+529|0]<<8))){break Mb}if(y[d+544|0]!=128|y[d+545|0]!=100|(y[d+546|0]!=1|y[d+548|0]!=128)){break Mb}if(y[d+549|0]|(y[d+550|0]|y[d+551|0]<<8)|(y[d+552|0]|y[d+553|0]<<8|(y[d+554|0]<<16|y[d+555|0]<<24)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)))){break Mb}x[114409]=0;c=O(2,d+264|0,5822)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break yb}f=N()|0;break j}Nb:{if((y[d+536|0]|y[d+537|0]<<8)!=532|(y[d+538|0]|y[d+539|0]<<8)!=512|(y[d+527|0]|y[d+526|0])){break Nb}if(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)){break Nb}x[c>>2]=16777381;x[114409]=0;c=O(2,d+264|0,10423)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);v[d+495|0]=1;break yb}f=N()|0;break j}if(!((y[d+536|0]|y[d+537|0]<<8)!=532|(y[d+538|0]|y[d+539|0]<<8)!=532|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=1229080643)){x[114409]=0;c=O(2,d+264|0,4597)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break Ib}f=N()|0;break j}Ob:{if((y[d+536|0]|y[d+537|0]<<8)!=532|(y[d+538|0]|y[d+539|0]<<8)!=532|(y[d+549|0]|(y[d+542|0]|y[d+543|0]<<8)>>>0>1)){break Ob}if(!z[a+480190>>1]|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24)|((y[d+540|0]|y[d+541|0]<<8)&4294)!=4)){break Ob}x[114409]=0;c=O(122,d+140|0,9327)|0;e=x[114409];x[114409]=0;Pb:{Qb:{if((e|0)!=1){x[114409]=0;e=O(668,a+484527|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Qb}xb(c);if(!e){break Ob}x[114409]=0;c=O(2,d+264|0,4623)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Pb}Eb(i,c);xb(c);break yb}f=N()|0;break j}f=N()|0;xb(c);break j}f=N()|0;break j}Rb:{if(y[d+536|0]|y[d+537|0]<<8){break Rb}if(!Yc(i)){break Rb}x[114409]=0;c=O(2,d+264|0,5662)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break yb}f=N()|0;break j}if((y[d+538|0]|y[d+539|0]<<8)>>>0>767){break yb}if(!Yc(i)){break yb}Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if((y[d+538|0]|y[d+539|0]<<8)>>>0>=533){x[114409]=0;c=O(2,d+128|0,10524)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);break Yb}f=N()|0;break j}if((y[d+536|0]|y[d+537|0]<<8)>>>0>=533){x[114409]=0;c=O(2,d+116|0,11356)|0;e=x[114409];x[114409]=0;Zb:{_b:{$b:{if((e|0)!=1){x[114409]=0;P(192,d+128|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break $b}e=y[d+536|0]|y[d+537|0]<<8;x[114409]=0;x[d+92>>2]=e-532;T(218,d+264|0,d+128|0,d+92|0);e=x[114409];x[114409]=0;if((e|0)==1){break _b}e=d+264|0;Eb(i,e);xb(e);Gb(d+128|0);break Yb}f=N()|0;break j}f=N()|0;break Zb}f=N()|0;Gb(d+128|0)}xb(c);break j}x[114409]=0;c=O(2,d+104|0,11020)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Xb}x[114409]=0;P(192,d+128|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break Wb}x[d+56>>2]=y[d+537|0]&15;e=y[d+536|0];x[114409]=0;x[d+28>>2]=e;P(669,d+92|0,d+28|0);e=x[114409];x[114409]=0;if((e|0)==1){break Vb}x[114409]=0;W(654,d+264|0,d+128|0,d+56|0,d+92|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ub}e=d+264|0;Eb(i,e);xb(e);xb(d+92|0);Gb(d+128|0)}xb(c);c=a+1304500|0;if(!kd(c)|!(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))){break yb}e=y[d+536|0]|y[d+537|0]<<8;f=y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24);x[114409]=0;e=O(670,e|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Jb}f=Hq(d+264|0);x[f+44>>2]=e;x[114409]=0;P(671,c|0,f|0);c=x[114409];x[114409]=0;if((c|0)!=1){break yb}f=N()|0;break j}f=N()|0;break j}f=N()|0;break Sb}f=N()|0;break Tb}f=N()|0;xb(d+92|0)}Gb(d+128|0)}xb(c);break j;case 1:c=y[d+536|0]|y[d+537|0]<<8;e=y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24);x[114409]=0;T(672,d+264|0,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=d+264|0;Eb(i,c);xb(c);if((y[d+536|0]|y[d+537|0]<<8)>>>0>=6092){break Kb}x[114409]=0;O(459,a+1074312|0,7)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break Kb}break s}f=N()|0;break j;case 4:x[114409]=0;c=O(2,d+80|0,11084)|0;e=x[114409];x[114409]=0;ac:{bc:{cc:{dc:{ec:{if((e|0)!=1){x[114409]=0;P(192,d+140|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break ec}x[d+92>>2]=y[d+537|0]&15;e=y[d+536|0];x[114409]=0;x[d+56>>2]=e;P(669,d+128|0,d+56|0);e=x[114409];x[114409]=0;if((e|0)==1){break dc}x[114409]=0;W(654,d+264|0,d+140|0,d+92|0,d+128|0);e=x[114409];x[114409]=0;if((e|0)==1){break cc}e=d+264|0;Eb(i,e);xb(e);xb(d+128|0);Gb(d+140|0);xb(c);break yb}f=N()|0;break j}f=N()|0;break ac}f=N()|0;break bc}f=N()|0;xb(d+128|0)}Gb(d+140|0)}xb(c);break j;case 6:x[114409]=0;c=O(2,d+264|0,4545)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break yb}f=N()|0;break j;case 7:if(!((y[d+536|0]|y[d+537|0]<<8)!=32767|(y[d+538|0]|y[d+539|0]<<8)!=533)){x[114409]=0;c=O(2,d+264|0,1549)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break yb}f=N()|0;break j}x[114409]=0;c=O(2,d+68|0,10634)|0;e=x[114409];x[114409]=0;fc:{gc:{hc:{if((e|0)!=1){x[114409]=0;P(192,d+140|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break hc}x[d+128>>2]=y[d+537|0]&15;x[d+92>>2]=(y[d+536|0]|y[d+537|0]<<8)>>>4&15;e=y[d+536|0]|y[d+537|0]<<8;x[114409]=0;x[d+56>>2]=e&15;ba(212,d+264|0,d+140|0,d+128|0,d+92|0,d+56|0);e=x[114409];x[114409]=0;if((e|0)==1){break gc}e=d+264|0;Eb(i,e);xb(e);Gb(d+140|0);xb(c);break yb}f=N()|0;break j}f=N()|0;break fc}f=N()|0;Gb(d+140|0)}xb(c);break j;case 13:break Lb;default:break yb}}x[114409]=0;c=O(2,d+264|0,2516)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(i,c);xb(c);break yb}f=N()|0;break j}c=y[d+536|0]|y[d+537|0]<<8;if((tT(4096)|0)>(c|0)){break Ib}break yb}f=N()|0;break j}x[114409]=0;O(459,a+1074312|0,38)|0;c=x[114409];x[114409]=0;if((c|0)==1){break s}}ic:{if(x[a+480180>>2]!=16777216|(y[d+536|0]|y[d+537|0]<<8)>>>0<2186){break ic}x[114409]=0;c=O(229,b|0,s|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}if(!c){break ic}c=y[d+536|0]|y[d+537|0]<<8;x[114409]=0;T(673,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break s}}c=x[a+480180>>2];jc:{if((c|0)==16777216){x[114409]=0;O(2,d+92|0,9613)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break jc}f=N()|0;break j}x[114409]=0;b=O(2,d+44|0,11020)|0;e=x[114409];x[114409]=0;if((e|0)==1){break z}x[114409]=0;P(192,d+56|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break y}x[d+40>>2]=y[d+539|0];e=y[d+538|0];x[114409]=0;x[d+24>>2]=e;P(669,d+28|0,d+24|0);e=x[114409];x[114409]=0;if((e|0)==1){break x}x[114409]=0;W(654,d+92|0,d+56|0,d+40|0,d+28|0);e=x[114409];x[114409]=0;if((e|0)==1){break w}}b=d+92|0;Eb(a+1304436|0,b);xb(b);if((c|0)!=16777216){xb(d+28|0);Gb(d+56|0);xb(d+44|0)}b=x[a+480180>>2];x[114409]=0;b=O(2,d+92|0,((b|0)==16777216?6105:2520)|0)|0;c=x[114409];x[114409]=0;f=1;if((c|0)==1){break t}Eb(a+1304448|0,b);xb(b);Eb(a+1304460|0,i);x[a+1304496>>2]=x[a+1074308>>2]?7:4;Ab(d+348|0);Ab(t)}_i(l);_i(o);_i(r);break d}f=N()|0;break j}f=N()|0;break u}f=N()|0;break v}f=N()|0;xb(d+28|0)}Gb(d+56|0)}xb(b);break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;de(g);break p}f=N()|0}Ab(d+264|0);break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0}Ab(d+348|0)}Ab(t);break g}f=N()|0}_i(l);_i(o);_i(r);break a}f=N()|0;break a}f=N()|0;break a}xb(i)}hb=d+688|0;return f|0}f=N()|0}xb(i);Q(f|0);p()}function mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=hb-1600|0;hb=d;Nc(b);a:{b:{if(!Mf(b,d+1592|0)){break b}if(!TR(d+1592|0)){break b}if(!c){g=1;break b}e=y[d+1595|0];v[d+1591|0]=e;x[d+1584>>2]=-1;x[d+1580>>2]=1048576;if(e>>>0>=5){e=Kf(b);x[d+1584>>2]=e;if(!Qb(b,e)){break b}x[d+208>>2]=134217727;L=d,M=x[Mb(d+208|0,d+1584|0)>>2]<<5,x[L+1580>>2]=M}G=br(d+1568|0);e=d+1596|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;x[d+208>>2]=f;f=O(306,d+1580|0,d+208|0)|0;g=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}f=x[f>>2];x[114409]=0;P(854,G|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break x}e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);g=0;x[114409]=0;e=U(855,b|0,G|0,e|0)|0;f=x[114409];x[114409]=0;y:{if((f|0)==1){break y}if(!e){break t}if(y[d+1591|0]>=5){x[114409]=0;O(229,b|0,x[d+1584>>2]+12|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break y}}x[114409]=0;P(419,a|0,0);e=x[114409];x[114409]=0;if((e|0)==1){break y}x[114409]=0;V(456,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break y}x[114409]=0;P(856,d+1544|0,G|0);e=x[114409];x[114409]=0;z:{A:{B:{C:{if((e|0)==1){break C}x[114409]=0;l=U(857,d+1552|0,d+1544|0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break C}x[114409]=0;U(596,l|0,a+1304400|0,-1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break B}x[114409]=0;U(596,l|0,a+1304424|0,-1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break B}x[114409]=0;e=O(858,l|0,d+1122|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break w}if(!e|!y[d+1122|0]|v[d+1122|0]<0){break u}e=d+1131|0;if((y[e|0]|y[e+1|0]<<8)>>>0>255){break u}f=d+1133|0;if((y[f|0]|y[f+1|0]<<8)>>>0>3999){break u}w[a+480188>>1]=y[d+1122|0];j=a+484360|0;h=d+1125|0;Pe(Wb(j),y[h|0]|y[h+1|0]<<8);w[a+480192>>1]=y[e|0]|y[e+1|0]<<8;w[a+480190>>1]=y[f|0]|y[f+1|0]<<8;e=d+1135|0;if(y[e|0]){break A}e=6;break z}e=N()|0;break c}e=N()|0;break d}e=y[e|0]}x[a+480196>>2]=e;e=d+1136|0;if(y[e|0]){e=y[e|0]}else{e=125}x[a+480204>>2]=D(e,1e4);r=d+1137|0;e=32;D:{if(v[r+1|0]&1){break D}e=2;if(y[r|0]&2){break D}e=1;if(y[r|0]&128){break D}e=y[r|0]&8?16:4}x[114409]=0;P(631,a|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break w}x[a+480208>>2]=x[a+480208>>2]|16777216;if(v[r|0]&1){x[a+480208>>2]=x[a+480208>>2]|16}if(!(!(y[r|0]&16)|x[a+480180>>2]!=2)){x[a+480208>>2]=x[a+480208>>2]|65536}if(!(!(y[r|0]&4)|x[a+480180>>2]!=2)){x[a+480208>>2]=x[a+480208>>2]|2}if(!(y[r+1|0]&8|x[a+480180>>2]!=32)){x[a+480208>>2]=x[a+480208>>2]|4}if(!(y[r+1|0]&4|x[a+480180>>2]!=32)){x[a+480208>>2]=x[a+480208>>2]|8}if(y[r+2|0]&32){x[a+480208>>2]=x[a+480208>>2]|32768}if(y[r+2|0]&8){x[114409]=0;U(458,a+1074312|0,5,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}}E:{e=x[a+480180>>2];F:{if((e|0)!=2){if((e|0)!=32){break F}e=y[d+1141|0];x[114409]=0;v[d+208|0]=e;v[d+148|0]=128;e=O(431,d+208|0,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){x[a+480200>>2]=y[e|0]<<1;break F}e=N()|0;break d}e=y[d+1141|0];x[114409]=0;v[d+208|0]=e;v[d+148|0]=64;e=O(431,d+208|0,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break E}x[a+480200>>2]=y[e|0]<<2}I=a+480188|0;f=d+1143|0;e=v[f|0];if(v[f|0]<0){e=e+52|0}else{H=rs(+(e|0)*.15500000000000003);G:{if(H<4294967296&H>=0){e=~~H>>>0;break G}e=0}e=e+51|0}x[a+480228>>2]=e;x[114409]=0;w[d+208>>1]=64;e=O(457,I|0,d+208|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){H:{f=z[e>>1];if(f){while(1){e=x[a+480180>>2];if((e|0)==32){e=y[(d+g|0)+1144|0];x[114409]=0;v[d+208|0]=e;v[d+148|0]=64;e=O(431,d+208|0,d+148|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break H}w[((g<<5)+a|0)+480286>>1]=y[e|0];e=x[a+480180>>2]}I:{if((e|0)==4){break I}e=(d+g|0)+1208|0;if(y[e|0]==127){x[((g<<5)+a|0)+480280>>2]=256;break I}if(y[e|0]==255){w[((g<<5)+a|0)+480284>>1]=256;break I}w[((g<<5)+a|0)+480284>>1]=y[e|0]}g=g+1|0;if((f|0)!=(g|0)){continue}break}}g=0;h=0;while(1){g=y[(d+h|0)+1272|0]!=0|g;h=h+1|0;if((h|0)!=16){continue}break}while(1){g=y[((i<<1)+d|0)+1289|0]!=0|g;i=i+1|0;if((i|0)!=128){continue}break}if(g&1){g=0;while(1){J:{e=(d+g|0)+1272|0;if(y[e|0]){x[114409]=0;P(489,d+148|0,1425);f=x[114409];x[114409]=0;K:{L:{M:{N:{O:{if((f|0)!=1){e=y[e|0];x[114409]=0;x[d+168>>2]=e-1;P(859,d+1080|0,d+168|0);e=x[114409];x[114409]=0;if((e|0)==1){break O}x[114409]=0;T(491,d+208|0,d+148|0,d+1080|0);e=x[114409];x[114409]=0;if((e|0)==1){break N}x[114409]=0;P(492,d+1064|0,((g<<5)+a|0)+901692|0);e=x[114409];x[114409]=0;if((e|0)==1){break M}x[114409]=0;O(450,d+1064|0,d+208|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break M}xb(d+208|0);xb(d+1080|0);Gb(d+148|0);break J}e=N()|0;break d}e=N()|0;break K}e=N()|0;break L}e=N()|0;xb(d+208|0)}xb(d+1080|0)}Gb(d+148|0);break d}x[114409]=0;f=O(122,d+1108|0,17381)|0;e=x[114409];x[114409]=0;P:{if((e|0)!=1){x[114409]=0;P(492,d+208|0,((g<<5)+a|0)+901692|0);e=x[114409];x[114409]=0;if((e|0)==1){break P}x[114409]=0;O(450,d+208|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break P}xb(f);break J}e=N()|0;break d}e=N()|0;xb(f);break d}g=g+1|0;if((g|0)!=16){continue}break}g=0;while(1){Q:{e=(d+1122|0)+(g<<1)|0;if(y[e+167|0]){x[114409]=0;P(489,d+148|0,10850);f=x[114409];x[114409]=0;R:{S:{T:{U:{V:{W:{X:{if((f|0)!=1){f=y[e+167|0];x[114409]=0;x[d+124>>2]=f-1;P(859,d+1080|0,d+124|0);f=x[114409];x[114409]=0;if((f|0)==1){break X}e=y[e+166|0];x[114409]=0;v[d+1052|0]=e;P(860,d+1064|0,d+1052|0);e=x[114409];x[114409]=0;if((e|0)==1){break W}x[114409]=0;W(861,d+208|0,d+148|0,d+1080|0,d+1064|0);e=x[114409];x[114409]=0;if((e|0)==1){break V}x[114409]=0;P(492,d+168|0,((g<<5)+a|0)+902204|0);e=x[114409];x[114409]=0;if((e|0)==1){break U}x[114409]=0;O(450,d+168|0,d+208|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break U}xb(d+208|0);xb(d+1064|0);xb(d+1080|0);Gb(d+148|0);break Q}e=N()|0;break d}e=N()|0;break R}e=N()|0;break S}e=N()|0;break T}e=N()|0;xb(d+208|0)}xb(d+1064|0)}xb(d+1080|0)}Gb(d+148|0);break d}x[114409]=0;f=O(122,d+1096|0,17381)|0;e=x[114409];x[114409]=0;Y:{if((e|0)!=1){x[114409]=0;P(492,d+208|0,((g<<5)+a|0)+902204|0);e=x[114409];x[114409]=0;if((e|0)==1){break Y}x[114409]=0;O(450,d+208|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Y}xb(f);break Q}e=N()|0;break d}e=N()|0;xb(f);break d}g=g+1|0;if((g|0)!=128){continue}break}}e=Wb(j);f=d+1123|0;f=y[f|0]|y[f+1|0]<<8;x[114409]=0;aa(580,e|0,l|0,f|0,255,254)|0;e=x[114409];x[114409]=0;Z:{_:{$:{aa:{ba:{ca:{if((e|0)!=1){m=d+1127|0;e=y[m|0]|y[m+1|0]<<8;f=y[d+1122|0];x[114409]=0;T(316,d+1080|0,l|0,D(e,f)<<1);e=x[114409];x[114409]=0;if((e|0)==1){break ca}e=y[m|0]|y[m+1|0]<<8;x[114409]=0;T(316,d+1064|0,l|0,e<<1);e=x[114409];x[114409]=0;if((e|0)==1){break ba}e=d+1129|0;e=y[e|0]|y[e+1|0]<<8;x[114409]=0;E=O(375,d+1052|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break aa}L=d,M=bc(E),x[L+148>>2]=M;L=d,M=dc(E),x[L+168>>2]=M;if(Hb(d+148|0,d+168|0)){while(1){e=x[d+148>>2];x[114409]=0;f=S(413,l|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break $}x[114409]=0;T(316,d+208|0,l|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break _}f=e;e=d+208|0;Zd(f,e);Ab(e);e=d+148|0;sf(e);if(Hb(e,d+168|0)){continue}break}}e=x[a+480180>>2];j=1;o=c&1;if(!o){break Z}f=y[m|0]|y[m+1|0]<<8;x[114409]=0;P(377,a+484344|0,f|0);f=x[114409];x[114409]=0;if((f|0)!=1){break Z}e=N()|0;break g}e=N()|0;break d}e=N()|0;break d}e=N()|0;break e}e=N()|0;break f}e=N()|0;break g}e=N()|0;break g}da:{ea:{fa:{ga:{ha:{ia:{if(y[m|0]|y[m+1|0]<<8){C=(e|0)==16?14:(e|0)==32?1:13;t=a+484344|0;while(1){x[114409]=0;e=S(335,d+1064|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break da}x[d+148>>2]=e;ja:{if(!o){break ja}x[114409]=0;e=U(378,t|0,s&65535,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break da}if(!e){break ja}q=0;if(!y[d+1122|0]){break ja}while(1){x[114409]=0;e=S(335,d+1080|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ea}ka:{if(qd(E)>>>0<=e>>>0){break ka}k=wc(E,e);Nc(k);e=Zb(t,s);x[114409]=0;g=U(451,e|0,0,q&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}f=0;if(!x[d+148>>2]){break ka}while(1){x[114409]=0;n=S(425,k|0)|0;e=x[114409];x[114409]=0;la:{ma:{if((e|0)!=1){if(!n){break ka}di(d+208|0);h=0;u=n&15;if(u){break ma}break la}e=N()|0;break g}while(1){na:{x[114409]=0;O(862,k|0,d+168|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{e=y[d+168|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(e-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}e=y[d+169|0];Ja:{if(e>>>0<=119){v[d+208|0]=e+C;break Ja}Ka:{switch(e-254|0){case 1:v[d+208|0]=255;break Ja;case 0:v[d+208|0]=254;break Ja;default:break Ka}}v[d+208|0]=253}x[114409]=0;e=S(621,d+208|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break na}j=e&j;break oa}v[d+209|0]=y[d+169|0]+1;break oa}La:{if(y[d+210|0]){break La}e=x[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break La}e=y[d+169|0];if(e&15){break La}v[d+210|0]=11;v[d+212|0]=e>>>4;break oa}i=0;e=y[d+169|0];while(1){if((e|0)==y[i+25920|0]){v[d+212|0]=i;v[d+210|0]=11;break oa}i=i+1|0;if((i|0)!=10){continue}break}}v[d+211|0]=4;v[d+213|0]=y[d+169|0];break oa}e=y[d+169|0];if(!(y[d+210|0]|e>>>0>9|x[a+480180>>2]!=32)){v[d+212|0]=e;v[d+210|0]=8;break oa}v[d+213|0]=e;v[d+211|0]=5;break oa}if(y[d+210|0]){i=y[d+169|0];break pa}e=x[a+480180>>2];B=(e|0)!=32;i=y[d+169|0];if(!(B|(i|0)!=255)){v[d+212|0]=64;v[d+210|0]=2;break oa}Ma:{if(!B){if(i&3){break pa}break Ma}if(i&15|(e|0)!=4){break pa}}v[d+210|0]=2;v[d+212|0]=(i&252)>>>2;break oa}e=y[d+169|0];if(!(y[d+210|0]|e>>>0>64|x[a+480180>>2]==1)){v[d+212|0]=e;v[d+210|0]=1;break oa}v[d+213|0]=e;v[d+211|0]=13;break oa}v[d+211|0]=14;e=y[d+169|0];v[d+213|0]=e;if(x[a+480180>>2]==32){break oa}v[d+213|0]=D((e&240)>>>4|0,10)+(e&15);break oa}e=y[d+169|0];v[d+213|0]=e;if(e>>>0<=31){v[d+211|0]=16;break oa}v[d+211|0]=17;break oa}i=y[d+169|0];if(i>>>0>=16){v[d+212|0]=i>>>4;v[d+210|0]=(e|0)==20?3:5;break oa}v[d+212|0]=i;v[d+210|0]=(e|0)==20?4:6;break oa}e=y[d+169|0];if(e>>>0>=16){v[d+210|0]=10;v[d+212|0]=e>>>4;break oa}v[d+212|0]=e;v[d+210|0]=9;break oa}v[d+211|0]=28;v[d+213|0]=y[d+169|0]|16;break oa}v[d+211|0]=28;v[d+213|0]=y[d+169|0]|32;break oa}v[d+212|0]=y[d+169|0];v[d+210|0]=y[e+23872|0];break oa}v[d+213|0]=y[d+169|0];e=y[d+211|0];v[d+211|0]=(e|0)==4?6:(e|0)==5?7:11;break oa}e=y[d+169|0];v[d+212|0]=(e>>>0)%10;if(e>>>0<=9){v[d+210|0]=5;break oa}if(e>>>0<=19){v[d+210|0]=6;break oa}if(e>>>0<=29){v[d+210|0]=3;break oa}if(e>>>0>39){break oa}v[d+210|0]=4;break oa}v[d+212|0]=y[d+169|0];v[d+210|0]=y[e+23872|0];break oa}e=y[d+169|0]+33|0;if((e&255)>>>0>9){break oa}v[d+212|0]=e;v[d+210|0]=15;break oa}if(e>>>0>55){break oa}v[d+213|0]=y[d+169|0];v[d+211|0]=y[e+23872|0];break oa}v[d+213|0]=i;v[d+211|0]=9}h=h+1|0;if(u>>>0>(h&255)>>>0){continue}break la}break}e=N()|0;break g}x[114409]=0;x[d+168>>2]=(n>>>4|0)+f;e=O(306,d+168|0,d+148|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ia}e=x[e>>2];if(e>>>0>f>>>0){while(1){h=y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24);v[g|0]=h;v[g+1|0]=h>>>8;v[g+2|0]=h>>>16;v[g+3|0]=h>>>24;h=y[d+212|0]|y[d+213|0]<<8;v[g+4|0]=h;v[g+5|0]=h>>>8;g=D(y[d+1122|0],6)+g|0;f=f+1|0;if((e|0)!=(f|0)){continue}break}f=e}if(A[d+148>>2]>f>>>0){continue}break}}q=q+1|0;if(y[d+1122|0]>(q&65535)>>>0){continue}break}}s=s+1|0;if(s>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}}if(!(!(z[a+480188>>1]==4&j)|x[a+480180>>2]!=1)){x[a+480208>>2]=x[a+480208>>2]|8454144}if(x[a+480180>>2]!=4){break ha}h=0;break ga}e=N()|0;break g}h=!((y[r|0]|y[r+1|0]<<8|(y[r+2|0]<<16|y[r+3|0]<<24))&512);e=0;if(x[a+480180>>2]!=4){break fa}}e=z[a+480192>>1]}x[114409]=0;s=O(863,d+1040|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Na:{Oa:{Pa:{if(z[a+480192>>1]){f=1;e=1;while(1){Qa:{Ra:{Sa:{if(!h){x[114409]=0;i=U(427,a|0,e&65535,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Sa}if(i){break Ra}}while(1){x[114409]=0;f=S(425,l|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break j}if(f){continue}break}if(y[d+1591|0]>=5){while(1){x[114409]=0;f=S(425,l|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){e=N()|0;break i}if(f){continue}break}}x[114409]=0;O(313,l|0,826)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break Qa}}e=N()|0;break i}g=Xb(d+148|0);x[114409]=0;U(596,l|0,g|0,-1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break Pa}x[114409]=0;O(348,i+492|0,g|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break Pa}Ta:{if(y[d+1591|0]<5){break Ta}x[114409]=0;U(596,l|0,g|0,-1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break Pa}x[114409]=0;O(348,i+524|0,g|0)|0;j=x[114409];x[114409]=0;if((j|0)!=1){break Ta}break Pa}x[114409]=0;j=O(864,l|0,d+208|0)|0;q=x[114409];x[114409]=0;if((q|0)==1){break Pa}if(!j){break Oa}j=x[a+480180>>2];x[114409]=0;T(865,d+208|0,i|0,j|0);i=x[114409];x[114409]=0;if((i|0)==1){break Pa}if(x[a+480180>>2]==4){f=Pb(s,f-1|0);i=y[d+1010|0]|y[d+1011|0]<<8|(y[d+1012|0]<<16|y[d+1013|0]<<24);v[f|0]=i;v[f+1|0]=i>>>8;v[f+2|0]=i>>>16;v[f+3|0]=i>>>24}xb(g)}e=e+1|0;f=e&65535;if(f>>>0<=z[a+480192>>1]){continue}break}}if(!h){break Na}w[a+480192>>1]=0;break Na}e=N()|0;xb(g);break i}xb(g)}e=z[a+480190>>1];x[114409]=0;t=O(866,d+196|0,e|0)|0;e=x[114409];x[114409]=0;j=1;if((e|0)!=1){j=y[d+1591|0]<=4?!(v[r|0]&1):j;q=0;e=0;Ua:{if(!z[a+480190>>1]){break Ua}C=c&2;h=1;f=1;while(1){Va:{c=e;m=Xb(d+184|0);x[114409]=0;U(596,l|0,m|0,-1)|0;e=x[114409];x[114409]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((e|0)==1){break $a}x[114409]=0;O(348,((h<<5)+a|0)+946304|0,m|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break $a}if(y[d+1591|0]<5){break _a}x[114409]=0;U(596,l|0,m|0,-1)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break Za}}e=N()|0;break Ya}Xe(m)}x[114409]=0;e=O(867,l|0,d+208|0)|0;g=x[114409];x[114409]=0;ab:{bb:{cb:{db:{eb:{fb:{gb:{if((g|0)==1){break gb}if(!e){break fb}e=x[a+480180>>2];x[114409]=0;o=D(h,104);n=o+a|0;g=n+484380|0;W(868,d+208|0,g|0,e|0,j|0);e=x[114409];x[114409]=0;if((e|0)==1){break gb}x[114409]=0;O(350,n+484423|0,m|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break gb}i=0;hb:{if(((y[d+228|0]|y[d+229|0]<<8)&61440)!=28672|y[d+1591|0]<5){break hb}x[114409]=0;i=S(869,l|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break hb}e=N()|0;break Ya}if(!C){break Xa}u=y[d+228|0]|y[d+229|0]<<8;k=u&61440;if(!(k|(y[d+243|0]|y[d+244|0]<<8|(y[d+245|0]<<16|y[d+246|0]<<24)))){e=y[d+228|0]|y[d+229|0]<<8;e=cd(d+148|0,e&1?16:8,e&1024?3:1,0,0);x[114409]=0;U(376,e|0,g|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break Xa}e=N()|0;break Ya}e=y[d+243|0]|y[d+244|0]<<8|(y[d+245|0]<<16|y[d+246|0]<<24);if(!((e|0)>=0|(e+h|0)<=0)){i=a+484380|0;k=D((y[d+243|0]|y[d+244|0]<<8|(y[d+245|0]<<16|y[d+246|0]<<24))+h|0,104);e=i+k|0;zc(g,x[e>>2]);h=i+o|0;i=z[h+34>>1]&-2|w[e+34>>1]&1;w[h+34>>1]=i;w[h+34>>1]=i&65471|z[e+34>>1]&64;if(!He(e)){break Xa}x[114409]=0;e=S(438,g|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){if(!e){break Xa}e=x[n+484400>>2];x[114409]=0;e=S(439,e|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[(a+k|0)+484400>>2];x[114409]=0;h=S(870,h|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break a}sc(e,h,el(g));break Xa}e=N()|0;break Ya}if((y[d+243|0]|y[d+244|0]<<8|(y[d+245|0]<<16|y[d+246|0]<<24))<=0){break Xa}if(v[d+228|0]&1){e=n+484414|0;w[e>>1]=z[e>>1]|1}if(y[d+229|0]&4){e=n+484414|0;w[e>>1]=z[e>>1]|64}e=y[d+243|0]|y[d+244|0]<<8|(y[d+245|0]<<16|y[d+246|0]<<24);x[114409]=0;T(316,d+168|0,b|0,e|0);e=x[114409];x[114409]=0;ib:{jb:{kb:{lb:{if((e|0)!=1){e=Qe(g);B=(k|0)==16384;if(!B&(k|0)!=8192){break jb}x[114409]=0;o=S(228,d+168|0)|0;F=x[114409];x[114409]=0;if((F|0)==1){break ib}x[d+148>>2]=o;F=x[d+148>>2];o=4/(e>>>0)|0;if(F>>>0>4294967295/(o>>>0)>>>0){break lb}o=D(o,F);break kb}e=N()|0;break Ya}o=-1}x[d+148>>2]=o;zc(g,o);if(!B){if((k|0)!=8192){break jb}x[114409]=0;h=S(438,g|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break bb}if(!h){break db}h=x[n+484400>>2];g=x[g>>2];if(v[d+228|0]&1){x[114409]=0;W(871,d+168|0,h|0,g|0,e|0);g=x[114409];x[114409]=0;e=c;if((g|0)!=1){break cb}break bb}x[114409]=0;W(872,d+168|0,h|0,g|0,e|0);g=x[114409];x[114409]=0;e=c;if((g|0)==1){break bb}break cb}x[114409]=0;h=S(438,g|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break bb}if(!h){break db}h=x[n+484400>>2];g=x[g>>2];if(v[d+228|0]&1){x[114409]=0;W(873,d+168|0,h|0,g|0,e|0);g=x[114409];x[114409]=0;e=c;if((g|0)==1){break bb}break cb}x[114409]=0;W(874,d+168|0,h|0,g|0,e|0);g=x[114409];x[114409]=0;e=c;if((g|0)==1){break bb}break cb}if((u&45056)==12288){e=SR(d+148|0,d+168|0,y[d+247|0]|y[d+248|0]<<8,i);g=iA(t,h-1|0);Zd(g,e);x[g+16>>2]=x[e+16>>2];Ab(e);break db}if((k|0)!=32768){e=1;if((k|0)!=4096){break cb}e=d+168|0;h=hf(d+148|0,e);x[114409]=0;e=O(875,d+142|0,e|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){mb:{if(!y[d+147|0]){break mb}i=z[d+144>>1]<<1;if((i&65535)>>>0>(y[d+247|0]|y[d+248|0]<<8)>>>0){break mb}i=(y[d+247|0]|y[d+248|0]<<8)-i|0;v[d+247|0]=i;v[d+248|0]=i>>>8;e=z[e>>1];x[114409]=0;O(229,d+168|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break eb}x[114409]=0;e=S(305,d+168|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break eb}x[114409]=0;T(316,d+124|0,d+168|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break eb}e=d+124|0;Zd(h,e);Ab(e)}x[114409]=0;e=f&65535;i=aa(876,a|0,e|0,h|0,1,1)|0;k=x[114409];x[114409]=0;if((k|0)==1){break eb}nb:{if(!i){x[114409]=0;i=Z(877,a|0,e|0,h|0,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break eb}e=1;if(!i){break nb}}ob:{if(!(y[d+247|0]|y[d+248|0]<<8)){break ob}e=y[d+247|0]|y[d+248|0]<<8;if(el(g)>>>0<=e>>>0){break ob}e=y[d+247|0]|y[d+248|0]<<8;i=Ko(g);n=n+484400|0;k=x[n>>2];x[114409]=0;k=S(439,k|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break a}n=x[n>>2];x[114409]=0;n=S(439,n|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break a}vk(k,n+(y[d+247|0]|y[d+248|0]<<8)|0,el(g)-(y[d+247|0]|y[d+248|0]<<8)|0);x[g>>2]=x[g>>2]-((e>>>0)/(i>>>0)|0)}e=y[d+216|0]|y[d+217|0]<<8|(y[d+218|0]<<16|y[d+219|0]<<24);x[d+120>>2]=e;x[d+12>>2]=e;e=d+12|0;if(A[g>>2]>(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))>>>0){x[g>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)}e=c}Ab(h);break cb}break eb}x[114409]=0;e=O(649,d+168|0,d+148|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){if(!e){break db}x[114409]=0;x[d+24>>2]=y[d+156|0]|y[d+157|0]<<8|(y[d+158|0]<<16|y[d+159|0]<<24);e=y[d+152|0]|y[d+153|0]<<8|(y[d+154|0]<<16|y[d+155|0]<<24);x[d+16>>2]=y[d+148|0]|y[d+149|0]<<8|(y[d+150|0]<<16|y[d+151|0]<<24);x[d+20>>2]=e;T(650,g|0,1,d+16|0);e=x[114409];x[114409]=0;if((e|0)!=1){break db}}e=N()|0;break ab}e=N()|0;break ab}e=N()|0;break Ya}xb(m);g=z[a+480190>>1];e=c;break Va}e=N()|0;Ab(h);break ab}e=c}Ab(d+168|0);break Wa}e=N()|0}Ab(d+168|0)}xb(m);break k}e=c}xb(m);g=z[a+480190>>1];f=f+1|0;h=f&65535;if(g>>>0>=h>>>0){continue}}break}if(!C|!(g&65535)){break Ua}i=1;m=1;while(1){b=iA(t,i-1|0);x[114409]=0;c=S(312,b|0)|0;f=x[114409];x[114409]=0;pb:{qb:{rb:{if((f|0)!=1){if(!c){break pb}sb:{tb:{c=w[b+18>>1]+i|0;c=((c|0)>0?c:m)&65535;g=(c|0)!=(m&65535)&(c|0)!=0&c>>>0<=z[a+480190>>1]&z[b+16>>1]!=0;if(!g){x[114409]=0;S(228,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break tb}break l}c=iA(t,c-1|0);f=z[b+16>>1];Nc(c);h=z[b+16>>1];x[114409]=0;h=O(231,c|0,h|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break l}if(!h){break pb}x[114409]=0;x[d+148>>2]=0;x[d+168>>2]=0;T(878,d+208|0,c|0,f|0);f=x[114409];x[114409]=0;ub:{if((f|0)!=1){x[114409]=0;f=S(445,d+208|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ub}x[114409]=0;f=S(879,f|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ub}h=x[d+208>>2];x[114409]=0;h=S(880,h|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break ub}x[114409]=0;f=aa(881,f|0,h|0,d+148|0,d+168|0,0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ub}x[114409]=0;O(313,c|0,x[d+148>>2])|0;c=x[114409];x[114409]=0;if((c|0)==1){break ub}Jc(d+208|0);break sb}e=N()|0;break k}e=N()|0;Jc(d+208|0);break k}Nc(b);f=0;x[d+148>>2]=0;x[d+168>>2]=0}x[114409]=0;P(882,d+208|0,b|0);c=x[114409];x[114409]=0;vb:{wb:{if((c|0)!=1){x[114409]=0;j=S(445,d+208|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break vb}c=x[d+208>>2];if(!g){x[114409]=0;f=S(879,j|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break rb}x[114409]=0;g=S(880,c|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break rb}x[114409]=0;f=aa(881,f|0,g|0,d+148|0,d+168|0,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break rb}x[114409]=0;O(313,b|0,x[d+148>>2])|0;g=x[114409];x[114409]=0;if((g|0)==1){break rb}g=x[d+148>>2];c=c-g|0;j=g+j|0}if(f){break wb}e=1;break qb}e=N()|0;break k}x[114409]=0;g=D(i,104)+a|0;i=g+484380|0;S(438,i|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break rb}F=g+484400|0;J=g+484414|0;h=0;g=x[d+168>>2];while(1){xb:{if(A[i>>2]<=h>>>0|(!c|(g|0)!=1?g:0)){break xb}if(!He(i)){break xb}x[114409]=0;x[d+124>>2]=0;x[d+184>>2]=0;g=S(879,j|0)|0;n=x[114409];x[114409]=0;if((n|0)==1){break rb}x[114409]=0;n=S(880,c|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break rb}x[114409]=0;g=ga(883,f|0,g|0,n|0,d+124|0,d+60|0,d+184|0)|0;n=x[114409];x[114409]=0;if((n|0)==1){break rb}x[114409]=0;x[d+148>>2]=g;O(313,b|0,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break rb}g=x[i>>2];x[114409]=0;n=x[d+148>>2];g=S(884,g-h|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break rb}Fh(d+184|0,g);yb:{if(x[d+184>>2]<=0){break yb}if(x[d+124>>2]!=(Qe(i)|0)){break yb}g=0;if(x[d+124>>2]<=0){break yb}while(1){k=x[F>>2];K=z[J>>1];o=D(Qe(i),h);C=x[x[d+60>>2]+(g<<2)>>2];u=x[d+184>>2];B=x[d+124>>2];zb:{if(K&1){x[114409]=0;ba(885,k+(o<<1)|0,C|0,B|0,u|0,g|0);k=x[114409];x[114409]=0;if((k|0)!=1){break zb}break rb}x[114409]=0;ba(886,k+o|0,C|0,B|0,u|0,g|0);k=x[114409];x[114409]=0;if((k|0)==1){break rb}}g=g+1|0;if((g|0)<x[d+124>>2]){continue}break}}x[114409]=0;k=x[d+184>>2];g=S(887,f|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break rb}c=c-n|0;j=j+n|0;x[d+168>>2]=g;h=h+k|0;continue}break}x[114409]=0;V(888,f|0);b=x[114409];x[114409]=0;if((b|0)!=1){break qb}break rb}break rb}e=N()|0;break k}e=N()|0;Jc(d+208|0);break k}Jc(d+208|0)}m=m+1|0;i=m&65535;if(i>>>0<=z[a+480190>>1]){continue}break}}Ab:{if(x[a+480180>>2]!=4){break Ab}while(1){if(z[a+480192>>1]<=q>>>0){break Ab}b=y[Pb(s,q)|0];c=y[Pb(s,q)+1|0];f=y[Pb(s,q)+2|0];g=y[Pb(s,q)+3|0];x[114409]=0;q=q+1|0;ia(889,a|0,q&65535,b|0,c|0,f|0,g|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}e=N()|0;break k}Bb:{Cb:{Db:{Eb:{if(!(y[r+2|0]&16)){break Eb}x[114409]=0;b=O(231,l|0,1)|0;c=x[114409];x[114409]=0;if((c|0)==1){break m}if(!b){break Eb}g=0;x[114409]=0;b=S(425,l|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break n}if(!(!(b&1)|!z[I>>1])){while(1){x[114409]=0;b=S(413,l|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Db}v[((g<<5)+a|0)+480288|0]=b;g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break}}while(1){x[114409]=0;b=O(231,l|0,1)|0;c=x[114409];x[114409]=0;Fb:{if((c|0)!=1){if(!b){break Eb}x[114409]=0;b=S(425,l|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Cb}if(!b){break Eb}x[114409]=0;c=S(413,l|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Bb}x[114409]=0;T(316,d+208|0,l|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break Bb}if(b>>>0>250){break Fb}x[114409]=0;P(676,d+208|0,(D(b,160)+a|0)+906140|0);b=x[114409];x[114409]=0;if((b|0)!=1){break Fb}e=N()|0;Ab(d+208|0);break k}e=N()|0;break k}Ab(d+208|0);continue}}q=a+901404|0;c=a+1074308|0;m=a+484344|0;b=gd(d+124|0);h=0;j=0;Gb:{Hb:{while(1){x[114409]=0;f=O(231,l|0,8)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Gb}if(!f){break Hb}x[114409]=0;f=S(413,l|0)|0;g=x[114409];x[114409]=0;Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if((g|0)!=1){x[114409]=0;g=S(413,l|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break Yb}x[114409]=0;T(316,d+148|0,l|0,g|0);g=x[114409];x[114409]=0;if((g|0)==1){break Xb}if((f|0)<=1397900629){if((f|0)==1229211981){break Vb}if((f|0)!=1229476432){break Jb}x[114409]=0;f=S(425,d+148|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}x[a+480216>>2]=f;x[114409]=0;f=S(425,d+148|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}x[a+480220>>2]=f;break Jb}if((f|0)==1397900630){break Wb}if((f|0)!=1414548815){break Jb}x[114409]=0;f=O(628,d+148|0,9651)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}if(!f){break Tb}x[114409]=0;f=S(413,d+148|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){x[114409]=0;T(316,d+168|0,d+148|0,f|0);f=x[114409];x[114409]=0;if((f|0)!=1){break Ub}}e=N()|0;break p}e=N()|0;break o}e=N()|0;break o}e=N()|0;break o}Zb:{_b:{$b:{f=x[a+480180>>2];switch(f-2|0){case 1:break Jb;case 0:break Kb;case 2:break _b;default:break $b}}if((f|0)==16){break Zb}if((f|0)!=32){break Jb}x[114409]=0;h=S(335,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break q}x[114409]=0;j=S(335,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break Jb}break q}x[114409]=0;x[d+208>>2]=32;f=S(228,d+148|0)|0;g=x[114409];x[114409]=0;ac:{if((g|0)==1){break ac}x[114409]=0;x[d+168>>2]=f;f=O(36,d+208|0,d+168|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break ac}f=x[f>>2];x[114409]=0;Z(890,d+148|0,b|0,4,f|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break Jb}}e=N()|0;break p}x[114409]=0;g=S(425,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ib}x[114409]=0;f=O(2,d+108|0,10917)|0;i=x[114409];x[114409]=0;bc:{cc:{dc:{if((i|0)!=1){x[114409]=0;P(192,d+168|0,f|0);i=x[114409];x[114409]=0;if((i|0)==1){break dc}x[114409]=0;x[d+60>>2]=g>>>4;x[d+32>>2]=g&15;W(527,d+208|0,d+168|0,d+60|0,d+32|0);g=x[114409];x[114409]=0;if((g|0)==1){break cc}g=d+208|0;Eb(b,g);xb(g);Gb(d+168|0);xb(f);break Jb}e=N()|0;break p}e=N()|0;break bc}e=N()|0;Gb(d+168|0)}xb(f);break p}x[114409]=0;O(641,d+148|0,q|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break q}x[114409]=0;V(642,q|0);f=x[114409];x[114409]=0;if((f|0)==1){break q}break Jb}x[114409]=0;f=S(228,d+168|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Sb}w[d+208>>1]=f>>>5;f=Ne(m);x[114409]=0;w[d+60>>1]=f;f=O(457,d+208|0,d+60|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Sb}f=z[f>>1];if(f){i=0;while(1){x[114409]=0;U(891,d+168|0,d+208|0,32)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Sb}g=Zb(m,i);x[114409]=0;O(892,g|0,d+208|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Sb}i=i+1|0;if((f|0)!=(i|0)){continue}break}}Ab(d+168|0)}x[114409]=0;f=O(628,d+148|0,9656)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}if(!f){break Qb}x[114409]=0;f=S(413,d+148|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){x[114409]=0;T(316,d+208|0,d+148|0,f|0);f=x[114409];x[114409]=0;if((f|0)!=1){break Rb}}e=N()|0;break p}e=N()|0;Ab(d+168|0);break p}x[114409]=0;f=S(228,d+208|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Pb}w[d+168>>1]=(f>>>0)/20;f=z[a+480188>>1];x[114409]=0;w[d+60>>1]=f;f=O(457,d+168|0,d+60|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Pb}f=z[f>>1];if(f){g=0;while(1){x[114409]=0;U(644,d+208|0,((g<<5)+a|0)+480289|0,20)|0;i=x[114409];x[114409]=0;if((i|0)==1){break Pb}g=g+1|0;if((f|0)!=(g|0)){continue}break}}Ab(d+208|0)}x[114409]=0;O(661,a|0,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break q}x[114409]=0;W(662,a|0,d+148|0,1,0);f=x[114409];x[114409]=0;if((f|0)==1){break q}if((h-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[114409]=0;T(673,a|0,d+148|0,h&65535);f=x[114409];x[114409]=0;if((f|0)==1){break q}}if(!x[c>>2]){break Jb}x[114409]=0;f=O(2,d+184|0,13386)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Ob}x[114409]=0;P(215,d+168|0,c|0);g=x[114409];x[114409]=0;if((g|0)==1){break Nb}x[114409]=0;T(3,d+208|0,f|0,d+168|0);g=x[114409];x[114409]=0;if((g|0)==1){break Mb}g=d+208|0;Eb(b,g);xb(g);xb(d+168|0);xb(f);break Jb}e=N()|0;Ab(d+208|0);break p}e=N()|0;break p}e=N()|0;break Lb}e=N()|0;xb(d+168|0)}xb(f);break p}x[114409]=0;h=S(335,d+148|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break q}}Ab(d+148|0);continue}break}e=N()|0;break p}ec:{fc:{gc:{hc:{ic:{jc:{kc:{if(x[a+480180>>2]!=32){break kc}f=h&65535;if(f>>>0<256){break kc}if(f>>>0<532){break jc}}lc:{if(x[a+480180>>2]!=2){break lc}f=h&65535;if(f>>>0<12544){break lc}if(f>>>0<12820){break jc}}if(x[a+480180>>2]!=2){break ic}f=h&65535;if(f>>>0<4864|f>>>0>4895){break ic}}x[114409]=0;V(643,q|0);f=x[114409];x[114409]=0;if((f|0)==1){break hc}}if(!(v[r+2|0]&1)){break ec}if(!(x[c>>2]|!z[a+480192>>1])){g=1;while(1){f=x[(((g&65535)<<2)+a|0)+900380>>2];if(f){x[114409]=0;h=O(354,f|0,2)|0;i=x[114409];x[114409]=0;if((i|0)==1){break gc}i=x[a+480180>>2];x[114409]=0;T(893,h|0,4,i|0);h=x[114409];x[114409]=0;if((h|0)==1){break fc}v[f+19|0]=y[f+19|0]+3>>>2}g=g+1|0;if(z[a+480192>>1]>=(g&65535)>>>0){continue}break}}if(A[c>>2]<18350080){x[114409]=0;f=a+1074312|0;O(459,f|0,27)|0;g=x[114409];x[114409]=0;if((g|0)==1){break hc}x[114409]=0;O(459,f|0,57)|0;f=x[114409];x[114409]=0;if((f|0)==1){break hc}}if(A[c>>2]<19070976){x[114409]=0;O(459,a+1074312|0,73)|0;f=x[114409];x[114409]=0;if((f|0)==1){break hc}}if(A[c>>2]>=19267584){break ec}x[114409]=0;O(459,a+1074312|0,50)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break ec}}e=N()|0;break o}e=N()|0;break o}e=N()|0;break o}mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{Dc:{if(Yc(b)){x[114409]=0;c=O(2,d+96|0,11348)|0;f=x[114409];x[114409]=0;Ec:{Fc:{Gc:{if((f|0)!=1){x[114409]=0;P(192,d+148|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break Gc}x[114409]=0;T(530,d+208|0,d+148|0,d+1591|0);f=x[114409];x[114409]=0;if((f|0)==1){break Fc}break Dc}e=N()|0;break o}e=N()|0;break Ec}e=N()|0;Gb(d+148|0)}xb(c);break o}x[114409]=0;c=O(2,d+84|0,13093)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Cc}x[114409]=0;P(192,d+148|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break Bc}x[114409]=0;W(423,d+208|0,d+148|0,d+1591|0,b|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ac}}f=d+208|0;Eb(b,f);xb(f);Gb(d+148|0);xb(c);x[114409]=0;c=O(2,d+72|0,11340)|0;f=x[114409];x[114409]=0;if((f|0)==1){break xc}x[114409]=0;P(192,d+148|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break wc}x[114409]=0;T(530,d+208|0,d+148|0,d+1591|0);f=x[114409];x[114409]=0;if((f|0)==1){break vc}f=d+208|0;Eb(a+1304436|0,f);xb(f);Gb(d+148|0);xb(c);x[114409]=0;c=O(2,f|0,10584)|0;f=x[114409];x[114409]=0;if((f|0)==1){break tc}Eb(a+1304448|0,c);xb(c);c=x[a+480180>>2];if((c|0)>15){break yc}switch(c-1|0){case 1:break pc;case 3:break qc;case 0:break rc;default:break v}}e=N()|0;break o}e=N()|0;break zc}e=N()|0;Gb(d+148|0)}xb(c);break o}if((c|0)==16){break sc}if((c|0)==32){break oc}if((c|0)!=16777216){break v}x[114409]=0;c=O(2,d+148|0,6105)|0;f=x[114409];x[114409]=0;if((f|0)==1){break nc}Eb(a+1304484|0,c);xb(c);x[114409]=0;c=O(2,d+168|0,9613)|0;f=x[114409];x[114409]=0;if((f|0)==1){break mc}Eb(a+1304472|0,c);xb(c);break v}e=N()|0;break o}e=N()|0;break uc}e=N()|0;Gb(d+148|0)}xb(c);break o}e=N()|0;break o}x[114409]=0;c=O(2,d+148|0,6110)|0;f=x[114409];x[114409]=0;Hc:{if((f|0)!=1){Eb(a+1304484|0,c);xb(c);x[114409]=0;c=O(2,d+168|0,4584)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Hc}Eb(a+1304472|0,c);xb(c);break v}e=N()|0;break o}e=N()|0;break o}x[114409]=0;c=O(2,d+148|0,8133)|0;f=x[114409];x[114409]=0;Ic:{if((f|0)!=1){Eb(a+1304484|0,c);xb(c);x[114409]=0;c=O(2,d+168|0,9958)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ic}Eb(a+1304472|0,c);xb(c);break v}e=N()|0;break o}e=N()|0;break o}x[114409]=0;c=O(2,d+148|0,6083)|0;f=x[114409];x[114409]=0;Jc:{if((f|0)!=1){Eb(a+1304484|0,c);xb(c);x[114409]=0;c=O(2,d+168|0,11118)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Jc}Eb(a+1304472|0,c);xb(c);break v}e=N()|0;break o}e=N()|0;break o}x[114409]=0;c=O(2,d+148|0,6455)|0;f=x[114409];x[114409]=0;Kc:{if((f|0)!=1){Eb(a+1304484|0,c);xb(c);x[114409]=0;c=O(2,d+168|0,10682)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Kc}Eb(a+1304472|0,c);xb(c);break v}e=N()|0;break o}e=N()|0;break o}x[114409]=0;c=O(2,d+148|0,2520)|0;f=x[114409];x[114409]=0;Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{if((f|0)!=1){Eb(a+1304484|0,c);xb(c);if(!(j&65535)){break Lc}x[114409]=0;c=O(2,d+48|0,11020)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Rc}x[114409]=0;P(192,d+60|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break Qc}x[114409]=0;x[d+44>>2]=(j&65280)>>>8;x[d+28>>2]=j&255;P(669,d+32|0,d+28|0);f=x[114409];x[114409]=0;if((f|0)==1){break Pc}x[114409]=0;W(654,d+168|0,d+60|0,d+44|0,d+32|0);f=x[114409];x[114409]=0;if((f|0)==1){break Oc}f=d+168|0;Eb(a+1304472|0,f);xb(f);xb(d+32|0);Gb(d+60|0);xb(c);break v}e=N()|0;break o}e=N()|0;break o}e=N()|0;break Mc}e=N()|0;break Nc}e=N()|0;xb(d+32|0)}Gb(d+60|0)}xb(c);break o}x[114409]=0;c=O(2,d+168|0,4760)|0;f=x[114409];x[114409]=0;if((f|0)!=1){Eb(a+1304472|0,c);xb(c);break v}e=N()|0;break o}e=N()|0;break o}e=N()|0;break o}e=N()|0;break o}e=N()|0;break k}e=N()|0;break k}e=N()|0;break k}e=N()|0;break i}e=N()|0;break g}e=N()|0;break g}e=N()|0;break g}e=N()|0;break d}e=N()|0;break d}e=N()|0;break d}e=N()|0;break c}e=N()|0;break c}e=N()|0;break d}Eb(a+1304460|0,b);Sc:{if(x[a+1074308>>2]){x[a+1304496>>2]=7;break Sc}if(x[a+480180>>2]==1){x[a+1304496>>2]=2;break Sc}x[a+1304496>>2]=4}g=1;if(e&1){x[114409]=0;c=O(2,d+60|0,12503)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}x[114409]=0;T(655,a|0,2,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break r}xb(c)}xb(b);RR(t);QR(s);hd(E);Ab(d+1064|0);Ab(d+1080|0)}Ab(l)}de(G);break b}e=N()|0;break o}e=N()|0;xb(c);break o}e=N()|0}Ab(d+148|0)}xb(b);break k}e=N()|0;break k}e=N()|0;break k}e=N()|0}RR(t);break i}e=N()|0}QR(s);break g}e=N()|0}hd(E)}Ab(d+1064|0)}Ab(d+1080|0)}Ab(l)}de(G);Q(e|0);p()}hb=d+1600|0;return g|0}R(0)|0;zb();p()}function Ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,X=0,Y=0,_=0,$=0,ca=0,da=0,ea=0,fa=0;d=hb-928|0;hb=d;Nc(b);a:{b:{if(!qS(b,d+876|0)){break b}if(!sS(d+876|0)){break b}if(!Qb(b,id(rS(d+876|0),lb))){break b}if(!c){f=1;break b}Pd(a,8);Ni(a);j=y[d+879|0]-48|0;v[d+875|0]=j;e=y[d+884|0]|y[d+885|0]<<8|(y[d+886|0]<<16|y[d+887|0]<<24);Tc(b,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));Ad(d+856|0,b,504);x[114409]=0;O(791,b|0,d+572|0)|0;e=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((e|0)!=1){if(y[d+572|0]&128|y[d+855|0]>63){break c}Sb(d+492|0,0,80);p:{if(!(y[d+908|0]|y[d+909|0]<<8|(y[d+910|0]<<16|y[d+911|0]<<24))){break p}e=y[d+908|0]|y[d+909|0]<<8|(y[d+910|0]<<16|y[d+911|0]<<24);x[114409]=0;e=O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;i=x[114409];x[114409]=0;if((i|0)!=1){if(!e){break p}x[114409]=0;O(792,b|0,d+492|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break p}}f=N()|0;break f}x[114409]=0;T(793,d+488|0,b|0,j&255);e=x[114409];x[114409]=0;if((e|0)!=1){e=d+488|0;I=wf(e);e=z[e>>1];if((e-128&65535)>>>0<65409){break c}w[a+480188>>1]=e;i=hb-16|0;hb=i;e=d+476|0;x[e>>2]=0;x[e+4>>2]=0;x[114409]=0;x[i+12>>2]=0;U(835,e+8|0,i+12|0,i+11|0)|0;C=x[114409];x[114409]=0;q:{if((C|0)!=1){hb=i+16|0;break q}break a}C=e;r:{if(y[d+900|0]|y[d+901|0]<<8|(y[d+902|0]<<16|y[d+903|0]<<24)){e=y[d+900|0]|y[d+901|0]<<8|(y[d+902|0]<<16|y[d+903|0]<<24);x[114409]=0;O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;e=x[114409];x[114409]=0;if((e|0)!=1){e=y[d+855|0];x[114409]=0;U(794,b|0,C|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break r}}f=N()|0;break g}if(y[d+855|0]){break d}}e=y[d+855|0];w[a+480192>>1]=e;w[a+480190>>1]=e;J=1;if((j&255)>>>0>=2){J=v[d+836|0]>=0;e=z[a+480192>>1]}if(e&65535){E=c&2;F=!J;h=1;s=1;n=1;while(1){x[114409]=0;o=n&65535;e=U(427,a|0,s&65535,o|0)|0;i=x[114409];x[114409]=0;s:{t:{if((i|0)!=1){if(!e){break e}j=x[((h<<2)+a|0)+900380>>2];w[d+120>>1]=0;x[114409]=0;x[d+116>>2]=0;l=S(247,d+460|0)|0;e=x[114409];x[114409]=0;u:{v:{w:{if((e|0)!=1){i=h-1|0;e=Pb(C,i);x:{if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break x}e=Pb(C,i);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;e=O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;i=x[114409];x[114409]=0;if((i|0)==1){break h}if(!e){break x}x[114409]=0;O(795,b|0,d+116|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}e=y[d+116|0]|y[d+117|0]<<8|(y[d+118|0]<<16|y[d+119|0]<<24);f=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);e=y[d+120|0]|y[d+121|0]<<8;f=(e<<8|e>>>8)<<16>>16>0?f<<((y[d+120|0]|y[d+121|0]<<8)>>>13&1):f;x[114409]=0;T(316,d+180|0,b|0,f|0);e=x[114409];x[114409]=0;if((e|0)==1){break h}e=d+180|0;Zd(l,e);Ab(e)}e=y[d+121|0]&15;k=(y[d+120|0]|y[d+121|0]<<8)&128;if(!k){break w}x[114409]=0;P(796,j|0,0);i=x[114409];x[114409]=0;X=1;if((i|0)!=1){break v}break h}f=N()|0;break g}if(e>>>0>=7){break v}i=y[e+23750|0];if(!e){e=i;break t}w[a+480190>>1]=(z[a+480190>>1]+i|0)-1;e=j+108|0;u=j+236|0;m=i-2|0;g=4;while(1){h=g-4|0;f=m<<3;q=h+(f+23808|0)|0;h=y[h+(f+23760|0)|0]+n|0;r=D(g,12);f=0;while(1){B=f+r|0;ea=fd(u,B),fa=h,w[ea>>1]=fa;B=fc(e,B);v[B|0]=y[B|0]+y[q|0];f=f+1|0;if((f|0)!=12){continue}break}h=1;g=g+1|0;if((g|0)!=10){continue}break}e=i;break u}i=1;if((e|0)!=7){e=1;break t}h=0;x[114409]=0;P(797,j|0,-24);i=x[114409];x[114409]=0;e=1;if((i|0)==1){break h}i=1}u=1;break s}f=N()|0;break g}h=0;if(k|F){break s}h=j+108|0;g=7;while(1){m=D(g,12);q=D(g,-12)+72|0;f=0;while(1){r=fc(h,f+m|0);v[r|0]=q+y[r|0];f=f+1|0;if((f|0)!=12){continue}break}g=g+1|0;if((g|0)!=10){continue}break}h=0}x[114409]=0;O(798,d+856|0,d+180|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}if(!(!y[d+184|0]|y[d+184|0]>16)){v[j+31|0]=y[d+184|0];u=1}if(!(!y[d+185|0]|y[d+185|0]>128)){v[j+30|0]=y[d+185|0]}if(e){f=0;while(1){x[114409]=0;j=D(f+o|0,104)+a|0;P(472,j+484380|0,8);g=x[114409];x[114409]=0;if((g|0)==1){break h}g=y[d+186|0];x[114409]=0;v[d+76|0]=g;v[d+36|0]=64;g=O(431,d+76|0,d+36|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break h}w[j+484410>>1]=y[g|0]<<2;v[j+484416|0]=y[d+187|0];f=f+1|0;if((e|0)!=(f|0)){continue}break}}y:{if(k|!E){break y}j=cd(d+76|0,8,1,1,0);k=y[d+182|0]|y[d+183|0]<<8;m=k;g=y[d+180|0]|y[d+181|0]<<8;x[114409]=0;f=S(228,l|0)|0;q=x[114409];x[114409]=0;if((q|0)==1){break h}if(y[d+121|0]&16){XA(j);f=f>>>1|0}if(y[d+121|0]&32){tC(j);f=f>>>1|0}if(y[d+121|0]&64){vm(j,2)}f=h?(f>>>0)/((-1<<e^-1)>>>0)|0:f;if(!e){break y}g=(g<<8|g>>>8)&65535;k=g+((k<<8|k>>>8)&65535)|0;q=m<<8|m>>>8;h=0;while(1){m=D(h+o|0,104)+a|0;r=m+484380|0;x[r>>2]=f;x[114409]=0;U(376,j|0,r|0,l|0)|0;r=x[114409];x[114409]=0;if((r|0)==1){break h}g=g<<1;k=k<<1;if((q&65535)>>>0>=2){x[m+484388>>2]=k;x[m+484384>>2]=g;m=m+484414|0;w[m>>1]=z[m>>1]|2}f=f<<1;h=h+1|0;if((h|0)!=(e|0)){continue}break}}Ab(l);n=i+n|0;s=s+1|0;h=s&65535;if(h>>>0<=z[a+480192>>1]){continue}break}}z:{if(!(y[d+496|0]|y[d+497|0]<<8|(y[d+498|0]<<16|y[d+499|0]<<24))|!(y[d+500|0]|y[d+501|0]<<8)){break z}e=y[d+496|0]|y[d+497|0]<<8|(y[d+498|0]<<16|y[d+499|0]<<24);x[114409]=0;e=O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;i=x[114409];x[114409]=0;if((i|0)==1){break i}if(!e){break z}e=y[d+500|0]|y[d+501|0]<<8;w[d+180>>1]=e<<8|e>>>8;e=y[d+855|0];x[114409]=0;w[d+116>>1]=e;e=O(457,d+180|0,d+116|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break j}h=z[e>>1];if(!h){break z}e=y[d+502|0]|y[d+503|0]<<8;f=(e<<8|e>>>8)&65535;j=d+124|0;l=d+120|0;e=0;while(1){x[114409]=0;U(799,b|0,d+180|0,f|0)|0;i=x[114409];x[114409]=0;A:{B:{C:{if((i|0)!=1){e=e+1|0;i=x[((e<<2)+a|0)+900380>>2];if(!y[d+180|0]){break A}k=uq(d+116|0,0,64);uq(l,y[d+180|0]-1&65535,64);n=y[d+180|0];uq(j,n+(y[d+181|0]?64/y[d+181|0]|0:0)|0,0);x[114409]=0;x[d+456>>2]=3;x[d+452>>2]=k;g=x[d+456>>2];x[d>>2]=x[d+452>>2];x[d+4>>2]=g;g=i+48|0;P(800,g|0,d|0);k=x[114409];x[114409]=0;if((k|0)==1){break C}if(y[d+180|0]!=1){break B}ea=d,fa=bc(g),x[ea+116>>2]=fa;k=x[rd(d+448|0,d+116|0)>>2];x[114409]=0;O(801,g|0,k|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break B}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}x[i>>2]=y[d+181|0]?y[d+181|0]<<9:32767;u=1;v[i+60|0]=y[i+60|0]|1}D:{if(f>>>0<5){break D}if(y[d+184|0]){g=y[d+184|0];ea=fc(i+108|0,24),fa=g+24|0,v[ea|0]=fa;u=1}if(f>>>0<19){break D}x[i+4>>2]=y[d+198|0]+1>>>1;if(f>>>0<21){break D}w[i+28>>1]=y[d+200|0]|y[d+201|0]<<8}i=D(z[fd(i+236|0,61)>>1],104)+a|0;v[i+484417|0]=y[d+183|0]<<4;E:{F:{if(f>>>0>=15){g=y[d+190|0]|y[d+191|0]<<8|(y[d+192|0]<<16|y[d+193|0]<<24);x[i+484384>>2]=g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24);g=y[d+194|0]|y[d+195|0]<<8|(y[d+196|0]<<16|y[d+197|0]<<24);k=g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24);g=y[d+190|0]|y[d+191|0]<<8|(y[d+192|0]<<16|y[d+193|0]<<24);x[i+484388>>2]=k+(g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24));break F}if(f>>>0<6){break E}}g=i+484414|0;w[g>>1]=z[g>>1]&65533|y[d+185|0]<<1&2;w[g>>1]=z[g>>1]&65531|y[d+185|0]>>>1&4;if(!(y[d+185|0]&4)){break E}w[i+484412>>1]=0}if((e|0)!=(h|0)){continue}break}}if(!(y[d+512|0]|y[d+513|0]<<8|(y[d+514|0]<<16|y[d+515|0]<<24))|!(y[d+516|0]|y[d+517|0]<<8)){break k}e=y[d+512|0]|y[d+513|0]<<8|(y[d+514|0]<<16|y[d+515|0]<<24);x[114409]=0;e=O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;i=x[114409];x[114409]=0;if((i|0)==1){break i}if(!e){break k}e=y[d+516|0]|y[d+517|0]<<8;w[d+180>>1]=e<<8|e>>>8;e=y[d+855|0];x[114409]=0;w[d+116>>1]=e;e=O(457,d+180|0,d+116|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){f=z[e>>1];if(!f){break k}e=y[d+518|0]|y[d+519|0]<<8;g=(e<<8|e>>>8)&65535;k=0;G:while(1){H:{x[114409]=0;U(802,b|0,d+180|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}x[114409]=0;T(803,d+76|0,2,d+180|0);e=x[114409];x[114409]=0;if((e|0)==1){break m}x[114409]=0;P(370,d+116|0,d+76|0);e=x[114409];x[114409]=0;if((e|0)==1){break m}k=k+1|0;j=((k<<2)+a|0)+900380|0;e=x[j>>2];x[114409]=0;O(348,e+492|0,d+116|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break n}e=d+116|0;xb(e);i=x[j>>2];x[114409]=0;P(804,e|0,i|0);e=x[114409];x[114409]=0;if((e|0)==1){break o}e=d+116|0;ea=d,fa=Xn(e),x[ea+76>>2]=fa;ea=d,fa=Zi(e),x[ea+36>>2]=fa;while(1){x[114409]=0;e=O(805,d+76|0,d+36|0)|0;i=x[114409];x[114409]=0;I:{if((i|0)!=1){if(e){break I}sq(d+116|0);if((f|0)!=(k|0)){continue G}break k}break H}x[114409]=0;e=S(806,d+76|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){i=(z[e>>1]<<5)+a|0;h=i+946328|0;e=x[j>>2];l=x[e+520>>2];x[h>>2]=x[e+516>>2];x[h+4>>2]=l;l=x[e+512>>2];h=i+946320|0;x[h>>2]=x[e+508>>2];x[h+4>>2]=l;l=x[e+504>>2];h=i+946312|0;x[h>>2]=x[e+500>>2];x[h+4>>2]=l;h=x[e+496>>2];i=i+946304|0;x[i>>2]=x[e+492>>2];x[i+4>>2]=h;ou(d+76|0);continue}break}}break}f=N()|0;sq(d+116|0);break g}f=N()|0;break g}f=N()|0;break f}f=N()|0;break f}f=N()|0;break g}f=N()|0;xb(d+116|0);break g}f=N()|0;break g}f=N()|0;break g}x[114409]=0;V(643,a+901404|0);e=x[114409];x[114409]=0;if((e|0)==1){break i}e=a+901692|0;i=y[1447]|y[1448]<<8|(y[1449]<<16|y[1450]<<24);v[e|0]=i;v[e+1|0]=i>>>8;v[e+2|0]=i>>>16;v[e+3|0]=i>>>24;v[a+901696|0]=y[1451];Nc(b);J:{K:{L:{M:{N:{O:{P:{if(!y[I|0]){break P}Y=c&1;s=a+484344|0;m=a+1304424|0;r=a+1304400|0;B=a+484360|0;i=0;F=0;while(1){x[114409]=0;W(807,b|0,d+876|0,d+492|0,d+572|0);c=x[114409];x[114409]=0;Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((c|0)==1){break Y}c=F&255;if(c){x[114409]=0;e=S(465,B|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break Y}if((e|0)==255){break e}}l=Ti(B,c);f=hb-16|0;hb=f;j=f+15|0;e=hb-16|0;hb=e;x[114409]=0;c=d+436|0;S(839,c+4|0)|0;g=x[114409];x[114409]=0;Z:{_:{if((g|0)==1){break _}x[114409]=0;x[e+12>>2]=0;U(840,c+8|0,e+12|0,j|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break _}ea=c,fa=mc(c),x[ea>>2]=fa;hb=e+16|0;break Z}R(0)|0;zb();p()}j=c;hb=f+16|0;Kq(l);n=y[d+875|0];if(n>>>0>1){break V}c=y[d+574|0]|y[d+575|0]<<8;if(((c<<8|c>>>8)&65535)>>>0>256|z[a+480188>>1]>16){break U}e=d+180|0;nS(e,d+572|0);c=y[d+574|0]|y[d+575|0]<<8;x[114409]=0;aa(808,l|0,e|0,(c<<8|c>>>8)&65535,65535,65535)|0;c=x[114409];x[114409]=0;if((c|0)==1){break X}ea=d,fa=bc(l),x[ea+180>>2]=fa;ea=d,fa=dc(l),x[ea+116>>2]=fa;if(Hb(d+180|0,d+116|0)){break W}break S}f=N()|0;break g}f=N()|0;break J}while(1){c=d+180|0;e=x[c>>2];w[e>>1]=z[e>>1]+i;ke(c);if(Hb(c,d+116|0)){continue}break}break S}nS(d+180|0,d+572|0);if(!(y[d+192|0]|y[d+193|0]<<8)){break U}c=y[d+192|0]|y[d+193|0]<<8;if(((c<<8|c>>>8)&65535)>>>0>64|z[a+480188>>1]>64){break U}k=y[d+200|0]|y[d+201|0]<<8|(y[d+202|0]<<16|y[d+203|0]<<24);if(!(y[d+204|0]|y[d+205|0]<<8)){g=32;break T}c=y[d+204|0]|y[d+205|0]<<8;x[114409]=0;w[d+116>>1]=c<<8|c>>>8;w[d+76>>1]=800;c=O(457,d+116|0,d+76|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){c=z[c>>1];x[114409]=0;g=cg(761,((c<<5)+50>>>0)/100|0,0);c=x[114409];x[114409]=0;if((c|0)!=1){break T}}f=N()|0;break J}ku(j);break e}c=y[d+188|0]|y[d+189|0]<<8|(y[d+190|0]<<16|y[d+191|0]<<24);x[114409]=0;c=O(229,b|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;e=x[114409];x[114409]=0;$:{if((e|0)==1){break $}f=0;aa:{if(!(c&z[a+480188>>1]!=0)){break aa}ba:{while(1){ca:{x[114409]=0;c=S(425,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ca}x[114409]=0;v[d+116|0]=c;v[d+76|0]=64;c=O(431,d+116|0,d+76|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ba}w[((f<<5)+a|0)+480286>>1]=y[c|0];f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break aa}break}f=N()|0;break J}f=N()|0;break J}da:{ea:{if(!(y[d+196|0]|y[d+197|0]<<8|(y[d+198|0]<<16|y[d+199|0]<<24))){break ea}c=y[d+196|0]|y[d+197|0]<<8|(y[d+198|0]<<16|y[d+199|0]<<24);x[114409]=0;c=O(229,b|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;e=x[114409];x[114409]=0;if((e|0)==1){break $}if(!c){break ea}f=0;if(!z[a+480188>>1]){break da}while(1){fa:{x[114409]=0;c=S(809,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break fa}ea=((f<<5)+a|0)+480284|0,fa=(Yb(c,-16,16)<<3)+128|0,w[ea>>1]=fa;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break da}break}f=N()|0;break J}x[114409]=0;P(421,a|0,1);c=x[114409];x[114409]=0;if((c|0)==1){break $}}e=hb-16|0;hb=e;c=d+168|0;x[c>>2]=0;x[c+4>>2]=0;x[114409]=0;x[e+12>>2]=0;U(836,c+8|0,e+12|0,e+11|0)|0;f=x[114409];x[114409]=0;ga:{if((f|0)!=1){hb=e+16|0;break ga}break a}e=y[d+184|0]|y[d+185|0]<<8|(y[d+186|0]<<16|y[d+187|0]<<24);x[114409]=0;e=O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;f=x[114409];x[114409]=0;ha:{ia:{ja:{ka:{if((f|0)==1){break ka}if(!e){break ja}e=y[d+574|0]|y[d+575|0]<<8;x[114409]=0;e=O(231,b|0,((e<<8|e>>>8)&65535)<<1)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ka}if(!e){break ja}e=y[d+574|0]|y[d+575|0]<<8;x[114409]=0;e=U(810,b|0,c|0,(e<<8|e>>>8)&65535)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ka}if(!e){break ja}ea=d,fa=bc(c),x[ea+164>>2]=fa;ea=d,fa=dc(c),x[ea+160>>2]=fa;if(Hb(d+164|0,d+160|0)){while(1){la:{e=y[d+194|0]|y[d+195|0]<<8;h=(e<<8|e>>>8)&65535;e=x[d+164>>2];e=y[e|0]|y[e+1|0]<<8;f=(e<<8|e>>>8)&65535;if(h>>>0<f>>>0){break la}e=y[d+180|0]|y[d+181|0]<<8|(y[d+182|0]<<16|y[d+183|0]<<24);x[114409]=0;O(229,b|0,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))+(f<<2)|0)|0;e=x[114409];x[114409]=0;ma:{na:{oa:{if((e|0)==1){break oa}x[114409]=0;e=S(474,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break oa}x[114409]=0;e=O(229,b|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break oa}if(!e){break la}x[114409]=0;e=O(231,b|0,42)|0;f=x[114409];x[114409]=0;if((f|0)==1){break oa}if(!e){break la}x[114409]=0;O(811,b|0,d+116|0)|0;e=x[114409];x[114409]=0;pa:{if((e|0)!=1){if(kd(l)){break pa}x[114409]=0;P(812,l|0,65534);e=x[114409];x[114409]=0;if((e|0)!=1){break pa}}f=N()|0;break ha}e=y[d+156|0]|y[d+157|0]<<8;x[114409]=0;e=(e<<8|e>>>8)&65535;x[d+112>>2]=e;e=O(231,b|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break na}if(!e){x[114409]=0;e=S(305,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break na}zc(d+112|0,e)}zc(d+112|0,65534);f=rc(l);x[114409]=0;P(813,l|0,f+x[d+112>>2]|0);e=x[114409];x[114409]=0;if((e|0)==1){break ia}h=0;if(!x[d+112>>2]){break ma}while(1){qa:{x[114409]=0;e=S(464,b|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break qa}e=e<<16>>16;if((e|0)>=0){x[114409]=0;P(812,l|0,e+i&65535);e=x[114409];x[114409]=0;if((e|0)==1){break qa}}h=h+1|0;if(h>>>0<A[d+112>>2]){continue}break ma}break}f=N()|0;break ha}f=N()|0;break ha}f=N()|0;break ha}ra:{sa:{ta:{if(y[d+116|0]){x[114409]=0;P(814,d+92|0,d+116|0);e=x[114409];x[114409]=0;ua:{if((e|0)!=1){x[114409]=0;P(815,d+100|0,d+92|0);e=x[114409];x[114409]=0;if((e|0)!=1){break ua}}f=N()|0;break ha}x[114409]=0;T(13,d+76|0,2,d+100|0);e=x[114409];x[114409]=0;if((e|0)==1){break sa}x[114409]=0;P(466,l|0,d+76|0);e=x[114409];x[114409]=0;if((e|0)==1){break ta}xb(d+76|0);xb(d+100|0)}if(!(y[d+148|0]|y[d+149|0]<<8|(y[d+150|0]<<16|y[d+151|0]<<24))){break la}e=y[d+148|0]|y[d+149|0]<<8|(y[d+150|0]<<16|y[d+151|0]<<24);x[114409]=0;e=O(229,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))|0;h=x[114409];x[114409]=0;if((h|0)==1){break ia}if(!e){break la}while(1){va:{x[114409]=0;e=O(816,b|0,d+100|0)|0;h=x[114409];x[114409]=0;wa:{xa:{if((h|0)!=1){if(!e){break la}e=y[d+103|0];x[114409]=0;T(316,d+76|0,b|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break xa}e=y[d+100|0]|y[d+101|0]<<8;x[114409]=0;e=S(817,f+((e<<8|e>>>8)&65535)|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break va}w[d+92>>1]=e;if((y[d+100|0]|y[d+101|0]<<8)!=65535){e=z[d+92>>1];if(rc(l)>>>0>e>>>0){break wa}}Ab(d+76|0);break la}f=N()|0;break ha}f=N()|0;break ha}ya:{if(y[d+102|0]==1){e=65535}else{if(y[d+102|0]!=2){break ya}x[114409]=0;e=S(464,d+76|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break va}x[114409]=0;h=O(818,j|0,d+92|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break va}w[h>>1]=e;e=65534}ea=vc(l,z[d+92>>1]),fa=e,w[ea>>1]=fa}Ab(d+76|0);continue}break}f=N()|0;Ab(d+76|0);break ha}f=N()|0;xb(d+76|0);break ra}f=N()|0}xb(d+100|0);break ha}e=d+164|0;ke(e);if(Hb(e,d+160|0)){continue}break}}k=g>>>(k>>>25&1)|0;qA(c);break R}f=N()|0;break ha}qA(c);break Q}f=N()|0}qA(c);break J}f=N()|0;break J}x[114409]=0;P(421,a|0,1);c=x[114409];x[114409]=0;za:{if((c|0)!=1){f=0;k=32;if(!z[a+480188>>1]){break R}while(1){c=y[(d+f|0)+838|0];x[114409]=0;v[d+180|0]=c;v[d+116|0]=64;c=O(431,d+180|0,d+116|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break za}w[((f<<5)+a|0)+480286>>1]=y[c|0];f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}break R}f=N()|0;break J}f=N()|0;break J}f=y[d+835|0];e=y[d+835|0];g=y[d+836|0];h=y[d+836|0];c=y[d+832|0]|y[d+833|0]<<8;x[114409]=0;M=e&64;K=g&32;q=(h&31)+1|0;c=Z(819,(c<<8|c>>>8)&65535,M>>>6|0,K>>>5|0,q|0)|0;e=x[114409];x[114409]=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((e|0)!=1){x[a+480204>>2]=c;ea=a,fa=Md(y[d+837|0],1,32),x[ea+480196>>2]=fa;if(K){x[a+480216>>2]=q;x[a+480220>>2]=q<<2}if(y[d+854|0]){c=y[d+854|0];x[114409]=0;v[d+180|0]=c;v[d+116|0]=64;c=O(431,d+180|0,d+116|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ba}x[a+480200>>2]=y[c|0]<<2}x[a+480228>>2]=k;x[a+480232>>2]=k;x[a+480208>>2]=x[a+480208>>2]&-3|(y[d+835|0]^-1)>>>4&2;Na:{if(!(y[d+536|0]|y[d+537|0]<<8|(y[d+538|0]<<16|y[d+539|0]<<24))){break Na}c=y[d+536|0]|y[d+537|0]<<8|(y[d+538|0]<<16|y[d+539|0]<<24);x[114409]=0;c=O(229,b|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ma}if(!c){break Na}c=y[d+540|0]|y[d+541|0]<<8|(y[d+542|0]<<16|y[d+543|0]<<24);x[114409]=0;U(461,b|0,r|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ma}if(y[I|0]<2){break Na}x[114409]=0;T(13,d+180|0,2,r|0);c=x[114409];x[114409]=0;if((c|0)==1){break La}x[114409]=0;P(466,l|0,d+180|0);c=x[114409];x[114409]=0;if((c|0)==1){break Ka}xb(d+180|0)}c=y[d+508|0]|y[d+509|0]<<8|(y[d+510|0]<<16|y[d+511|0]<<24);Oa:{if((c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))>>>0<2){break Oa}c=y[d+504|0]|y[d+505|0]<<8|(y[d+506|0]<<16|y[d+507|0]<<24);x[114409]=0;c=O(229,b|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ma}if(!c){break Oa}c=y[d+508|0]|y[d+509|0]<<8|(y[d+510|0]<<16|y[d+511|0]<<24);x[114409]=0;Z(584,m|0,b|0,(c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))-1|0,4)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ma}}if(!(y[d+548|0]|y[d+549|0]<<8|(y[d+550|0]<<16|y[d+551|0]<<24))){break Aa}c=y[d+548|0]|y[d+549|0]<<8|(y[d+550|0]<<16|y[d+551|0]<<24);x[114409]=0;c=O(229,b|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ma}if(!c){break Aa}x[114409]=0;c=O(231,b|0,12)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ma}if(!c){break Aa}x[114409]=0;O(313,b|0,6)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ma}x[114409]=0;c=S(464,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ma}if((c|0)!=1){break Aa}x[114409]=0;e=S(474,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ia}if(!e){break Aa}x[114409]=0;c=O(231,b|0,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Ia}if(c){break Ja}break Aa}f=N()|0;break J}f=N()|0;break J}f=N()|0;break J}f=N()|0;xb(d+180|0);break J}c=Gt(d+180|0,m);x[114409]=0;Z(584,m|0,b|0,e|0,4)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Da}if(!Yc(c)){x[114409]=0;e=U(820,d+52|0,2,13)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Ha}x[114409]=0;T(821,d+116|0,c|0,e|0);g=x[114409];x[114409]=0;if((g|0)==1){break Ga}x[114409]=0;T(822,d- -64|0,d+116|0,m|0);g=x[114409];x[114409]=0;if((g|0)==1){break Fa}g=d- -64|0;Eb(m,g);xb(g);xb(d+116|0);xb(e)}xb(c);break Aa}f=N()|0;break J}f=N()|0;break Ca}f=N()|0;break Ea}f=N()|0;xb(d+116|0)}xb(e);break Ca}f=N()|0}xb(c);break J}f=N()|0;break J}Pa:{if(!(y[d+560|0]|y[d+561|0]<<8|(y[d+562|0]<<16|y[d+563|0]<<24))|n>>>0<2){break Pa}g=0;if(!z[a+480188>>1]){break Pa}while(1){c=y[d+560|0]|y[d+561|0]<<8|(y[d+562|0]<<16|y[d+563|0]<<24);x[114409]=0;c=O(229,b|0,(c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))+(g<<2)|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}Qa:{if(!c){break Qa}x[114409]=0;c=S(474,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}x[114409]=0;c=O(229,b|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}k=0;e=0;if(!c){break Qa}while(1){Ra:{x[114409]=0;c=O(231,b|0,8)|0;h=x[114409];x[114409]=0;Sa:{Ta:{Ua:{if((h|0)!=1){if(!c){break Ra}x[114409]=0;O(823,b|0,d+180|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ua}if(!(y[d+180|0]|y[d+181|0]<<8|(y[d+182|0]<<16|y[d+183|0]<<24))){break Ra}c=y[d+180|0]|y[d+181|0]<<8|(y[d+182|0]<<16|y[d+183|0]<<24);switch(((c&31)<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))-1|0){case 1:break Sa;case 0:break Ta;default:continue}}f=N()|0;break J}f=N()|0;break J}c=y[d+184|0]|y[d+185|0]<<8|(y[d+186|0]<<16|y[d+187|0]<<24);k=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);continue}c=y[d+184|0]|y[d+185|0]<<8|(y[d+186|0]<<16|y[d+187|0]<<24);e=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);continue}break}if(!k|!e){break Qa}x[114409]=0;c=O(229,b|0,k|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break L}if(!c){break Qa}x[114409]=0;U(644,b|0,((g<<5)+a|0)+480289|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break L}}g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break}}c=y[d+572|0]|y[d+573|0]<<8;w[d+100>>1]=c<<8|c>>>8;dg(d+100|0,(i^-1)&65535);x[114409]=0;P(377,s|0,z[d+100>>1]+i&65535);c=x[114409];x[114409]=0;Va:{if((c|0)==1){break Va}Wa:{if(z[d+100>>1]){_=f&16;$=i&65535;e=0;while(1){Xa:{if(!Y){break Xa}c=y[d+892|0]|y[d+893|0]<<8|(y[d+894|0]<<16|y[d+895|0]<<24);x[114409]=0;c=O(229,b|0,(c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))+(e<<2)|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Wa}if(!c){break Xa}x[114409]=0;c=S(474,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Wa}x[114409]=0;c=O(229,b|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Wa}if(!c){break Xa}c=Xb(d+76|0);g=v[d+834|0];x[114409]=0;k=S(247,d+36|0)|0;f=x[114409];x[114409]=0;Ya:{Za:{if((f|0)!=1){o=g+48|0;h=y[d+875|0];if(h){break Za}x[114409]=0;O(824,b|0,d+180|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break N}w[d+92>>1]=y[d+180|0];E=y[d+181|0]+1|0;break Ya}f=N()|0;break M}x[114409]=0;O(825,b|0,d+168|0)|0;f=x[114409];x[114409]=0;_a:{$a:{if((f|0)!=1){f=y[d+168|0]|y[d+169|0]<<8;w[d+92>>1]=f<<8|f>>>8;f=y[d+170|0]|y[d+171|0]<<8;E=((f<<8|f>>>8)&65535)+1|0;if(!(y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))){break _a}n=x[b+8>>2];f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);x[114409]=0;O(229,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;f=x[114409];x[114409]=0;if((f|0)==1){break N}x[114409]=0;O(826,b|0,d+180|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break N}f=y[d+184|0]|y[d+185|0]<<8|(y[d+186|0]<<16|y[d+187|0]<<24);x[114409]=0;f=O(229,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;t=x[114409];x[114409]=0;if((t|0)==1){break N}if(!f){break $a}f=y[d+188|0]|y[d+189|0]<<8|(y[d+190|0]<<16|y[d+191|0]<<24);x[114409]=0;U(461,b|0,c|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;f=x[114409];x[114409]=0;if((f|0)!=1){break $a}break N}break N}ab:{if(!(y[d+196|0]|y[d+197|0]<<8|(y[d+198|0]<<16|y[d+199|0]<<24))){break ab}f=y[d+196|0]|y[d+197|0]<<8|(y[d+198|0]<<16|y[d+199|0]<<24);x[114409]=0;f=O(229,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;t=x[114409];x[114409]=0;if((t|0)==1){break N}if(!f){break ab}x[114409]=0;f=S(474,b|0)|0;t=x[114409];x[114409]=0;if((t|0)==1){break N}x[114409]=0;f=O(229,b|0,f|0)|0;t=x[114409];x[114409]=0;if((t|0)==1){break N}if(!f){break ab}x[114409]=0;T(316,d+116|0,b|0,D(z[d+92>>1],E)|0);f=x[114409];x[114409]=0;if((f|0)==1){break N}f=d+116|0;Zd(k,f);Ab(f)}x[114409]=0;O(229,b|0,n|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break N}}o=h>>>0>2?g+24|0:o}x[114409]=0;f=e+$|0;g=U(378,s|0,f&65535,E|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break N}if(g){t=Zb(s,f);x[114409]=0;O(476,t|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break N}dg(d+92|0,z[a+480188>>1]);n=0;while(1){x[114409]=0;f=U(451,t|0,n|0,0)|0;g=x[114409];x[114409]=0;bb:{cb:{if((g|0)!=1){g=0;if(z[d+92>>1]){break cb}break bb}break N}while(1){db:{if(!y[d+875|0]){x[114409]=0;P(827,d+180|0,b|0);h=x[114409];x[114409]=0;if((h|0)!=1){h=d+180|0;G=ed(h);L=wf(h);h=y[h|0];v[f+1|0]=h>>>3&16|y[G|0]>>>4|h>>>1&32;v[f+3|0]=y[G|0]&15;v[f+5|0]=y[L|0];h=h&63;h=h?h+o|0:0;break db}break N}x[114409]=0;P(594,d+180|0,b|0);h=x[114409];x[114409]=0;eb:{fb:{if((h|0)!=1){h=d+180|0;G=ed(h);L=wf(h);ca=fi(h);x[114409]=0;H=S(425,k|0)|0;da=x[114409];x[114409]=0;if((da|0)==1){break N}v[f+4|0]=H;H=y[h|0];h=H&127;if(!h){break fb}h=h+o|0;break eb}break N}h=0;if((H|0)!=128){break eb}v[f|0]=254}v[f+1|0]=y[G|0]&63;v[f+3|0]=y[L|0];v[f+5|0]=y[ca|0]}if(h-1>>>0<=119){v[f|0]=h}x[114409]=0;ba(828,f|0,(M|0)!=0|0,(K|0)!=0|0,q|0,(_|0)!=0|0);G=x[114409];x[114409]=0;if((G|0)!=1){u=(h|0)>84&J|u;f=f+6|0;g=g+1|0;if(z[d+92>>1]<=(g&65535)>>>0){break bb}continue}break}break N}n=n+1|0;if((E|0)!=(n|0)){continue}break}}Ab(k);xb(c)}e=e+1|0;if(e>>>0<z[d+100>>1]){continue}break}}ea=d,fa=Xn(j),x[ea+180>>2]=fa;ea=d,fa=Zi(j),x[ea+116>>2]=fa;gb:{while(1){x[114409]=0;c=O(829,d+180|0,d+116|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break O}hb:{ib:{jb:{kb:{lb:{mb:{if(!c){e=z[d+100>>1];if(y[d+492|0]|y[d+493|0]<<8|(y[d+494|0]<<16|y[d+495|0]<<24)){c=y[d+492|0]|y[d+493|0]<<8|(y[d+494|0]<<16|y[d+495|0]<<24);x[114409]=0;c=O(229,b|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;f=x[114409];x[114409]=0;if((f|0)==1){break Va}if(c){break mb}}ku(j);break P}x[114409]=0;c=S(830,d+180|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break lb}e=wf(c);f=z[c>>1];if(!f){f=0;break kb}x[114409]=0;g=O(539,l|0,f-1&65535)|0;f=x[114409];x[114409]=0;if((f|0)==1){break hb}f=z[c>>1];if(!g){break kb}x[114409]=0;f=O(831,l|0,f-1&65535)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break jb}break hb}i=e+i|0;break Q}f=N()|0;break J}if(z[e>>1]==((f&65535)+1|0)){break ib}x[114409]=0;f=U(832,s|0,1,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break hb}if((f|0)==65535){break ib}ea=vc(l,z[c>>1]),fa=f,w[ea>>1]=fa}c=Zb(s,f);e=z[e>>1];x[114409]=0;e=S(833,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break gb}x[114409]=0;e=U(478,d+20|0,12,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break gb}e=lo(Oe(e,x[Zb(s,f)+12>>2]-1|0));x[114409]=0;O(479,c|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break gb}if(z[d+100>>1]>f>>>0){break ib}w[d+100>>1]=f+1}x[114409]=0;S(834,d+180|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){continue}break O}break}f=N()|0;break J}f=N()|0;break J}f=N()|0;break J}f=N()|0;break J}ku(j);F=F+1|0;if(y[I|0]>(F&255)>>>0){continue}break}}x[114409]=0;P(468,a+484360|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){if(!(u&1)){e=z[a+480192>>1];if(e){f=1;while(1){b=(((f&65535)<<2)+a|0)+900380|0;c=x[b>>2];if(c){_b(nu(c));e=z[a+480192>>1]}x[b>>2]=0;f=f+1|0;if((f&65535)>>>0<=(e&65535)>>>0){continue}break}}w[a+480192>>1]=0}nb:{ob:{pb:{qb:{rb:{sb:{tb:{if(X){x[114409]=0;b=O(2,d+180|0,12244)|0;c=x[114409];x[114409]=0;if((c|0)==1){break tb}x[114409]=0;T(655,a|0,2,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break sb}xb(b)}e=17381;switch(y[d+875|0]){case 3:break ob;case 2:break pb;case 1:break qb;case 0:break rb;default:break nb}}f=N()|0;break g}f=N()|0;xb(b);break g}e=z[a+480188>>1]>4?13174:13160;break nb}e=13106;break nb}e=13075;break nb}e=13048}x[114409]=0;b=O(2,d+8|0,13124)|0;c=x[114409];x[114409]=0;ub:{vb:{wb:{xb:{yb:{if((c|0)!=1){x[114409]=0;P(192,d+76|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break yb}x[114409]=0;T(530,d+116|0,d+76|0,d+875|0);c=x[114409];x[114409]=0;if((c|0)==1){break xb}c=d+116|0;Eb(a+1304436|0,c);xb(c);Gb(d+76|0);xb(b);x[114409]=0;b=O(2,c|0,8478)|0;c=x[114409];x[114409]=0;if((c|0)==1){break vb}Eb(a+1304448|0,b);xb(b);x[114409]=0;O(211,a+1304460|0,e|0)|0;b=x[114409];x[114409]=0;f=1;if((b|0)==1){break ub}x[a+1304496>>2]=2;break d}f=N()|0;break g}f=N()|0;break wb}f=N()|0;Gb(d+76|0)}xb(b);break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break J}f=N()|0;Ab(k)}xb(c);break J}f=N()|0;break J}f=N()|0}ku(j);break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;Ab(l)}iS(C)}Ab(d+856|0);Q(f|0);p()}f=0}iS(C)}Ab(d+856|0)}hb=d+928|0;return f|0}R(0)|0;zb();p()}function st(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,X=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;k=hb-176|0;hb=k;f=hb-16|0;hb=f;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[f+12>>2]=0;U(1455,a+8|0,f+12|0,f+11|0)|0;g=x[114409];x[114409]=0;a:{if((g|0)!=1){hb=f+16|0;break a}R(0)|0;zb();p()}ja=a;s=k+144|0;v[s+26|0]=0;w[s+24>>1]=0;x[s+16>>2]=0;x[s+20>>2]=-1;x[s+8>>2]=-1;x[s+12>>2]=-1;x[s>>2]=0;x[s+4>>2]=0;qa=x[d+16>>2];ca=y[d+6|0];ka=b+484360|0;if(ca>>>0>=ai(ka)>>>0){ca=y[ka+16|0]}H=Ti(ka,ca);x[114409]=0;B=O(1413,k+104|0,b|0)|0;a=x[114409];x[114409]=0;b:{if((a|0)!=1){f=x[B+4>>2];x[114409]=0;Y=U(1414,k+72|0,b|0,ca|0)|0;a=x[114409];x[114409]=0;c:{if((a|0)!=1){m=x[d>>2];d:{e:{a=z[d+4>>1];f:{if(a>>>0>=rc(H)>>>0){break f}while(1){x[114409]=0;g=O(539,H|0,a&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}if(g){break f}m=0;a=a+1|0;if(rc(H)>>>0>(a&65535)>>>0){continue}break}}x[d>>2]=m;w[d+4>>1]=a;x[f+52>>2]=m;x[f+48>>2]=m;x[s+16>>2]=m;w[f+64>>1]=a;w[f+62>>1]=a;w[s+24>>1]=a;M=Po(k- -64|0);ra=Zc(k+60|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{sa=c&7;wa=(sa|0)!=7;s:{if(wa){break s}x[114409]=0;U(1415,M|0,1,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,2,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,3,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,28,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,35,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,37,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,36,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1415,M|0,38,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1416,ra|0,12,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;U(1416,ra|0,13,1)|0;a=x[114409];x[114409]=0;if((a|0)==1){break r}if((qa|0)!=2){break s}a=z[d+12>>1];if(rc(H)>>>0<=a>>>0){break s}a=z[vc(H,a)>>1];x[114409]=0;g=b+484344|0;e=O(414,g|0,a|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break g}if(!e){break s}m=Zb(g,a);e=x[d+8>>2];x[114409]=0;m=O(1417,m|0,e|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break g}if(!m){break s}a=Zb(g,a);x[114409]=0;a=U(451,a|0,e|0,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break h}if(!z[b+480188>>1]){break s}g=B+20|0;while(1){t:{u:{v:{switch(y[a|0]-253|0){case 0:if(z[b+480192>>1]){break u}break;case 1:case 2:break u;default:break v}}x[114409]=0;e=S(546,a|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break i}if(!e){break t}if(tt(a)){break t}}ya=Vc(g,h),za=-1,x[ya+16>>2]=za}a=a+6|0;h=h+1|0;if(h>>>0<z[b+480188>>1]){continue}break}}$=f- -64|0;J=f+48|0;_=f+68|0;na=f+44|0;ta=B+8|0;da=c&1;u=B+20|0;F=b+1074312|0;L=b+484344|0;m=0;while(1){x[f+48>>2]=x[f+52>>2];a=z[f+64>>1];w[f+62>>1]=a;x[114409]=0;a=O(539,H|0,a|0)|0;g=x[114409];x[114409]=0;w:{if((g|0)!=1){x:{if(!a){break x}if(A[f+48>>2]<A[Zb(L,z[vc(H,z[f+62>>1])>>1])+12>>2]){break x}x[J>>2]=0;a=k+4|0;Kb(a,F,63);if(Ib(a)){a=x[f+56>>2];x[f+56>>2]=0;x[f+48>>2]=a}a=z[f+64>>1]+1|0;w[f+62>>1]=a;w[f+64>>1]=a}a=x[d+16>>2];if(!(C[B+32>>3]>=C[d+8>>3])|(a|0)!=3){break w}break k}a=N()|0;break d}g=z[f+62>>1];y:{if(rc(H)>>>0>g>>>0){g=z[vc(H,z[f+62>>1])>>1];break y}g=65535}w[f+60>>1]=g;x[114409]=0;g=O(414,L|0,g&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}if(!(z[f+60>>1]==65535|(a|0)!=2|g)&z[f+62>>1]==z[d+12>>1]){break k}z:{if(z[f+60>>1]<Ne(L)>>>0){break z}while(1){A:{B:{if(z[f+60>>1]!=65535){g=z[f+62>>1];if(rc(H)>>>0>g>>>0){break B}}if(z[H+28>>1]==z[f+62>>1]){break z}g=z[H+28>>1];break A}g=z[f+62>>1]+1|0}w[f+62>>1]=g;C:{if(rc(H)>>>0>(g&65535)>>>0){g=z[vc(H,z[f+62>>1])>>1];break C}g=65535}w[f+60>>1]=g;w[f+64>>1]=z[f+62>>1];x[114409]=0;g=O(414,L|0,g&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}D:{if(g){break D}g=z[f+62>>1];x[114409]=0;g=Z(1418,Y|0,g|0,0,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}if(!g){break D}if(qa>>>0<=1){g=z[f+62>>1];x[s+8>>2]=0;w[s+20>>1]=g}if(!a){break z}x[114409]=0;g=Z(1419,Y|0,$|0,J|0,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}if(!g){break z}C[s>>3]=C[B+32>>3];x[114409]=0;P(1420,ja|0,s|0);g=x[114409];x[114409]=0;if((g|0)==1){break m}x[s+16>>2]=x[J>>2];w[s+24>>1]=z[$>>1];x[114409]=0;V(1421,B|0);g=x[114409];x[114409]=0;if((g|0)==1){break m}g=z[f+64>>1];w[f+62>>1]=g;ya=f,za=z[vc(H,g)>>1],w[ya+60>>1]=za;x[f+52>>2]=x[f+48>>2];break z}if(z[f+60>>1]>=Ne(L)>>>0){continue}break}}if(z[$>>1]==65535){break j}g=z[f+60>>1];x[114409]=0;g=O(414,L|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}if(!g){if(z[H+28>>1]==z[f+62>>1]){if(!a){break j}x[114409]=0;a=Z(1419,Y|0,$|0,J|0,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break m}if(!a){break j}C[s>>3]=C[B+32>>3];x[114409]=0;P(1420,ja|0,s|0);a=x[114409];x[114409]=0;if((a|0)==1){break m}x[s+16>>2]=x[J>>2];w[s+24>>1]=z[$>>1];x[114409]=0;V(1421,B|0);a=x[114409];x[114409]=0;if((a|0)==1){break m}x[f+52>>2]=x[f+48>>2];continue}w[f+64>>1]=z[f+62>>1]+1;continue}if(A[f+48>>2]>=A[Zb(L,z[f+60>>1])+12>>2]){x[J>>2]=0}g=z[f+62>>1];if(!((a|0)!=2|(g|0)!=z[d+12>>1])&x[J>>2]==x[d+8>>2]){break k}e=x[J>>2];x[114409]=0;g=Z(1418,Y|0,g|0,e|0,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}if(g){if(qa>>>0<=1){w[s+20>>1]=z[f+62>>1];x[s+8>>2]=x[f+48>>2]}if(!a){break j}x[114409]=0;a=Z(1419,Y|0,$|0,J|0,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break m}if(!a){break j}C[s>>3]=C[B+32>>3];x[114409]=0;P(1420,ja|0,s|0);a=x[114409];x[114409]=0;if((a|0)==1){break m}x[s+16>>2]=x[J>>2];w[s+24>>1]=z[$>>1];x[114409]=0;V(1421,B|0);a=x[114409];x[114409]=0;if((a|0)==1){break m}x[f+52>>2]=x[f+48>>2];continue}w[s+22>>1]=z[f+62>>1];a=x[f+48>>2];x[s+12>>2]=a;x[f+52>>2]=a+1;E:{F:{if(a>>>0>=A[Zb(L,z[f+60>>1])+12>>2]){x[J>>2]=0;break F}if(x[J>>2]){break E}}a=0;if(!z[b+480188>>1]){break E}while(1){I=C[B+32>>3];ya=Vc(u,a),Aa=I,C[ya>>3]=Aa;g=x[f>>2];ya=Vc(u,a),za=g,x[ya+8>>2]=za;a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}a=Zb(L,z[f+60>>1]);g=x[f+48>>2];x[114409]=0;a=U(451,a|0,g|0,0)|0;g=x[114409];x[114409]=0;G:{H:{if((g|0)!=1){g=0;oa=0;ba=0;h=0;if(z[b+480188>>1]){break H}break G}a=N()|0;break d}while(1){e=k+4|0;Kb(e,F,77);I:{if(ya=Ib(e),za=0,Ba=x[((h<<5)+b|0)+480280>>2]&1024,Ba?ya:za){break I}x[114409]=0;e=S(1422,a|0)|0;j=x[114409];x[114409]=0;J:{K:{L:{M:{N:{O:{if((j|0)==1){break O}if(e){P:{if(!da){break P}e=y[a+1|0];if(e-251>>>0<5|!e){break P}x[114409]=0;j=S(1423,a|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break O}x[114409]=0;e=S(1424,a|0)|0;t=x[114409];x[114409]=0;if((t|0)==1){break L}w[k+48>>1]=e;e=k+4|0;v[e|0]=y[a+1|0];w[e+2>>1]=z[k+48>>1];x[114409]=0;e=O(1425,ta|0,e|0)|0;t=x[114409];x[114409]=0;if((t|0)==1){break L}w[e>>1]=j}au((D(h,896)+f|0)+1418|0);break I}j=D(h,896)+f|0;e=j+1422|0;t=y[a+4|0]|y[a+5|0]<<8;v[e|0]=t;v[e+1|0]=t>>>8;e=j+1418|0;t=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[e|0]=t;v[e+1|0]=t>>>8;v[e+2|0]=t>>>16;v[e+3|0]=t>>>24;Q:{R:{switch(y[a+3|0]-16|0){case 1:e=k+4|0;Kb(e,F,5);if(!Ib(e)){break I}r=y[a+5|0];if(r){break Q}break I;case 3:break M;case 4:break N;case 0:break R;default:break I}}r=y[a+5|0]}x[114409]=0;T(1426,b|0,f|0,r&255);e=x[114409];x[114409]=0;if((e|0)!=1){break I}}a=N()|0;break d}q=j+1461|0;t=j+1423|0;e=y[t|0];if(!e){if(x[b+480180>>2]&16777250){break K}e=y[t|0]}v[q|0]=e;break J}e=y[a+5|0];if((e&240)!=224){break I}ba=(e&15)+1|0;break I}a=N()|0;break d}v[t|0]=y[j+1461|0]}e=y[a+5|0];j=e&240;if((j|0)==96){oa=(e&15)+oa|0;break I}if((j|0)!=224|ba){break I}e=y[a+5|0]&15;if(x[b+480180>>2]&2){ba=0;if(!e){break I}}ba=e+1|0}a=a+6|0;h=h+1|0;if(h>>>0<z[b+480188>>1]){continue}break}}n=ba>>>0<=1?1:ba;t=D(n,x[f+40>>2]+oa|0);la=0;ua=0;ea=0;ma=0;if(z[b+480188>>1]){X=t-1|0;e=t-n|0;ga=D(e,1e4);h=0;while(1){l=0;j=D(h,896)+f|0;o=j+1418|0;a=o;if(!(y[a|0]|y[a+1|0]|y[a+2|0])){l=!y[a+3|0]}S:{if(l){break S}a=k+4|0;Kb(a,F,77);if(ya=Ib(a),za=0,Ba=x[((h<<5)+b|0)+480280>>2]&1024,Ba?ya:za){break S}i=y[j+1423|0];pa=j+1421|0;r=y[pa|0];l=y[o|0];a=j+1419|0;q=y[a|0];if(q){v[j+1429|0]=0;v[j+1433|0]=q;ya=Vc(u,h),za=255,v[ya+21|0]=za}x[114409]=0;G=S(546,o|0)|0;q=x[114409];x[114409]=0;if((q|0)==1){break n}q=j+608|0;if(G){v[j+1429|0]=l;x[114409]=0;V(1427,q|0);G=x[114409];x[114409]=0;if((G|0)==1){break n}}x[114409]=0;G=S(546,o|0)|0;ha=x[114409];x[114409]=0;if((ha|0)==1){break n}T:{U:{V:{W:{X:{Y:{if(!(G|y[a|0])){break Y}G=j+1433|0;a=y[G|0];if(z[b+480192>>1]){if(z[b+480192>>1]<a>>>0){break Y}a=x[((y[G|0]<<2)+b|0)+900380>>2];if(!a){break Y}Z:{if(!(v[a+15|0]&1)){break Z}G=x[a+8>>2];x[114409]=0;T(1428,q|0,G|0,b|0);G=x[114409];x[114409]=0;if((G|0)!=1){break Z}a=N()|0;break d}if(!be(l)){break Y}a=z[fd(a+236|0,l-1|0)>>1]}if(!a|z[b+480190>>1]<a>>>0){break Y}a=D(a,104)+b|0;if(!(y[a+484414|0]&32)){break Y}a=z[a+484408>>1];x[114409]=0;T(1428,q|0,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break X}}_:{$:{aa:{G=j+1420|0;a=y[G|0];switch(a-1|0){case 1:break V;case 2:case 3:break $;case 0:break aa;default:break _}}a=y[j+1422|0];ya=Vc(u,h),za=a,v[ya+21|0]=za;break V}a=y[j+1422|0];if(!a){break V}v[j+1462|0]=a;break V}if((a|0)==11){break W}break V}a=N()|0;break d}if(!y[j+1422|0]){break V}a=k+4|0;Yy(a,b,o,0);l=mc(a);x[j+1384>>2]=x[a>>2];if(!y[l|0]){break V}r=0;break U}ba:{ca:{da:{switch(r-12|0){case 0:a=x[f+48>>2];l=z[f+60>>1];x[114409]=0;a=aa(1429,b|0,l|0,a|0,h&65535,0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break n}x[f+56>>2]=0;w[f+64>>1]=a;if(!(!(x[b+480180>>2]&5)&ua)){x[f+52>>2]=0}ea=1;if(!da){ma=1;break S}x[j+1412>>2]=0;v[j+1469|0]=0;ma=1;break T;case 2:x[114409]=0;a=Z(1430,b|0,f|0,h&65535,i|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break ca}if((a|0)==-1){r=14;break U}x[f+52>>2]=a;if(!ma){w[f+64>>1]=z[f+62>>1]+1}ua=1;if(!da){break S}x[j+1412>>2]=0;v[j+1469|0]=0;break T;case 5:a=k+4|0;Kb(a,F,5);r=17;if(Ib(a)){break U}a=x[f+48>>2];l=z[f+60>>1];x[114409]=0;a=aa(1429,b|0,l|0,a|0,h&65535,0)|0;l=x[114409];x[114409]=0;ea:{fa:{if((l|0)!=1){x[k+48>>2]=D(a,1e4);if(!da|!(x[b+480180>>2]&16777250)){break ea}a=x[k+48>>2];if(a>>>0<1e4){break fa}v[j+1463|0]=(a>>>0)/1e4;break ea}a=N()|0;break d}x[k+48>>2]=D(y[j+1463|0],1e4)}a=x[b+8>>2];o=x[k+48>>2];if(o>>>0>=32e4){a=x[a+24>>2];x[114409]=0;x[k+4>>2]=D(a,1e4);a=O(1431,k+48|0,k+4|0)|0;l=x[114409];x[114409]=0;if((l|0)!=1){x[na>>2]=x[a>>2];break U}a=N()|0;break d}l=x[na>>2];ha=(o>>>0)/1e4|0;K=D(ga,ha&15);o=l-K|0;x[na>>2]=(ha&240)==16?l+K|0:l>>>0>=o>>>0?o:0;l=x[a+20>>2];a=x[a+24>>2];o=k+4|0;Kb(o,F,8);Jo(na,D(l,1e4),Ib(o)?255e4:D(a,1e4));break U;case 8:r=20;ga:{switch((i&240)-144>>>4|0){case 0:if(i>>>0>145){break U}x[j+696>>2]=x[j+696>>2]&-257|((i|0)==145)<<8;break U;case 1:v[j+1464|0]=i&15;break U;case 2:o=h;a=h;if(x[b+480180>>2]==2){o=z[b+480188>>1]-1|0;a=0}if(!(i&15)){ea=0;g=1;l=o&65535;if(l>>>0<(a&65535)>>>0){break U}while(1){I=C[B+32>>3];g=a&65535;ya=Vc(u,g),Aa=I,C[ya>>3]=Aa;o=x[f>>2];ya=Vc(u,g),za=o,x[ya+8>>2]=za;o=x[f+48>>2];ya=Vc(u,g),za=o,x[ya+12>>2]=za;x[(D(g,896)+f|0)+1412>>2]=x[f+48>>2];g=1;a=a+1|0;if(l>>>0>=(a&65535)>>>0){continue}break}break U}l=k+4|0;Kb(l,F,16);if(!Ib(l)){ea=0;la=1;if(x[b+480180>>2]!=2|(a&65535)>>>0>(o&65535)>>>0){break U}break ba}if((a&65535)>>>0<=(o&65535)>>>0){break ba}ea=0;la=1;break U;case 6:break ga;default:break U}}v[j+1472|0]=i&15;break U;case 7:r=19;a=i&240;if((a|0)!=240){if((a|0)!=96){break U}if(i&15){ya=f,za=x[Vc(u,h)+12>>2],x[ya+56>>2]=za;la=1;break U}I=C[B+32>>3];ya=Vc(u,h),Aa=I,C[ya>>3]=Aa;a=x[f>>2];ya=Vc(u,h),za=a,x[ya+8>>2]=za;a=x[f+48>>2];ya=Vc(u,h),za=a,x[ya+12>>2]=za;x[j+1412>>2]=x[f+48>>2];g=1;break U}v[j+1472|0]=i&15;break U;case 1:case 3:case 4:case 6:break U;default:break da}}if((r|0)!=28){break U}if((i&240)==160){a=k+4|0;Kb(a,F,58);r=28;if(Ib(a)){break U}v[j+1464|0]=i&15;break U}r=28;break U}a=N()|0;break d}l=x[J>>2]+1|0;while(1){x[(D(a&65535,896)+f|0)+1412>>2]=l;la=1;ea=0;a=a+1|0;if((a&65535)>>>0<=(o&65535)>>>0){continue}break}}if(!da){break S}ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{switch(r-2|0){case 0:if(!i){break ha}a=k+4|0;Kb(a,F,90);if(!Ib(a)){v[j+1440|0]=i}v[j+1439|0]=i;break T;case 1:if(!i){break ha}a=k+4|0;Kb(a,F,90);if(!Ib(a)){v[j+1439|0]=i}v[j+1440|0]=i;break T;case 2:if(!i){break ha}x[j+1384>>2]=i;break T;case 8:if(!i){break ha}x[j+1272>>2]=i<<8;break T;case 4:case 9:if(!i){break ha}v[j+1437|0]=i;break T;case 11:ya=Vc(u,h),za=i,v[ya+21|0]=za;break T;case 21:i=i<<(!(x[b+480180>>2]&59593760)&i<<24>>24>=0);a=i&255;if(a>>>0<=128){x[_>>2]=a<<1;break T}if(x[b+480180>>2]&16777250){break T}x[_>>2]=256;break T;case 22:a=k+4|0;Kb(a,F,9);pa:{if(Ib(a)){a=j+1445|0;if(i){v[a|0]=i;break pa}i=y[a|0];break pa}if(i){v[f+1445|0]=i;break pa}i=y[f+1445|0]}a=i&15;l=i&255;qa:{if(!((a|0)!=15|l>>>0<16)){i=(i&240)>>>4<<!(x[b+480180>>2]&59593760);a=x[_>>2]+(i<<1)|0;break qa}l=l&240;if(!(!a|(l|0)!=240)){i=a<<(x[b+480180>>2]&59593760?1:2);a=x[_>>2]-i|0;break qa}if(l){i=(i>>>3&30)<<!(x[b+480180>>2]&59593760);a=x[_>>2]+D(e,i)|0;break qa}i=a<<(x[b+480180>>2]&59593760?1:2);a=x[_>>2]-D(e,i)|0}x[_>>2]=a;ce(_,0,256);break T;case 19:if(i>>>0>64){break T}x[j+1368>>2]=i;break T;case 20:a=j+1444|0;ra:{if(i){v[a|0]=i;break ra}i=y[a|0]}r=j+1368|0;a=x[r>>2];l=i&15;o=i&255;sa:{if(!((l|0)!=15|o>>>0<16)){x[k+4>>2]=a+(o>>>4|0);break sa}if(!(!l|(o&240)!=240)){x[k+4>>2]=a-l;break sa}if(l){x[k+4>>2]=a-D(e,l);break sa}x[k+4>>2]=a+D(e,o>>>4|0)}ce(k+4|0,0,64);x[r>>2]=x[k+4>>2];break T;case 7:Xl(b,q,i,8);break T;case 25:break ia;case 6:break ja;case 24:break ka;case 3:break la;case 5:break ma;case 18:break na;case 17:break oa;default:break T}}if(!z[b+480188>>1]|i>>>0>15){break na}l=(i&1)<<14;a=0;while(1){o=D(a,896)+f|0;x[o+696>>2]=(l|x[o+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}if((i&240)!=128){break T}Xl(b,q,i&15,4);break T}if(i){v[j+1437|0]=i}i=0}Kk(q,i);break T}MN(b,q,i);break T}LN(q,i);break T}KN(q,i);break T}i=0}ta:{ua:{switch(y[G|0]-2|0){case 0:Xl(b,q,y[j+1422|0],6);break ta;case 5:a=k+4|0;Kb(a,F,53);l=Ib(a);a=y[j+1422|0];if(l){v[j+1451|0]=a&15;break ta}Kk(q,a<<4);break ta;case 6:break ua;default:break ta}}Kk(q,y[j+1422|0])}va:{wa:{xa:{ya:{za:{a=y[pa|0];switch(a-5|0){case 1:break va;case 3:break xa;case 0:case 2:break ya;default:break za}}switch(a-26|0){case 1:break wa;case 0:break ya;default:break va}}Aa:{if(x[b+480180>>2]&16777248){a=t;if(!(y[b+480208|0]&4)){break Aa}}a=e}l=y[j+1451|0];o=k+4|0;Kb(o,F,21);o=Ib(o);j=j+1447|0;a=D(a,l);v[j|0]=y[j|0]+(o?a<<2:a);break va}Ba:{if(x[b+480180>>2]&16777248){a=t;if(!(y[b+480208|0]&4)){break Ba}}a=e}l=y[j+1454|0];o=k+4|0;Kb(o,F,21);o=Ib(o);j=j+1448|0;a=D(a,l);v[j|0]=y[j|0]+(o?a<<2:a);break va}a=j+1449|0;v[a|0]=y[a|0]+D(X,y[j+1457|0]);x[114409]=0;P(1432,b|0,q|0);a=x[114409];x[114409]=0;if((a|0)==1){break n}}a=k+4|0;Kb(a,F,78);if(!Ib(a)){break S}a=i&255;if(!a){break S}JN(q,a)}h=h+1|0;if(h>>>0<z[b+480188>>1]){continue}break}}if(x[b+480180>>2]==4&x[f+40>>2]==65535){break j}x[f+32>>2]=x[b+480216>>2];if(IN(Zb(L,z[f+60>>1]))){ya=f,za=x[Zb(L,z[f+60>>1])+16>>2],x[ya+32>>2]=za}x[114409]=0;j=O(1433,b|0,f|0)|0;a=x[114409];x[114409]=0;Ca:{Da:{if((a|0)!=1){a=D(j,t);C[B+32>>3]=+(a>>>0)/+A[b+24620>>2]+C[B+32>>3];x[f>>2]=a+x[f>>2];if(!(!z[b+480188>>1]|wa)){r=0;pa=(m|0)!=0&(j|0)!=(m|0);G=t>>>0<=1?1:t;ha=n-1|0;while(1){Ea:{if(x[Vc(u,r)+16>>2]==-1){break Ea}o=1;Fa:{Ga:{n=D(r,896)+f|0;X=n+1421|0;switch(y[X|0]-4|0){case 0:case 2:break Fa;default:break Ga}}o=y[n+1420|0]==11}if(y[n+1419|0]){x[n+1268>>2]=0}i=n+1423|0;h=y[i|0];x[114409]=0;ga=n+1418|0;a=S(546,ga|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break p}q=n+608|0;e=h&15;l=0;Ha:{if(!a){break Ha}Ia:{Ja:{Ka:{if(!o){break Ka}if(!y[Vc(u,r)+20|0]){break Ka}a=x[n+1308>>2];x[114409]=0;a=Zo(1434,b,q,a,0);l=lb;K=x[114409];x[114409]=0;if((K|0)==1){break Ja}x[n+616>>2]=a;x[n+620>>2]=l}v[n+1432|0]=y[n+1429|0];K=n+1300|0;xa=x[K>>2];a=y[n+1433|0];if(!a){break Ia}x[114409]=0;ia(1435,b|0,q|0,a|0,o|0,1,1);a=x[114409];x[114409]=0;if((a|0)!=1){break Ia}break o}a=N()|0;break d}a=y[ga|0];x[114409]=0;fa(1436,b|0,q|0,a|0,o|0,1,0,65535);a=x[114409];x[114409]=0;if((a|0)==1){break o}a=h>>>4|0;ya=Vc(u,r),za=1,v[ya+20|0]=za;h=y[X|0];La:{if(!((y[i|0]&240)!=208|(h-19&255)>>>0>1)){l=e;if(e>>>0<t>>>0){break La}}l=(h|0)==33?a>>>0<t>>>0?a:0:0}l=!(x[b+480180>>2]&16777250)|(!l|ba>>>0<2)?l:D(ha,x[f+40>>2]+oa|0)+l|0;if(!o){ya=Vc(u,r),za=0,x[ya+16>>2]=za}h=y[X|0];Ma:{Na:{if((h|0)==9){break Na}Oa:{if((h|0)!=19){if((h|0)!=20|(a|0)!=8){break Oa}break Na}if((a|0)==8){break Na}}if(y[n+1420|0]!=2){break Ma}}x[K>>2]=xa}Pa:{Qa:{switch(h-39|0){default:if((h|0)!=10){break Pa}v[k+4|0]=0;a=x[f+48>>2];h=z[f+60>>1];x[114409]=0;a=aa(1429,b|0,h|0,a|0,r&65535,k+4|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){if(!y[k+4|0]){a=a<<8;if(!a){a=x[n+1272>>2]}a=(y[n+1464|0]<<16)+a|0}x[114409]=0;T(1437,b|0,q|0,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){break Ha}}a=N()|0;break d;case 2:a=x[n+684>>2];h=y[i|0];x[114409]=0;h=sqa(h,0,a,0);a=lb;K=a>>>8|0;a=cg(761,(a&255)<<24|h>>>8,K);h=x[114409];x[114409]=0;if((h|0)==1){break o}x[114409]=0;T(1437,b|0,q|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break o}break Ha;case 1:break Pa;case 0:break Qa}}if(!x[n+712>>2]){break Pa}x[114409]=0;W(1438,B|0,r&65535,m|0,-1);a=x[114409];x[114409]=0;if((a|0)==1){break o}a=y[i|0];x[114409]=0;T(1439,f|0,q|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break o}l=x[f+40>>2]-1|0;break Ha}if(y[n+1420|0]!=15){break Ha}h=x[n+712>>2];if(!h){break Ha}a=y[n+1422|0];if(a>>>0>9){break Ha}Ra:{if(!a){a=x[n+1272>>2];break Ra}a=x[(h+(a<<2)|0)- -64>>2];x[n+1272>>2]=a}x[114409]=0;T(1437,b|0,q|0,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){break Ha}a=N()|0;break d}Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{switch(y[ga|0]-253|0){case 0:if(z[b+480192>>1]){break _a}break;case 1:case 2:break _a;default:break $a}}h=y[X|0];if((h-19&255)>>>0<=1){if((y[i|0]&240)!=192){a=g;break Ya}a=g;if(e>>>0<t>>>0){break _a}break Ya}if((h|0)==25){break _a}a=g;if(!((h|0)==33&(e|0)!=0&e+l>>>0<t>>>0)){break Za}}h=y[X|0];a=1}if((h|0)==13){break Xa}}if(y[n+1420|0]==1){x[n+1296>>2]=y[n+1422|0]<<2}if((!x[n+712>>2]|a)&1){break Wa}e=0;if(h>>>0>42){break Ua}break Va}x[n+1296>>2]=y[i|0]<<2;h=13;if(!((!x[n+712>>2]|a)&1)){break Va}}if(!(a&1)){break Ta}break Sa}K=k+4|0;Kb(K,M,h);e=1;if(Ib(K)){break Ua}e=a;if(y[X|0]!=19){break Ua}h=y[i|0]&240;if((h|0)!=32){e=a;if((h|0)!=16){break Ua}}e=1}a=n+1420|0;if(y[a|0]<16){h=k+4|0;tl(h,ra,y[a|0]);if((Ib(h)|e)&1){break Sa}break Ta}if(e&1){break Sa}}if(pa){x[114409]=0;W(1438,B|0,r&65535,m|0,-1);a=x[114409];x[114409]=0;if((a|0)==1){break p}}ab:{bb:{cb:{a=y[X|0];if(a-6>>>0>=2){db:{switch(a-19|0){case 1:break bb;case 0:break cb;default:break db}}if((a|0)!=11){break ab}}if(!t|!y[i|0]&x[b+480180>>2]==1){break ab}a=n+1480|0;h=0;while(1){v[a|0]=!h|y[a|0]&254;Gn(b,q,y[i|0]);h=h+1|0;if((G|0)!=(h|0)){continue}break}break ab}h=y[i|0];if(!(h&15)){if(!(x[b+480180>>2]&1048580)){break ab}h=y[i|0]}a=n+1480|0;v[a|0]=y[a|0]|1;a=h&240;if((a|0)!=176){if((a|0)!=160){break ab}Sp(b,q,h&15,0);break ab}Rp(b,q,h&15,0);break ab}eb:{fb:{gb:{a=y[i|0];switch(a-158|0){case 1:break fb;case 0:break gb;default:break eb}}x[114409]=0;W(1438,B|0,r&65535,m|0,-1);a=x[114409];x[114409]=0;if((a|0)==1){break p}x[n+696>>2]=x[n+696>>2]&-129;break ab}x[114409]=0;W(1438,B|0,r&65535,m|0,-1);a=x[114409];x[114409]=0;if((a|0)==1){break p}x[n+696>>2]=x[n+696>>2]|128;if(!x[n+684>>2]|x[q+4>>2]){break ab}x[114409]=0;a=S(546,ga|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break p}if(!(y[n+696|0]&2?a:1)){break ab}a=x[n+684>>2]-1|0;x[q>>2]=-1;x[q+4>>2]=a;break ab}if((a&240)!=112|a>>>0<115){break ab}x[114409]=0;T(1440,q|0,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break p}}e=n+1480|0;v[e|0]=y[e|0]|1;hb:{ib:{jb:{kb:{a=n+1420|0;switch(y[a|0]-3|0){case 0:case 1:break ib;case 3:break jb;case 2:break kb;default:break hb}}a=y[n+1422|0];e=k+4|0;Kb(e,F,41);Sp(b,q,a,Ib(e));break hb}a=y[n+1422|0];e=k+4|0;Kb(e,F,41);Rp(b,q,a,Ib(e));break hb}i=y[n+1422|0];lb:{if(i){break lb}h=k+4|0;Kb(h,F,41);i=0;if(!Ib(h)){break lb}i=y[n+1462|0];if(!i){break hb}}if(!t){break hb}h=y[a|0]==3?i<<4:i;a=0;while(1){v[e|0]=!a|y[e|0]&254;Gn(b,q,h&255);a=a+1|0;if((t|0)!=(a|0)){continue}break}}if(o){a=x[Vc(u,r)+16>>2];e=Vc(u,r);x[e+16>>2]=x[e+16>>2]+t;x[114409]=0;W(1438,B|0,r&65535,j|0,(a+l|0)+1|0);a=x[114409];x[114409]=0;if((a|0)!=1){break Ea}a=N()|0;break d}a=Vc(u,r);x[a+16>>2]=x[a+16>>2]+(t-l|0);break Ea}x[114409]=0;V(1441,q|0);a=x[114409];x[114409]=0;if((a|0)==1){break p}ya=Vc(u,r),za=0,x[ya+16>>2]=za}r=r+1|0;if(r>>>0<z[b+480188>>1]){continue}break}}if(!la){break Ca}a=k+4|0;Kb(a,F,68);if(ya=Ib(a),za=0,Ba=ma|ua,Ba?ya:za){break Ca}a=k+48|0;Kb(a,F,49);if(Ib(a)&ma){break Ca}a=k+40|0;Kb(a,F,103);m=j;if(Ib(a)&ea){continue}a=0;m=hb-16|0;hb=m;h=m+15|0;e=hb-16|0;hb=e;x[114409]=0;g=k+4|0;S(1460,g+4|0)|0;t=x[114409];x[114409]=0;mb:{nb:{if((t|0)==1){break nb}x[114409]=0;x[e+12>>2]=0;U(1461,g+8|0,e+12|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break nb}ya=g,za=mc(g),x[ya>>2]=za;hb=e+16|0;break mb}R(0)|0;zb();p()}hb=m+16|0;if(!z[b+480188>>1]){break Da}while(1){ob:{m=D(a,896)+f|0;e=y[m+1423|0];m=y[m+1421|0];if(!(!(!((m|0)!=20|e>>>0<177)&e>>>0<192)&(e>>>0<97|e>>>0>111|(m|0)!=19))){I=C[Vc(u,a)>>3];x[114409]=0;C[k+48>>3]=I;m=O(1442,g|0,k+48|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ob}if(!x[m>>2]){x[114409]=0;m=O(1442,g|0,k+48|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ob}x[m>>2]=1}x[114409]=0;m=O(1442,g|0,k+48|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ob}m=x[m>>2];x[114409]=0;e=O(1443,m|0,(e&15)+1|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break ob}x[114409]=0;m=O(1442,g|0,k+48|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ob}x[m>>2]=e}a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break Da}break}break q}a=N()|0;break d}ya=k,za=Xn(g),x[ya+40>>2]=za;ya=k,za=Zi(g),x[ya+36>>2]=za;while(1){x[114409]=0;a=O(1444,k+40|0,k+36|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}if(!a){pb:{if(x[b+480180>>2]!=32){break pb}a=0;if(!z[b+480188>>1]){break pb}while(1){e=D(a,896)+f|0;if(!(y[e+1421|0]!=20|(y[e+1423|0]+79&255)>>>0>14)){I=C[B+32>>3];ya=Vc(u,a),Aa=I,C[ya>>3]=Aa;e=x[f>>2];ya=Vc(u,a),za=e,x[ya+8>>2]=za}a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}AN(g);break Ca}x[114409]=0;e=S(1445,k+40|0)|0;a=x[114409];x[114409]=0;qb:{rb:{if((a|0)!=1){m=yb(e);I=C[B+32>>3];C[B+32>>3]=(I-C[e>>3])*+(x[m>>2]-1|0)+I;a=0;if(z[b+480188>>1]){break rb}break qb}break q}while(1){if(C[Vc(u,a)>>3]!=C[e>>3]){a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break qb}break}e=x[f>>2];h=Vc(u,a);x[f>>2]=x[f>>2]+D(x[m>>2]-1|0,e-x[h+8>>2]|0);e=k+48|0;Kb(e,F,16);if(!Ib(e)&x[b+480180>>2]!=2){break qb}I=C[B+32>>3];ya=Vc(u,a),Aa=I,C[ya>>3]=Aa;e=x[f>>2];ya=Vc(u,a),za=e,x[ya+8>>2]=za;e=x[f+48>>2];ya=Vc(u,a),za=e+1|0,x[ya+12>>2]=za}x[114409]=0;S(1446,k+40|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){continue}break}break q}m=j;continue}}a=N()|0;break d}a=N()|0;AN(g);break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}v[s+26|0]=1}sb:{tb:{if(!(!z[b+480188>>1]|(sa|0)!=7)){a=0;while(1){if(x[Vc(u,a)+16>>2]!=-1){x[114409]=0;W(1438,B|0,a&65535,m|0,-1);g=x[114409];x[114409]=0;if((g|0)==1){break tb}}a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}if(y[s+26|0]){w[s+20>>1]=z[f+62>>1];x[s+8>>2]=x[f+48>>2]}C[s>>3]=C[B+32>>3];x[114409]=0;P(1420,ja|0,s|0);a=x[114409];x[114409]=0;if((a|0)==1){break sb}ub:{vb:{if(!da){break vb}wb:{if(x[d+16>>2]?y[s+26|0]:1){d=b+1074376|0;g=sc(d,f,602);a=0;while(1){e=D(a,896);Qp((e+g|0)+608|0,(f+e|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}Xy(d);a=0;x[b+1074400>>2]=0;v[b+1074464|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];d=b+1304392|0;if(yd(d)){f=x[d>>2];x[114409]=0;V(1447,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break sb}}xb:{if(z[b+480188>>1]){g=(sa|0)==7;while(1){f=D(a,896)+b|0;e=y[f+1075805|0];if(e){v[f+1075808|0]=e}if(!(y[Vc(u,a)+21|0]==255|g)){e=Vc(u,a);x[114409]=0;v[k+4|0]=64;e=O(431,e+21|0,k+4|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break xb}x[f+1075672>>2]=y[e|0]<<2}yb:{e=f+1075088|0;m=x[e>>2];if(!m|!(y[m+35|0]&2)){break yb}if(!yd(d)){break yb}m=x[d>>2];e=x[e>>2];x[114409]=0;j=m;m=a&65535;T(1448,j|0,m|0,e+68|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[d>>2];x[114409]=0;T(1449,e|0,m|0,1);e=x[114409];x[114409]=0;if((e|0)!=1){break yb}}a=N()|0;break d}x[f+1075e3>>2]=0;a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}d=Vz(k+4|0);ya=k,za=Xn(ta),x[ya+40>>2]=za;ya=k,za=Zi(ta),x[ya+36>>2]=za;zb:{while(1){Ab:{x[114409]=0;a=O(1450,k+40|0,k+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ab}if(!a){m=250;a=d;Bb:{while(1){g=1;if(x[a>>2]){break Bb}a=a+4|0;m=m-32|0;if(m>>>0>31){continue}break}g=(x[d+28>>2]&67108863)!=0}if(!g){break wb}a=0;while(1){f=k+48|0;Kb(f,d,a);Cb:{if(!Ib(f)){break Cb}f=x[(D(a,160)+b|0)+906300>>2];g=x[x[f>>2]+172>>2];x[114409]=0;V(g|0,f|0);f=x[114409];x[114409]=0;if((f|0)!=1){break Cb}a=N()|0;break d}a=a+1|0;if((a|0)!=250){continue}break}break wb}x[114409]=0;f=S(1451,k+40|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break zb}g=y[f|0]-1&255;a=x[(D(g,160)+b|0)+906300>>2];if(a){e=k+48|0;Kb(e,d,g);if(!Ib(e)){x[114409]=0;U(1452,d|0,g|0,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break ub}g=x[x[a>>2]+168>>2];x[114409]=0;P(g|0,a|0,-1);g=x[114409];x[114409]=0;if((g|0)==1){break ub}}g=z[f+2>>1];e=x[x[a>>2]+44>>2];f=z[f+4>>1];x[114409]=0;va(e|0,a|0,g|0,E(E(E(f>>>0)*E(.0010010009864345193))));a=x[114409];x[114409]=0;if((a|0)==1){break ub}}x[114409]=0;S(1453,k+40|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){continue}}break}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}if((c|0)==3){break wb}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074444>>2]=x[b+480200>>2]}if(y[ka+16|0]==(ca|0)){break vb}x[114409]=0;P(468,ka|0,ca|0);a=x[114409];x[114409]=0;if((a|0)==1){break sb}}if(c&9){x[114409]=0;P(1454,b+1304360|0,Y|0);a=x[114409];x[114409]=0;if((a|0)==1){break sb}}pt(Y);FN(B);hb=k+176|0;return}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0}pt(Y);break c}a=N()|0}FN(B);break b}a=N()|0}em(ja);Q(a|0);p()}function wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=hb-1744|0;hb=e;Nc(b);f=hb-16|0;hb=f;i=f+8|0;h=e+1618|0;cR(i,h);g=Fb(i);i=nc(b,ac(f,i));if((g|0)==(i|0)){cc(b,Fb(f+8|0))}hb=f+16|0;f=(g|0)==(i|0);if(!f){dR(h)}a:{if(!f){break a}if(!jR(e+1618|0)){break a}if(!Qb(b,id(256,0))){break a}b:{if(!c){break b}Pd(a,1048576);Ni(a);d=Vb(e+1604|0,10936);x[114409]=0;P(192,e+1344|0,d|0);f=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((f|0)!=1){r=e+1626|0;x[e+144>>2]=y[r+1|0];f=y[r|0];x[114409]=0;x[e+16>>2]=f;P(669,e+72|0,e+16|0);f=x[114409];x[114409]=0;if((f|0)==1){break q}x[114409]=0;W(654,e+256|0,e+1344|0,e+144|0,e+72|0);f=x[114409];x[114409]=0;if((f|0)==1){break p}f=e+256|0;Eb(a+1304436|0,f);xb(f);i=e+72|0;xb(i);h=e+1344|0;Gb(h);xb(d);d=Vb(f,10770);Eb(a+1304448|0,d);xb(d);Ng(i,2,e+1628|0);Kc(h,i);x[114409]=0;T(13,f|0,7,h|0);d=x[114409];x[114409]=0;if((d|0)==1){break k}d=e+256|0;Eb(a+1304460|0,d);xb(d);f=e+1344|0;xb(f);x[a+1304496>>2]=7;Qu(f,2,e+1660|0);Kc(d,f);Eb(a+1304400|0,d);xb(d);d=e+1730|0;w[a+480188>>1]=y[d|0]|y[d+1|0]<<8;d=Md(y[e+1734|0],1,31);x[a+480204>>2]=125e4;x[a+480208>>2]=32792;x[a+480196>>2]=d;t=e+1740|0;w[a+480192>>1]=y[t|0]|y[t+1|0]<<8;u=e+1742|0;w[a+480190>>1]=y[u|0]|y[u+1|0]<<8;d=Md(y[e+1735|0],1,32);x[a+480216>>2]=d;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=d<<2;bv(b,f);E=a+484360|0;s=e+1724|0;Qq(Wb(E),f,y[s|0]|y[s+1|0]<<8,65535,65535);d=e+1726|0;Pe(Wb(E),y[d|0]|y[d+1|0]<<8);o=tg(b);Ad(e+1328|0,b,o?274:0);x[114409]=0;d=S(413,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break m}x[114409]=0;T(316,e+1312|0,b|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break m}q=z[a+480188>>1];if(o){w[a+480188>>1]=q+8}C=c&1;if(!C){break l}d=e+1728|0;d=y[d|0]|y[d+1|0]<<8;x[114409]=0;P(377,a+484344|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){break l}break f}f=N()|0;break n}f=N()|0;break o}f=N()|0;xb(e+72|0)}Gb(e+1344|0)}xb(d);break c}f=N()|0;break d}m=e+1728|0;if(!(y[m|0]|y[m+1|0]<<8)){break g}B=a+484344|0;F=e+1736|0;h=0;while(1){x[114409]=0;d=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}x[114409]=0;x[e+144>>2]=d;d=S(413,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break i}x[114409]=0;T(316,e+256|0,b|0,d+1&-2);d=x[114409];x[114409]=0;if((d|0)==1){break i}zc(e+144|0,1024);r:{if(!C){break r}d=x[e+144>>2];if(!d){break r}x[114409]=0;d=U(378,B|0,h&65535,d|0)|0;f=x[114409];x[114409]=0;s:{if((f|0)!=1){if(!d){break r}j=0;if(v[F|0]&1){g=0;while(1){x[114409]=0;d=O(231,e+256|0,1)|0;f=x[114409];x[114409]=0;t:{if((f|0)!=1){if(!d){break r}x[114409]=0;d=S(425,e+256|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break j}f=0;if((d|0)!=255){break t}x[114409]=0;f=S(425,e+256|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;d=S(425,e+256|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){break t}}break j}break j}u:{if(!(d&127)){break u}i=Zb(B,h);x[114409]=0;i=U(451,i|0,g|0,j&65535)|0;k=x[114409];x[114409]=0;if((k|0)==1){break j}v[e+72|0]=0;v[e+73|0]=0;v[e+74|0]=0;v[e+75|0]=0;v[e+75|0]=0;v[e+76|0]=0;v[e+77|0]=0;v[e+78|0]=0;if(d&1){x[114409]=0;k=S(425,e+256|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break j}v[e+72|0]=k}if(d&2){x[114409]=0;k=S(425,e+256|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break j}v[e+73|0]=k}if(d&4){x[114409]=0;k=S(425,e+256|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break j}v[e+74|0]=k}if(d&8){x[114409]=0;k=S(425,e+256|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break j}v[e+75|0]=k}if(d&16){x[114409]=0;k=S(425,e+256|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break j}v[e+76|0]=k}if(d&32){x[114409]=0;k=S(425,e+256|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break j}v[e+77|0]=k}if(d&64){x[114409]=0;d=S(425,e+256|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break j}v[e+78|0]=d}x[114409]=0;d=O(920,i|0,e+72|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break j}x[114409]=0;x[e+16>>2]=f;x[e+240>>2]=x[e+144>>2]+(g^-1);l=O(306,e+16|0,e+240|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break j}n=d|n;k=0;d=i;G=x[l>>2];if(!G){break u}while(1){d=D(z[a+480188>>1],6)+d|0;l=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[d|0]=l;v[d+1|0]=l>>>8;v[d+2|0]=l>>>16;v[d+3|0]=l>>>24;l=y[i+4|0]|y[i+5|0]<<8;v[d+4|0]=l;v[d+5|0]=l>>>8;k=k+1|0;if((G|0)!=(k|0)){continue}break}}g=(f+g|0)+1|0;d=x[e+144>>2];if(g>>>0>=d>>>0){while(1){j=j+1|0;g=g-d|0;if(d>>>0<=g>>>0){continue}break}}if(q>>>0>(j&65535)>>>0){continue}break}break r}f=0;if(x[e+144>>2]){break s}break r}break j}while(1){d=Zb(B,h);x[114409]=0;i=O(477,d|0,f|0)|0;d=x[114409];x[114409]=0;v:{w:{if((d|0)!=1){d=0;if(q){break w}break v}break j}while(1){x:{x[114409]=0;O(921,e+256|0,e+72|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break x}x[114409]=0;g=O(920,i+D(d,6)|0,e+72|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break x}n=g|n;d=d+1|0;if((q|0)!=(d|0)){continue}break v}break}break j}f=f+1|0;if(f>>>0<A[e+144>>2]){continue}break}}Ab(e+256|0);h=h+1|0;if(h>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}break g}f=N()|0;xb(e+1344|0);break c}f=N()|0;Ab(e+256|0);break e}f=N()|0;break e}f=N()|0;break e}d=e+1732|0;f=y[d+1|0]<<8;if(!((y[d|0]|f)>>>0<=1|(f|y[d|0])>>>0>4999)){y:{if(n&1){f=y[d|0]|y[d+1|0]<<8;d=0;x[114409]=0;g=cg(432,((f>>>1|0)+11025e5>>>0)/(f>>>0)|0,0);f=x[114409];x[114409]=0;if((f|0)==1){break f}break y}f=x[a+480216>>2];i=x[a+480196>>2];d=y[d|0]|y[d+1|0]<<8;x[114409]=0;g=na(581,+(2646e7/+(D(d,D(f,i))>>>0)))|0;f=x[114409];x[114409]=0;d=2;if((f|0)!=1){break y}f=N()|0;break e}x[a+480224>>2]=d;x[a+480204>>2]=g}d=z[a+480188>>1];x[114409]=0;v[e+256|0]=0;B=U(922,e+1300|0,d|0,e+256|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){f=a+1304412|0;i=a+484344|0;g=a+1304424|0;k=0;z:{A:{B:{C:{D:{while(1){x[114409]=0;d=O(231,e+1312|0,8)|0;h=x[114409];x[114409]=0;E:{if((h|0)!=1){if(d){break E}if(z[a+480188>>1]){d=0;while(1){f=v[Cc(B,d)|0];F:{if((f|0)<=(d|0)|(f|0)>=z[a+480188>>1]){break F}h=((f<<5)+a|0)+480288|0;f=y[h|0];if(!f){break F}g=((d<<5)+a|0)+480288|0;j=y[g|0];if(!j){v[g|0]=f;break F}g=(D(j-1&255,160)+a|0)+906300|0;if((Xj(g)|0)!=255){while(1){g=(D(Xj(g),160)+a|0)+906300|0;if((Xj(g)|0)!=255){continue}break}}f=g+28|0;h=y[h|0]-1&255;h=h>>>0<250?h+128|0:0;v[f|0]=h;v[f+1|0]=h>>>8;v[f+2|0]=h>>>16;v[f+3|0]=h>>>24}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}}x[e+248>>2]=0;x[e+252>>2]=0;x[e+240>>2]=0;x[e+244>>2]=0;x[e+232>>2]=0;x[e+236>>2]=0;x[e+224>>2]=0;x[e+228>>2]=0;G:{H:{I:{J:{K:{L:{if(o){g=0;x[114409]=0;O(923,e+1328|0,e+256|0)|0;d=x[114409];x[114409]=0;M:{if((d|0)!=1){while(1){d=z[a+480192>>1];x[114409]=0;d=O(924,a|0,d+1&65535)|0;f=x[114409];x[114409]=0;N:{O:{P:{Q:{R:{S:{T:{if((f|0)!=1){f=g<<1;h=f+(e+240|0)|0;w[h>>1]=d;l=f+(e+224|0)|0;f=e+f|0;j=f+258|0;w[l>>1]=y[j|0]|y[j+1|0]<<8;if((d|0)==65535){break O}f=y[f+258|0]|y[f+259|0]<<8;x[114409]=0;d=U(427,a|0,d|0,f+1&65535)|0;f=x[114409];x[114409]=0;if((f|0)==1){break T}if(!d){break N}x[114409]=0;P(489,e+144|0,11499);f=x[114409];x[114409]=0;if((f|0)==1){break S}x[114409]=0;x[e+16>>2]=g+1;T(925,e+72|0,e+144|0,e+16|0);f=x[114409];x[114409]=0;if((f|0)==1){break R}x[114409]=0;O(348,d+492|0,e+72|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Q}xb(e+72|0);Gb(e+144|0);break N}f=N()|0;break z}f=N()|0;break z}f=N()|0;break z}f=N()|0;break P}f=N()|0;xb(e+72|0)}Gb(e+144|0);break z}w[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break M}}f=N()|0;break z}f=y[e+256|0]|y[e+257|0]<<8;d=0;x[114409]=0;l=O(375,e+212|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break G}if(y[e+256|0]|y[e+257|0]<<8){while(1){x[114409]=0;f=S(335,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break I}x[114409]=0;T(316,e+72|0,b|0,f<<5);f=x[114409];x[114409]=0;if((f|0)==1){break J}f=e+72|0;Zd(wc(l,d),f);Ab(f);d=d+1|0;if(d>>>0<(y[e+256|0]|y[e+257|0]<<8)>>>0){continue}break}}d=y[m|0]|y[m+1|0]<<8;x[114409]=0;n=U(926,e+200|0,d|0,23944)|0;d=x[114409];x[114409]=0;if((d|0)==1){break K}if(y[s|0]|y[s+1|0]<<8){h=0;while(1){g=e+h|0;U:{if(y[g+274|0]>=(y[e+256|0]|y[e+257|0]<<8)>>>0){break U}if(z[vc(Wb(E),h)>>1]>=(y[m|0]|y[m+1|0]<<8)>>>0){break U}f=z[vc(Wb(E),h)>>1];V:{if(z[vc(n,f)>>1]==65535){d=y[g+274|0];I=vc(n,f),J=d,w[I>>1]=J;break V}if(z[vc(n,f)>>1]==y[g+274|0]){break V}x[114409]=0;d=U(927,i|0,f|0,0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break L}if((d|0)==65535){break V}I=vc(Wb(E),h),J=d,w[I>>1]=J;f=d}x[114409]=0;d=O(414,i|0,f|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break L}if(!d){break U}C=wc(l,y[g+274|0]);Nc(C);x[114409]=0;d=S(228,C|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break L}if(!x[Zb(i,f)+12>>2]){break U}F=d>>>5|0;j=0;while(1){d=Zb(i,f);g=z[a+480188>>1];x[114409]=0;d=U(451,d|0,j|0,g-8&65535)|0;g=x[114409];x[114409]=0;if((g|0)==1){break L}g=0;while(1){di(e+72|0);o=y[e+76|0]|y[e+77|0]<<8;v[d+4|0]=o;v[d+5|0]=o>>>8;o=y[e+72|0]|y[e+73|0]<<8|(y[e+74|0]<<16|y[e+75|0]<<24);v[d|0]=o;v[d+1|0]=o>>>8;v[d+2|0]=o>>>16;v[d+3|0]=o>>>24;W:{if(j>>>0>=F>>>0){break W}x[114409]=0;O(928,C|0,e+72|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break L}if(v[e+72|0]>=0){break W}v[d|0]=61;v[d+1|0]=y[(e+240|0)+(g<<1)|0];o=y[e+72|0]&31;v[e+144|0]=o;if(o){df(e+144|0,15);v[d+3|0]=20;v[d+5|0]=y[e+144|0]|208}v[d+2|0]=1;v[d+4|0]=y[e+73|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}j=j+1|0;if(j>>>0<A[Zb(i,f)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<(y[s|0]|y[s+1|0]<<8)>>>0){continue}break}}vf(n);hd(l)}d=e+1736|0;if(!(!(y[d|0]&2)|!(y[m|0]|y[m+1|0]<<8))){d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=(((d&8?z[a+480188>>1]:q)&65535)+((y[r|0]|y[r+1|0]<<8)>>>0>591?k:0)|0)+(d>>>4&1)|0;j=0;while(1){g=0;X:{if(!d){break X}while(1){Y:{x[114409]=0;f=O(231,b|0,4)|0;i=x[114409];x[114409]=0;if((i|0)==1){break Y}if(!f){break X}f=y[r|0]|y[r+1|0]<<8;x[114409]=0;P(929,f|0,b|0);f=x[114409];x[114409]=0;if((f|0)==1){break Y}g=g+1|0;if((d|0)!=(g|0)){continue}break X}break}f=N()|0;break z}j=j+1|0;if(j>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}}x[114409]=0;s=O(375,e+188|0,255)|0;d=x[114409];x[114409]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){h=0;while(1){d=h;x[114409]=0;O(930,b|0,e+144|0)|0;f=x[114409];x[114409]=0;da:{ea:{fa:{ga:{if((f|0)!=1){x[114409]=0;f=S(413,b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break ga}i=y[r|0]|y[r+1|0]<<8;x[114409]=0;f=(f|0)==32?428:f;f=f?i>>>0>513?f+4|0:f:f;T(316,e+256|0,b|0,f|0);i=x[114409];x[114409]=0;if((i|0)==1){break fa}h=d+1|0;i=e+256|0;m=hf(e+16|0,Zd(wc(s,d),i));Ab(i);if(d>>>0>=(y[t|0]|y[t+1|0]<<8)>>>0){break da}x[114409]=0;d=h&65535;g=U(427,a|0,d|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break ea}f=N()|0;break _}f=N()|0;break Z}f=N()|0;break Z}f=N()|0;break Z}if(!g){break da}x[114409]=0;T(369,e+72|0,2,e+144|0);d=x[114409];x[114409]=0;ha:{ia:{ja:{if((d|0)==1){break ja}x[114409]=0;P(370,e+256|0,e+72|0);d=x[114409];x[114409]=0;if((d|0)==1){break ja}x[114409]=0;O(348,g+492|0,e+256|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break ia}xb(e+256|0);if(!f){break da}x[114409]=0;O(931,m|0,e+256|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break aa}n=0;if((y[r|0]|y[r+1|0]<<8)>>>0<513){break ha}x[114409]=0;n=S(335,m|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break ha}f=N()|0;break _}f=N()|0;break _}f=N()|0;xb(e+256|0);break _}f=3;ka:{if((y[r|0]|y[r+1|0]<<8)>>>0<514){break ka}x[114409]=0;f=S(413,m|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break ka}f=N()|0;break _}x[g>>2]=y[e+358|0]|y[e+359|0]<<8;v[g+16|0]=y[((y[e+360|0]|y[e+361|0]<<8)&3)+23946|0];v[g+17|0]=y[(y[e+361|0]&3)+23946|0];v[g+18|0]=y[((y[e+360|0]|y[e+361|0]<<8)>>>12&3)+23950|0];j=0;la:{ma:{na:{oa:{while(1){pa:{if(!(f&1)){break pa}x[114409]=0;O(932,m|0,e+72|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break oa}x[114409]=0;i=O(354,g|0,y[j+23954|0])|0;d=x[114409];x[114409]=0;if((d|0)==1){break na}if((j|0)!=3){d=y[i+12|0]&-17}else{d=y[e+72|0]<<4&16|y[i+12|0]&-17}v[i+12|0]=d;v[i+12|0]=y[i+12|0]&254|v[e+72|0]&1;v[i+12|0]=y[i+12|0]&251|y[e+72|0]<<1&4;v[i+12|0]=y[i+12|0]&253|y[e+72|0]>>>1&2;d=y[e+73|0];x[114409]=0;v[e+56|0]=d;v[e+44|0]=16;d=O(431,e+56|0,e+44|0)|0;q=x[114409];x[114409]=0;if((q|0)==1){break ma}d=y[d|0];x[114409]=0;P(496,i|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break ma}d=y[e+74|0];v[i+15|0]=d;v[i+16|0]=d;v[i+13|0]=y[e+75|0];v[i+14|0]=y[e+76|0];d=0;if(!Lb(i)){break pa}while(1){q=(e+72|0)+(d<<2)|0;k=y[q+8|0]|y[q+9|0]<<8;I=Pb(i,d),J=k,w[I>>1]=J;q=Md(y[q+10|0]|y[q+11|0]<<8,0,64);I=Pb(i,d),J=q,v[I+2|0]=J;d=d+1|0;if(Lb(i)>>>0>d>>>0){continue}break}}f=f>>>1|0;j=j+1|0;if((j|0)!=4){continue}break}if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}x[114409]=0;T(933,g|0,127,1);d=x[114409];x[114409]=0;if((d|0)==1){break ca}x[114409]=0;T(934,g|0,0,1);d=x[114409];x[114409]=0;if((d|0)==1){break ca}if(!n){break da}x[114409]=0;O(935,m|0,e+72|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break $}if(!(n&2)){break la}d=y[e+74|0]|y[e+75|0]<<8;x[114409]=0;d=gb(936,a|0,+(d>>>0))|0;f=x[114409];x[114409]=0;if((f|0)==1){break $}x[114409]=0;T(933,g|0,d|0,1);d=x[114409];x[114409]=0;if((d|0)==1){break $}d=y[e+76|0];x[114409]=0;T(934,g|0,d|0,1);d=x[114409];x[114409]=0;if((d|0)!=1){break la}break $}f=N()|0;break _}f=N()|0;break _}f=N()|0;break _}v[g+25|0]=y[e+73|0]==1;if(!(n&4)){break da}v[g+31|0]=y[e+79|0]+1;v[g+34|0]=y[e+80|0]+1;if(v[e+80|0]<0){v[g+30|0]=y[e+87|0]+1}if(y[e+84|0]){d=0;i=g+108|0;while(1){f=d+1|0;x[e+56>>2]=f+v[e+84|0];gR(e+56|0);j=x[e+56>>2];I=fc(i,d),J=j,v[I|0]=J;d=f;if(d>>>0<128){continue}break}}x[114409]=0;P(796,g|0,0);d=x[114409];x[114409]=0;if((d|0)==1){break $}}Ab(m);if((h|0)!=255){continue}break}m=Vz(e+72|0);r=Vz(e+144|0);g=0;qa:{ra:{while(1){x[114409]=0;O(930,b|0,e+256|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break qa}x[114409]=0;d=S(413,b|0)|0;f=x[114409];x[114409]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{if((f|0)!=1){x[114409]=0;T(316,e+56|0,b|0,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break za}if((y[u|0]|y[u+1|0]<<8)>>>0>g>>>0){x[114409]=0;T(369,e+44|0,2,e+256|0);f=x[114409];x[114409]=0;if((f|0)==1){break sa}x[114409]=0;P(370,e+16|0,e+44|0);f=x[114409];x[114409]=0;if((f|0)==1){break sa}x[114409]=0;O(348,((g<<5)+a|0)+946336|0,e+16|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ya}xb(e+16|0)}if(!d|(y[u|0]|y[u+1|0]<<8)>>>0<=g>>>0){break ta}x[114409]=0;d=D(g+1|0,104)+a|0;f=d+484380|0;P(472,f|0,32);i=x[114409];x[114409]=0;if((i|0)==1){break xa}x[114409]=0;O(937,e+56|0,e+16|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break wa}x[f>>2]=y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24);x[d+484404>>2]=y[e+20|0]|y[e+21|0]<<8|(y[e+22|0]<<16|y[e+23|0]<<24);if(y[e+24|0]>=2){i=d+484414|0;w[i>>1]=z[i>>1]|1;x[f>>2]=x[f>>2]>>>1}if(y[e+25|0]>=2){i=d+484414|0;w[i>>1]=z[i>>1]|64;x[f>>2]=x[f>>2]>>>1}n=2;Aa:{if(y[e+27|0]!=1){n=6;if(y[e+27|0]!=2){break Aa}}f=d+484414|0;w[f>>1]=z[f>>1]|n}x[d+484384>>2]=y[e+28|0]|y[e+29|0]<<8|(y[e+30|0]<<16|y[e+31|0]<<24);x[d+484388>>2]=y[e+32|0]|y[e+33|0]<<8|(y[e+34|0]<<16|y[e+35|0]<<24);w[d+484410>>1]=(y[e+36|0]|y[e+37|0]<<8)>>>7;if(y[e+38|0]!=128){break va}f=d+484414|0;j=z[f>>1]|256;w[f>>1]=j;break ua}f=N()|0;break Z}f=N()|0;break Z}f=N()|0;xb(e+16|0);break ra}f=N()|0;break ra}f=N()|0;break ra}w[d+484408>>1]=v[e+38|0]+128;j=z[d+484414>>1]}f=d+484414|0;w[f>>1]=j|32;v[d+484416|0]=y[e+39|0];if(y[e+26|0]&2){d=e+44|0;Kb(d,r,g);le(d,1)}if(y[e+26|0]&5){w[f>>1]=z[f>>1]|16384}if(!(y[e+26|0]&8)){break ta}d=e+44|0;Kb(d,m,g);le(d,1);d=0;while(1){f=d<<1;Ba:{if(z[f+(e+224|0)>>1]!=(g|0)){break Ba}f=x[((z[f+(e+240|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ba}v[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}Ab(e+56|0);g=g+1|0;if((g|0)==256){break ba}continue}break}f=N()|0}Ab(e+56|0);break Z}f=N()|0;break Z}f=N()|0;break z}f=N()|0;break _}Ca:{if(!(y[t|0]|y[t+1|0]<<8)){break Ca}f=0;Da:{Ea:{while(1){Fa:{d=wc(s,f);x[114409]=0;d=S(228,d|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break Fa}Ga:{if(!d){f=f+1|0;break Ga}d=wc(s,f);Nc(d);x[114409]=0;O(931,d|0,e+256|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Ea}i=hb-16|0;hb=i;d=e+16|0;x[d>>2]=0;x[d+4>>2]=0;x[114409]=0;x[i+12>>2]=0;U(946,d+8|0,i+12|0,i+11|0)|0;h=x[114409];x[114409]=0;Ha:{if((h|0)!=1){hb=i+16|0;break Ha}R(0)|0;zb();p()}h=y[e+256|0]|y[e+257|0]<<8;x[114409]=0;i=d;U(938,b|0,d|0,h|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Da}f=f+1|0;h=x[((f<<2)+a|0)+900380>>2];if(!(!h|y[h+34|0])){x[h+4>>2]=32;x[114409]=0;P(796,h|0,0);d=x[114409];x[114409]=0;if((d|0)==1){break Da}u=h+108|0;q=h+236|0;d=0;while(1){g=d+e|0;Ia:{if(y[g+258|0]>=(y[e+256|0]|y[e+257|0]<<8)>>>0){break Ia}n=ol(i,y[g+258|0]);g=y[n|0];j=g+1|0;k=d+12|0;I=fd(q,k),J=j,w[I>>1]=J;if(g>>>0>=z[a+480190>>1]){break Ia}g=D(j,104)+a|0;v[g+484418|0]=y[e+354|0]&3;v[g+484419|0]=y[e+355|0];v[g+484420|0]=y[e+356|0];v[g+484421|0]=y[e+357|0];w[g+484412>>1]=y[n+1|0]<<1;v[g+484417|0]=y[n+2|0];g=e+56|0;j=j-1|0;Kb(g,m,j);if(Ib(g)){v[h+14|0]=0}g=e+56|0;Kb(g,r,j);if(!Ib(g)){break Ia}I=fc(u,k),J=61,v[I|0]=J}d=d+1|0;if((d|0)!=96){continue}break}}fR(i)}if((y[t|0]|y[t+1|0]<<8)>>>0>f>>>0){continue}break Ca}break}f=N()|0;break Z}f=N()|0;break Z}f=N()|0;fR(i);break Z}Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if(!(!(c&2)|!z[a+480190>>1])){g=0;while(1){g=g+1|0;d=D(g,104)+a|0;c=d+484416|0;f=v[c|0];i=d+484417|0;h=v[i|0];x[114409]=0;j=d+484380|0;ma(939,j|0,+((+(h|0)*.0078125-+(f-49|0))*.08333333333333333));f=x[114409];x[114409]=0;if((f|0)==1){break Ja}v[i|0]=0;v[c|0]=0;c=z[d+484414>>1];Va:{if(!(c&16384)){c=cd(e+256|0,c&1?16:8,c&64?3:1,0,12);x[114409]=0;U(376,c|0,j|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break Va}f=N()|0;break Z}x[114409]=0;f=S(413,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ua}x[114409]=0;O(313,b|0,12)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ua}c=Xb(e+256|0);x[114409]=0;U(461,b|0,c|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ta}x[114409]=0;O(350,d+484423|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Ta}x[114409]=0;d=O(2,e+4|0,12291)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Sa}x[114409]=0;P(192,e+56|0,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ra}x[e>>2]=g;f=HA(a);x[114409]=0;T(13,e+44|0,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break Qa}x[114409]=0;W(654,e+16|0,e+56|0,e|0,e+44|0);f=x[114409];x[114409]=0;if((f|0)==1){break Pa}x[114409]=0;T(655,a|0,2,e+16|0);f=x[114409];x[114409]=0;if((f|0)==1){break Oa}xb(e+16|0);xb(e+44|0);Gb(e+56|0);xb(d);xb(c)}if(z[a+480190>>1]>g>>>0){continue}break}}hd(s);$q(B);Ab(e+1312|0);Ab(e+1328|0);break b}f=N()|0;break Z}f=N()|0;break Ka}f=N()|0;break Ka}f=N()|0;break La}f=N()|0;break Ma}f=N()|0;break Na}f=N()|0;xb(e+16|0)}xb(e+44|0)}Gb(e+56|0)}xb(d)}xb(c);break Z}f=N()|0;break Z}f=N()|0;break _}f=N()|0}Ab(m)}hd(s);break z}f=N()|0;vf(n);break H}f=N()|0;break H}f=N()|0;break H}f=N()|0}hd(l);break z}f=N()|0;break z}f=N()|0;break z}x[114409]=0;d=S(413,e+1312|0)|0;h=x[114409];x[114409]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((h|0)!=1){x[114409]=0;h=S(413,e+1312|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break hb}x[114409]=0;T(316,e+72|0,e+1312|0,h|0);h=x[114409];x[114409]=0;if((h|0)==1){break hb}if((d|0)<=844387157){if((d|0)==4674381){break _a}if((d|0)==5068115){break Za}if(n&1|(d|0)!=726487106){break Xa}x[a+480224>>2]=2;x[114409]=0;H=+ha(940,e+72|0);d=x[114409];x[114409]=0;if((d|0)==1){break Wa}if(H<=1e-8){break Xa}d=x[a+480216>>2];h=x[a+480196>>2];x[114409]=0;d=na(581,+(2646e7/(H*+(D(d,h)>>>0))))|0;h=x[114409];x[114409]=0;if((h|0)==1){break gb}x[a+480204>>2]=d;break Xa}if((d|0)<=1314144591){if((d|0)==844387158){break Ya}if((d|0)!=1280004692){break Xa}j=0;if(!z[a+480188>>1]){break Xa}while(1){x[114409]=0;d=O(231,e+72|0,1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break C}if(!d){break Xa}d=Xb(e+256|0);x[114409]=0;U(596,e+72|0,d|0,-1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break eb}h=Rb(d);l=Cb(d);x[114409]=0;W(447,e+16|0,3,h|0,l|0);h=x[114409];x[114409]=0;if((h|0)==1){break db}x[114409]=0;P(370,e+144|0,e+16|0);h=x[114409];x[114409]=0;if((h|0)==1){break db}x[114409]=0;O(358,((j<<5)+a|0)+480289|0,e+144|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break cb}xb(e+144|0);xb(d);j=j+1|0;if(j>>>0<z[a+480188>>1]){continue}break}break Xa}if((d|0)==1397445204){break fb}if((d|0)!=1314144592){break Xa}d=0;if(!(y[m|0]|y[m+1|0]<<8)){break Xa}while(1){x[114409]=0;h=O(231,e+72|0,1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break ab}if(!h){break Xa}x[114409]=0;h=O(941,i|0,d&65535)|0;j=x[114409];x[114409]=0;if((j|0)==1){break ab}if(!h){break Xa}h=Xb(e+256|0);x[114409]=0;U(596,e+72|0,h|0,-1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break $a}j=Zb(i,d);x[114409]=0;O(476,j|0,h|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break $a}xb(h);d=d+1|0;if(d>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}break Xa}f=N()|0;break z}f=N()|0;break z}f=N()|0;break A}x[114409]=0;d=S(335,e+72|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break B}d=d>>>0<256?48:d>>>8|0;x[a+480228>>2]=d;x[a+480232>>2]=d>>>1;d=0;if(!z[a+480188>>1]){break Xa}while(1){x[114409]=0;h=O(942,e+72|0,e+256|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break D}if(h){w[((d<<5)+a|0)+480286>>1]=(y[e+256|0]|y[e+257|0]<<8)>>>10;h=y[e+259|0];I=Cc(B,d),J=h,v[I|0]=J}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}break Xa}f=N()|0;break bb}f=N()|0;break bb}f=N()|0;xb(e+144|0)}xb(d);break A}f=N()|0;break A}f=N()|0;xb(h);break A}x[114409]=0;O(313,e+72|0,1)|0;d=x[114409];x[114409]=0;if((d|0)==1){break B}x[114409]=0;d=S(305,e+72|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break B}x[114409]=0;Z(584,g|0,e+72|0,d|0,2)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break Xa}break B}x[114409]=0;O(943,e+72|0,e+16|0)|0;d=x[114409];x[114409]=0;ib:{if((d|0)!=1){d=Xb(e+256|0);x[114409]=0;U(596,e+72|0,d|0,-1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ib}if(RA(d,8414)){x[114409]=0;T(13,e+144|0,7,d|0);h=x[114409];x[114409]=0;if((h|0)==1){break ib}h=e+144|0;Eb(f,h);xb(h)}xb(d);break Xa}f=N()|0;break A}f=N()|0;xb(d);break A}x[114409]=0;k=S(413,e+72|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break B}}Ab(e+72|0);continue}break}f=N()|0;break A}f=N()|0;break A}f=N()|0;break A}f=N()|0}Ab(e+72|0)}$q(B);break e}f=N()|0;break e}f=N()|0}Ab(e+1312|0)}Ab(e+1328|0)}Q(f|0);p()}d=1}hb=e+1744|0;return d|0}function Z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=E(0),r=0,s=E(0),t=E(0),u=0,C=0,F=0,G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=E(0),X=E(0),Y=0,Z=E(0),_=E(0),$=0,aa=0,ba=0,ca=E(0),da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;V=hb-16|0;hb=V;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;e=b;d=0;b=0;b:{c:{d:{f=x[a+1420>>2];if((f|0)<=0){break d}while(1){x[(D(d,20)+a|0)+1436>>2]=0;d=d+1|0;if((f|0)!=(d|0)){continue}break}if((f|0)<=3){break d}b=c;break c}if((c|0)<4){break b}b=c-3|0;d=0;e:{while(1){f:{g:{h:{g=d+e|0;if(!(y[g|0]!=79|(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24))!=(y[83456]|y[83457]<<8|(y[83458]<<16|y[83459]<<24)))){j=d+26|0;if((j|0)>=(b|0)){break f}k=d+27|0;m=e+j|0;h=y[m|0];if((k+h|0)>=(b|0)){break f}i=h+27|0;c=0;if(h){break h}break g}d=d+1|0;if((d|0)<(b|0)){continue}break e}while(1){i=y[e+(c+k|0)|0]+i|0;c=c+1|0;if((h|0)!=(c|0)){continue}break}}c=0;k=0;while(1){h=22;c=ix(c,y[e+(d+k|0)|0]);k=k+1|0;if((k|0)!=22){continue}break}while(1){c=ix(c,0);h=h+1|0;if((h|0)!=26){continue}break}x[a+1420>>2]=f+1;f=D(f,20)+a|0;x[f+1432>>2]=c;x[f+1428>>2]=i-26;x[f+1424>>2]=y[g+22|0]|y[g+23|0]<<8|(y[g+24|0]<<16|y[g+25|0]<<24);c=y[e+(j+y[m|0]|0)|0]==255?-1:y[g+6|0]|y[g+7|0]<<8|(y[g+8|0]<<16|y[g+9|0]<<24);x[f+1436>>2]=j;x[f+1440>>2]=c;f=x[a+1420>>2];if((f|0)==4){break e}d=d+1|0;if((d|0)<(b|0)){continue}break e}break}b=d}if((f|0)<=0){break b}}g=0;while(1){h=D(g,20)+a|0;l=h+1432|0;c=x[l>>2];d=0;J=h+1428|0;i=x[J>>2];j=x[h+1436>>2];m=b-j|0;k=(i|0)<(m|0)?i:m;if((k|0)>0){while(1){c=ix(c,y[e+(d+j|0)|0]);d=d+1|0;if((k|0)!=(d|0)){continue}break}}x[J>>2]=i-k;x[l>>2]=c;i:{if((i|0)<=(m|0)){d=c;c=h+1424|0;if((d|0)==x[c>>2]){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(g,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;b=j+k|0;break b}d=f-1|0;x[a+1420>>2]=d;d=D(d,20)+a|0;x[c+16>>2]=x[d+1440>>2];f=d+1432|0;h=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=h;d=d+1424|0;f=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=f;f=x[a+1420>>2];break i}g=g+1|0}if((f|0)>(g|0)){continue}break}}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!LH(a)){x[f>>2]=0;b=0;break a}na=V+12|0;da=hb-16|0;hb=da;x[a+1504>>2]=0;x[a+1508>>2]=0;j:{if(x[a+96>>2]){break j}k:{l:{m:{if(x[a+1380>>2]!=-1){break m}c=Ee(a);if(x[a+96>>2]){break k}if((c|0)!=79){break l}if((Ee(a)|0)!=103){break l}if((Ee(a)|0)!=103){break l}if((Ee(a)|0)!=83){break l}if(!FH(a)){break k}if(!(v[a+1375|0]&1)){break m}v[a+1376|0]=0;x[a+1384>>2]=0;gc(a,32);break k}h=dx(a);break k}gc(a,30)}if(!h){break j}if(lc(a,1)){gc(a,35);break j}n:{o:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=lc(a,Jl(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break j}x[da+12>>2]=c;g=D(c,6)+a|0;if(!y[g+412|0]){k=x[a+112>>2];j=k>>1;break o}k=x[a+116>>2];j=k>>1;c=lc(a,1);i=lc(a,1);if(c|!y[g+412|0]){break o}x[V+4>>2]=k-x[a+112>>2]>>2;c=x[a+112>>2]+k>>2;break n}ea(2707,9049,3152,6707);p()}x[V+4>>2]=0;c=j}x[da+8>>2]=c;p:{if(!(!y[g+412|0]|i)){c=D(k,3);x[V+8>>2]=c-x[a+112>>2]>>2;k=c+x[a+112>>2]>>2;break p}x[V+8>>2]=j}x[da+4>>2]=k;k=1}if(k){q:{J=x[V+4>>2];ka=x[V+8>>2];ja=x[da+4>>2];P=hb-2368|0;hb=P;ha=x[a+404>>2];ma=D(x[da+12>>2],6)+a|0;fa=y[ma+413|0];Y=ha+D(fa,40)|0;R=x[((y[ma+412|0]<<2)+a|0)+104>>2];r:{l=x[a+4>>2];s:{if((l|0)>0){while(1){c=y[(x[Y+4>>2]+D(m,3)|0)+2|0];o=(P+1344|0)+(m<<2)|0;x[o>>2]=0;g=y[(c+Y|0)+9|0];if(!z[((g<<1)+a|0)+132>>1]){gc(a,21);c=0;break s}h=x[a+260>>2];t:{u:{if(lc(a,1)){c=2;k=x[((m<<2)+a|0)+996>>2];i=h+D(g,1596)|0;r=x[(y[i+1588|0]<<2)+47372>>2];g=Jl(r)-1|0;sa=k,ta=lc(a,g),w[sa>>1]=ta;sa=k,ta=lc(a,g),w[sa+2>>1]=ta;n=0;if(y[i|0]){while(1){C=y[(i+n|0)+1|0];h=C+i|0;j=y[h+33|0];g=0;F=y[h+49|0];v:{if(!F){break v}h=x[a+124>>2]+D(y[h+65|0],2096)|0;if(x[a+1396>>2]<=9){wk(a)}g=x[a+1392>>2];l=w[(h+((g&1023)<<1)|0)+36>>1];w:{if((l|0)>=0){u=g;l=l&65535;g=y[l+x[h+8>>2]|0];x[a+1392>>2]=u>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:l;break w}g=Il(a,h)}if(!y[h+23|0]){break v}g=x[x[h+2088>>2]+(g<<2)>>2]}if(j){L=-1<<F^-1;h=c+j|0;while(1){l=0;j=w[((i+(C<<4)|0)+((g&L)<<1)|0)+82>>1];x:{if((j|0)<0){break x}j=x[a+124>>2]+D(j&65535,2096)|0;if(x[a+1396>>2]<=9){wk(a)}l=x[a+1392>>2];U=w[(j+((l&1023)<<1)|0)+36>>1];y:{if((U|0)>=0){u=l;U=U&65535;l=y[U+x[j+8>>2]|0];x[a+1392>>2]=u>>>l;l=x[a+1396>>2]-l|0;x[a+1396>>2]=(l|0)>0?l:0;l=(l|0)<0?-1:U;break y}l=Il(a,j)}if(!y[j+23|0]){break x}l=x[x[j+2088>>2]+(l<<2)>>2]}g=g>>F;w[k+(c<<1)>>1]=l;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}n=n+1|0;if(n>>>0<y[i|0]){continue}break}}if(x[a+1396>>2]!=-1){break u}}x[o>>2]=1;break t}w[P+320>>1]=257;c=x[i+1592>>2];if((c|0)>=3){g=2;while(1){c=i+338|0;h=g<<1;l=h+i|0;F=y[l+1088|0];n=F<<1;j=z[c+n>>1];o=y[l+1089|0];C=o<<1;L=w[k+n>>1];l=w[C+k>>1]-L|0;n=l>>31;c=(D((l^n)-n|0,z[c+h>>1]-j|0)|0)/(z[c+C>>1]-j|0)|0;l=L+((l|0)<0?0-c|0:c)|0;n=h+k|0;h=z[n>>1];z:{A:{if(h){c=P+320|0;v[c+o|0]=1;v[c+F|0]=1;v[c+g|0]=1;c=h<<16>>16;j=r-l|0;if((c|0)>=((j|0)<(l|0)?j:l)<<1){if((j|0)>(l|0)){break z}l=r+(h^-1)|0;break A}if(c&1){l=l-(c+1>>>1|0)|0;break A}l=(c>>1)+l|0;break A}v[(P+320|0)+g|0]=0}w[n>>1]=l}c=x[i+1592>>2];g=g+1|0;if((c|0)>(g|0)){continue}break}}l=0;if((c|0)<=0){break t}while(1){if(!y[(P+320|0)+l|0]){w[k+(l<<1)>>1]=65535;c=x[i+1592>>2]}l=l+1|0;if((l|0)<(c|0)){continue}break}}l=x[a+4>>2];m=m+1|0;if((l|0)>(m|0)){continue}break}}B:{C:{c=x[a+80>>2];if(!(x[a+84>>2]!=x[a+92>>2]?c:0)){sc(P+320|0,P+1344|0,l<<2);h=z[Y>>1];if(h){i=x[(ha+D(fa,40)|0)+4>>2];l=0;while(1){k=i+D(l,3)|0;g=y[k+1|0];j=P+1344|0;k=j+(y[k|0]<<2)|0;if(!(x[(g<<2)+j>>2]?x[k>>2]:0)){x[(P+1344|0)+(g<<2)>>2]=0;x[k>>2]=0}l=l+1|0;if((h|0)!=(l|0)){continue}break}}U=R>>1;ga=ha+D(fa,40)|0;if(y[ga+8|0]){c=0;while(1){g=0;k=x[a+4>>2];if((k|0)>0){j=x[ga+4>>2];l=0;while(1){if(y[(j+D(l,3)|0)+2|0]==(c|0)){m=g+P|0;h=l<<2;D:{if(x[h+(P+1344|0)>>2]){i=0;h=1;break D}i=x[(a+h|0)+800>>2];h=0}v[m|0]=h;x[(P+256|0)+(g<<2)>>2]=i;g=g+1|0}l=l+1|0;if((k|0)!=(l|0)){continue}break}}$=P+256|0;F=hb-16|0;hb=F;k=x[a+4>>2];m=x[a+396>>2];h=y[(c+ga|0)+24|0];n=m+D(h,24)|0;j=x[n+4>>2];ia=z[((h<<1)+a|0)+268>>1];i=U<<((ia|0)==2);l=i>>>0>j>>>0?j:i;j=x[n>>2];L=(l-(i>>>0>j>>>0?j:i)>>>0)/A[n+8>>2]|0;o=L<<2;i=D(k,o+4|0);Q=x[x[a+124>>2]+D(y[n+13|0],2096)>>2];pa=x[a+92>>2];E:{if(x[a+80>>2]){l=on(a,i);k=x[a+4>>2];break E}l=xd(i)}j=0;if((k|0)>0){r=(k<<2)+l|0;while(1){x[(j<<2)+l>>2]=r;r=o+r|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}j=l;F:{G:{H:{if((g|0)>0){k=U<<2;i=0;while(1){if(!y[i+P|0]){Sb(x[$+(i<<2)>>2],0,k)}i=i+1|0;if((i|0)!=(g|0)){continue}break}if((g|0)==1|(ia|0)!=2){break H}i=0;if((g|0)<=0){break G}while(1){if(!y[i+P|0]){break G}i=i+1|0;if((i|0)!=(g|0)){continue}break}break F}i=0;if((ia|0)==2){break G}}u=m+D(h,24)|0;qa=(L|0)<=0;k=0;while(1){if(!qa){O=0;oa=(g|0)<=0;ra=oa|(k|0)!=0;l=0;while(1){i=0;if(!ra){while(1){if(!y[i+P|0]){m=x[a+124>>2]+D(y[n+13|0],2096)|0;if(x[a+1396>>2]<=9){wk(a)}h=x[a+1392>>2];r=w[(m+((h&1023)<<1)|0)+36>>1];I:{if((r|0)>=0){o=h;r=r&65535;h=y[r+x[m+8>>2]|0];x[a+1392>>2]=o>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:r;break I}h=Il(a,m)}h=y[m+23|0]?x[x[m+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break F}x[x[j+(i<<2)>>2]+(O<<2)>>2]=x[x[u+16>>2]+(h<<2)>>2]}i=i+1|0;if((i|0)!=(g|0)){continue}break}}J:{if((Q|0)<=0){break J}h=0;if((l|0)>=(L|0)){break J}while(1){i=0;if(!oa){while(1){K:{if(y[i+P|0]){break K}m=i<<2;r=w[(x[u+20>>2]+(y[x[x[m+j>>2]+(O<<2)>>2]+h|0]<<4)|0)+(k<<1)>>1];if((r|0)<0){break K}r=x[a+124>>2]+D(r&65535,2096)|0;S=x[m+$>>2];K=x[n+8>>2];T=x[n>>2]+D(K,l)|0;L:{M:{if(ia){C=0;m=1;if((K|0)<=0){break L}while(1){la=S+(T<<2)|0;o=K-C|0;I=0;q=E(0);aa=CH(a,r);N:{if((aa|0)<0){break N}I=x[r>>2];ba=(o|0)>(I|0)?I:o;aa=D(I,aa);if(y[r+22|0]){I=1;if((ba|0)<=0){break N}o=0;while(1){I=la+(o<<2)|0;q=E(B[x[r+28>>2]+(o+aa<<2)>>2]+q);B[I>>2]=B[I>>2]+q;q=E(B[r+12>>2]+q);I=1;o=o+1|0;if((ba|0)!=(o|0)){continue}break}break N}I=1;if((ba|0)<=0){break N}o=0;while(1){I=la+(o<<2)|0;B[I>>2]=B[I>>2]+B[x[r+28>>2]+(o+aa<<2)>>2];I=1;o=o+1|0;if((ba|0)!=(o|0)){continue}break}}if(!I){break M}o=x[r>>2];T=o+T|0;C=o+C|0;if((K|0)>(C|0)){continue}break}break L}C=0;m=1;ba=(K|0)/x[r>>2]|0;if((ba|0)<=0){break L}S=S+(T<<2)|0;while(1){la=S+(C<<2)|0;m=K-(C+T|0)|0;I=0;q=E(0);aa=CH(a,r);O:{if((aa|0)<0){break O}I=1;o=x[r>>2];m=(m|0)>(o|0)?o:m;if((m|0)<=0){break O}aa=D(o,aa);o=0;while(1){I=la+(D(o,ba)<<2)|0;t=E(B[x[r+28>>2]+(o+aa<<2)>>2]+q);B[I>>2]=B[I>>2]+t;q=y[r+22|0]?t:q;I=1;o=o+1|0;if((m|0)!=(o|0)){continue}break}}if(!I){break M}m=1;C=C+1|0;if((ba|0)!=(C|0)){continue}break}break L}m=0}if(!m){break F}}i=i+1|0;if((i|0)!=(g|0)){continue}break}}l=l+1|0;h=h+1|0;if((Q|0)<=(h|0)){break J}if((l|0)<(L|0)){continue}break}}O=O+1|0;if((l|0)<(L|0)){continue}break}}k=k+1|0;if((k|0)!=8){continue}break}break F}if((g|0)==(i|0)){break F}o=(L|0)<=0;C=o|(g|0)<3;r=m+D(h,24)|0;I=(g|0)!=2;l=0;while(1){P:{if(!I){if(o){break P}i=0;k=0;while(1){h=x[n>>2]+D(x[n+8>>2],i)|0;x[F+12>>2]=h&1;x[F+8>>2]=h>>1;if(!l){m=x[a+124>>2]+D(y[n+13|0],2096)|0;if(x[a+1396>>2]<=9){wk(a)}h=x[a+1392>>2];K=w[(m+((h&1023)<<1)|0)+36>>1];Q:{if((K|0)>=0){u=h;K=K&65535;h=y[K+x[m+8>>2]|0];x[a+1392>>2]=u>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:K;break Q}h=Il(a,m)}h=y[m+23|0]?x[x[m+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break F}x[x[j>>2]+(k<<2)>>2]=x[x[r+16>>2]+(h<<2)>>2]}R:{if((Q|0)<=0){break R}h=0;if((i|0)>=(L|0)){break R}while(1){m=x[n+8>>2];K=w[(x[r+20>>2]+(y[x[x[j>>2]+(k<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];S:{if((K|0)>=0){if(!EH(a,x[a+124>>2]+D(K&65535,2096)|0,$,2,F+12|0,F+8|0,U,m)){break F}i=i+1|0;break S}i=i+1|0;m=x[n>>2]+D(m,i)|0;x[F+8>>2]=m>>1;x[F+12>>2]=m&1}h=h+1|0;if((Q|0)<=(h|0)){break R}if((i|0)<(L|0)){continue}break}}k=k+1|0;if((i|0)<(L|0)){continue}break}break P}if(C){break P}i=0;k=0;while(1){m=x[n>>2]+D(x[n+8>>2],i)|0;h=(m|0)/(g|0)|0;x[F+12>>2]=m-D(g,h);x[F+8>>2]=h;if(!l){m=x[a+124>>2]+D(y[n+13|0],2096)|0;if(x[a+1396>>2]<=9){wk(a)}h=x[a+1392>>2];K=w[(m+((h&1023)<<1)|0)+36>>1];T:{if((K|0)>=0){u=h;K=K&65535;h=y[K+x[m+8>>2]|0];x[a+1392>>2]=u>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:K;break T}h=Il(a,m)}h=y[m+23|0]?x[x[m+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break F}x[x[j>>2]+(k<<2)>>2]=x[x[r+16>>2]+(h<<2)>>2]}U:{if((Q|0)<=0){break U}h=0;if((i|0)>=(L|0)){break U}while(1){m=x[n+8>>2];K=w[(x[r+20>>2]+(y[x[x[j>>2]+(k<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];V:{if((K|0)>=0){if(!EH(a,x[a+124>>2]+D(K&65535,2096)|0,$,g,F+12|0,F+8|0,U,m)){break F}i=i+1|0;break V}i=i+1|0;m=x[n>>2]+D(m,i)|0;K=(m|0)/(g|0)|0;x[F+8>>2]=K;x[F+12>>2]=m-D(g,K)}h=h+1|0;if((Q|0)<=(h|0)){break U}if((i|0)<(L|0)){continue}break}}k=k+1|0;if((i|0)<(L|0)){continue}break}}l=l+1|0;if((l|0)!=8){continue}break}}if(!x[a+80>>2]){_b(j)}x[a+92>>2]=pa;hb=F+16|0;c=c+1|0;if(c>>>0<y[ga+8|0]){continue}break}c=x[a+80>>2]}if(!(x[a+84>>2]!=x[a+92>>2]?c:0)){g=z[Y>>1];if(g){i=(U|0)<=1?1:U;k=ha+D(fa,40)|0;h=a+800|0;while(1){c=g;g=c-1|0;if((R|0)>=2){j=x[k+4>>2]+D(g,3)|0;m=x[h+(y[j+1|0]<<2)>>2];j=x[h+(y[j|0]<<2)>>2];l=0;while(1){n=l<<2;r=n+m|0;s=B[r>>2];n=j+n|0;q=B[n>>2];W:{if(!(q<=E(0))){if(!(s<=E(0))){t=E(q-s);break W}t=q;q=E(s+q);break W}if(!(s<=E(0))){t=E(s+q);break W}t=q;q=E(q-s)}B[n>>2]=q;B[r>>2]=t;l=l+1|0;if((i|0)!=(l|0)){continue}break}}if((c|0)>1){continue}break}}if(x[a+4>>2]<=0){break B}I=U<<2;l=0;while(1){c=l<<2;g=c+a|0;j=x[g+800>>2];X:{if(x[c+(P+320|0)>>2]){Sb(j,0,I);break X}C=x[g+996>>2];m=1;c=y[(Y+y[(x[Y+4>>2]+D(l,3)|0)+2|0]|0)+9|0];Y:{if(!z[((c<<1)+a|0)+132>>1]){gc(a,21);break Y}r=R>>1;k=x[a+260>>2]+D(c,1596)|0;c=D(y[k+1588|0],w[C>>1]);g=0;n=x[k+1592>>2];if((n|0)>=2){while(1){h=y[(k+m|0)+838|0]<<1;i=w[h+C>>1];if((i|0)>=0){i=D(y[k+1588|0],i&65535);h=z[(h+k|0)+338>>1];if((h|0)!=(g|0)){o=i-c|0;n=h-g|0;F=(o|0)/(n|0)|0;L=(h|0)<(r|0)?h:r;Z:{if((L|0)<=(g|0)){break Z}Q=j+(g<<2)|0;B[Q>>2]=B[Q>>2]*B[((c&255)<<2)+47392>>2];g=g+1|0;if((L|0)<=(g|0)){break Z}u=o;o=o>>31;Q=F>>31;Q=((u^o)-o|0)-D(n,(Q^F)-Q|0)|0;K=o|1;o=0;while(1){T=j+(g<<2)|0;u=T;q=B[T>>2];o=o+Q|0;T=(o|0)<(n|0);c=(c+F|0)+(T?0:K)|0;B[u>>2]=q*B[((c&255)<<2)+47392>>2];o=o-(T?0:n)|0;g=g+1|0;if((L|0)!=(g|0)){continue}break}}n=x[k+1592>>2];g=h}c=i}m=m+1|0;if((m|0)<(n|0)){continue}break}}if((g|0)<(r|0)){q=B[(c<<2)+47392>>2];while(1){c=j+(g<<2)|0;B[c>>2]=B[c>>2]*q;g=g+1|0;if((r|0)!=(g|0)){continue}break}}}}l=l+1|0;c=x[a+4>>2];if((l|0)<(c|0)){continue}break}break C}ea(2707,9049,3335,2120);p()}ea(2707,9049,3302,2120);p()}l=0;if((c|0)<=0){break B}while(1){Y=y[ma+412|0];L=R>>1;g=L<<2;ba=x[a+92>>2];k=x[((l<<2)+a|0)+800>>2];c=L<<2;I=k+c|0;_:{if(x[a+80>>2]){m=on(a,g);break _}m=xd(g)}i=(m+c|0)-8|0;h=x[((Y<<2)+a|0)+1068>>2];$:{if(R>>>0<2){g=h;break $}c=k;g=h;while(1){B[i+4>>2]=E(B[g>>2]*B[c>>2])-E(B[g+4>>2]*B[c+8>>2]);B[i>>2]=E(B[g>>2]*B[c+8>>2])+E(B[g+4>>2]*B[c>>2]);g=g+8|0;i=i-8|0;c=c+16|0;if((I|0)!=(c|0)){continue}break}}if(i>>>0>=m>>>0){c=((L<<2)+k|0)-12|0;while(1){B[i+4>>2]=E(B[g+4>>2]*B[c>>2])-E(B[g>>2]*B[c+8>>2]);B[i>>2]=E(B[g>>2]*E(-B[c>>2]))-E(B[g+4>>2]*B[c+8>>2]);c=c-16|0;g=g+8|0;i=i-8|0;if(m>>>0<=i>>>0){continue}break}}K=R>>2;if((R|0)>=16){c=K<<2;i=c+m|0;j=c+k|0;g=(h+(L<<2)|0)-32|0;n=k;c=m;while(1){q=B[c>>2];t=B[i>>2];s=B[c+4>>2];G=B[i+4>>2];B[j+4>>2]=s+G;B[j>>2]=B[c>>2]+B[i>>2];s=E(G-s);q=E(t-q);B[n+4>>2]=E(B[g+16>>2]*s)-E(B[g+20>>2]*q);B[n>>2]=E(B[g+20>>2]*s)+E(B[g+16>>2]*q);q=B[c+8>>2];t=B[i+8>>2];s=B[c+12>>2];G=B[i+12>>2];B[j+12>>2]=s+G;B[j+8>>2]=B[c+8>>2]+B[i+8>>2];s=E(G-s);q=E(t-q);B[n+12>>2]=E(B[g>>2]*s)-E(B[g+4>>2]*q);B[n+8>>2]=E(B[g+4>>2]*s)+E(B[g>>2]*q);c=c+16|0;i=i+16|0;n=n+16|0;j=j+16|0;g=g-32|0;if(h>>>0<=g>>>0){continue}break}}i=Jl(R);g=R>>4;j=L-1|0;c=R>>3;n=0-c|0;DH(g,k,j,n,h);DH(g,k,j-K|0,n,h);Q=R>>5;g=0-g|0;qp(Q,k,j,g,h,16);qp(Q,k,j-c|0,g,h,16);qp(Q,k,j-(c<<1)|0,g,h,16);qp(Q,k,j+D(c,-3)|0,g,h,16);n=2;if((i|0)>=10){n=i-4>>>1|0;c=2;while(1){r=2<<c;if((r|0)>0){F=8<<c;g=0;o=R>>c+2;C=0-(o>>1)|0;T=R>>c+4;while(1){qp(T,k,j-D(g,o)|0,C,h,F);g=g+1|0;if((r|0)!=(g|0)){continue}break}}c=c+1|0;if((n|0)!=(c|0)){continue}break}}fa=i-7|0;if((fa|0)>(n|0)){while(1){g=R>>n+6;if((g|0)>0){F=2<<n;T=8<<n;ha=32<<n;ga=R>>n+2;ia=0-(ga>>1)|0;i=h;c=j;while(1){r=F;if((r|0)>0){o=D(T,12)+i|0;q=B[o>>2];C=(T<<3)+i|0;t=B[C>>2];$=(T<<2)+i|0;s=B[$>>2];G=B[o+4>>2];M=B[C+4>>2];W=B[$+4>>2];X=B[i+4>>2];ca=B[i>>2];o=(c<<2)+k|0;C=o+(ia<<2)|0;$=0-ga<<2;while(1){O=C-4|0;N=B[O>>2];Z=B[C>>2];_=B[o>>2];B[o>>2]=Z+_;u=o-4|0;H=B[u>>2];B[u>>2]=B[O>>2]+H;H=E(H-N);N=E(_-Z);B[O>>2]=E(H*ca)+E(N*X);B[C>>2]=E(N*ca)-E(H*X);O=C-12|0;Z=B[O>>2];u=o-8|0;H=B[u>>2];S=u;u=C-8|0;_=B[u>>2];B[S>>2]=_+H;S=o-12|0;N=B[S>>2];B[S>>2]=B[O>>2]+N;N=E(N-Z);H=E(H-_);B[O>>2]=E(N*s)+E(H*W);B[u>>2]=E(H*s)-E(N*W);O=C-20|0;Z=B[O>>2];u=o-16|0;H=B[u>>2];S=u;u=C-16|0;_=B[u>>2];B[S>>2]=_+H;S=o-20|0;N=B[S>>2];B[S>>2]=B[O>>2]+N;N=E(N-Z);H=E(H-_);B[O>>2]=E(N*t)+E(H*M);B[u>>2]=E(H*t)-E(N*M);O=C-28|0;Z=B[O>>2];u=o-24|0;H=B[u>>2];S=u;u=C-24|0;_=B[u>>2];B[S>>2]=_+H;S=o-28|0;N=B[S>>2];B[S>>2]=B[O>>2]+N;N=E(N-Z);H=E(H-_);B[O>>2]=E(N*q)+E(H*G);B[u>>2]=E(H*q)-E(N*G);C=C+$|0;o=o+$|0;O=r>>>0>1;r=r-1|0;if(O){continue}break}}c=c-8|0;i=(ha<<2)+i|0;r=g>>>0>1;g=g-1|0;if(r){continue}break}}n=n+1|0;if((fa|0)!=(n|0)){continue}break}}g=Q<<6;if((0-g|0)<0){c=(j<<2)+k|0;i=c-g|0;q=B[h+(R>>3<<2)>>2];ca=E(-q);while(1){g=c-32|0;M=B[g>>2];W=B[c>>2];B[c>>2]=M+W;h=c-4|0;t=B[h>>2];j=h;h=c-36|0;X=B[h>>2];B[j>>2]=X+t;j=c-8|0;s=B[j>>2];u=j;j=c-40|0;H=B[j>>2];B[u>>2]=H+s;n=c-12|0;G=B[n>>2];u=n;n=c-44|0;N=B[n>>2];B[u>>2]=N+G;B[g>>2]=W-M;B[h>>2]=t-X;h=c-16|0;t=B[h>>2];u=h;h=c-48|0;Z=B[h>>2];B[u>>2]=Z+t;G=E(G-N);s=E(s-H);B[j>>2]=E(G+s)*q;B[n>>2]=E(G-s)*q;j=c-28|0;s=B[j>>2];n=c-60|0;G=B[n>>2];r=c-24|0;M=B[r>>2];F=c-56|0;W=B[F>>2];o=c-20|0;X=B[o>>2];u=o;o=c-52|0;H=B[o>>2];B[u>>2]=H+X;B[r>>2]=W+M;B[j>>2]=G+s;B[h>>2]=X-H;B[o>>2]=Z-t;t=E(s-G);s=E(M-W);B[F>>2]=E(t-s)*q;B[n>>2]=E(t+s)*ca;BH(c);BH(g);c=c+-64|0;if(i>>>0<c>>>0){continue}break}}n=L-4|0;if((R|0)>=16){g=m+(n<<2)|0;i=(m+(K<<2)|0)-16|0;c=x[((Y<<2)+a|0)+1100>>2];while(1){h=(z[c>>1]<<2)+k|0;B[g+12>>2]=B[h>>2];B[g+8>>2]=B[h+4>>2];B[i+12>>2]=B[h+8>>2];B[i+8>>2]=B[h+12>>2];h=(z[c+2>>1]<<2)+k|0;B[g+4>>2]=B[h>>2];B[g>>2]=B[h+4>>2];B[i+4>>2]=B[h+8>>2];B[i>>2]=B[h+12>>2];c=c+4|0;g=g-16|0;i=i-16|0;if(m>>>0<=i>>>0){continue}break}}i=m+(L<<2)|0;h=i-16|0;if(m>>>0<h>>>0){c=x[((Y<<2)+a|0)+1084>>2];j=i;g=m;while(1){q=B[c+4>>2];r=j-4|0;t=B[r>>2];s=B[g+4>>2];G=E(t+s);M=B[c>>2];W=B[g>>2];F=j-8|0;X=B[F>>2];ca=E(W-X);H=E(E(q*G)-E(M*ca));t=E(s-t);B[g+4>>2]=H+t;q=E(E(M*G)+E(q*ca));s=E(X+W);B[g>>2]=q+s;B[r>>2]=H-t;B[F>>2]=s-q;q=B[c+12>>2];j=j-12|0;t=B[j>>2];s=B[g+12>>2];G=E(t+s);M=B[c+8>>2];W=B[g+8>>2];X=B[h>>2];ca=E(W-X);H=E(E(q*G)-E(M*ca));t=E(s-t);B[g+12>>2]=H+t;q=E(E(M*G)+E(q*ca));s=E(X+W);B[g+8>>2]=q+s;B[h>>2]=s-q;B[j>>2]=H-t;c=c+16|0;j=h;g=g+16|0;h=h-16|0;if(g>>>0<h>>>0){continue}break}}h=i-32|0;if(m>>>0<=h>>>0){g=x[((Y<<2)+a|0)+1076>>2]+(L<<2)|0;c=(n<<2)+k|0;j=((R<<2)+k|0)-16|0;while(1){q=B[g-4>>2];t=B[i-8>>2];s=B[g-8>>2];G=B[i-4>>2];M=E(E(q*t)-E(s*G));B[k>>2]=M;B[c+12>>2]=-M;q=E(E(s*E(-t))-E(G*q));B[I>>2]=q;B[j+12>>2]=q;q=B[g-12>>2];t=B[i-16>>2];s=B[g-16>>2];G=B[i-12>>2];M=E(E(q*t)-E(s*G));B[k+4>>2]=M;B[c+8>>2]=-M;q=E(E(s*E(-t))-E(G*q));B[I+4>>2]=q;B[j+8>>2]=q;q=B[g-20>>2];t=B[i-24>>2];s=B[g-24>>2];G=B[i-20>>2];M=E(E(q*t)-E(s*G));B[k+8>>2]=M;B[c+4>>2]=-M;q=E(E(s*E(-t))-E(G*q));B[I+8>>2]=q;B[j+4>>2]=q;q=B[g-28>>2];t=B[h>>2];g=g-32|0;s=B[g>>2];G=B[i-28>>2];M=E(E(q*t)-E(s*G));B[k+12>>2]=M;B[c>>2]=-M;q=E(E(s*E(-t))-E(G*q));B[I+12>>2]=q;B[j>>2]=q;j=j-16|0;c=c-16|0;I=I+16|0;k=k+16|0;i=h;h=h-32|0;if(m>>>0<=h>>>0){continue}break}}if(!x[a+80>>2]){_b(m)}x[a+92>>2]=ba;l=l+1|0;if((l|0)<x[a+4>>2]){continue}break}}HH(a);aa:{if(y[a+1377|0]){x[a+1060>>2]=0-U;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=R-ja;break aa}c=x[a+1412>>2];if(!c){break aa}g=ka-J|0;if((g|0)<=(c|0)){x[a+1412>>2]=c-g;x[V+4>>2]=ka;J=ka;break aa}J=c+J|0;x[V+4>>2]=J;x[a+1412>>2]=0}c=x[a+1064>>2];ba:{ca:{da:{if(x[a+1388>>2]==x[a+1404>>2]){ea:{if(!c|!(y[a+1375|0]&4)){break ea}c=x[a+1408>>2];g=x[a+1060>>2];if(c>>>0>=g+(ja-J|0)>>>0){break ea}g=c-g|0;c=(c>>>0>=g>>>0?g:0)+J|0;c=(c|0)<(ja|0)?c:ja;x[na>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break ba}x[a+1064>>2]=1;x[a+1060>>2]=x[a+1408>>2]+(J-U|0);break da}if(!c){break ca}}x[a+1060>>2]=x[a+1060>>2]+(ka-J|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break r}x[na>>2]=ja}c=1}hb=P+2368|0;break q}ea(2707,9049,3451,2120);p()}}else{c=0}hb=da+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((Wg(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;b=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((Wg(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;b=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;b=1;break a}i=x[V+12>>2];j=x[V+4>>2];c=x[V+8>>2];k=0;ia:{ja:{h=x[a+992>>2];ka:{if(!h){J=x[a+4>>2];h=0;break ka}m=h<<1;la:{if((m|0)==x[a+112>>2]){g=a+1092|0}else{g=0;if((m|0)!=x[a+116>>2]){break la}g=a+1096|0}g=x[g>>2]}if(!g){break ja}J=x[a+4>>2];if((J|0)>0){l=(h|0)<=0;while(1){if(!l){m=(k<<2)+a|0;J=0;while(1){n=x[m+800>>2]+(j+J<<2)|0;r=J<<2;B[n>>2]=E(B[g+(h+(J^-1)<<2)>>2]*B[r+x[m+928>>2]>>2])+E(B[g+r>>2]*B[n>>2]);J=J+1|0;if((h|0)!=(J|0)){continue}break}J=x[a+4>>2]}k=k+1|0;if((J|0)>(k|0)){continue}break}}h=x[a+992>>2]}l=i-c|0;x[a+992>>2]=l;if((J|0)>0){k=0;while(1){if((c|0)<(i|0)){m=(k<<2)+a|0;J=0;g=c;while(1){B[x[m+928>>2]+(J<<2)>>2]=B[x[m+800>>2]+(g<<2)>>2];J=J+1|0;g=c+J|0;if((l|0)!=(J|0)){continue}break}J=x[a+4>>2]}k=k+1|0;if((J|0)>(k|0)){continue}break}}if(!h){break ja}c=((c|0)>(i|0)?i:c)-j|0;x[a+1416>>2]=c+x[a+1416>>2];break ia}c=0}g=c;h=x[a+4>>2];if((h|0)>0){c=0;while(1){i=(c<<2)+a|0;x[i+864>>2]=x[i+800>>2]+(j<<2);c=c+1|0;if((h|0)!=(c|0)){continue}break}}if(d){x[d>>2]=h}x[f>>2]=g;x[e>>2]=a+864;b=x[a+32>>2]-b|0}hb=V+16|0;return b|0}function Fg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=hb-2704|0;hb=d;a:{b:{c:{d:{e:{f:{if(xv(c)){zc(b,268435456);o=x[c+8>>2];i=d+2684|0;e=i;x[e>>2]=0;x[e+4>>2]=0;Pj(e+8|0);x[d+2680>>2]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((y[a+3|0]-4&255)>>>0<=4){x[114409]=0;e=S(305,c|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break n}x[d+2680>>2]=e;break t}e=y[a+3|0];if(e>>>0>18){break t}e=1<<e;u:{if(!(e&126991)){if(e&396800){break u}break t}if(!y[a|0]){break t}}e=x[b>>2];x[114409]=0;e=O(652,a|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break s}x[114409]=0;T(878,d+512|0,c|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break s}g=d+512|0;e=x[g+4>>2];x[i>>2]=x[g>>2];x[i+4>>2]=e;f=i+8|0;$y(f);e=g+8|0;$l(f,e);x[f>>2]=x[e>>2];x[f+4>>2]=x[e+4>>2];h=x[yb(e)>>2];t=yb(f),u=h,x[t>>2]=u;t=yb(e),u=0,x[t>>2]=u;x[e>>2]=0;x[e+4>>2]=0;Jc(g);e=0;x[114409]=0;f=S(445,i|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break n}x[d+2680>>2]=x[i>>2];if(!f){break g}}e=y[a+3|0];if(e>>>0>18){break p}g=1<<e;v:{if(!(g&126991)){e=0;if(g&396800){break v}break p}e=!y[a|0]}if(e|A[b>>2]<262145){break p}e=x[d+2680>>2];g=y[a+3|0];x[114409]=0;x[d+496>>2]=((g|0)==11)<<4;g=O(36,d+496|0,d+2680|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){x[d+512>>2]=e-x[g>>2];e=y[a+3|0];if(e>>>0>16){break r}w:{if(!(1<<e&126991)){if((e|0)==11){break w}break r}if(!(y[a|0]&7)){break r}}e=x[d+512>>2];if(e>>>0<=2147483647){e=e<<1;break q}e=-1;break q}a=N()|0;break b}a=N()|0;break b}e=0;x[114409]=0;g=S(1341,a|0)|0;h=x[114409];x[114409]=0;x:{y:{if((h|0)!=1){z:{A:{switch(y[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:e=y[a|0];break z;case 9:e=16;break z;case 11:e=4;break z;case 10:case 17:case 18:break A;default:break z}}e=8}g=D(e,g)>>>3|0;e=g-1|0;h=x[d+512>>2];if(e>>>0>-1-h>>>0){break y}e=e+h|0;break x}a=N()|0;break b}e=-1}e=(e>>>0)/(g>>>0)|0}x[d+512>>2]=e;zc(b,e);break o}B:{C:{D:{E:{if(!(y[a+3|0]==4|y[a+3|0]==5|(y[a+3|0]==8|y[a+3|0]==7))){if(y[a+3|0]!=6){break o}e=0;if(A[d+2680>>2]<10){break g}x[114409]=0;O(313,c|0,4)|0;e=x[114409];x[114409]=0;if((e|0)==1){break n}x[114409]=0;e=S(413,c|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break E}x[d+496>>2]=e;e=x[d+2680>>2];x[114409]=0;x[d+2676>>2]=e;e=O(306,d+496|0,d+2676|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break D}x[d+512>>2]=x[e>>2];rg(c,8);e=x[d+512>>2];if(e>>>0>50529027){break C}e=D(e,85);break B}x[114409]=0;x[d+512>>2]=x[d+2680>>2];e=S(1341,a|0)|0;g=x[114409];x[114409]=0;F:{G:{if((g|0)!=1){g=x[d+512>>2];e=8/(e>>>0)|0;if(g>>>0>4294967295/(e>>>0)>>>0){break G}e=D(e,g);break F}a=N()|0;break b}e=-1}x[d+512>>2]=e;zc(b,e);break o}a=N()|0;break b}a=N()|0;break b}e=-1}x[d+512>>2]=e;zc(b,(e>>>0)/(y[a|0]>>>3>>>0)|0)}if(!x[b>>2]){e=0;break g}w[b+34>>1]=z[b+34>>1]&65534|y[a|0]>15;w[b+34>>1]=z[b+34>>1]&65471|(y[a+1|0]!=1)<<6;x[114409]=0;e=S(438,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}if(!e){e=0;x[b>>2]=0;break g}e=cd(d+512|0,8,1,0,11);x[114409]=0;e=O(1342,a|0,e|0)|0;g=x[114409];x[114409]=0;H:{I:{J:{K:{L:{if((g|0)!=1){if(!e){break H}e=0;x[114409]=0;a=O(1343,c|0,d+512|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break I}if(!a){break h}a=x[b>>2];x[114409]=0;x[d+496>>2]=a+1>>>1;a=S(305,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break L}zc(d+496|0,a);x[114409]=0;a=S(879,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}e=x[d+496>>2];if(e){break J}e=16;break h}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=a+16|0;b=x[b+20>>2];f=0;while(1){m=f;f=d+512|0;g=m+y[f|y[a|0]&15]|0;v[b|0]=g;f=y[f|y[a|0]>>>4]+(g&255)|0;v[b+1|0]=f;a=a+1|0;b=b+2|0;e=e-1|0;if(e){continue}break}e=x[d+496>>2]+16|0;break h}a=N()|0;break b}if(!(y[a+3|0]!=4&y[a+3|0]!=5)){a=y[a+3|0];x[114409]=0;a=Z(1344,d+1592|0,c|0,b|0,(a|0)==5|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}Ab(a);e=x[c+8>>2]-o|0;break h}M:{if(!(y[a+3|0]!=6|y[a+1|0]!=1)){x[114409]=0;O(313,c|0,4)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;a=S(413,c|0)|0;e=x[114409];x[114409]=0;N:{O:{P:{if((e|0)!=1){x[114409]=0;x[d+496>>2]=a;e=S(425,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break P}x[114409]=0;T(1345,d+512|0,c|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break N}a=d+512|0;zc(d+496|0,x[a>>2]);x[114409]=0;f=x[d+496>>2];P(715,d+1584|0,a|0);a=x[114409];x[114409]=0;Q:{if((a|0)==1){break Q}a=x[b+20>>2];x[114409]=0;a=S(439,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break M}b=el(b);x[114409]=0;T(1346,d+1576|0,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break Q}x[114409]=0;T(1347,d+1584|0,d+1576|0,e<<24>>24);a=x[114409];x[114409]=0;if((a|0)!=1){break O}}a=N()|0;Jc(d+512|0);break b}a=N()|0;break b}a=N()|0;break b}e=f+9|0;Jc(d+512|0);break h}a=N()|0;break b}if(!(y[a+3|0]!=9|y[a+1|0]!=1|y[a|0]!=16)){a=x[d+2680>>2];e=z[Yl(d+1574|0)>>1];x[114409]=0;e=Z(1348,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(y[a+3|0]!=8|y[a+1|0]!=1|y[a|0]>16){break m}e=0;x[114409]=0;f=O(231,c|0,8)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}if(!f){break h}x[114409]=0;f=S(413,c|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}x[d+2680>>2]=f;if(f>>>0<4){break h}x[114409]=0;T(316,d+496|0,c|0,f|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}e=d+496|0;f=Lm(d+512|0,e);Ab(e);x[114409]=0;h=S(1349,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}if(!x[b>>2]){break j}q=y[a|0];r=(q|0)!=16;a=0;g=0;while(1){R:{if(r){break R}x[114409]=0;s=O(233,f|0,8)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break R}a=R(75852)|0;break k}x[114409]=0;m=O(233,f|0,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}x[114409]=0;e=O(233,f|0,1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break l}S:{T:{U:{if(!e){e=8;while(1){x[114409]=0;j=O(233,f|0,1)|0;n=x[114409];x[114409]=0;if((n|0)==1){break S}if(j){break U}e=e+16|0;continue}}x[114409]=0;e=O(233,f|0,3)|0;j=x[114409];x[114409]=0;if((j|0)!=1){break T}break l}x[114409]=0;j=O(233,f|0,4)|0;n=x[114409];x[114409]=0;if((n|0)==1){break l}e=e+j|0}g=(g&255)+(((m?-1:0)^e)&255)|0;V:{if((q|0)!=16){v[x[b+20>>2]+a|0]=g;break V}w[x[b+20>>2]+(a<<1)>>1]=s&255|g<<8}a=a+1|0;if(a>>>0<A[b>>2]){continue}break j}break}a=R(75852)|0;break k}break a}a=N()|0;break b}if(!(y[a+3|0]!=7|y[a+1|0]!=1|y[a|0]>16)){e=0;if(A[d+2680>>2]<5){break h}a=x[b+20>>2];x[114409]=0;a=S(439,a|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}x[114409]=0;a=S(442,a|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}b=el(b);x[114409]=0;e=U(1350,c|0,a|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=8|y[a+1|0]!=1)){W:{X:{Y:{Z:{_:{a=y[a+3|0];switch(a|0){case 2:break X;case 1:break Y;case 0:break Z;default:break _}}e=0;switch(a-10|0){case 0:break W;case 2:break X;default:break h}}x[114409]=0;e=U(1351,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;e=U(1352,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}a=x[d+2680>>2];e=y[cz(d+495|0)|0];x[114409]=0;e=Z(1353,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;e=U(1354,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=8|y[a+1|0]!=3)){$:{aa:{ba:{ca:{g=y[a+3|0];switch(g|0){case 2:break $;case 1:break ba;case 0:break ca;default:break aa}}x[114409]=0;e=U(1355,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;e=U(1356,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}e=0;if((g|0)!=12){break h}}e=x[d+2680>>2];g=y[cz(d+494|0)|0];x[114409]=0;e=Z(1357,b|0,f|0,e|0,g|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}if(y[a+3|0]!=12){break h}f=x[b>>2]<<1;if((f|0)<=0){break h}a=x[b+20>>2];b=f+a|0;while(1){v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break h}if(!(y[a|0]!=8|y[a+1|0]!=2)){e=0;da:{switch(y[a+3|0]){case 0:x[114409]=0;e=U(1358,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 1:x[114409]=0;e=U(1359,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 2:break da;default:break h}}a=x[d+2680>>2];e=y[cz(d+493|0)|0];x[114409]=0;e=Z(1360,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+2|0]|(y[a|0]!=16|y[a+1|0]!=1))){ea:{fa:{ga:{ha:{a=y[a+3|0];switch(a|0){case 2:break ea;case 1:break ga;case 0:break ha;default:break fa}}x[114409]=0;e=U(1361,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;e=U(1362,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}e=0;if((a|0)!=12){break h}}a=x[d+2680>>2];e=z[Yl(d+490|0)>>1];x[114409]=0;e=Z(1363,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=16|y[a+1|0]!=1|y[a+2|0]!=1)){e=0;ia:{switch(y[a+3|0]){case 0:x[114409]=0;e=U(1364,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 1:x[114409]=0;e=U(1365,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 2:break ia;default:break h}}a=x[d+2680>>2];e=z[Yl(d+488|0)>>1];x[114409]=0;e=Z(1366,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+2|0]|(y[a|0]!=16|y[a+1|0]!=3))){ja:{ka:{la:{ma:{g=y[a+3|0];switch(g|0){case 2:break ja;case 1:break la;case 0:break ma;default:break ka}}x[114409]=0;e=U(1367,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;e=U(1368,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}e=0;if((g|0)!=12){break h}}e=x[d+2680>>2];g=z[Yl(d+486|0)>>1];x[114409]=0;e=Z(1369,b|0,f|0,e|0,g|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}if(y[a+3|0]!=12){break h}f=x[b>>2]<<2;if((f|0)<=0){break h}a=x[b+20>>2];b=f+a|0;while(1){w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break h}if(!(y[a|0]!=16|y[a+1|0]!=3|y[a+2|0]!=1)){e=0;na:{switch(y[a+3|0]){case 0:x[114409]=0;e=U(1370,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 1:x[114409]=0;e=U(1371,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 2:break na;default:break h}}a=x[d+2680>>2];e=z[Yl(d+484|0)>>1];x[114409]=0;e=Z(1372,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+2|0]|(y[a|0]!=16|y[a+1|0]!=2))){e=0;oa:{switch(y[a+3|0]){case 0:x[114409]=0;e=U(1373,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 1:x[114409]=0;e=U(1374,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 2:break oa;default:break h}}a=x[d+2680>>2];e=z[Yl(d+482|0)>>1];x[114409]=0;e=Z(1375,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=16|y[a+1|0]!=2|y[a+2|0]!=1)){e=0;pa:{switch(y[a+3|0]){case 0:x[114409]=0;e=U(1376,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 1:x[114409]=0;e=U(1377,b|0,f|0,x[d+2680>>2])|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h;case 2:break pa;default:break h}}a=x[d+2680>>2];e=z[Yl(d+480|0)>>1];x[114409]=0;e=Z(1378,b|0,f|0,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=24|y[a+1|0]!=1))){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d>>1]=y[d+478|0]|y[d+479|0]<<8;e=Z(1379,b|0,f|0,e|0,d|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+2>>1]=y[d+476|0]|y[d+477|0]<<8;e=Z(1380,b|0,f|0,e|0,d+2|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=24|y[a+1|0]!=2))){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+4>>1]=y[d+474|0]|y[d+475|0]<<8;e=Z(1381,b|0,f|0,e|0,d+4|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+6>>1]=y[d+472|0]|y[d+473|0]<<8;e=Z(1382,b|0,f|0,e|0,d+6|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=32|y[a+1|0]!=1))){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+8>>1]=y[d+470|0]|y[d+471|0]<<8;e=Z(1383,b|0,f|0,e|0,d+8|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+10>>1]=y[d+468|0]|y[d+469|0]<<8;e=Z(1384,b|0,f|0,e|0,d+10|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=32|y[a+1|0]!=2))){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+12>>1]=y[d+466|0]|y[d+467|0]<<8;e=Z(1385,b|0,f|0,e|0,d+12|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+14>>1]=y[d+464|0]|y[d+465|0]<<8;e=Z(1386,b|0,f|0,e|0,d+14|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=64|y[a+1|0]!=1))){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+16>>1]=y[d+462|0]|y[d+463|0]<<8;e=Z(1387,b|0,f|0,e|0,d+16|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+18>>1]=y[d+460|0]|y[d+461|0]<<8;e=Z(1388,b|0,f|0,e|0,d+18|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=64|y[a+1|0]!=2))){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+20>>1]=y[d+458|0]|y[d+459|0]<<8;e=Z(1389,b|0,f|0,e|0,d+20|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+22>>1]=y[d+456|0]|y[d+457|0]<<8;e=Z(1390,b|0,f|0,e|0,d+22|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=32|y[a+1|0]!=1|y[a+3|0]!=3)){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+24>>1]=y[d+454|0]|y[d+455|0]<<8;e=Z(1391,b|0,f|0,e|0,d+24|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+26>>1]=y[d+452|0]|y[d+453|0]<<8;e=Z(1392,b|0,f|0,e|0,d+26|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=32|y[a+1|0]!=2|y[a+3|0]!=3)){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+28>>1]=y[d+450|0]|y[d+451|0]<<8;e=Z(1393,b|0,f|0,e|0,d+28|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+30>>1]=y[d+448|0]|y[d+449|0]<<8;e=Z(1394,b|0,f|0,e|0,d+30|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=64|y[a+1|0]!=1|y[a+3|0]!=3)){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+32>>1]=y[d+446|0]|y[d+447|0]<<8;e=Z(1395,b|0,f|0,e|0,d+32|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+34>>1]=y[d+444|0]|y[d+445|0]<<8;e=Z(1396,b|0,f|0,e|0,d+34|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=64|y[a+1|0]!=2|y[a+3|0]!=3)){e=x[d+2680>>2];if(!y[a+2|0]){x[114409]=0;w[d+36>>1]=y[d+442|0]|y[d+443|0]<<8;e=Z(1397,b|0,f|0,e|0,d+36|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[114409]=0;w[d+38>>1]=y[d+440|0]|y[d+441|0]<<8;e=Z(1398,b|0,f|0,e|0,d+38|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}qa:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=24|y[a+3|0]!=16)){x[d+512>>2]=-2147483648;e=x[d+2680>>2];ra:{if(!y[a+2|0]){x[114409]=0;x[d+48>>2]=x[d+436>>2];x[d+432>>2]=0;a=x[d+432>>2];x[d+40>>2]=x[d+428>>2];x[d+44>>2]=a;e=aa(1399,b|0,f|0,e|0,d+512|0,d+40|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break ra}break qa}x[114409]=0;x[d- -64>>2]=x[d+424>>2];x[d+420>>2]=0;a=x[d+420>>2];x[d+56>>2]=x[d+416>>2];x[d+60>>2]=a;e=aa(1400,b|0,f|0,e|0,d+512|0,d+56|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break qa}}if(!e){break h}a=x[d+512>>2];if((a|0)==-2147483648){break h}f=z[b+32>>1];x[114409]=0;f=sqa(f,0,a,0);a=lb;f=f+1073741824|0;a=f>>>0<1073741824?a+1|0:a;a=cg(761,(a&2147483647)<<1|f>>>31,a>>>31|0);f=x[114409];x[114409]=0;if((f|0)==1){break qa}t=b,u=Md(a,1,64),w[t+32>>1]=u;w[b+34>>1]=z[b+34>>1]|8192;break h}sa:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=32|y[a+3|0]!=16)){x[d+512>>2]=-2147483648;e=x[d+2680>>2];ta:{if(!y[a+2|0]){x[114409]=0;x[d+80>>2]=x[d+412>>2];x[d+408>>2]=0;a=x[d+408>>2];x[d+72>>2]=x[d+404>>2];x[d+76>>2]=a;e=aa(1401,b|0,f|0,e|0,d+512|0,d+72|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break ta}break sa}x[114409]=0;x[d+96>>2]=x[d+400>>2];x[d+396>>2]=0;a=x[d+396>>2];x[d+88>>2]=x[d+392>>2];x[d+92>>2]=a;e=aa(1402,b|0,f|0,e|0,d+512|0,d+88|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break sa}}if(!e){break h}a=x[d+512>>2];if((a|0)==-2147483648){break h}f=z[b+32>>1];x[114409]=0;a=sqa(f,0,a,0);f=lb;g=a+1073741824|0;f=g>>>0<1073741824?f+1|0:f;a=cg(761,(f&2147483647)<<1|g>>>31,f>>>31|0);f=x[114409];x[114409]=0;if((f|0)==1){break sa}t=b,u=Md(a,1,64),w[t+32>>1]=u;w[b+34>>1]=z[b+34>>1]|8192;break h}ua:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=32|y[a+3|0]!=15)){x[d+512>>2]=1065353216;e=x[d+2680>>2];va:{if(!y[a+2|0]){x[114409]=0;x[d+380>>2]=0;x[d+384>>2]=1065353216;a=x[d+388>>2];x[d+112>>2]=x[d+384>>2];x[d+116>>2]=a;a=x[d+380>>2];x[d+104>>2]=x[d+376>>2];x[d+108>>2]=a;e=aa(1403,b|0,f|0,e|0,d+512|0,d+104|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break va}break ua}x[114409]=0;x[d+364>>2]=0;x[d+368>>2]=1065353216;a=x[d+372>>2];x[d+128>>2]=x[d+368>>2];x[d+132>>2]=a;a=x[d+364>>2];x[d+120>>2]=x[d+360>>2];x[d+124>>2]=a;e=aa(1404,b|0,f|0,e|0,d+512|0,d+120|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break ua}}if(!e){break h}k=B[d+512>>2];if(k==E(1)){break h}k=bz(E(k*E(z[b+32>>1])),E(1),E(64));x[114409]=0;a=eb(1405,E(k))|0;f=x[114409];x[114409]=0;if((f|0)==1){break ua}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break h}wa:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=64|y[a+3|0]!=15)){x[d+512>>2]=0;x[d+516>>2]=1072693248;e=x[d+2680>>2];xa:{if(!y[a+2|0]){x[114409]=0;x[d+344>>2]=0;x[d+348>>2]=1072693248;x[d+336>>2]=0;x[d+340>>2]=0;x[d+144>>2]=0;x[d+148>>2]=0;x[d+152>>2]=0;x[d+156>>2]=1072693248;a=x[d+356>>2];x[d+160>>2]=x[d+352>>2];x[d+164>>2]=a;a=x[d+332>>2];x[d+136>>2]=x[d+328>>2];x[d+140>>2]=a;e=aa(1406,b|0,f|0,e|0,d+512|0,d+136|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break xa}break wa}x[114409]=0;x[d+312>>2]=0;x[d+316>>2]=1072693248;x[d+304>>2]=0;x[d+308>>2]=0;x[d+176>>2]=0;x[d+180>>2]=0;x[d+184>>2]=0;x[d+188>>2]=1072693248;a=x[d+324>>2];x[d+192>>2]=x[d+320>>2];x[d+196>>2]=a;a=x[d+300>>2];x[d+168>>2]=x[d+296>>2];x[d+172>>2]=a;e=aa(1407,b|0,f|0,e|0,d+512|0,d+168|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break wa}}if(!e){break h}l=C[d+512>>3];if(l==1){break h}l=az(l*+z[b+32>>1],1,64);x[114409]=0;a=na(1408,+l)|0;f=x[114409];x[114409]=0;if((f|0)==1){break wa}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break h}ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{if(!(y[a|0]!=32|y[a+1|0]!=1|y[a+3|0]!=13)){e=y[a+2|0];a=x[d+2680>>2];if(!e){x[d+288>>2]=939524096;e=d+288|0;break Ea}x[d+280>>2]=939524096;e=d+280|0;break Ca}if(!(y[a|0]!=32|y[a+1|0]!=2|y[a+3|0]!=13)){e=y[a+2|0];a=x[d+2680>>2];if(!e){x[d+272>>2]=939524096;e=d+272|0;break Aa}x[d+264>>2]=939524096;e=d+264|0;break ya}if(y[a|0]!=32|y[a+1|0]!=1|y[a+3|0]!=14){break Ba}e=y[a+2|0];a=x[d+2680>>2];if(e){break Da}x[d+256>>2]=872415232;e=d+256|0}x[114409]=0;g=x[e+4>>2];x[d+200>>2]=x[e>>2];x[d+204>>2]=g;e=Z(1409,b|0,f|0,a|0,d+200|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}x[d+248>>2]=872415232;e=d+248|0}x[114409]=0;g=x[e+4>>2];x[d+208>>2]=x[e>>2];x[d+212>>2]=g;e=Z(1410,b|0,f|0,a|0,d+208|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}e=0;if(y[a|0]!=32|y[a+1|0]!=2|y[a+3|0]!=14){break h}e=y[a+2|0];a=x[d+2680>>2];if(e){break za}x[d+240>>2]=872415232;e=d+240|0}x[114409]=0;g=x[e+4>>2];x[d+216>>2]=x[e>>2];x[d+220>>2]=g;e=Z(1411,b|0,f|0,a|0,d+216|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break h}break f}x[d+232>>2]=872415232;e=d+232|0}x[114409]=0;g=x[e+4>>2];x[d+224>>2]=x[e>>2];x[d+228>>2]=g;e=Z(1412,b|0,f|0,a|0,d+224|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}break h}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=R(75852)|0}if((ib|0)!=(ca(75852)|0)){break d}Y(a|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break i}}e=h+4|0;Ab(f);break h}a=N()|0;break d}x[114409]=0;O(229,c|0,e+o|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}}Jc(i)}hb=d+2704|0;return e|0}a=N()|0;break b}a=N()|0}Ab(f);break b}a=N()|0}Jc(i);Q(a|0);p()}R(0)|0;zb();p()}function gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;d=hb-352|0;hb=d;Nc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{if(!Mf(b,d+344|0)){break Q}if(!_U(d+344|0)){break Q}if(!c){o=1;break Q}q=km(d+328|0,b);x[114409]=0;T(453,d+316|0,q|0,1);b=x[114409];x[114409]=0;R:{S:{T:{U:{V:{W:{X:{Y:{if((b|0)!=1){x[114409]=0;T(454,d+160|0,d+316|0,1229866575);b=x[114409];x[114409]=0;if((b|0)==1){break W}x[114409]=0;o=O(455,d+160|0,d+306|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Y}Ab(d+160|0);if(!o){break R}x[114409]=0;P(419,a|0,524288);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;V(456,a|0);b=x[114409];x[114409]=0;if((b|0)!=1){break X}break c}b=N()|0;break a}b=N()|0;Ab(d+160|0);break b}x[a+480208>>2]=12;b=y[d+314|0]|y[d+315|0]<<8;F=a,G=Md((b<<8|b>>>8)&65535,1,127),w[F+480188>>1]=G;b=y[d+306|0]|y[d+307|0]<<8;x[114409]=0;w[d+160>>1]=b<<8|b>>>8;w[d+252>>1]=255;b=O(457,d+160|0,d+252|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}w[a+480192>>1]=z[b>>1];b=y[d+308|0]|y[d+309|0]<<8;x[114409]=0;w[d+160>>1]=b<<8|b>>>8;w[d+252>>1]=3999;b=O(457,d+160|0,d+252|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}w[a+480190>>1]=z[b>>1];x[114409]=0;b=a+1074312|0;U(458,b|0,6,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;O(459,b|0,21)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;O(459,b|0,13)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;b=O(2,d+292|0,5253)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}Eb(a+1304436|0,b);xb(b);x[114409]=0;b=O(2,d+280|0,6298)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}Eb(a+1304448|0,b);xb(b);x[114409]=0;e=O(2,d+268|0,11042)|0;b=x[114409];x[114409]=0;if((b|0)==1){break h}x[114409]=0;P(192,d+252|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break j}x[114409]=0;P(460,d+236|0,d+348|0);b=x[114409];x[114409]=0;if((b|0)==1){break l}x[114409]=0;P(460,d+216|0,d+349|0);b=x[114409];x[114409]=0;if((b|0)==1){break n}x[114409]=0;W(195,d+160|0,d+252|0,d+236|0,d+216|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}b=d+160|0;Eb(a+1304460|0,b);xb(b);xb(d+216|0);xb(d+236|0);b=d+252|0;Gb(b);xb(e);x[a+1304496>>2]=2;x[114409]=0;T(454,b|0,d+316|0,1312902469);b=x[114409];x[114409]=0;if((b|0)==1){break p}x[114409]=0;b=S(228,d+252|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break r}x[114409]=0;f=a+1304400|0;U(461,d+252|0,f|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break r}x[114409]=0;T(454,d+236|0,d+316|0,1397706311);b=x[114409];x[114409]=0;if((b|0)==1){break s}b=a+484360|0;Kq(Wb(b));Z:{g=y[d+310|0]|y[d+311|0]<<8;_:{if(!g){break _}e=0;g=(g<<8|g>>>8)&65535;while(1){x[114409]=0;h=O(231,d+236|0,46)|0;i=x[114409];x[114409]=0;$:{if((i|0)!=1){if(!h){break _}x[114409]=0;U(462,d+236|0,d+160|0,44)|0;h=x[114409];x[114409]=0;if((h|0)!=1){if(!Yc(f)){break $}x[114409]=0;O(463,f|0,d+160|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break $}}b=N()|0;break t}b=N()|0;break t}x[114409]=0;h=S(464,d+236|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break Z}if(!kd(Wb(b))){x[114409]=0;i=S(465,b|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break Z}if((i|0)==255){break _}}i=Wb(b);x[114409]=0;T(6,d+216|0,2,d+160|0);k=x[114409];x[114409]=0;if((k|0)==1){break u}x[114409]=0;P(466,i|0,d+216|0);i=x[114409];x[114409]=0;if((i|0)==1){break v}xb(d+216|0);i=Wb(b);x[114409]=0;aa(467,i|0,d+236|0,h|0,65535,65535)|0;h=x[114409];x[114409]=0;if((h|0)==1){break Z}e=e+1|0;if(g>>>0>(e&65535)>>>0){continue}break}}x[114409]=0;P(468,b|0,0);b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;T(454,d+216|0,d+316|0,1229869908);b=x[114409];x[114409]=0;if((b|0)==1){break x}x[114409]=0;b=S(469,d+216|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break E}aa:{if(!b){break aa}if(z[a+480192>>1]){g=1;while(1){x[114409]=0;O(470,d+216|0,d+160|0)|0;b=x[114409];x[114409]=0;ba:{ca:{da:{if((b|0)!=1){b=y[d+190|0]|y[d+191|0]<<8;x[114409]=0;b=U(427,a|0,g&65535,(b<<8|b>>>8)&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break da}if(!b){break ba}e=y[d+190|0]|y[d+191|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>3999){break ba}x[114409]=0;T(471,d+72|0,2,d+160|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;P(370,d+100|0,d+72|0);e=x[114409];x[114409]=0;if((e|0)!=1){break ca}}b=N()|0;break y}b=N()|0;break y}b=N()|0;break y}x[114409]=0;O(348,b+492|0,d+100|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break z}xb(d+100|0);x[114409]=0;T(471,d+72|0,2,d+160|0);e=x[114409];x[114409]=0;if((e|0)==1){break A}x[114409]=0;P(370,d+100|0,d+72|0);e=x[114409];x[114409]=0;if((e|0)==1){break A}e=y[d+190|0]|y[d+191|0]<<8;x[114409]=0;O(348,((((e<<8|e>>>8)&65535)<<5)+a|0)+946304|0,d+100|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break B}xb(d+100|0);x[b>>2]=0;e=y[d+206|0]|y[d+207|0]<<8;x[b+8>>2]=(e<<8|e>>>8)+128&65535;zc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+190|0]|y[d+191|0]<<8;x[114409]=0;b=D((b<<8|b>>>8)&65535,104)+a|0;P(472,b+484380|0,0);e=x[114409];x[114409]=0;if((e|0)==1){break C}e=y[d+192|0]|y[d+193|0]<<8;x[114409]=0;w[d+100>>1]=e<<8|e>>>8;w[d+72>>1]=64;e=O(457,d+100|0,d+72|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break D}w[b+484410>>1]=z[e>>1]<<2;e=y[d+194|0]|y[d+195|0]<<8|(y[d+196|0]<<16|y[d+197|0]<<24);x[114409]=0;e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);f=sqa(e,e>>31,8303,0);e=lb;f=f+4181|0;e=f>>>0<4181?e+1|0:e;e=cg(432,tqa(f,e,8363,0),lb);f=x[114409];x[114409]=0;if((f|0)==1){break C}x[b+484404>>2]=e;if(!(y[d+202|0]|y[d+203|0]<<8|(y[d+204|0]<<16|y[d+205|0]<<24))|!(y[d+209|0]&3)){break ba}e=y[d+198|0]|y[d+199|0]<<8|(y[d+200|0]<<16|y[d+201|0]<<24);h=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);x[b+484384>>2]=h;e=y[d+202|0]|y[d+203|0]<<8|(y[d+204|0]<<16|y[d+205|0]<<24);f=b+484414|0;w[f>>1]=z[f>>1]|2;x[b+484388>>2]=h+(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));if(!(y[d+209|0]&2)){break ba}w[f>>1]=z[f>>1]|4}g=g+1|0;if(z[a+480192>>1]>=(g&65535)>>>0){continue}break}}x[114409]=0;T(454,d+144|0,d+316|0,1447382614);b=x[114409];x[114409]=0;if((b|0)==1){break E}x[114409]=0;b=x[d+156>>2];x[d+32>>2]=x[d+152>>2];x[d+36>>2]=b;b=x[d+148>>2];x[d+24>>2]=x[d+144>>2];x[d+28>>2]=b;W(473,d+24|0,0,a|0,0);b=x[114409];x[114409]=0;if((b|0)==1){break E}x[114409]=0;T(454,d+128|0,d+316|0,1346719318);b=x[114409];x[114409]=0;if((b|0)==1){break E}x[114409]=0;b=x[d+140>>2];x[d+16>>2]=x[d+136>>2];x[d+20>>2]=b;b=x[d+132>>2];x[d+8>>2]=x[d+128>>2];x[d+12>>2]=b;W(473,d+8|0,1,a|0,y[d+348|0]>2|0);b=x[114409];x[114409]=0;if((b|0)==1){break E}if(!z[a+480192>>1]){break aa}b=1;while(1){e=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|v[e+60|0]&1)){x[e>>2]=32767}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}Ab(d+216|0);x[114409]=0;T(454,d+160|0,d+316|0,1346458708);b=x[114409];x[114409]=0;if((b|0)==1){break F}x[114409]=0;b=S(312,d+160|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break H}if(!(c&1)|b^1){break V}x[114409]=0;T(454,d+216|0,d+316|0,1347305805);b=x[114409];x[114409]=0;if((b|0)==1){break I}x[114409]=0;O(313,d+216|0,1)|0;b=x[114409];x[114409]=0;if((b|0)==1){break K}e=y[d+312|0]|y[d+313|0]<<8;b=0;x[114409]=0;k=a+484344|0;P(377,k|0,(e<<8|e>>>8)&65535);e=x[114409];x[114409]=0;if((e|0)==1){break K}f=hb-16|0;hb=f;e=d+116|0;x[e>>2]=0;x[e+4>>2]=0;x[114409]=0;x[f+12>>2]=0;U(497,e+8|0,f+12|0,f+11|0)|0;g=x[114409];x[114409]=0;ea:{if((g|0)!=1){hb=f+16|0;break ea}R(0)|0;zb();p()}if(y[d+312|0]|y[d+313|0]<<8){t=d+53|0;u=d+51|0;A=d+52|0;B=d+50|0;C=d+49|0;f=0;while(1){x[114409]=0;r=S(464,d+160|0)|0;g=x[114409];x[114409]=0;fa:{ga:{ha:{ia:{ja:{if((g|0)!=1){x[114409]=0;g=S(474,d+160|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ja}x[114409]=0;T(316,d+100|0,d+160|0,g|0);g=x[114409];x[114409]=0;if((g|0)==1){break ia}x[114409]=0;g=U(378,k|0,f&65535,r|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break ha}if(!g){break fa}n=Xb(d+88|0);x[114409]=0;U(475,d+216|0,n|0,-1)|0;g=x[114409];x[114409]=0;if((g|0)!=1){g=Zb(k,f);x[114409]=0;O(476,g|0,n|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break ga}}break N}b=N()|0;break L}b=N()|0;break L}b=N()|0;break L}b=N()|0;break M}g=Zb(k,f);x[114409]=0;s=O(477,g|0,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}WU(e);m=0;ka:{while(1){x[114409]=0;g=O(231,d+100|0,1)|0;h=x[114409];x[114409]=0;la:{ma:{na:{if((h|0)!=1){if(!g){break ka}x[114409]=0;i=S(425,d+100|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}if(i){break ma}F=d,G=bc(e),x[F+48>>2]=G;F=d,G=dc(e),x[F+40>>2]=G;if(Hb(d+48|0,d+40|0)){break na}break la}break N}while(1){oa:{g=x[d+48>>2];h=Zb(k,f);i=y[g+1|0];g=y[g|0];x[114409]=0;g=U(478,d+72|0,g|0,i|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break oa}g=Oe(g,m);x[114409]=0;O(479,h|0,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break oa}g=d+48|0;ke(g);if(Hb(g,d+40|0)){continue}break la}break}break N}di(d+48|0);h=z[a+480188>>1];x[114409]=0;g=S(425,d+100|0)|0;j=x[114409];x[114409]=0;pa:{qa:{if((j|0)!=1){h=h>>>0<i>>>0;i=D(i-1|0,6)+s|0;ra:{if(!(g&1)){break ra}x[114409]=0;j=S(425,d+100|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break N}l=h?d+48|0:i;if((j|0)!=31){if((j-1&255)>>>0>252){break ra}j=(D(j>>>4|0,12)+(j&15)|0)+13|0}else{j=255}v[l|0]=j}if(!(g&2)){break pa}x[114409]=0;j=S(425,d+100|0)|0;l=x[114409];x[114409]=0;if((l|0)!=1){break qa}}break N}v[(h?C:i+1|0)|0]=j}if(!(g&60)){continue}v[d+71|0]=0;v[d+70|0]=0;v[d+69|0]=0;v[d+68|0]=0;if(g&4){x[114409]=0;j=S(425,d+100|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break N}v[d+70|0]=j}if(g&8){x[114409]=0;j=S(425,d+100|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break N}v[d+68|0]=j}if(g&16){x[114409]=0;j=S(425,d+100|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break N}v[d+71|0]=j}if(g&32){x[114409]=0;g=S(425,d+100|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break N}v[d+69|0]=g}VU(d+71|0,d+69|0);VU(d+70|0,d+68|0);g=y[d+70|0];if(!(y[d+71|0]==13|g?(g|0)!=13:0)){zh(d+71|0,d+70|0);zh(d+69|0,d+68|0)}x[114409]=0;ba(480,d+60|0,d+71|0,d+69|0,d+70|0,d+68|0);g=x[114409];x[114409]=0;sa:{if((g|0)==1){break sa}x[114409]=0;g=O(481,y[d+60|0],y[d+61|0])|0;j=x[114409];x[114409]=0;if((j|0)==1){break sa}ta:{if(!g){break ta}F=d,G=bc(e),x[F+40>>2]=G;g=x[rd(d- -64|0,d+40|0)>>2];x[114409]=0;U(482,e|0,g|0,d+60|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break ta}break N}v[(h?B:i+2|0)|0]=y[d+71|0];v[(h?A:i+4|0)|0]=y[d+69|0];g=y[d+70|0];v[(h?u:i+3|0)|0]=g;v[(h?t:i+5|0)|0]=y[d+68|0];if((g|0)==40){E=1;continue}if((g|0)!=31){continue}b=1;continue}break N}WU(e);m=m+1|0;if(r>>>0<=m>>>0){break ka}g=Zb(k,f);x[114409]=0;s=O(477,g|0,m|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}break}break N}xb(n)}Ab(d+100|0);f=f+1|0;g=y[d+312|0]|y[d+313|0]<<8;if(f>>>0<((g<<8|g>>>8)&65535)>>>0){continue}break}}UU(e);g=b;Ab(d+216|0);if(!(c&4)){break T}e=0;if(!E){break U}f=z[a+480188>>1];if(!f){e=1;break U}b=0;while(1){e=1;h=(b<<5)+a|0;v[h+480288|0]=1;h=h+480280|0;x[h>>2]=x[h>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break U}b=N()|0;break t}b=N()|0;break b}g=0;e=0;if(!(c&4)){break S}}x[114409]=0;x[d+88>>2]=-1778364416;x[d+92>>2]=-16756736;T(454,d+216|0,d+316|0,1146310725);b=x[114409];x[114409]=0;ua:{va:{wa:{xa:{ya:{za:{if((b|0)!=1){x[114409]=0;b=S(469,d+216|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break wa}if(!b){break ya}x[114409]=0;h=S(464,d+216|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break wa}if(h){break za}f=e;break xa}b=N()|0;break G}b=0;f=e;while(1){x[114409]=0;i=S(425,d+216|0)|0;k=x[114409];x[114409]=0;Aa:{Ba:{if((k|0)!=1){if(z[a+480188>>1]<=b>>>0){break Aa}if(!e){break Ba}k=((b<<5)+a|0)+480280|0;x[k>>2]=x[k>>2]&-67108865|((i|0)!=0)<<26;break Aa}break wa}if(i){break Aa}f=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((h|0)!=(b|0)){continue}break}break xa}Ab(d+216|0);if(!e){break T}break ua}x[114409]=0;O(483,d+216|0,d+88|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break va}}b=N()|0;Ab(d+216|0);break G}Ab(d+216|0);if(!(f&1)){break T}}x[114409]=0;V(484,a+906300|0);b=x[114409];x[114409]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{if((b|0)==1){break Ha}b=a+906316|0;x[b>>2]=810369604;x[b+4>>2]=1869112133;v[a+906324|0]=16;v[a+906325|0]=0;v[a+906326|0]=10;v[a+906327|0]=0;b=a+906328|0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;x[114409]=0;x[d+216>>2]=0;b=a+906332|0;T(485,b|0,b+16|0,d+216|0);b=x[114409];x[114409]=0;if((b|0)==1){break Ga}x[114409]=0;e=O(122,d+100|0,5483)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Fa}x[114409]=0;O(486,a+906348|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Ea}xb(e);x[114409]=0;e=O(122,d+116|0,5467)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Da}x[114409]=0;O(487,a+906380|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Ca}xb(e);x[114409]=0;b=a+906304|0;P(488,b|0,8);e=x[114409];x[114409]=0;if((e|0)==1){break Ha}SU(d+216|0,y[d+89|0],y[d+91|0],y[d+93|0],y[d+95|0]);e=x[d+220>>2];b=x[b>>2];f=x[d+216>>2];v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;v[b+4|0]=e;v[b+5|0]=e>>>8;v[b+6|0]=e>>>16;v[b+7|0]=e>>>24;break T}b=N()|0;break G}b=N()|0;break G}b=N()|0;break G}b=N()|0;xb(e);break G}b=N()|0;break G}b=N()|0;xb(e);break G}if(!g){break S}b=0;Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{while(1){db:{x[114409]=0;x[d+60>>2]=D(b,127)>>>5;P(489,d+88|0,11441);e=x[114409];x[114409]=0;if((e|0)==1){break db}x[114409]=0;P(490,d+48|0,d+60|0);e=x[114409];x[114409]=0;if((e|0)==1){break cb}x[114409]=0;T(491,d+216|0,d+88|0,d+48|0);e=x[114409];x[114409]=0;if((e|0)==1){break bb}x[114409]=0;e=(b<<5)+a|0;P(492,d+40|0,e+902204|0);f=x[114409];x[114409]=0;if((f|0)==1){break ab}x[114409]=0;O(450,d+40|0,d+216|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break ab}xb(d+216|0);xb(d+48|0);f=d+88|0;Gb(f);x[114409]=0;P(489,f|0,11423);f=x[114409];x[114409]=0;if((f|0)==1){break Za}x[114409]=0;P(490,d+48|0,d+60|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ya}x[114409]=0;T(491,d+216|0,d+88|0,d+48|0);f=x[114409];x[114409]=0;if((f|0)==1){break Xa}x[114409]=0;P(492,d+40|0,e+903228|0);f=x[114409];x[114409]=0;if((f|0)==1){break Wa}x[114409]=0;O(450,d+40|0,d+216|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Wa}xb(d+216|0);xb(d+48|0);f=d+88|0;Gb(f);x[114409]=0;P(489,f|0,11405);f=x[114409];x[114409]=0;if((f|0)==1){break Ta}x[114409]=0;P(490,d+48|0,d+60|0);f=x[114409];x[114409]=0;if((f|0)==1){break Sa}x[114409]=0;T(491,d+216|0,d+88|0,d+48|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ra}x[114409]=0;P(492,d+40|0,e+904252|0);f=x[114409];x[114409]=0;if((f|0)==1){break Qa}x[114409]=0;O(450,d+40|0,d+216|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Qa}xb(d+216|0);xb(d+48|0);f=d+88|0;Gb(f);x[114409]=0;P(489,f|0,11396);f=x[114409];x[114409]=0;if((f|0)==1){break Na}x[114409]=0;P(490,d+48|0,d+60|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ma}x[114409]=0;T(491,d+216|0,d+88|0,d+48|0);f=x[114409];x[114409]=0;if((f|0)==1){break La}x[114409]=0;P(492,d+40|0,e+905276|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ka}x[114409]=0;O(450,d+40|0,d+216|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ka}xb(d+216|0);xb(d+48|0);Gb(d+88|0);b=b+1|0;if((b|0)!=32){continue}break S}break}b=N()|0;break G}b=N()|0;break _a}b=N()|0;break $a}b=N()|0;xb(d+216|0)}xb(d+48|0)}Gb(d+88|0);break G}b=N()|0;break G}b=N()|0;break Ua}b=N()|0;break Va}b=N()|0;xb(d+216|0)}xb(d+48|0)}Gb(d+88|0);break G}b=N()|0;break G}b=N()|0;break Oa}b=N()|0;break Pa}b=N()|0;xb(d+216|0)}xb(d+48|0)}Gb(d+88|0);break G}b=N()|0;break G}b=N()|0;break Ia}b=N()|0;break Ja}b=N()|0;xb(d+216|0)}xb(d+48|0)}Gb(d+88|0);break G}x[114409]=0;T(454,d+216|0,d+316|0,1397575756);b=x[114409];x[114409]=0;if((b|0)==1){break O}x[114409]=0;b=S(312,d+216|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break P}e=1;if(!(!z[a+480190>>1]|(!(c&2)|b^1))){c=1;while(1){x[114409]=0;b=S(474,d+216|0)|0;f=x[114409];x[114409]=0;eb:{if((f|0)!=1){x[114409]=0;f=S(474,d+216|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break P}if(!(b&7)){break eb}e=(D(e,104)+a|0)+484380|0;x[e>>2]=f;b=cd(d+88|0,b&4?32:b&2?16:8,1,1,0);x[114409]=0;U(376,b|0,e|0,d+216|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break eb}break P}break P}c=c+1|0;e=c&65535;if(e>>>0<=z[a+480190>>1]){continue}break}}Ab(d+216|0);Ab(d+160|0);Ab(d+236|0);Ab(d+252|0)}kB(d+316|0);Ab(q)}hb=d+352|0;return o|0}b=N()|0;Ab(d+216|0);break G}b=N()|0;break G}b=N()|0;xb(n)}Ab(d+100|0)}UU(e);break J}b=N()|0}Ab(d+216|0);break G}b=N()|0;break G}b=N()|0}Ab(d+160|0);break t}b=N()|0;break t}b=N()|0;break y}b=N()|0;break y}b=N()|0;break y}b=N()|0;xb(d+100|0);break y}b=N()|0;break y}b=N()|0;xb(d+100|0)}Ab(d+216|0);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;xb(d+216|0);break t}b=N()|0}Ab(d+236|0);break q}b=N()|0;break q}b=N()|0}Ab(d+252|0);break b}b=N()|0;break b}b=N()|0;xb(d+216|0);break m}b=N()|0}xb(d+236|0);break k}b=N()|0}Gb(d+252|0);break i}b=N()|0}xb(e);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}kB(d+316|0)}Ab(q);Q(b|0);p()}function Pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;e=hb-352|0;hb=e;Nc(b);a:{if(!Eu(b,e+340|0)){break a}if(!HQ(e+340|0)){break a}r=km(e+324|0,b);l=Lz(e+312|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(!c){x[114409]=0;W(979,e+80|0,r|0,1,1413891155);b=x[114409];x[114409]=0;if((b|0)==1){break t}break v}x[114409]=0;T(980,e+80|0,r|0,1);b=x[114409];x[114409]=0;if((b|0)==1){break u}}if(x[l>>2]){vd(l);zQ(l);kq(l);Lf(yb(l),x[l>>2],ff(l));u=yb(l),A=0,x[u>>2]=A;x[l>>2]=0;x[l+4>>2]=0}b=e+80|0;$l(l,b);x[l>>2]=x[b>>2];x[l+4>>2]=x[b+4>>2];k=x[yb(b)>>2];u=yb(l),A=k,x[u>>2]=A;u=yb(b),A=0,x[u>>2]=A;x[b>>2]=0;x[b+4>>2]=0;bm(b);x[114409]=0;T(981,b|0,l|0,1413891155);b=x[114409];x[114409]=0;w:{x:{if((b|0)!=1){x[114409]=0;d=O(982,e+80|0,9890)|0;b=x[114409];x[114409]=0;if((b|0)==1){break x}Ab(e+80|0);if((c|0)!=0&d){break w}break b}d=N()|0;break d}d=N()|0;Ab(e+80|0);break d}x[114409]=0;P(419,a|0,4194304);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[a+480208>>2]=12;x[114409]=0;T(981,e+296|0,l|0,1280592212);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=S(228,e+296|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break h}x[114409]=0;U(688,e+296|0,a+1304400|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break h}n=a+484360|0;Kq(Wb(n));k=hb-16|0;hb=k;b=e+284|0;x[b>>2]=0;x[b+4>>2]=0;x[114409]=0;x[k+12>>2]=0;U(1002,b+8|0,k+12|0,k+11|0)|0;d=x[114409];x[114409]=0;y:{if((d|0)!=1){hb=k+16|0;break y}R(0)|0;zb();p()}k=b;x[114409]=0;v[e+283|0]=0;T(983,e+268|0,l|0,1196314451);b=x[114409];x[114409]=0;if((b|0)==1){break j}b=e+268|0;u=e,A=bc(b),x[u+264>>2]=A;u=e,A=dc(b),x[u+260>>2]=A;z:{if(!Hb(e+264|0,e+260|0)){break z}o=e+216|0;m=e+228|0;q=e+248|0;A:{while(1){i=km(e+80|0,x[e+264>>2]);x[114409]=0;b=O(984,i|0,e+8|0)|0;d=x[114409];x[114409]=0;B:{if((d|0)!=1){if(b&y[e+17|0]==1){break B}Ab(i);d=0;break c}d=N()|0;break l}u=a,A=Md(y[e+18|0],z[a+480188>>1],127),w[u+480188>>1]=A;x[114409]=0;f=S(985,e+204|0)|0;b=x[114409];x[114409]=0;C:{D:{E:{F:{G:{H:{if((b|0)!=1){x[114409]=0;T(986,e+24|0,1,e+8|0);b=x[114409];x[114409]=0;if((b|0)==1){break H}x[114409]=0;P(370,e+180|0,e+24|0);b=x[114409];x[114409]=0;if((b|0)==1){break H}x[114409]=0;P(987,e- -64|0,q|0);b=x[114409];x[114409]=0;if((b|0)==1){break G}x[114409]=0;O(450,e- -64|0,e+180|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break G}xb(e+180|0);if(kd(Wb(n))){break E}x[114409]=0;b=S(465,n|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break F}if((b|0)!=255){break E}b=2;break D}d=N()|0;break l}d=N()|0;break m}d=N()|0;xb(e+180|0);break m}d=N()|0;break m}b=Wb(n);x[114409]=0;T(6,e+180|0,4,q|0);d=x[114409];x[114409]=0;I:{J:{K:{L:{M:{if((d|0)!=1){x[114409]=0;P(466,b|0,e+180|0);b=x[114409];x[114409]=0;if((b|0)==1){break M}xb(e+180|0);x[114409]=0;T(980,e+24|0,i|0,1);b=x[114409];x[114409]=0;if((b|0)==1){break L}b=e+24|0;u=e,A=bc(b),x[u+200>>2]=A;u=e,A=dc(b),x[u+196>>2]=A;if(Hb(e+200|0,e+196|0)){break K}break J}d=N()|0;break m}d=N()|0;xb(e+180|0);break m}d=N()|0;break m}while(1){N:{d=x[e+200>>2];b=hf(e+180|0,yb(d));h=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+64>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+68>>2]=h;O:{d=e- -64|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if((d|0)!=1212960847){if((d|0)!=1312903248){break O}d=0;if(!z[a+480188>>1]){break O}while(1){P:{x[114409]=0;h=O(231,b|0,2)|0;j=x[114409];x[114409]=0;if((j|0)==1){break P}if(!h){break O}x[114409]=0;P(452,e+40|0,b|0);h=x[114409];x[114409]=0;Q:{R:{S:{T:{if((h|0)!=1){h=ed(e+40|0);switch(y[e+40|0]){case 4:break R;case 2:break S;case 0:break T;default:break Q}}break N}h=y[h|0];u=Cc(f,d),A=h^128,v[u|0]=A;h=e+52|0;se(h,m,d);le(h,0);break Q}u=Cc(f,d),A=128,v[u|0]=A;h=e+52|0;se(h,m,d);le(h,1);break Q}u=Cc(f,d),A=128,v[u|0]=A;h=e+52|0;se(h,m,d);le(h,0)}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break O}break}break N}if(Nz(e- -64|0)>>>0<9){break O}j=0;x[114409]=0;O(313,b|0,2)|0;d=x[114409];x[114409]=0;h=65535;if((d|0)==1){break N}while(1){x[114409]=0;d=O(231,b|0,1)|0;g=x[114409];x[114409]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((g|0)!=1){if(!d){break O}x[114409]=0;d=S(425,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}switch(d|0){case 0:break O;case 14:break V;case 13:break W;case 12:break Y;case 8:break Z;case 7:break _;case 4:break $;case 1:break aa;default:break X}}break N}if(z[e+240>>1]==65535){d=Wb(n);x[114409]=0;d=S(537,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}w[e+240>>1]=d}d=Wb(n);x[114409]=0;d=S(537,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}x[114409]=0;w[e+242>>1]=d;d=O(988,b|0,e+283|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}ba:{ca:{switch(d-254|0){case 1:x[114409]=0;d=$(989)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break ba}break N;case 0:break ca;default:break ba}}x[114409]=0;d=$(990)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}}g=Wb(n);x[114409]=0;P(812,g|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break N}h=(h&65535)==65535?j:h;break U}x[114409]=0;d=S(335,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}if(d>>>0>=(h&65535)>>>0){w[e+244>>1]=d-h}Pe(Wb(n),z[e+244>>1]);break U}x[114409]=0;d=S(425,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}v[e+247|0]=d;break U}x[114409]=0;d=S(425,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}v[e+246|0]=d;break U}x[114409]=0;d=O(943,b|0,e+52|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}if(y[e+52|0]|!d|(y[e+54|0]|y[e+53|0]!=255)){break X}if(y[e+55|0]|y[e+56|0]!=1){break X}if(!y[e+57|0]){break U}}Ab(b);b=1;break I}x[114409]=0;P(827,e+177|0,b|0);d=x[114409];x[114409]=0;da:{ea:{fa:{ga:{if((d|0)!=1){d=e+177|0;g=ed(d);s=wf(d);if(y[d|0]>=xc(f)>>>0){break U}switch(y[s|0]){case 4:break ea;case 2:break fa;case 0:break ga;default:break da}}break N}g=y[g|0];u=Cc(f,y[d|0]),A=g^128,v[u|0]=A;g=e+52|0;se(g,m,y[d|0]);le(g,0);break da}u=Cc(f,y[d|0]),A=128,v[u|0]=A;g=e+52|0;se(g,m,y[d|0]);le(g,1);break da}u=Cc(f,y[d|0]),A=128,v[u|0]=A;g=e+52|0;se(g,m,y[d|0]);le(g,0)}ha:{if(t){break ha}t=0;if(!Rk(k)){break U}if(y[Cc(FQ(k),y[d|0])|0]!=y[Cc(f,y[d|0])|0]){break ha}g=e+52|0;se(g,FQ(k)+24|0,y[d|0]);g=Ib(g);s=e+40|0;se(s,m,y[d|0]);if((Ib(s)|0)==(g|0)){break U}}t=1;break U}x[114409]=0;P(452,e+52|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break N}d=ed(e+52|0);g=y[e+52|0];if(xc(o)>>>0<=g>>>0){break U}d=y[d|0];u=Cc(o,y[e+52|0]),A=(d>>>2|0)+1|0,v[u|0]=A}j=j+1|0;continue}}Ab(b);b=e+200|0;bj(b);if(Hb(b,e+196|0)){continue}break J}break}d=N()|0;Ab(b);break C}b=0;if(z[e+240>>1]==65535|z[e+242>>1]==65535){break I}b=Wb(n);x[114409]=0;V(991,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){b=0;x[114409]=0;P(992,k|0,f|0);d=x[114409];x[114409]=0;if((d|0)!=1){break I}}d=N()|0;break C}bm(e+24|0)}Zt(f);Ab(i);if(b){break A}b=e+264|0;sf(b);if(Hb(b,e+260|0)){continue}break z}break}bm(e+24|0);break m}d=0;if((b|0)!=2){break c}}d=0;x[114409]=0;P(468,n|0,0);b=x[114409];x[114409]=0;if((b|0)==1){break s}if(kd(k)){break c}ia:{if(c&2){x[114409]=0;T(983,e+180|0,l|0,1347244868);b=x[114409];x[114409]=0;if((b|0)==1){break ia}b=e+180|0;u=e,A=bc(b),x[u+64>>2]=A;u=e,A=dc(b),x[u+52>>2]=A;if(Hb(e- -64|0,e+52|0)){d=a+480190|0;f=e+93|0;h=e+97|0;m=y[e+283|0];while(1){b=x[e- -64>>2];ja:{ka:{la:{ma:{na:{if(!m){x[114409]=0;i=O(993,b|0,e+80|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break na}if(!i){break ja}i=y[e+132|0]|y[e+133|0]<<8;w[e+40>>1]=i+1;if(i>>>0>3998){break la}x[114409]=0;i=O(424,d|0,e+40|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break na}w[a+480190>>1]=z[i>>1];x[114409]=0;P(994,e+80|0,(D(z[e+40>>1],104)+a|0)+484380|0);i=x[114409];x[114409]=0;if((i|0)==1){break na}x[114409]=0;T(995,e+8|0,1,f|0);i=x[114409];x[114409]=0;oa:{pa:{if((i|0)==1){break pa}x[114409]=0;P(370,e+24|0,e+8|0);i=x[114409];x[114409]=0;if((i|0)==1){break pa}x[114409]=0;O(348,((z[e+40>>1]<<5)+a|0)+946304|0,e+24|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break oa}xb(e+24|0);break la}d=N()|0;break ka}d=N()|0;xb(e+24|0);break ka}x[114409]=0;i=O(996,b|0,e+80|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break ma}if(!i){break ja}i=y[e+136|0]|y[e+137|0]<<8;w[e+40>>1]=i+1;if(i>>>0>3998){break la}x[114409]=0;i=O(424,d|0,e+40|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break ma}w[a+480190>>1]=z[i>>1];x[114409]=0;P(997,e+80|0,(D(z[e+40>>1],104)+a|0)+484380|0);i=x[114409];x[114409]=0;if((i|0)==1){break ma}x[114409]=0;T(995,e+8|0,1,h|0);i=x[114409];x[114409]=0;qa:{ra:{if((i|0)==1){break ra}x[114409]=0;P(370,e+24|0,e+8|0);i=x[114409];x[114409]=0;if((i|0)==1){break ra}x[114409]=0;O(348,((z[e+40>>1]<<5)+a|0)+946304|0,e+24|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break qa}xb(e+24|0);break la}d=N()|0;break ka}d=N()|0;xb(e+24|0);break ka}d=N()|0;break ka}d=N()|0;break ka}if((z[e+40>>1]-1&65535)>>>0>3998){break ja}i=cd(e+80|0,8,1,0,2);x[114409]=0;U(376,i|0,(D(z[e+40>>1],104)+a|0)+484380|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break ja}d=N()|0}hd(e+180|0);break k}b=e- -64|0;sf(b);if(Hb(b,e+52|0)){continue}break}}hd(e+180|0)}b=0;u=a,A=y[am(k,0)+43|0],x[u+480196>>2]=A;u=a,A=D(y[am(k,0)+42|0],1e4),x[u+480204>>2]=A;Pe(Wb(n),z[am(k,0)+40>>1]);sa:{if(z[a+480188>>1]){while(1){x[114409]=0;d=(b<<5)+a|0;f=d+480280|0;V(403,f|0);h=x[114409];x[114409]=0;if((h|0)==1){break sa}u=d+480286|0,A=y[Cc(am(k,0)+12|0,b)|0],w[u>>1]=A;u=d+480284|0,A=y[Cc(am(k,0),b)|0],w[u>>1]=A;d=e+80|0;se(d,am(k,0)+24|0,b);d=Ib(d);x[f>>2]=x[f>>2]&-257|(d?256:0);b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}}x[114409]=0;b=O(2,e- -64|0,(y[e+283|0]?13004:12877)|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break n}Eb(a+1304436|0,b);xb(b);x[114409]=0;b=O(2,e+52|0,6118)|0;d=x[114409];x[114409]=0;if((d|0)==1){break o}Eb(a+1304448|0,b);xb(b);x[a+1304496>>2]=4;d=1;if(!(c&1)|!z[a+480188>>1]){break c}x[114409]=0;T(983,e+40|0,l|0,1146045008);b=x[114409];x[114409]=0;if((b|0)==1){break p}b=qd(e+40|0);x[114409]=0;i=a+484344|0;P(377,i|0,b&65535);b=x[114409];x[114409]=0;if((b|0)==1){break r}b=e+40|0;u=e,A=bc(b),x[u+180>>2]=A;u=e,A=dc(b),x[u+24>>2]=A;if(Hb(e+180|0,e+24|0)){while(1){m=x[e+180>>2];x[114409]=0;b=S(228,m|0)|0;c=x[114409];x[114409]=0;ta:{ua:{va:{if((c|0)==1){break va}x[114409]=0;c=S(413,m|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break va}if((b|0)!=(c|0)){break ta}x[114409]=0;b=O(998,m|0,8)|0;c=x[114409];x[114409]=0;if((c|0)==1){break va}if(b){break ua}break ta}d=N()|0;break q}x[114409]=0;q=O(988,m|0,e+283|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;o=S(335,m|0)|0;b=x[114409];x[114409]=0;wa:{if((b|0)==1){break wa}x[114409]=0;b=U(378,i|0,q|0,o|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break wa}if(!o|b^1){break ta}h=0;while(1){xa:{b=Zb(i,q);x[114409]=0;c=O(477,b|0,h|0)|0;b=x[114409];x[114409]=0;ya:{za:{Aa:{if((b|0)!=1){x[114409]=0;b=S(335,m|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Aa}if(b>>>0<3){break ya}x[114409]=0;T(316,e+80|0,m|0,b-2|0);b=x[114409];x[114409]=0;if((b|0)!=1){break za}d=N()|0;break q}d=N()|0;break q}d=N()|0;break q}while(1){x[114409]=0;b=O(231,e+80|0,3)|0;d=x[114409];x[114409]=0;if((d|0)==1){break xa}if(b){x[114409]=0;P(452,e+8|0,e+80|0);b=x[114409];x[114409]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){b=e+8|0;j=b;b=ed(b);w[e+264>>1]=z[a+480188>>1]-1;b=y[b|0];x[114409]=0;w[e+260>>1]=b;b=O(457,e+264|0,e+260|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break xa}d=z[b>>1];f=c+D(d,6)|0;b=v[j|0];if((b|0)>=0){break Ba}x[114409]=0;b=S(425,e+80|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break xa}if(y[e+283|0]){break Da}if((b|0)!=255){break Ea}b=254;break Ca}break xa}if(b>>>0>128){break Ca}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break Ca}b=b>>>0<85?b+36|0:b}v[f|0]=b;b=y[j|0]}if(b&64){x[114409]=0;b=S(425,e+80|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break xa}v[f+1|0]=b+1;b=y[j|0]}if(b&32){x[114409]=0;b=S(425,e+80|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break xa}v[e+264|0]=b;v[f+2|0]=1;x[114409]=0;v[e+260|0]=127;b=O(431,e+264|0,e+260|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break xa}v[f+4|0]=y[b|0]+1>>>1;b=y[j|0]}if(!(b&16)){continue}x[114409]=0;P(452,e+264|0,e+80|0);b=x[114409];x[114409]=0;if((b|0)==1){break xa}j=e+264|0;b=y[ed(j)|0];v[f+5|0]=b;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{switch(y[j|0]-1|0){case 0:v[(c+D(d,6)|0)+3|0]=11;if(!y[e+283|0]){v[f+5|0]=b<<3|15;continue}v[f+5|0]=b<<4|15;continue;case 1:v[(c+D(d,6)|0)+3|0]=11;if(y[e+283|0]){v[f+5|0]=b<<4;continue}v[f+5|0]=b<<3&240;continue;case 2:v[(c+D(d,6)|0)+3|0]=11;if(y[e+283|0]){v[f+5|0]=b|240;continue}v[f+5|0]=b>>>1|240;continue;case 3:v[(c+D(d,6)|0)+3|0]=11;if(y[e+283|0]){v[f+5|0]=b&15;continue}if(b>>>0<=1){v[f+5|0]=b|240;continue}v[f+5|0]=b>>>1&15;continue;case 10:v[(c+D(d,6)|0)+3|0]=2;u=f,A=Yt(b,y[e+283|0])|240,v[u+5|0]=A;continue;case 11:v[(c+D(d,6)|0)+3|0]=2;u=f,A=Yt(b,y[e+283|0]),v[u+5|0]=A;continue;case 12:v[(c+D(d,6)|0)+3|0]=3;u=f,A=Yt(b,y[e+283|0])|240,v[u+5|0]=A;continue;case 13:v[(c+D(d,6)|0)+3|0]=3;u=f,A=Yt(b,y[e+283|0]),v[u+5|0]=A;continue;case 14:v[(c+D(d,6)|0)+3|0]=4;if(y[e+283|0]){continue}v[f+5|0]=(b&252)>>>2;continue;case 16:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&1|16;continue;case 15:v[(c+D(d,6)|0)+3|0]=6;v[f+5|0]=b&240;continue;case 17:v[(c+D(d,6)|0)+3|0]=6;v[f+5|0]=(b&240)>>>4;continue;case 18:v[(c+D(d,6)|0)+3|0]=20;continue;case 20:v[(c+D(d,6)|0)+3|0]=5;continue;case 21:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|48;continue;case 22:v[(c+D(d,6)|0)+3|0]=7;v[f+5|0]=b|240;continue;case 23:v[(c+D(d,6)|0)+3|0]=7;continue;case 30:v[(c+D(d,6)|0)+3|0]=8;continue;case 31:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|64;continue;case 40:v[(c+D(d,6)|0)+3|0]=10;x[114409]=0;b=S(425,e+80|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break Oa}break xa;case 41:v[(c+D(d,6)|0)+3|0]=15;continue;case 42:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|192;continue;case 43:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|208;continue;case 72:break Ga;case 71:break Ha;case 70:break Ia;case 61:break Ja;case 60:break Ka;case 53:break La;case 52:break Ma;case 51:break Na;case 50:break Pa;default:break Fa}}v[(c+D(d,6)|0)+3|0]=12;b=(b&254)>>>1|0}v[f+5|0]=b;x[114409]=0;O(313,e+80|0,1)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}break xa}v[(c+D(d,6)|0)+3|0]=14;v[f+5|0]=0;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|176;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|224;continue}v[(c+D(d,6)|0)+3|0]=16;continue}v[(c+D(d,6)|0)+3|0]=17;continue}v[(c+D(d,6)|0)+3|0]=1;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|32;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|128;continue}v[(c+D(d,6)|0)+3|0]=0;continue}break}Ab(e+80|0)}h=h+1|0;if((o|0)!=(h|0)){continue}break ta}break}d=N()|0;Ab(e+80|0);break q}d=N()|0;break q}d=N()|0;break q}b=e+180|0;sf(b);if(Hb(b,e+24|0)){continue}break}}Qa:{Ra:{if(Rk(k)>>>0<2){break Ra}if(!Rk(k)){break Ra}d=0;while(1){b=Ti(n,d&255);c=am(k,d);f=z[vc(b,z[c+36>>1])>>1];x[114409]=0;f=O(414,i|0,f|0)|0;h=x[114409];x[114409]=0;Sa:{Ta:{if((h|0)!=1){if(!f){break Sa}f=z[c+36>>1];x[114409]=0;f=O(831,b|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break Ta}}d=N()|0;break q}if(z[a+480188>>1]!=0&t){m=c+24|0;b=0;while(1){j=Mz(m,b);h=Zb(i,f);Ua:{if(j){x[114409]=0;j=U(478,e+80|0,20,145)|0;o=x[114409];x[114409]=0;if((o|0)!=1){j=gi(ko(Oe(j,0),b&65535));x[114409]=0;O(479,h|0,j|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break Ua}}d=N()|0;break q}j=y[Cc(c,b)|0];x[114409]=0;j=U(478,e+180|0,9,j|0)|0;o=x[114409];x[114409]=0;if((o|0)!=1){j=gi(ko(Oe(j,0),b&65535));x[114409]=0;O(479,h|0,j|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break Ua}}d=N()|0;break q}b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}}b=Zb(i,f);h=y[c+43|0];x[114409]=0;h=U(478,e+24|0,16,h|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break Qa}h=gi(Oe(h,0));x[114409]=0;O(479,b|0,h|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Qa}b=Zb(i,f);c=y[c+42|0];x[114409]=0;c=U(478,e+8|0,17,c|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){c=gi(Oe(c,0));x[114409]=0;O(479,b|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break Sa}}d=N()|0;break q}d=d+1|0;if(Rk(k)>>>0>d>>>0){continue}break}}hd(e+40|0);d=1;break c}d=N()|0;break q}d=N()|0;break k}d=N()|0;break k}d=N()|0;break d}d=N()|0;break d}d=N()|0;break k}d=N()|0}hd(e+40|0);break k}d=N()|0;break k}d=N()|0;break k}d=N()|0;break k}Zt(f)}Ab(i)}hd(e+268|0);break i}d=N()|0}EQ(k);break g}d=N()|0}Ab(e+296|0);break d}d=N()|0;break d}d=N()|0}bm(l);Ab(r);Q(d|0);p()}hd(e+268|0);EQ(k);Ab(e+296|0)}bm(l);Ab(r)}hb=e+352|0;return d|0}function Y2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=0,K=0,L=E(0),M=0,N=0,O=0,P=E(0);r=hb-1520|0;hb=r;f=r+8|0;g=Sb(f,0,1512);if(e){i=x[e+4>>2];e=x[e>>2];x[g+80>>2]=e;x[g+84>>2]=i;e=i&-8;x[g+92>>2]=e;x[g+84>>2]=e}x[g+1420>>2]=-1;x[g+124>>2]=0;x[g+32>>2]=0;x[g+96>>2]=0;x[g+100>>2]=0;v[r+56|0]=1;x[r+48>>2]=a+b;x[r+40>>2]=a;b=0;n=hb-1024|0;hb=n;v[f+1377|0]=1;a:{if(!ts(f)){break a}e=y[f+1375|0];if(!(e&2)){gc(f,34);break a}if(e&4){gc(f,34);break a}if(e&1){gc(f,34);break a}if(x[f+1116>>2]!=1){gc(f,34);break a}e=y[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!hx(f,n+1018|0,6)|y[n+1018|0]!=102|(y[n+1019|0]!=105|y[n+1020|0]!=115)){break b}if(y[n+1021|0]!=104|y[n+1022|0]!=101|y[n+1023|0]!=97){break b}if((Ee(f)|0)!=100){break b}if(Ee(f)){break b}gc(f,38);break a}gc(f,34);break a}if((Ee(f)|0)!=1){gc(f,34);break a}if(!hx(f,n+1018|0,6)){gc(f,10);break a}if(!gx(n+1018|0)){gc(f,34);break a}if(yi(f)){gc(f,34);break a}e=Ee(f);x[f+4>>2]=e;if(!e){gc(f,34);break a}if(e>>>0>=17){gc(f,5);break a}e=yi(f);x[f>>2]=e;if(!e){gc(f,34);break a}yi(f);yi(f);yi(f);e=Ee(f);i=e>>>4|0;x[f+116>>2]=1<<i;g=e&15;x[f+112>>2]=1<<g;if(g-14>>>0<=4294967287){gc(f,20);break a}if(e+32<<24>>24>=0){gc(f,20);break a}c:{if(g>>>0>i>>>0){gc(f,20);break c}if(!(Ee(f)&1)){gc(f,34);break c}if(!ts(f)){break a}if(!dx(f)){break a}if(!cx(f)){break a}d:{if((Wg(f)|0)==3){while(1){N=(n+1018|0)+b|0,O=Wg(f),v[N|0]=O;b=b+1|0;if((b|0)!=6){continue}break}if(!gx(n+1018|0)){gc(f,20);break c}g=bx(f);e=Ud(f,g+1|0);x[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=Wg(f);v[x[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=x[f+20>>2]}v[e+g|0]=0;b=bx(f);x[f+28>>2]=0;x[f+24>>2]=b;e:{f:{if((b|0)<=0){break f}b=Ud(f,b<<2);x[f+28>>2]=b;if(!b){gc(f,3);break c}if(x[f+24>>2]<=0){break f}while(1){g=bx(f);b=Ud(f,g+1|0);i=h<<2;x[i+x[f+28>>2]>>2]=b;e=x[i+x[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=Wg(f);v[x[i+x[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=x[i+x[f+28>>2]>>2]}v[e+g|0]=0;h=h+1|0;if((h|0)<x[f+24>>2]){continue}break}}if(!(Wg(f)&1)){gc(f,20);break c}KH(f,y[f+1376|0]);v[f+1376|0]=0;while(1){b=cx(f);KH(f,b);v[f+1376|0]=0;if(b){continue}break}b=0;if(!dx(f)){break a}if(!LH(f)){if(x[f+100>>2]!=21){break a}x[f+100>>2]=20;break a}e=0;while(1){g=e<<24;l=0;while(1){g=g>>31&79764919^g<<1;l=l+1|0;if((l|0)!=8){continue}break}x[(e<<2)+455904>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((Wg(f)|0)==5){while(1){N=(n+1018|0)+b|0,O=Wg(f),v[N|0]=O;b=b+1|0;if((b|0)!=6){continue}break}if(!gx(n+1018|0)){gc(f,20);break c}b=lc(f,8)+1|0;x[f+120>>2]=b;b=Ud(f,D(b,2096));x[f+124>>2]=b;if(!b){gc(f,3);break c}Sb(b,0,D(x[f+120>>2],2096));g:{h:{if(x[f+120>>2]>0){while(1){b=x[f+124>>2];if((lc(f,8)&255)!=66){gc(f,20);break c}if((lc(f,8)&255)!=67){gc(f,20);break c}if((lc(f,8)&255)!=86){gc(f,20);break c}g=b+D(q,2096)|0;N=g,O=lc(f,8)&255|lc(f,8)<<8,x[N>>2]=O;N=g,O=lc(f,8)&255|(lc(f,8)<<8&65280|lc(f,8)<<16),x[N+4>>2]=O;b=0;m=g+4|0;h=lc(f,1);if(!h){b=lc(f,1)}v[g+23|0]=b;if(!(x[g>>2]|!x[m>>2])){gc(f,20);break c}e=x[m>>2];i:{if(b&255){e=on(f,e);break i}e=Ud(f,e);x[g+8>>2]=e}if(!e){gc(f,3);break c}j:{if(!h){b=0;l=0;h=x[m>>2];if((h|0)<=0){break j}while(1){k:{l:{if(y[g+23|0]){if(!lc(f,1)){break l}}h=lc(f,5)+1|0;v[b+e|0]=h;if((h&255)!=32){l=l+1|0;break k}gc(f,20);break c}v[b+e|0]=255}b=b+1|0;h=x[m>>2];if((b|0)<(h|0)){continue}break}break j}k=lc(f,5);l=0;b=0;h=x[m>>2];if((h|0)<=0){break j}while(1){i=lc(f,Jl(h-b|0));k=k+1|0;if((k|0)>=32){gc(f,20);break c}h=b+i|0;if((h|0)>x[m>>2]){gc(f,20);break c}Sb(b+e|0,k,i);b=h;h=x[m>>2];if((b|0)<(h|0)){continue}break}}m:{n:{if(y[g+23|0]){if(h>>2>(l|0)){break n}if(x[f+16>>2]<(h|0)){x[f+16>>2]=h;h=x[m>>2]}b=Ud(f,h);x[g+8>>2]=b;if(!b){gc(f,3);break c}sc(b,e,x[m>>2]);xi(f,e,x[m>>2]);e=x[g+8>>2];v[g+23|0]=0}l=0;b=0;h=0;i=x[m>>2];if((i|0)>0){while(1){h=((y[b+e|0]-11&255)>>>0<244)+h|0;b=b+1|0;if((i|0)!=(b|0)){continue}break}}x[g+2092>>2]=h;b=Ud(f,i<<2);x[g+32>>2]=b;if(b){h=g+2092|0;break m}gc(f,3);break c}x[g+2092>>2]=l;h=g+2092|0;o:{if(!l){l=0;break o}b=Ud(f,l);x[g+8>>2]=b;if(!b){gc(f,3);break c}b=on(f,x[h>>2]<<2);x[g+32>>2]=b;if(!b){gc(f,3);break c}l=on(f,x[h>>2]<<2);if(l){break o}gc(f,3);break c}b=x[m>>2]+(x[h>>2]<<3)|0;if(b>>>0<=A[f+16>>2]){break m}x[f+16>>2]=b}k=x[m>>2];i=0;b=hb-128|0;hb=b;s=Sb(b,0,128);p:{q:{r:{s:{t:{u:{v:{w:{if((k|0)<=0){break w}while(1){if(y[e+i|0]!=255){break w}i=i+1|0;if((k|0)!=(i|0)){continue}break}break v}if((i|0)!=(k|0)){break u}}i=1;if(!x[g+2092>>2]){break t}ea(11723,9049,1103,3800);p()}b=e+i|0;j=y[b|0];if(j>>>0>=32){break s}AH(g,0,i,0,j,l);j=y[b|0];if(j){b=1;while(1){x[s+(b<<2)>>2]=1<<32-b;o=(b|0)==(j|0);b=b+1|0;if(!o){continue}break}}H=1;o=i+1|0;if((k|0)<=(o|0)){i=1;break t}while(1){I=e+o|0;j=y[I|0];x:{if((j|0)==255){break x}if(j>>>0>31){break r}i=0;b=j;if(!b){break t}while(1){K=s+(b<<2)|0;u=x[K>>2];if(!u){u=(b|0)>1;b=b-1|0;if(u){continue}break t}break}x[K>>2]=0;AH(g,Hl(u),o,H,j,l);H=H+1|0;i=y[I|0];if(i>>>0<=b>>>0){break x}while(1){j=s+(i<<2)|0;if(x[j>>2]){break q}x[j>>2]=u+(1<<32-i);i=i-1|0;if((i|0)>(b|0)){continue}break}}i=1;o=o+1|0;if((k|0)!=(o|0)){continue}break}}hb=s+128|0;break p}ea(10809,9049,1104,3800);p()}ea(10802,9049,1118,3800);p()}ea(11767,9049,1133,3800);p()}if(!i){if(y[g+23|0]){xi(f,l,0)}gc(f,20);break c}b=x[h>>2];if(b){b=Ud(f,(b<<2)+4|0);x[g+2084>>2]=b;if(!b){gc(f,3);break c}b=Ud(f,(x[h>>2]<<2)+4|0);x[g+2088>>2]=b;if(!b){gc(f,3);break c}x[g+2088>>2]=b+4;x[b>>2]=-1;i=0;k=0;y:{if(y[g+23|0]){k=x[g+2092>>2];if((k|0)<=0){break y}while(1){b=i<<2;N=b+x[g+2084>>2]|0,O=Hl(x[b+x[g+32>>2]>>2]),x[N>>2]=O;i=i+1|0;k=x[g+2092>>2];if((i|0)<(k|0)){continue}break}break y}if(x[g+4>>2]>0){while(1){if(zH(g,y[e+i|0])){N=x[g+2084>>2]+(k<<2)|0,O=Hl(x[x[g+32>>2]+(i<<2)>>2]),x[N>>2]=O;k=k+1|0}i=i+1|0;if((i|0)<x[g+4>>2]){continue}break}}if(x[g+2092>>2]==(k|0)){break y}ea(3741,9049,1200,5968);p()}eH(x[g+2084>>2],k,2432);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;z:{A:{u=x[g+(y[g+23|0]?2092:4)>>2];if((u|0)>0){b=0;while(1){I=y[(y[g+23|0]?x[(b<<2)+l>>2]:b)+e|0];B:{if(!zH(g,I)){break B}K=b<<2;j=Hl(x[K+x[g+32>>2]>>2]);s=x[g+2084>>2];i=0;k=x[g+2092>>2];if((k|0)>=2){while(1){o=k>>>1|0;M=o+i|0;H=j>>>0<A[s+(M<<2)>>2];i=H?i:M;k=H?o:k-o|0;if((k|0)>1){continue}break}}k=i<<2;if((j|0)!=x[k+s>>2]){break A}if(y[g+23|0]){x[k+x[g+2088>>2]>>2]=x[l+K>>2];v[x[g+8>>2]+i|0]=I;break B}x[k+x[g+2088>>2]>>2]=b}b=b+1|0;if((u|0)!=(b|0)){continue}break}}break z}ea(8065,9049,1230,5968);p()}}if(y[g+23|0]){xi(f,l,x[h>>2]<<2);xi(f,x[g+32>>2],x[h>>2]<<2);xi(f,e,x[m>>2]);x[g+32>>2]=0}Sb(g+36|0,255,2048);b=x[g+(y[g+23|0]?2092:4)>>2];if((b|0)>0){i=(b|0)>=32767?32767:b;l=x[g+8>>2];b=0;while(1){C:{if(y[b+l|0]>10){break C}D:{if(y[g+23|0]){e=Hl(x[x[g+2084>>2]+(b<<2)>>2]);break D}e=x[x[g+32>>2]+(b<<2)>>2]}if(e>>>0>1023){break C}while(1){w[(g+(e<<1)|0)+36>>1]=b;l=x[g+8>>2];e=(1<<y[l+b|0])+e|0;if(e>>>0<1024){continue}break}}b=b+1|0;if((i|0)!=(b|0)){continue}break}}b=lc(f,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){gc(f,20);break c}if(b){N=g,P=JH(lc(f,32)),B[N+12>>2]=P;N=g,P=JH(lc(f,32)),B[N+16>>2]=P;N=g,O=lc(f,4)+1|0,v[N+20|0]=O;N=g,O=lc(f,1),v[N+22|0]=O;e=x[g>>2];i=x[m>>2];E:{if(y[g+21|0]==1){C=J(rs(+E(E(mp(+E(i|0)))/E(e|0))));F:{if(F(C)<2147483648){b=~~C;break F}b=-2147483648}C=J(Vw(+E(E(b|0)+E(1)),e));G:{if(F(C)<2147483648){l=~~C;break G}l=-2147483648}b=((i|0)>=(l|0))+b|0;t=E(b|0);if(Vw(+E(t+E(1)),e)<=+(i|0)){b=-1}else{C=J(Vw(+t,e));H:{if(F(C)<2147483648){e=~~C;break H}e=-2147483648}b=(e|0)>(i|0)?-1:b}if((b|0)>=0){break E}gc(f,20);break c}b=D(e,i)}x[g+24>>2]=b;if(!b){gc(f,20);break c}e=on(f,b<<1);if(!e){break h}b=0;k=x[g+24>>2];if((k|0)>0){while(1){i=lc(f,y[g+20|0]);if((i|0)==-1){xi(f,e,x[g+24>>2]<<1);gc(f,20);break c}w[e+(b<<1)>>1]=i;b=b+1|0;k=x[g+24>>2];if((b|0)<(k|0)){continue}break}}I:{if(y[g+21|0]==1){s=y[g+23|0];J:{if(s){b=x[h>>2];if(b){break J}break I}b=x[m>>2]}b=Ud(f,D(x[g>>2],b)<<2);x[g+28>>2]=b;if(!b){xi(f,e,x[g+24>>2]<<1);gc(f,3);break c}m=x[(s?h:m)>>2];if((m|0)>0){o=g+2088|0;t=E(0);h=0;while(1){i=s?x[x[o>>2]+(h<<2)>>2]:h;b=1;j=0;K:{k=x[g>>2];if((k|0)<=0){break K}while(1){L=E(E(B[g+12>>2]+t)+E(B[g+16>>2]*E(z[e+(((i>>>0)/(b>>>0)>>>0)%A[g+24>>2]<<1)>>1])));B[x[g+28>>2]+(D(h,k)+j<<2)>>2]=L;t=y[g+22|0]?L:t;j=j+1|0;k=x[g>>2];if((j|0)>=(k|0)){break K}l=x[g+24>>2];sqa(l,0,b,0);if(lb){xi(f,e,l<<1);gc(f,20);break c}else{b=D(b,l);continue}}}h=h+1|0;if((m|0)!=(h|0)){continue}break}}v[g+21|0]=2;k=x[g+24>>2];break I}b=Ud(f,k<<2);x[g+28>>2]=b;k=x[g+24>>2];if(!b){break g}b=0;if((k|0)<=0){break I}t=E(0);while(1){L=E(E(B[g+12>>2]+t)+E(B[g+16>>2]*E(z[e+(b<<1)>>1])));B[x[g+28>>2]+(b<<2)>>2]=L;t=y[g+22|0]?L:t;b=b+1|0;k=x[g+24>>2];if((b|0)<(k|0)){continue}break}}xi(f,e,k<<1)}q=q+1|0;if((q|0)<x[f+120>>2]){continue}break}}L:{b=lc(f,6)+1&255;if(!b){break L}while(1){if(!lc(f,16)){G=G+1|0;if((b|0)!=(G|0)){continue}break L}break}gc(f,20);break c}b=lc(f,6)+1|0;x[f+128>>2]=b;b=Ud(f,D(b,1596));x[f+260>>2]=b;M:{if(b){l=0;if(x[f+128>>2]>0){break M}G=0;break d}gc(f,3);break c}G=0;N:while(1){b=lc(f,16);w[((l<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){gc(f,20);break c}if(!b){e=x[f+260>>2]+D(l,1596)|0;N=e,O=lc(f,8),v[N|0]=O;N=e,O=lc(f,16),w[N+2>>1]=O;N=e,O=lc(f,16),w[N+4>>1]=O;N=e,O=lc(f,6),v[N+6|0]=O;N=e,O=lc(f,8),v[N+7|0]=O;b=(lc(f,4)&255)+1|0;v[e+8|0]=b;if((b|0)==(b&255)){b=0;while(1){N=b+e|0,O=lc(f,8),v[N+9|0]=O;b=b+1|0;if(b>>>0<y[e+8|0]){continue}break}}gc(f,4);break c}b=x[f+260>>2]+D(l,1596)|0;g=lc(f,5);v[b|0]=g;e=-1;h=0;j=0;O:{if(g&255){while(1){g=lc(f,4);v[(b+j|0)+1|0]=g;g=g&255;e=(e|0)<(g|0)?g:e;j=j+1|0;if(j>>>0<y[b|0]){continue}break}while(1){g=b+h|0;N=g,O=lc(f,3)+1|0,v[N+33|0]=O;i=lc(f,2);v[g+49|0]=i;P:{if(i&255){i=lc(f,8);v[g+65|0]=i;if(x[f+120>>2]<=(i&255)){break O}if(y[g+49|0]==31){break P}}j=0;while(1){i=lc(f,8)-1|0;w[((b+(h<<4)|0)+(j<<1)|0)+82>>1]=i;if(x[f+120>>2]<=i<<16>>16){break O}j=j+1|0;if((j|0)<1<<y[g+49|0]){continue}break}}g=(e|0)!=(h|0);h=h+1|0;if(g){continue}break}}j=2;N=b,O=lc(f,2)+1|0,v[N+1588|0]=O;e=lc(f,4);x[b+1592>>2]=2;h=0;w[b+338>>1]=0;v[b+1589|0]=e;w[b+340>>1]=1<<e;k=y[b|0];Q:{if(k){while(1){e=0;g=b+y[(b+h|0)+1|0]|0;if(y[g+33|0]){while(1){i=lc(f,y[b+1589|0]);w[(b+(x[b+1592>>2]<<1)|0)+338>>1]=i;j=x[b+1592>>2]+1|0;x[b+1592>>2]=j;e=e+1|0;if(e>>>0<y[g+33|0]){continue}break}k=y[b|0]}h=h+1|0;if(h>>>0<(k&255)>>>0){continue}break}if((j|0)<=0){break Q}}e=0;while(1){g=z[(b+(e<<1)|0)+338>>1];h=(n+16|0)+(e<<2)|0;w[h+2>>1]=e;w[h>>1]=g;e=e+1|0;j=x[b+1592>>2];if((e|0)<(j|0)){continue}break}}g=b+338|0;eH(n+16|0,j,2431);j=x[b+1592>>2];h=((j|0)<=1?1:j)-1|0;e=0;while(1){if((e|0)==(h|0)){e=0;R:{if((j|0)<=0){break R}while(1){v[(b+e|0)+838|0]=y[((n+16|0)+(e<<2)|0)+2|0];e=e+1|0;j=x[b+1592>>2];if((e|0)<(j|0)){continue}break}e=2;if((j|0)<=2){break R}while(1){x[n+12>>2]=0;x[n+8>>2]=0;h=0;if((e|0)>0){j=g+(e<<1)|0;k=-1;q=65536;while(1){m=g+(h<<1)|0;i=z[m>>1];if(!((k|0)>=(i|0)|z[j>>1]<=i>>>0)){x[n+12>>2]=h;i=z[m>>1];k=i}if(!((i|0)>=(q|0)|z[j>>1]>=i>>>0)){x[n+8>>2]=h;q=z[m>>1]}h=h+1|0;if((h|0)!=(e|0)){continue}break}}h=b+(e<<1)|0;v[h+1088|0]=x[n+12>>2];v[h+1089|0]=x[n+8>>2];e=e+1|0;j=x[b+1592>>2];if((e|0)<(j|0)){continue}break}}G=(j|0)>(G|0)?j:G;l=l+1|0;if((l|0)<x[f+128>>2]){continue N}break d}i=n+16|0;k=z[i+(e<<2)>>1];e=e+1|0;if((k|0)!=z[i+(e<<2)>>1]){continue}break}}break}gc(f,20);break c}gc(f,3);break c}xi(f,e,k<<1);gc(f,3);break c}gc(f,20);break c}gc(f,3);break c}gc(f,3);break c}gc(f,20);break c}b=lc(f,6)+1|0;x[f+264>>2]=b;b=Ud(f,D(b,24));x[f+396>>2]=b;if(!b){gc(f,3);break c}q=0;Sb(b,0,D(x[f+264>>2],24));S:{T:{if(x[f+264>>2]>0){i=20;while(1){b=x[f+396>>2];e=lc(f,16);w[((q<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>2){break S}h=b+D(q,24)|0;N=h,O=lc(f,24),x[N>>2]=O;b=lc(f,24);x[h+4>>2]=b;if(b>>>0<A[h>>2]){break S}N=h,O=lc(f,24)+1|0,x[N+8>>2]=O;N=h,O=lc(f,6)+1|0,v[N+12|0]=O;b=lc(f,8);v[h+13|0]=b;if(x[f+120>>2]<=(b&255)){break S}b=0;U:{if(!y[h+12|0]){e=0;break U}while(1){g=(n+16|0)+b|0;l=lc(f,3);if(lc(f,1)){e=lc(f,5)}else{e=0}v[g|0]=l+(e<<3);b=b+1|0;e=y[h+12|0];if(b>>>0<e>>>0){continue}break}}b=Ud(f,e<<4);x[h+20>>2]=b;if(!b){break T}if(y[h+12|0]){l=0;while(1){e=y[(n+16|0)+l|0];b=0;while(1){V:{if(e>>>b&1){g=lc(f,8);k=b<<1;j=l<<4;w[k+(j+x[h+20>>2]|0)>>1]=g;if(x[f+120>>2]<=w[k+(j+x[h+20>>2]|0)>>1]){break S}break V}w[(x[h+20>>2]+(l<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}l=l+1|0;if(l>>>0<y[h+12|0]){continue}break}}b=Ud(f,x[(x[f+124>>2]+D(y[h+13|0],2096)|0)+4>>2]<<2);x[h+16>>2]=b;if(!b){break T}l=0;Sb(b,0,x[(x[f+124>>2]+D(y[h+13|0],2096)|0)+4>>2]<<2);b=x[f+124>>2];e=y[h+13|0];if(x[(b+D(e,2096)|0)+4>>2]>0){while(1){b=x[D(e,2096)+b>>2];e=Ud(f,b);k=l<<2;x[k+x[h+16>>2]>>2]=e;if(!x[k+x[h+16>>2]>>2]){break T}if((b|0)>0){j=y[h+12|0];e=l;while(1){g=b-1|0;v[g+x[k+x[h+16>>2]>>2]|0]=(e|0)%(j&255);j=y[h+12|0];e=(e|0)/(j|0)|0;m=b>>>0>1;b=g;if(m){continue}break}}l=l+1|0;b=x[f+124>>2];e=y[h+13|0];if((l|0)<x[(b+D(e,2096)|0)+4>>2]){continue}break}}q=q+1|0;if((q|0)<x[f+264>>2]){continue}break}}b=lc(f,6)+1|0;x[f+400>>2]=b;b=Ud(f,D(b,40));x[f+404>>2]=b;if(!b){gc(f,3);break c}l=0;Sb(b,0,D(x[f+400>>2],40));if(x[f+400>>2]>0){while(1){b=x[f+404>>2];if(lc(f,16)){gc(f,20);break c}g=b+D(l,40)|0;b=Ud(f,D(x[f+4>>2],3));x[g+4>>2]=b;if(!b){gc(f,3);break c}if(lc(f,1)){b=lc(f,4)+1|0}else{b=1}v[g+8|0]=b;W:{if(lc(f,1)){b=lc(f,8)+1|0;w[g>>1]=b;X:{e=x[f+4>>2];b=b&65535;if((e|0)>=(b|0)){i=0;if(b){break X}break W}gc(f,20);break c}while(1){e=lc(f,Jl(e-1|0));b=D(i,3);v[b+x[g+4>>2]|0]=e;e=lc(f,Jl(x[f+4>>2]-1|0));v[(b+x[g+4>>2]|0)+1|0]=e;e=x[f+4>>2];b=b+x[g+4>>2]|0;h=y[b|0];if((e|0)<=(h|0)){gc(f,20);break c}b=y[b+1|0];if((b|0)>=(e|0)){gc(f,20);break c}if((b|0)!=(h|0)){i=i+1|0;if(i>>>0>=z[g>>1]){break W}continue}break}gc(f,20);break c}w[g>>1]=0}if(lc(f,2)){gc(f,20);break c}h=x[f+4>>2];Y:{Z:{b=y[g+8|0];if(b>>>0<=1){e=0;if((h|0)>0){while(1){v[(x[g+4>>2]+D(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<x[f+4>>2]){continue}break}b=y[g+8|0]}if(!(b&255)){break Y}break Z}e=0;if((h|0)<=0){break Z}while(1){_:{b=lc(f,4);h=D(e,3);v[(h+x[g+4>>2]|0)+2|0]=b;if(y[(h+x[g+4>>2]|0)+2|0]>=y[g+8|0]){break _}e=e+1|0;if((e|0)<x[f+4>>2]){continue}break Z}break}gc(f,20);break c}b=0;while(1){lc(f,8);e=b+g|0;N=e,O=lc(f,8),v[N+9|0]=O;h=lc(f,8);v[e+24|0]=h;if(x[f+128>>2]<=y[e+9|0]){gc(f,20);break c}if(x[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=y[g+8|0]){break Y}continue}break}gc(f,20);break c}l=l+1|0;if((l|0)<x[f+400>>2]){continue}break}}b=lc(f,6);x[f+408>>2]=b+1;$:{if(b>>>0>2147483646){break $}g=f+412|0;e=0;while(1){b=g+D(e,6)|0;N=b,O=lc(f,1),v[N|0]=O;N=b,O=lc(f,16),w[N+2>>1]=O;N=b,O=lc(f,16),w[N+4>>1]=O;h=lc(f,8);v[b+1|0]=h;if(z[b+2>>1]){gc(f,20);break c}if(z[b+4>>1]){gc(f,20);break c}if(x[f+400>>2]>(h&255)){e=e+1|0;if((e|0)>=x[f+408>>2]){break $}continue}break}gc(f,20);break c}HH(f);b=0;x[f+992>>2]=0;if(x[f+4>>2]>0){g=G<<1;j=0;while(1){e=(j<<2)+f|0;N=e,O=Ud(f,x[f+116>>2]<<2),x[N+800>>2]=O;N=e,O=Ud(f,x[f+116>>2]<<1&2147483646),x[N+928>>2]=O;h=Ud(f,g);x[e+996>>2]=h;i=x[e+800>>2];if(h?!i|!x[e+928>>2]:1){gc(f,3);break c}Sb(i,0,x[f+116>>2]<<2);j=j+1|0;if((j|0)<x[f+4>>2]){continue}break}}if(!GH(f,0,x[f+112>>2])){break a}if(!GH(f,1,x[f+116>>2])){break a}x[f+104>>2]=x[f+112>>2];e=x[f+116>>2];x[f+108>>2]=e;h=e<<1&2147483646;l=x[f+264>>2];if((l|0)<=0){e=4}else{e=(e|0)/2|0;k=x[f+396>>2];j=0;i=0;while(1){g=k+D(i,24)|0;m=x[g+4>>2];o=e>>>0>m>>>0?m:e;m=x[g>>2];g=(o-(e>>>0>m>>>0?m:e)>>>0)/A[g+8>>2]|0;j=(g|0)>(j|0)?g:j;i=i+1|0;if((l|0)!=(i|0)){continue}break}e=(j<<2)+4|0}e=D(e,x[f+4>>2]);e=e>>>0<h>>>0?h:e;x[f+12>>2]=e;aa:{ba:{if(!x[f+80>>2]){break ba}g=x[f+92>>2];if((g|0)!=x[f+84>>2]){break aa}if(g>>>0>=(e+x[f+88>>2]|0)+1512>>>0){break ba}gc(f,3);break a}ca:{if(x[f+1380>>2]==-1){x[f+52>>2]=y[f+48|0]?0:x[f+32>>2]-x[f+36>>2]|0;break ca}x[f+52>>2]=0}b=1;break a}ea(3568,9049,4196,4950);p()}i=3}gc(f,i)}b=0}hb=n+1024|0;da:{ea:{if(!b){x[d>>2]=x[r+104>>2]?1:x[r+108>>2];break ea}e=Ud(r+8|0,1512);if(e){N=c,O=x[sc(e,r+8|0,1512)+32>>2]-a|0,x[N>>2]=O;x[d>>2]=0;break da}}MH(r+8|0);e=0}hb=r+1520|0;return e|0}function Soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;d=hb-272|0;hb=d;Nc(b);f=hb-16|0;hb=f;g=f+8|0;k=d+250|0;Cu(g,k);h=Fb(g);g=nc(b,ac(f,g));if((h|0)==(g|0)){cc(b,Fb(f+8|0))}hb=f+16|0;f=(g|0)==(h|0);if(!f){XT(k)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!f){break u}if(!$T(d+250|0)){break u}if(!c){e=1;break u}Pd(a,1024);Ni(a);x[a+480208>>2]=x[a+480208>>2]|12;Kg(a+1074312|0,21);if(y[d+266|0]|y[d+267|0]<<8){e=y[d+266|0]|y[d+267|0]<<8;x[a+480204>>2]=D((e<<8|e>>>8)&65535,1e4)}if(y[d+264|0]|y[d+265|0]<<8){e=y[d+264|0]|y[d+265|0]<<8;x[a+480196>>2]=(e<<8|e>>>8)&65535}if(!y[d+260|0]){Cj(a,1)}e=y[d+254|0]|y[d+255|0]<<8|(y[d+256|0]<<16|y[d+257|0]<<24);oB(b,a+1304400|0,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))-14|0);b=km(d+144|0,b);x[114409]=0;T(578,d+236|0,b|0,1);e=x[114409];x[114409]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){Ab(b);x[114409]=0;T(579,d+144|0,d+236|0,1395544366);b=x[114409];x[114409]=0;if((b|0)==1){break E}x[114409]=0;b=S(469,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break L}if(!b){break F}x[114409]=0;b=S(464,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break L}x[114409]=0;e=S(464,d+144|0)|0;f=x[114409];x[114409]=0;N:{if((f|0)==1){break N}x[114409]=0;O(313,d+144|0,4)|0;f=x[114409];x[114409]=0;if((f|0)==1){break N}f=a+484360|0;g=Wb(f);x[114409]=0;aa(580,g|0,d+144|0,b|0,65535,65535)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break M}}break L}e=N()|0;Ab(b);break a}Pe(Wb(f),e);b=d+144|0;Ab(b);x[114409]=0;T(579,b|0,d+236|0,1346458708);b=x[114409];x[114409]=0;if((b|0)==1){break K}x[114409]=0;b=S(469,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break J}if(!b){break H}x[114409]=0;b=S(464,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break J}w[a+480188>>1]=b;if((b-33&65535)>>>0<65504){break H}x[114409]=0;b=S(464,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break J}x[114409]=0;o=a+484344|0;P(377,o|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break J}x[114409]=0;k=S(474,d+144|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break J}switch(k-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=N()|0;Ab(d+144|0);break b}e=N()|0;break b}e=N()|0;Ab(d+144|0);break b}if(!k){break G}}Ab(d+144|0);break A}Ab(d+144|0);x[114409]=0;T(579,d+216|0,d+236|0,1398157625);b=x[114409];x[114409]=0;if((b|0)==1){break D}x[114409]=0;b=S(469,d+216|0)|0;e=x[114409];x[114409]=0;O:{if((e|0)==1){break O}if(!b){break B}x[114409]=0;O(313,d+216|0,2)|0;b=x[114409];x[114409]=0;if((b|0)==1){break O}x[114409]=0;e=S(474,d+216|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}f=x[a+480204>>2];b=0;x[114409]=0;e=na(581,+((+(e>>>0)*2.3283064365386963e-10+ +((f>>>0)/1e4>>>0))*1e4))|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}x[a+480204>>2]=e;x[114409]=0;O(582,d+216|0,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}while(1){if(z[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;e=y[e|0]|y[e+1|0]<<8;x[114409]=0;x[d+80>>2]=(e<<8|e>>>8)&65535;x[d+64>>2]=180;e=O(436,d+80|0,d- -64|0)|0;f=x[114409];x[114409]=0;P:{if((f|0)==1){break P}e=x[e>>2];x[114409]=0;e=e-90|0;f=e>>31<<7|e>>>25;e=cg(432,tqa(e<<7|45,f,90,0),lb);f=x[114409];x[114409]=0;if((f|0)==1){break P}w[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}Ab(d+144|0);break A}e=N()|0;break b}e=N()|0;break b}x[114409]=0;O(313,d+216|0,16)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;b=O(231,d+216|0,2)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}if(b){x[114409]=0;b=S(464,d+216|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;w[d+80>>1]=b;w[d+64>>1]=256;b=O(457,d+80|0,d- -64|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}x[a+480200>>2]=z[b>>1]}x[114409]=0;O(313,d+216|0,128)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;b=O(582,d+216|0,d+80|0)|0;e=x[114409];x[114409]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;e=y[e|0]|y[e+1|0]<<8;x[114409]=0;x[d+64>>2]=(e<<8|e>>>8)&65535;x[d+44>>2]=128;e=O(436,d- -64|0,d+44|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){w[((b<<5)+a|0)+480286>>1]=x[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}x[a+480228>>2]=x[a+480228>>2]<<1}Ab(d+216|0);x[114409]=0;T(579,d+144|0,d+236|0,1413830740);b=x[114409];x[114409]=0;R:{S:{if((b|0)!=1){x[114409]=0;b=S(469,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}if(!b){break R}x[114409]=0;O(583,d+144|0,d+80|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}if((y[d+90|0]|y[d+91|0]<<8)!=65535){break S}x[114409]=0;O(313,d+144|0,1)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break S}break d}e=N()|0;break b}x[114409]=0;b=S(305,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;Z(584,a+1304424|0,d+144|0,b|0,2)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}}Ab(d+144|0);x[114409]=0;T(579,d+80|0,d+236|0,1229869908);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;b=S(469,d+80|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){if(!b){break w}x[114409]=0;b=S(464,d+80|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}T:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break T}x[114409]=0;e=O(231,d+80|0,D(f,(b>>>14&2)+50|0)|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break y}if(!e){break T}w[a+480190>>1]=f;g=a+480190|0;if(!f){break z}h=d+162|0;j=(b|0)>=0;b=1;U:{V:{while(1){W:{e=b;X:{Y:{Z:{if(!j){x[114409]=0;e=S(464,d+80|0)|0;n=x[114409];x[114409]=0;if((n|0)==1){break Z}e=e+1|0}x[114409]=0;w[d+44>>1]=e;O(585,d+80|0,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){if((z[d+44>>1]-4e3&65535)>>>0<61537){break X}x[114409]=0;e=O(424,g|0,d+44|0)|0;n=x[114409];x[114409]=0;if((n|0)!=1){break Y}}e=N()|0;break f}e=N()|0;break f}w[a+480190>>1]=z[e>>1];n=z[d+44>>1];e=y[d+268|0]|y[d+269|0]<<8|(y[d+270|0]<<16|y[d+271|0]<<24);x[114409]=0;W(586,d+144|0,(D(n,104)+a|0)+484380|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24),k|0);e=x[114409];x[114409]=0;if((e|0)==1){break W}x[114409]=0;T(587,d- -64|0,2,h|0);e=x[114409];x[114409]=0;if((e|0)==1){break V}x[114409]=0;P(370,d+216|0,d- -64|0);e=x[114409];x[114409]=0;if((e|0)==1){break V}x[114409]=0;O(348,((z[d+44>>1]<<5)+a|0)+946304|0,d+216|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break U}xb(d+216|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=N()|0;break f}e=N()|0;break f}e=N()|0;xb(d+216|0);break f}Ab(d+80|0);break A}e=N()|0;break f}e=0;break v}x[114409]=0;b=S(464,d+80|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break x}}e=N()|0;break f}if((b|0)!=4){break w}b=z[g>>1];x[114409]=0;w[d+144>>1]=b;w[d+216>>1]=255;b=O(457,d+144|0,d+216|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}w[a+480192>>1]=z[b>>1];x[114409]=0;T(579,d+216|0,d+236|0,1229278806);b=x[114409];x[114409]=0;if((b|0)==1){break i}while(1){x[114409]=0;b=O(231,d+80|0,15)|0;e=x[114409];x[114409]=0;_:{$:{if((e|0)!=1){aa:{if(!b){break $}x[114409]=0;O(588,d+80|0,d- -64|0)|0;b=x[114409];x[114409]=0;ba:{if((b|0)!=1){b=d- -64|0;b=y[b|0]|y[b+1|0]<<8;if(z[a+480192>>1]<=((b<<8|b>>>8)&65535)>>>0){continue}h=d- -64|0;b=h;b=y[b|0]|y[b+1|0]<<8;b=D((b<<8|b>>>8)&65535,104)+a|0;v[b+484524|0]=y[d+72|0];e=y[d+71|0];v[b+484523|0]=255;v[b+484525|0]=e;b=h;b=y[b|0]|y[b+1|0]<<8;e=h;e=y[e|0]|y[e+1|0]<<8;x[114409]=0;e=U(427,a|0,(b<<8|b>>>8)+1&65535,(e<<8|e>>>8)+1&65535)|0;b=x[114409];x[114409]=0;if((b|0)==1){break aa}if(!e){continue}b=y[d+69|0]|y[d+70|0]<<8;x[114409]=0;w[d+144>>1]=b<<8|b>>>8;w[d+44>>1]=4095;b=O(457,d+144|0,d+44|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break aa}x[e>>2]=z[b>>1];if(y[d+67|0]==255){continue}b=y[d+67|0];x[114409]=0;b=O(229,d+216|0,D(b,34)+2|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break aa}if(!b){continue}x[114409]=0;O(589,d+216|0,d+144|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break aa}v[e+60|0]=y[e+60|0]|1;b=y[d+144|0]|y[d+145|0]<<8;x[d+44>>2]=(b<<8|b>>>8)&65535;x[114409]=0;x[d+60>>2]=3;x[d+52>>2]=240;x[d+48>>2]=16;x[d+56>>2]=d+44;b=x[d+60>>2];x[d+8>>2]=x[d+56>>2];x[d+12>>2]=b;b=S(590,d+8|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break aa}x[114409]=0;f=e+48|0;P(496,f|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break aa}b=0;if(Lb(f)){break ba}break _}break aa}while(1){ca:{v[d+44|0]=64;g=(d+144|0)+(b<<1)|0;h=y[g+2|0];x[114409]=0;v[d+40|0]=h;h=O(431,d+44|0,d+40|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break ca}h=y[h|0];E=Pb(f,b),F=h,v[E+2|0]=F;g=y[g+3|0];E=Pb(f,b),F=g,w[E>>1]=F;b=b+1|0;if(Lb(f)>>>0>b>>>0){continue}break _}break}}}e=N()|0;Ab(d+216|0);break f}Ab(d+216|0);break w}if(y[d+68|0]!=255){v[e+60|0]=y[e+60|0]|4;b=y[d+68|0];v[e+63|0]=b;v[e- -64|0]=b}if(kd(f)){continue}v[e+60|0]=y[e+60|0]|2;b=Lb(f)-1|0;v[e+61|0]=b;v[e+62|0]=b;continue}}b=d+80|0;Ab(b);x[114409]=0;T(591,b|0,d+236|0,1145131092);b=x[114409];x[114409]=0;if((b|0)==1){break j}b=d+80|0;E=d,F=bc(b),x[E+40>>2]=F;E=d,F=dc(b),x[E+36>>2]=F;if(Hb(d+40|0,d+36|0)){t=c&1;n=d+216|4;s=(k|0)!=841887798;u=(k|0)!=841887796;while(1){g=x[d+40>>2];x[114409]=0;O(313,g|0,4)|0;b=x[114409];x[114409]=0;da:{ea:{fa:{if((b|0)!=1){x[114409]=0;f=S(464,g|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break l}x[114409]=0;h=S(464,g|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break m}h=s?h:(h>>>0)/A[a+480196>>2]|0;if(!t|f>>>0>255){break da}x[114409]=0;b=U(378,o|0,f|0,h|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}if(!b){break da}if(s){break ea}x[114409]=0;O(313,g|0,4)|0;b=x[114409];x[114409]=0;if((b|0)==1){break m}j=0;if(!z[a+480188>>1]){break da}while(1){x[114409]=0;b=S(464,g|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break fa}x[114409]=0;T(316,d+144|0,g|0,b+(b&1)&65535);b=x[114409];x[114409]=0;if((b|0)==1){break n}x[d+216>>2]=0;x[d+220>>2]=0;l=0;ga:{while(1){x[114409]=0;b=O(231,d+144|0,6)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}if(!(b&A[d+216>>2]<h>>>0)){break ga}b=Zb(o,f);x[114409]=0;b=U(451,b|0,x[d+216>>2],j&65535)|0;e=x[114409];x[114409]=0;ha:{ia:{if((e|0)!=1){x[114409]=0;P(592,d+44|0,d+144|0);e=x[114409];x[114409]=0;if((e|0)==1){break o}e=d+44|0;i=ed(e);B=wf(e);C=fi(e);q=mc(e);m=v[e|0];if((m-1&255)>>>0>95){break ia}v[b|0]=m+13;if(!x[d+220>>2]){break ha}v[b+3|0]=19;x[114409]=0;x[d+64>>2]=15;m=O(436,n|0,d- -64|0)|0;r=x[114409];x[114409]=0;if((r|0)==1){break o}v[b+5|0]=y[m|0]|208;break ha}break o}if((m|0)>=0){break ha}if(x[d+220>>2]){v[b+3|0]=19;x[114409]=0;x[d+64>>2]=15;m=O(436,n|0,d- -64|0)|0;r=x[114409];x[114409]=0;if((r|0)!=1){v[b+5|0]=y[m|0]|192;break ha}break o}v[b|0]=254}if(y[i|0]){v[b+2|0]=1;x[114409]=0;v[d+64|0]=64;i=O(431,i|0,d- -64|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break o}v[b+4|0]=y[i|0]}i=y[B|0];if(i){v[b+1|0]=i}i=y[C|0];if(i|y[q|0]){v[b+3|0]=i;v[b+5|0]=y[q|0];x[114409]=0;V(573,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}}b=v[e+5|0];e=b&255;if((b|0)<0){x[114409]=0;b=S(425,d+144|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break o}e=b|e<<8&32512}b=x[a+480196>>2];x[114409]=0;l=e+l|0;T(593,d- -64|0,l|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){b=x[d+68>>2];x[d+216>>2]=x[d+64>>2];x[d+220>>2]=b;continue}break}break o}Ab(d+144|0);j=j+1|0;if(z[a+480188>>1]>(j&65535)>>>0){continue}break}break da}e=N()|0;break k}e=N()|0;break k}b=Zb(o,f);x[114409]=0;b=U(451,b|0,0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}j=0;if(!h){break da}while(1){e=0;ja:{if(!z[a+480188>>1]){break ja}while(1){ka:{x[114409]=0;P(594,d+144|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break ka}la:{if(!u){x[d+216>>2]=x[d+144>>2];f=d+216|0;l=ed(f);i=wf(f);q=fi(f);f=v[f|0];if((f|0)>0){v[b|0]=(D((f&240)>>>4|0,12)+(f&15)|0)+12}f=y[l|0];if(f>>>0>=4){v[b+2|0]=1;v[b+4|0]=(f>>>2|0)-1;f=y[l|0]}v[b+1|0]=f<<4&48|y[i|0]>>>4;v[b+3|0]=y[i|0]&15;v[b+5|0]=y[q|0];break la}x[114409]=0;f=x[d+144>>2];x[d+32>>2]=f;x[d+16>>2]=f;P(595,d+16|0,b|0);f=x[114409];x[114409]=0;if((f|0)==1){break ka}f=fc(d+144|0,0);v[b+1|0]=y[b+1|0]|y[f|0]&48}x[114409]=0;V(573,b|0);f=x[114409];x[114409]=0;if((f|0)==1){break ka}f=y[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!y[b+5|0]){break na}break ma}f=y[b+5|0];l=f&240;if(l){v[b+5|0]=l;break ma}if(f){break ma}}v[b+3|0]=0}b=b+6|0;e=e+1|0;if(z[a+480188>>1]>(e&65535)>>>0){continue}break ja}break}e=N()|0;break k}j=j+1|0;if((j|0)!=(h|0)){continue}break}}b=d+40|0;sf(b);if(Hb(b,d+36|0)){continue}break}}hd(d+80|0);x[114409]=0;T(579,d+144|0,d+236|0,1346458702);b=x[114409];x[114409]=0;if((b|0)==1){e=N()|0;break b}x[114409]=0;b=S(469,d+144|0)|0;e=x[114409];x[114409]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Xb(d+80|0);b=0;Ca:{while(1){Da:{x[114409]=0;e=O(231,d+144|0,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Da}if(!e){break Ca}if(Ne(o)>>>0<=b>>>0){break Ca}x[114409]=0;U(596,d+144|0,f|0,32)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Da}e=Zb(o,b);x[114409]=0;O(476,e|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=N()|0;xb(f);break Ba}xb(f)}b=d+144|0;Ab(b);x[114409]=0;T(579,b|0,d+236|0,1414679374);b=x[114409];x[114409]=0;if((b|0)==1){break Aa}x[114409]=0;b=S(469,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break wa}if(!b){break xa}f=Xb(d+80|0);b=0;while(1){x[114409]=0;e=O(231,d+144|0,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break za}if(!e|z[a+480188>>1]<=b>>>0){break ya}x[114409]=0;U(596,d+144|0,f|0,32)|0;e=x[114409];x[114409]=0;if((e|0)==1){break za}x[114409]=0;O(358,((b<<5)+a|0)+480289|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=N()|0}Ab(d+144|0);break b}e=N()|0;break b}e=N()|0;xb(f);break va}xb(f)}b=d+144|0;Ab(b);x[114409]=0;T(591,b|0,d+236|0,1145129300);b=x[114409];x[114409]=0;if((b|0)==1){break ua}b=d+144|0;E=d,F=bc(b),x[E+80>>2]=F;E=d,F=dc(b),x[E+216>>2]=F;if(Hb(d+80|0,d+216|0)){e=c&2;while(1){b=x[d+80>>2];x[114409]=0;c=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=z[a+480190>>1])){c=D(c,104)+a|0;f=z[c+484518>>1];f=cd(d- -64|0,f&1?16:8,f&64?2:1,1,0);x[114409]=0;U(376,f|0,c+484484|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break p}}b=d+80|0;sf(b);if(Hb(b,d+216|0)){continue}break}}hd(d+144|0);b=gd(d+80|0);if((k|0)!=841887798){break sa}x[114409]=0;c=O(2,d+144|0,5447)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ta}Eb(b,c);xb(c);break ra}e=N()|0}Ab(d+144|0);break b}e=N()|0;break b}e=N()|0;break q}x[114409]=0;T(579,d+144|0,d+236|0,1447383635);c=x[114409];x[114409]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){x[114409]=0;c=S(469,d+144|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break qa}if(!c){break Fa}x[114409]=0;e=S(474,d+144|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Ka}x[114409]=0;c=O(2,d+20|0,10998)|0;f=x[114409];x[114409]=0;if((f|0)==1){break Ja}x[114409]=0;P(192,d- -64|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break Ia}x[114409]=0;x[d+44>>2]=e>>>4;x[d+40>>2]=e&15;W(597,d+216|0,d- -64|0,d+44|0,d+40|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ha}e=d+216|0;Eb(b,e);xb(e);Gb(d- -64|0);break Ea}e=N()|0;break q}e=N()|0;break r}e=N()|0;break r}e=N()|0;break Ga}e=N()|0;Gb(d- -64|0)}xb(c);break r}x[114409]=0;c=O(2,d+216|0,4728)|0;e=x[114409];x[114409]=0;if((e|0)==1){break t}Eb(b,c)}xb(c);Ab(d+144|0)}x[114409]=0;c=O(2,d- -64|0,4728)|0;e=x[114409];x[114409]=0;if((e|0)==1){break pa}Eb(a+1304436|0,c);xb(c);x[114409]=0;c=O(2,d+44|0,6114)|0;e=x[114409];x[114409]=0;if((e|0)==1){break oa}Eb(a+1304448|0,c);xb(c);Eb(a+1304460|0,b);x[a+1304496>>2]=2;xb(b);e=1;break v}e=N()|0;break r}e=N()|0;break q}e=N()|0;break q}VA(d+236|0)}hb=d+272|0;return e|0}e=N()|0;break r}e=N()|0;break k}Ab(d+144|0)}xb(b);break b}e=N()|0;hd(d+144|0);break b}e=N()|0;Ab(d+144|0);break k}e=N()|0;break k}e=N()|0;break k}e=N()|0}hd(d+80|0);break b}e=N()|0;break b}e=N()|0;break f}e=N()|0;break f}e=N()|0}Ab(d+80|0);break b}e=N()|0;break b}e=N()|0;Ab(d+144|0);break b}e=N()|0;Ab(d+216|0)}VA(d+236|0)}Q(e|0);p()}function fG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;r=hb-48|0;hb=r;a:{if(c>>>0<=2){c=c<<2;I=x[c+61116>>2];J=x[c+61104>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=_c(b)}if(qk(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=_c(b)}e:{f:{while(1){if(v[g+1459|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=_c(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=hb-16|0;hb=l;h=(q(E(E(o|0)*E(Infinity))),j(2));b=h&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=h<<25;d=h>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);lf(l,c,0,0,0,b+81|0);k=x[l>>2];i=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[r>>2]=k;x[r+4>>2]=i;x[r+8>>2]=c;x[r+12>>2]=h&-2147483648|d;hb=l+16|0;k=x[r+8>>2];i=x[r+12>>2];h=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+5964|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=_c(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=_c(b)}if((g&-33)==88){f=hb-432|0;hb=f;c=x[b+4>>2];p:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break p}g=_c(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break s}x[b+4>>2]=c+1;g=y[c|0];break r}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){H=1;x[b+4>>2]=c+1;g=y[c|0]}else{H=1;g=_c(b)}continue}break}g=_c(b)}s=1;if((g|0)!=48){break q}while(1){c=t;t=c-1|0;u=u-!c|0;c=x[b+4>>2];t:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break t}g=_c(b)}if((g|0)==48){continue}break}H=1}m=1073676288;while(1){u:{c=g|32;v:{w:{K=g-48|0;if(K>>>0<10){break w}if((g|0)!=46&c-97>>>0>5){break u}if((g|0)!=46){break w}if(s){break u}s=1;t=k;u=i;break v}c=(g|0)>57?c-87|0:K;x:{if((i|0)<=0&k>>>0<=7|(i|0)<0){e=c+(e<<4)|0;break x}if(!i&k>>>0<=28){Ag(f+48|0,c);wd(f+32|0,C,F,h,m,0,0,0,1073414144);C=x[f+32>>2];F=x[f+36>>2];h=x[f+40>>2];m=x[f+44>>2];wd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],C,F,h,m);eg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,z,B);z=x[f+8>>2];B=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break x}if(!c|n){break x}wd(f+80|0,C,F,h,m,0,0,0,1073610752);eg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,z,B);z=x[f+72>>2];B=x[f+76>>2];n=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;i=k?i:i+1|0;H=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=_c(b)}continue}break}y:{if(!H){c=x[b+116>>2];z:{A:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break A}x[b+4>>2]=c-2;if(!s){break z}x[b+4>>2]=c-3;break z}if(d){break z}}Oh(b,0,0)}ui(f+96|0,+(o|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break y}if((i|0)<=0&k>>>0<=7|(i|0)<0){h=k;m=i;while(1){e=e<<4;h=h+1|0;m=h?m:m+1|0;if((h|0)!=8|m){continue}break}}B:{C:{D:{if((g&-33)==80){h=eG(b,d);c=lb;m=c;if(h|(c|0)!=-2147483648){break B}if(d){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break D}break C}l=0;p=0;Oh(b,0,0);c=0;b=0;break y}h=0;m=0;if(x[b+116>>2]<0){break B}}x[b+4>>2]=x[b+4>>2]-1}h=0;m=0}if(!e){ui(f+112|0,+(o|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break y}b=s?t:k;i=(s?u:i)<<2|b>>>30;c=h+(b<<2)|0;b=i+m|0;k=c-32|0;i=(c>>>0<h>>>0?b+1|0:b)-(c>>>0<32)|0;b=i;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[114232]=68;Ag(f+160|0,o);wd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);wd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break y}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(i|0)){if((e|0)>=0){while(1){eg(f+416|0,l,p,z,B,0,0,0,-1073807360);b=kG(l,p,z,B,1073610752);c=(b|0)>=0;b=c;eg(f+400|0,l,p,z,B,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:z,b?x[f+428>>2]:B);b=k;k=b-1|0;i=i-!b|0;z=x[f+408>>2];B=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];e=c|e<<1;if((e|0)>=0){continue}break}}b=i-((I>>31)+(k>>>0<I>>>0)|0)|0;c=(k-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;E:{if((c|0)>=113){Ag(f+384|0,o);t=x[f+392>>2];u=x[f+396>>2];C=x[f+384>>2];F=x[f+388>>2];h=0;b=0;break E}ui(f+352|0,uk(1,144-c|0));Ag(f+336|0,o);C=x[f+336>>2];F=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];jG(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],C,F,t,u);w=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}d=!(e&1)&((zl(l,p,z,B,0,0,0,0)|0)!=0&(c|0)<32);dn(f+320|0,d+e|0);wd(f+304|0,C,F,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;eg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,w,L);b=d;wd(f+288|0,C,F,t,u,b?0:l,b?0:p,b?0:z,b?0:B);eg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);Bw(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,h,w,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];h=x[f+252>>2];if(!zl(b,d,c,h,0,0,0,0)){x[114232]=68}iG(f+224|0,b,d,c,h,k);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break y}x[114232]=68;Ag(f+208|0,o);wd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);wd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=b;x[r+28>>2]=c;hb=f+432|0;k=x[r+24>>2];i=x[r+28>>2];h=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;w=o;f=d;b=0;o=0;e=hb-8976|0;hb=e;K=0-I|0;L=K-J|0;F:{G:{while(1){if((c|0)!=48){H:{if((c|0)!=46){break F}c=x[g+4>>2];if((c|0)==x[g+104>>2]){break H}x[g+4>>2]=c+1;c=y[c|0];break G}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0]}else{c=_c(g)}b=1;continue}break}c=_c(g)}n=1;if((c|0)!=48){break F}while(1){b=k;k=b-1|0;i=i-!b|0;b=x[g+4>>2];I:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break I}c=_c(g)}if((c|0)==48){continue}break}b=1}x[e+784>>2]=0;J:{K:{d=(c|0)==46;l=c-48|0;L:{M:{N:{if(d|l>>>0<=9){while(1){O:{if(d&1){if(!n){k=h;i=m;n=1;break O}d=!b;break N}h=h+1|0;m=h?m:m+1|0;if((o|0)<=2044){H=(c|0)==48?H:h;b=(e+784|0)+(o<<2)|0;if(s){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;b=1;d=s+1|0;c=(d|0)==9;s=c?0:d;o=c+o|0;break O}if((c|0)==48){break O}x[e+8960>>2]=x[e+8960>>2]|1;H=18396}c=x[g+4>>2];P:{if((c|0)!=x[g+104>>2]){x[g+4>>2]=c+1;c=y[c|0];break P}c=_c(g)}d=(c|0)==46;l=c-48|0;if(d|l>>>0<10){continue}break}}k=n?k:h;i=n?i:m;if(!(!b|(c&-33)!=69)){l=eG(g,f);b=lb;p=b;Q:{if(l|(b|0)!=-2147483648){break Q}if(!f){break L}l=0;p=0;if(x[g+116>>2]<0){break Q}x[g+4>>2]=x[g+4>>2]-1}i=i+p|0;k=k+l|0;i=k>>>0<l>>>0?i+1|0:i;break K}d=!b;if((c|0)<0){break M}}if(x[g+116>>2]<0){break M}x[g+4>>2]=x[g+4>>2]-1}if(!d){break K}x[114232]=28}h=0;m=0;Oh(g,0,0);c=0;b=0;break J}b=x[e+784>>2];if(!b){ui(e,+(w|0)*0);h=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break J}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(h>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){Ag(e+48|0,w);dn(e+32|0,b);wd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break J}if(k>>>0>K>>>1>>>0&(i|0)>=0|(i|0)>0){x[114232]=68;Ag(e+96|0,w);wd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);wd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break J}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[114232]=68;Ag(e+144|0,w);wd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);wd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break J}if(s){if((s|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);s=s+1|0;if((s|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}n=k;R:{if((k|0)<(H|0)|(H|0)>=9|(k|0)>17){break R}if((n|0)==9){Ag(e+192|0,w);dn(e+176|0,x[e+784>>2]);wd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break J}if((n|0)<=8){Ag(e+272|0,w);dn(e+256|0,x[e+784>>2]);wd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);Ag(e+224|0,x[(0-n<<2)+61104>>2]);hG(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break J}b=(D(n,-3)+J|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break R}Ag(e+352|0,w);dn(e+336|0,c);wd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);Ag(e+304|0,x[(n<<2)+61032>>2]);wd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break J}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}s=0;b=(n|0)%9|0;S:{if(!b){d=0;break S}d=0;b=(n|0)<0?b+9|0:b;T:{if(!c){c=0;break T}k=x[(0-b<<2)+61104>>2];i=1e9/(k|0)|0;l=0;g=0;while(1){h=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];o=(m>>>0)/(k>>>0)|0;h=h+o|0;x[l>>2]=h;h=!h&(d|0)==(g|0);d=h?d+1&2047:d;n=h?n-9|0:n;l=D(i,m-D(k,o)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break T}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}n=(n-b|0)+9|0}while(1){g=(e+784|0)+(d<<2)|0;U:{while(1){if(((n|0)!=36|A[g>>2]>=10384593)&(n|0)>=36){break U}o=c+2047|0;l=0;b=c;while(1){c=b;h=o&2047;o=(e+784|0)+(h<<2)|0;b=x[o>>2];m=b>>>3|0;k=l;l=b<<29;k=k+l|0;b=m;i=k>>>0<l>>>0?b+1|0:b;if(!i&k>>>0<1000000001){l=0}else{b=k;l=vqa(b,i,1e9,0);k=b-sqa(l,lb,1e9,0)|0}x[o>>2]=k;b=(h|0)!=(c-1&2047)?c:(d|0)==(h|0)?c:k?c:h;o=h-1|0;if((d|0)!=(h|0)){continue}break}s=s-29|0;if(!l){continue}break}d=d-1&2047;if((d|0)==(b|0)){k=e+784|0;c=k+((b+2046&2047)<<2)|0;g=c;m=x[c>>2];c=b-1&2047;x[g>>2]=m|x[k+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(d<<2)>>2]=l;continue}break}V:{W:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;X:{while(1){b=d;g=0;Y:{while(1){Z:{d=b+g&2047;if((d|0)==(c|0)){break Z}d=x[(e+784|0)+(d<<2)>>2];i=x[(g<<2)+61056>>2];if(d>>>0<i>>>0){break Z}if(d>>>0>i>>>0){break Y}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break Y}k=0;i=0;g=0;h=0;m=0;while(1){d=b+g&2047;if((d|0)==(c|0)){c=c+1&2047;x[(e+(c<<2)|0)+780>>2]=0}dn(e+768|0,x[(e+784|0)+(d<<2)>>2]);wd(e+752|0,k,i,h,m,0,0,1342177280,1075633366);eg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);h=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Ag(e+720|0,w);wd(e+704|0,k,i,h,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);h=x[e+712>>2];m=x[e+716>>2];k=0;i=0;l=x[e+704>>2];p=x[e+708>>2];f=s+113|0;g=f-I|0;o=(g|0)<(J|0);d=o?(g|0)>0?g:0:J;if((d|0)<=112){break X}break V}s=h+s|0;d=c;if((b|0)==(c|0)){continue}break}m=1e9>>>h|0;o=-1<<h^-1;g=0;d=b;while(1){i=g;g=(e+784|0)+(b<<2)|0;f=x[g>>2];i=i+(f>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);d=i?d+1&2047:d;n=i?n-9|0:n;g=D(m,f&o);b=b+1&2047;if((c|0)!=(b|0)){continue}break}if(!g){continue}if((d|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue W}x[l>>2]=x[l>>2]|1;continue}break}break}ui(e+656|0,uk(1,225-d|0));jG(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,h,m);C=x[e+696>>2];F=x[e+700>>2];z=x[e+688>>2];B=x[e+692>>2];ui(e+640|0,uk(1,113-d|0));gG(e+672|0,l,p,h,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];i=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];Bw(e+624|0,l,p,h,m,k,i,t,u);eg(e+608|0,z,B,C,F,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);h=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}n=b+4&2047;_:{if((n|0)==(c|0)){break _}n=x[(e+784|0)+(n<<2)>>2];$:{if(n>>>0<=499999999){if(!n&(b+5&2047)==(c|0)){break $}ui(e+496|0,+(w|0)*.25);eg(e+480|0,k,i,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];k=x[e+480>>2];i=x[e+484>>2];break $}if((n|0)!=5e8){ui(e+592|0,+(w|0)*.75);eg(e+576|0,k,i,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];k=x[e+576>>2];i=x[e+580>>2];break $}M=+(w|0);if((b+5&2047)==(c|0)){ui(e+528|0,M*.5);eg(e+512|0,k,i,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];k=x[e+512>>2];i=x[e+516>>2];break $}ui(e+560|0,M*.75);eg(e+544|0,k,i,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];k=x[e+544>>2];i=x[e+548>>2]}if((d|0)>111){break _}gG(e+464|0,k,i,t,u,0,0,0,1073676288);if(zl(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break _}eg(e+448|0,k,i,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];k=x[e+448>>2];i=x[e+452>>2]}eg(e+432|0,l,p,h,m,k,i,t,u);Bw(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],z,B,C,F);h=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];aa:{if((L-2|0)>=(f&2147483647)){break aa}x[e+408>>2]=h;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;wd(e+384|0,l,p,h,m,0,0,0,1073610752);c=kG(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(c|0)>=0;h=b?x[e+392>>2]:h;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;s=b+s|0;if(!(o&((d|0)!=(g|0)|(c|0)<0)&(zl(k,i,t,u,0,0,0,0)|0)!=0)&(s+110|0)<=(L|0)){break aa}x[114232]=68}iG(e+368|0,l,p,h,m,s);h=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=h;x[r+36>>2]=m;hb=e+8976|0;k=x[r+40>>2];i=x[r+44>>2];h=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ba:{c=x[b+4>>2];ca:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ca}c=_c(b)}if((c|0)==40){g=1;break ba}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];da:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break da}c=_c(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ea:{if(d){if(g){break ea}break a}break i}while(1){if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g){continue}break}break a}x[114232]=28;Oh(b,0,0)}i=0}x[a>>2]=h;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=i;hb=r+48|0}function ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-368|0;hb=d;Nc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!Tu(b,d+363|0)){break q}if(!LS(d+363|0)){break q}if(!c){u=1;break q}F=km(d+344|0,b);x[114409]=0;T(753,d+332|0,F|0,0);b=x[114409];x[114409]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)!=1){x[114409]=0;T(754,d+316|0,d+332|0,20041);b=x[114409];x[114409]=0;if((b|0)==1){break E}x[114409]=0;e=S(312,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}if(!e){break r}x[114409]=0;e=O(755,d+316|0,d+225|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}if(!e){break r}x[114409]=0;P(419,a|0,16384);b=x[114409];x[114409]=0;if((b|0)==1){break w}x[a+480208>>2]=8;x[114409]=0;e=a+1074312|0;U(458,e|0,9,1)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;O(459,e|0,21)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;O(459,e|0,30)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;e=O(2,d+212|0,4485)|0;b=x[114409];x[114409]=0;if((b|0)==1){break B}Eb(a+1304436|0,e);xb(e);x[114409]=0;e=O(2,d+200|0,6703)|0;b=x[114409];x[114409]=0;if((b|0)==1){break A}Eb(a+1304448|0,e);xb(e);x[114409]=0;f=O(2,d+188|0,13273)|0;b=x[114409];x[114409]=0;if((b|0)==1){break z}h=10696;b=y[d+367|0];switch(b-16|0){case 1:break x;case 0:break D;default:break C}}b=N()|0;break a}b=N()|0;break b}h=10615;break x}if(!b){break y}h=17381;break x}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}h=9122}x[114409]=0;e=O(2,d+176|0,h|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;T(3,d- -64|0,f|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}b=d- -64|0;Eb(a+1304460|0,b);xb(b);xb(e);xb(f);x[a+1304496>>2]=4;x[114409]=0;T(369,d+164|0,3,d+225|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;P(370,d- -64|0,d+164|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}b=d- -64|0;Eb(a+1304400|0,b);xb(b);x[114409]=0;T(756,d+152|0,3,d+257|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}x[114409]=0;P(370,d+164|0,d+152|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}x[114409]=0;T(13,d- -64|0,4,d+164|0);b=x[114409];x[114409]=0;if((b|0)==1){break i}b=d- -64|0;Eb(a+1304412|0,b);xb(b);xb(d+164|0);x[a+480200>>2]=y[d+281|0]+1;G=a,H=Md(y[d+282|0],1,255),x[G+480196>>2]=H;G=a,H=D(Md(y[d+283|0],4,255),1e4),x[G+480204>>2]=H;f=a+484360|0;e=Wb(f);b=y[d+277|0]|y[d+278|0]<<8;x[114409]=0;aa(580,e|0,d+316|0,b|0,65535,65535)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}Pe(Wb(f),y[d+279|0]|y[d+280|0]<<8);w[a+480188>>1]=0;b=0;while(1){x[114409]=0;i=(b<<5)+a|0;q=i+480280|0;V(403,q|0);e=x[114409];x[114409]=0;if((e|0)==1){break j}f=b+d|0;e=y[f+284|0]<<1&254;w[i+480284>>1]=(e|0)==254?256:e;F:{if(v[f+284|0]<0){x[q>>2]=x[q>>2]|1024;break F}w[a+480188>>1]=b+1}x[114409]=0;U(757,d+316|0,i+480289|0,8)|0;e=x[114409];x[114409]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}x[114409]=0;T(754,d- -64|0,d+332|0,17741);b=x[114409];x[114409]=0;if((b|0)==1){break k}e=d+316|0;b=d- -64|0;Zd(e,b);Ab(b);x[114409]=0;e=S(228,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;Z(584,a+1304424|0,d+316|0,e|0,0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;T(754,d- -64|0,d+332|0,21321);b=x[114409];x[114409]=0;if((b|0)==1){break l}e=d+316|0;b=d- -64|0;Zd(e,b);Ab(b);x[114409]=0;e=S(312,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}G:{if(e){x[114409]=0;T(754,d- -64|0,d+332|0,16723);b=x[114409];x[114409]=0;if((b|0)==1){break m}x[114409]=0;q=S(425,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}H:{if(!q){break H}f=c&2;while(1){x[114409]=0;i=S(425,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}if(!i){break H}x[114409]=0;e=O(231,d+316|0,56)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}if(!e){break H}if(i>>>0>z[a+480190>>1]){w[a+480190>>1]=i}x[114409]=0;k=D(i,104)+a|0;j=k+484380|0;P(472,j|0,0);b=x[114409];x[114409]=0;if((b|0)==1){break n}x[114409]=0;U(541,d+316|0,((i<<5)+a|0)+946304|0,32)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}x[114409]=0;U(544,d+316|0,k+484423|0,8)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}I:{if(y[d+367|0]<=15){x[114409]=0;m=S(335,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break I}break n}x[114409]=0;m=S(413,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}}x[k+484404>>2]=m<<1;x[114409]=0;e=S(413,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}x[j>>2]=e;x[114409]=0;e=S(413,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}u=k+484384|0;x[u>>2]=e;x[114409]=0;e=S(413,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}r=k+484388|0;x[r>>2]=e;if(e){b=k+484414|0;w[b>>1]=z[b>>1]|2;x[r>>2]=e+x[u>>2]}x[114409]=0;e=S(425,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break G}if(y[d+367|0]<=15){w[k+484410>>1]=e}x[114409]=0;i=S(425,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break n}e=k+484414|0;b=z[e>>1];A=8;if(i&1){b=b|1;w[e>>1]=b;x[j>>2]=x[j>>2]>>>1;x[u>>2]=x[u>>2]>>>1;x[r>>2]=x[r>>2]>>>1;A=16}w[e>>1]=b&65531|i<<1&4;b=cd(d+164|0,A,1,0,((i&12)!=0)<<3);J:{if(!f){break J}x[114409]=0;U(376,b|0,j|0,d- -64|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break J}break n}g=g+1|0;if(q>>>0>(g&255)>>>0){continue}break}}Ab(d- -64|0)}x[114409]=0;T(754,d- -64|0,d+332|0,18761);b=x[114409];x[114409]=0;if((b|0)==1){break p}e=d+316|0;b=d- -64|0;Zd(e,b);Ab(b);x[114409]=0;e=S(312,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break w}if(e){s=vA(d+164|0);o=vA(d+152|0);B=vA(d+140|0);x[114409]=0;T(754,d+124|0,d+332|0,17750);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;b=x[d+136>>2];x[d+40>>2]=x[d+132>>2];x[d+44>>2]=b;b=x[d+128>>2];x[d+32>>2]=x[d+124>>2];x[d+36>>2]=b;P(758,d+32|0,s|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;T(754,d+108|0,d+332|0,17744);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;b=x[d+120>>2];x[d+24>>2]=x[d+116>>2];x[d+28>>2]=b;b=x[d+112>>2];x[d+16>>2]=x[d+108>>2];x[d+20>>2]=b;P(758,d+16|0,o|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;T(754,d+92|0,d+332|0,17734);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;b=x[d+104>>2];x[d+8>>2]=x[d+100>>2];x[d+12>>2]=b;b=x[d+96>>2];x[d>>2]=x[d+92>>2];x[d+4>>2]=b;P(758,d|0,B|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;k=S(425,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break o}if(k){l=d+65|0;A=0;while(1){x[114409]=0;P(452,d+52|0,d+316|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}C=ed(d+52|0);K:{L:{M:{if(!y[d+52|0]){break M}b=y[C|0];x[114409]=0;e=O(231,d+316|0,D(b,14)+32|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break o}if(!e){break M}b=y[d+52|0];x[114409]=0;g=U(427,a|0,b|0,0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break o}if(g){break L}}b=y[C|0];x[114409]=0;O(313,d+316|0,D(b,14)+32|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break K}break o}x[114409]=0;U(541,d+316|0,g+492|0,32)|0;b=x[114409];x[114409]=0;if((b|0)==1){break o}if(!y[C|0]){break K}u=g+88|0;r=g+68|0;i=g+48|0;q=g+236|0;t=0;b=0;while(1){x[114409]=0;O(759,d+316|0,d- -64|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}f=y[d- -64|0];N:{if(!f|f>>>0>z[a+480190>>1]){break N}if(y[l|0]>128){v[l|0]=128}if(y[l|0]>=(b&255)>>>0){while(1){e=y[d- -64|0];G=fd(q,b&255),H=e,w[G>>1]=H;b=b+1|0;if(y[l|0]>=(b&255)>>>0){continue}break}}f=y[l|0];b=y[d+67|0];x[114409]=0;T(760,i|0,b|0,s|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}b=y[d+69|0];x[114409]=0;T(760,r|0,b|0,o|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}b=y[d+77|0];x[114409]=0;T(760,u|0,b|0,B|0);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[g>>2]=(y[d+70|0]|y[d+71|0]<<8)+1>>>1;j=y[d- -64|0];O:{if(y[d+67|0]&64){w[(D(j,104)+a|0)+484410>>1]=y[d+66|0];break O}b=(D(j,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}b=y[d+68|0];x[114409]=0;w[d+90>>1]=b<<1;w[d+88>>1]=254;e=O(457,d+90|0,d+88|0)|0;b=x[114409];x[114409]=0;P:{if((b|0)!=1){n=D(j,104)+a|0;w[n+484408>>1]=z[e>>1];v[n+484418|0]=y[(y[d+75|0]&3)+23717|0];j=n+484419|0;v[j|0]=y[d+74|0];b=n+484420|0;v[b|0]=y[d+73|0]+3>>>2;v[n+484421|0]=y[d+72|0];e=y[j|0];if(!e){E=255;break P}b=y[b|0];x[114409]=0;e=cg(761,(((b<<8|e>>>1)&65407)>>>0)/(e>>>0)|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;E=S(762,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break P}}break o}break o}b=f+1|0;v[j|0]=E;if(!(y[d+69|0]&64)){break N}e=n+484414|0;w[e>>1]=z[e>>1]|32}t=t+1|0;if(y[C|0]>(t&255)>>>0){continue}break}}A=A+1|0;if(k>>>0>(A&255)>>>0){continue}break}}Zn(B);Zn(o);Zn(s)}u=1;n=Cq(d+164|0);if(!(c&1)){break s}x[114409]=0;T(754,d- -64|0,d+332|0,21076);b=x[114409];x[114409]=0;Q:{R:{S:{if((b|0)!=1){b=Zd(d+316|0,d- -64|0);x[114409]=0;c=S(312,b|0)|0;b=x[114409];x[114409]=0;T:{U:{V:{W:{X:{Y:{if((b|0)!=1){Ab(d- -64|0);Z:{if(!c){break Z}x[114409]=0;f=S(335,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break Y}x[114409]=0;P(763,n|0,f+1|0);b=x[114409];x[114409]=0;if((b|0)==1){break Y}if(!f){break Z}b=1;while(1){x[114409]=0;e=S(335,d+316|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break X}x[114409]=0;T(316,d- -64|0,d+316|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break X}e=d- -64|0;Zd(wc(n,b),e);c=(b|0)==(f|0);Ab(e);b=b+1|0;if(!c){continue}break}}x[114409]=0;T(754,d- -64|0,d+332|0,16720);b=x[114409];x[114409]=0;if((b|0)==1){break W}b=Zd(d+316|0,d- -64|0);x[114409]=0;c=S(312,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break V}Ab(d- -64|0);if(!c){break T}c=0;x[114409]=0;s=S(425,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break u}if(s){while(1){t=32;_:{if(y[d+367|0]>=16){x[114409]=0;O(764,d+316|0,d- -64|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break S}b=y[d- -64|0];if(!(b>>>0<=z[a+480188>>1]|b>>>0>32)){w[a+480188>>1]=y[d- -64|0]}t=y[d- -64|0];if(!t){break _}}b=0;while(1){x[114409]=0;f=S(335,d+316|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break R}if(!(!f|b>>>0>31|z[a+480188>>1]>b>>>0)){w[a+480188>>1]=b+1}b=b+1|0;if((t|0)!=(b|0)){continue}break}}c=c+1|0;if(s>>>0>(c&65535)>>>0){continue}break}}x[114409]=0;O(229,d+316|0,1)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break U}break u}b=N()|0;Ab(d- -64|0);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;Ab(d- -64|0);break t}x[114409]=0;o=a+484344|0;P(377,o|0,s|0);b=x[114409];x[114409]=0;if((b|0)==1){break u}if(!s){break T}q=d+66|0;g=0;while(1){B=Xb(d+152|0);$:{if(y[d+367|0]<16){C=32;c=64;break $}x[114409]=0;O(764,d+316|0,d- -64|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break v}C=y[d- -64|0];c=y[d+65|0];x[114409]=0;T(765,d+52|0,3,q|0);b=x[114409];x[114409]=0;if((b|0)==1){break v}x[114409]=0;P(370,d+140|0,d+52|0);b=x[114409];x[114409]=0;if((b|0)==1){break v}b=d+140|0;Eb(B,b);xb(b);c=c+1|0}x[114409]=0;e=U(378,o|0,g&65535,c|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break v}aa:{if(!e){x[114409]=0;O(313,d+316|0,C<<1)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break aa}break v}b=Zb(o,g);x[114409]=0;O(476,b|0,B|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break v}k=0;if(!C){break aa}while(1){x[114409]=0;e=S(335,d+316|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break v}ba:{if(!e){break ba}if(qd(n)>>>0<=e>>>0){break ba}j=k&65535;if(j>>>0>=z[a+480188>>1]){break ba}l=wc(n,e);Nc(l);h=0;while(1){x[114409]=0;e=O(231,l|0,1)|0;b=x[114409];x[114409]=0;ca:{da:{ea:{fa:{ga:{ha:{if((b|0)!=1){if(!e){break ba}b=Zb(o,g);x[114409]=0;b=U(451,b|0,h|0,j|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}x[114409]=0;f=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}r=f<<24>>24;m=(r&252)>>>2|0;switch((r&3)-1|0){case 2:break ea;case 1:break fa;case 0:break ga;default:break ha}}break v}h=(h+m|0)+1|0;break ca}if(!h){h=0;break ca}e=Zb(o,g);x[114409]=0;f=U(451,e|0,h-1|0,j|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){while(1){e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;e=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=e;v[b+5|0]=e>>>8;h=h+1|0;if(c>>>0<=h>>>0){break ca}b=D(z[a+480188>>1],6)+b|0;e=m&255;m=m-1|0;if(e){continue}break ca}}break v}if(h>>>0<=m>>>0){break da}e=Zb(o,g);x[114409]=0;f=U(451,e|0,m|0,j|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Q}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;e=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=e;v[b+5|0]=e>>>8;break da}if(m&1){x[114409]=0;f=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Q}v[b|0]=f>>>0>120?-1:f}if(m&2){x[114409]=0;f=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Q}v[b+1|0]=f}f=0;t=0;if(m&4){x[114409]=0;t=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}}i=0;if(m&8){x[114409]=0;f=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}i=f>>>4|0;f=f&15}A=0;E=0;if(m&16){x[114409]=0;E=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}}if((r|0)<0){x[114409]=0;A=S(425,l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}}x[114409]=0;ia(766,b|0,t|0,f|0,i|0,E|0,A|0);b=x[114409];x[114409]=0;if((b|0)==1){break v}}h=h+1|0}if(c>>>0>h>>>0){continue}break}}k=k+1|0;if((k&65535)>>>0<C>>>0){continue}break}}xb(B);g=g+1|0;if((s|0)!=(g|0)){continue}break}}x[114409]=0;T(754,d- -64|0,d+332|0,20048);b=x[114409];x[114409]=0;ia:{ja:{ka:{if((b|0)!=1){b=Zd(d+316|0,d- -64|0);x[114409]=0;c=S(312,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break ka}Ab(d- -64|0);if(!c){break s}c=a+484344|0;if(!Ne(c)){break s}while(1){x[114409]=0;b=O(231,d+316|0,16)|0;a=x[114409];x[114409]=0;if((a|0)==1){break ja}if(!b){break s}x[114409]=0;U(767,d+316|0,d- -64|0,16)|0;a=x[114409];x[114409]=0;if((a|0)==1){break ia}a=Zb(c,0);x[114409]=0;O(768,a|0,d- -64|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break ia}if(Ne(c)){continue}break}break s}b=N()|0;break t}b=N()|0;Ab(d- -64|0);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}break v}break n}b=N()|0;break c}b=N()|0;xb(B);break t}b=N()|0}hd(n);break c}hd(n)}Ab(d+316|0);uA(d+332|0);Ab(F)}hb=d+368|0;return u|0}b=N()|0;break c}b=N()|0;Zn(B);Zn(o);Zn(s);break c}b=N()|0;Ab(d- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;xb(d+164|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;xb(e);break d}b=N()|0}xb(f)}Ab(d+316|0)}uA(d+332|0)}Ab(F);Q(b|0);p()}function gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-560|0;hb=d;Nc(b);a:{if(!fo(b,d+480|0)){break a}if(!CP(d+480|0)){break a}if(!Qb(b,id(BP(d+480|0),lb))){break a}b:{if(!c){break b}Pd(a,4);Ni(a);x[a+1074372>>2]=4;l=gd(d+468|0);c:{d:{e:{f:{j=d+518|0;g:{if(!(dd(j,13647,20)|(y[d+540|0]|y[d+541|0]<<8|(y[d+542|0]<<16|y[d+543|0]<<24))!=276)){if((y[d+538|0]|y[d+539|0]<<8)>>>0<260){break g}e=Yq(d+497|0,0,20)?1154:34;break e}if(!dd(j,13626,20)){e=1;break e}x[114409]=0;T(756,d+456|0,3,j|0);g=x[114409];x[114409]=0;h:{i:{j:{if((g|0)==1){break j}x[114409]=0;P(370,d+104|0,d+456|0);g=x[114409];x[114409]=0;if((g|0)==1){break j}x[114409]=0;T(13,d+192|0,4,d+104|0);g=x[114409];x[114409]=0;if((g|0)==1){break i}g=d+192|0;Eb(l,g);xb(g);xb(d+104|0);if((y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))!=1852141647|(y[j+4|0]|y[j+5|0]<<8|(y[j+6|0]<<16|y[j+7|0]<<24))!=542396493){break h}e=1048;break e}e=N()|0;break c}e=N()|0;xb(d+104|0);break c}if(!dd(j,13286,12)){e=16;if((y[d+530|0]|y[d+531|0]<<8|(y[d+532|0]<<16|y[d+533|0]<<24))==538976288&(y[d+534|0]|y[d+535|0]<<8|(y[d+536|0]<<16|y[d+537|0]<<24))==538976288){break e}x[a+1074372>>2]=5;break e}if(dd(j,7501,20)){break f}}e=48;break e}if(!dd(j,24032,15)){x[114409]=0;g=a+1074312|0;O(459,g|0,54)|0;i=x[114409];x[114409]=0;B=1;if((i|0)==1){break d}x[114409]=0;O(459,g|0,51)|0;g=x[114409];x[114409]=0;e=16;if((g|0)==1){break d}break e}k:{if(dd(j,24048,14)){if(dd(j,24063,14)){break k}}x[114409]=0;g=a+1074312|0;O(459,g|0,57)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;O(459,g|0,51)|0;g=x[114409];x[114409]=0;e=16;if((g|0)!=1){break e}break d}e=dd(j,13374,11)?16:256}x[114409]=0;t=d+497|0;T(756,d+104|0,3,t|0);g=x[114409];x[114409]=0;l:{m:{n:{o:{p:{if((g|0)==1){break p}x[114409]=0;P(370,d+192|0,d+104|0);g=x[114409];x[114409]=0;if((g|0)==1){break p}g=d+192|0;Eb(a+1304400|0,g);xb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;q=a+484360|0;Pe(Wb(q),y[d+546|0]|y[d+547|0]<<8);w[a+480188>>1]=y[d+548|0]|y[d+549|0]<<8;i=y[d+552|0]|y[d+553|0]<<8;x[114409]=0;w[d+192>>1]=i;w[d+104>>1]=255;g=O(457,g|0,d+104|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break o}w[a+480192>>1]=z[g>>1];if(y[d+556|0]|y[d+557|0]<<8){x[a+480196>>2]=y[d+556|0]|y[d+557|0]<<8}if(y[d+558|0]|y[d+559|0]<<8){g=x[19558];G=a,H=Md(D(y[d+558|0]|y[d+559|0]<<8,1e4),D(x[g+20>>2],1e4),D(x[g+24>>2],1e4)),x[G+480204>>2]=H}x[a+480208>>2]=0;x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+554|0]|y[d+555|0]<<8)<<4&16;g=(y[d+554|0]|y[d+555|0]<<8)<<3&32768;x[a+480208>>2]=g|x[a+480208>>2]&-32769;i=Wb(q);f=y[d+544|0]|y[d+545|0]<<8;x[114409]=0;aa(580,i|0,b|0,f|0,65535,65535)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}f=g>>>15|0?(e|0)==34?146:e:e;if(!(y[d+544|0]|y[d+545|0]<<8|f>>>0>1023)){g=Wb(q);x[114409]=0;T(1082,g|0,1,0);g=x[114409];x[114409]=0;if((g|0)==1){break d}}g=y[d+540|0]|y[d+541|0]<<8|(y[d+542|0]<<16|y[d+543|0]<<24);x[114409]=0;O(229,b|0,g+60|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if((y[d+538|0]|y[d+539|0]<<8)>>>0>=260){x[114409]=0;T(1083,b|0,d+480|0,a|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}}v[d+455|0]=0;i=hb-16|0;hb=i;g=d+456|0;x[g>>2]=0;x[g+4>>2]=0;x[114409]=0;x[i+12>>2]=0;U(1100,g+8|0,i+12|0,i+11|0)|0;e=x[114409];x[114409]=0;q:{if((e|0)!=1){hb=i+16|0;break q}R(0)|0;zb();p()}if(z[a+480192>>1]){break n}i=-1;break m}e=N()|0;break c}e=N()|0;break c}C=c&2;E=d+122|0;F=d+225|0;e=1;m=1;i=-1;while(1){r:{x[114409]=0;k=S(413,b|0)|0;h=x[114409];x[114409]=0;s:{t:{u:{v:{w:{x:{if((h|0)!=1){rg(b,4);x[114409]=0;U(1084,b|0,d+192|0,(k?k:263)|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break r}y:{if((f|0)==1){if((y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))==245){x[a+1074308>>2]=16777381;x[114409]=0;f=O(2,d+180|0,9209)|0;k=x[114409];x[114409]=0;if((k|0)!=1){Eb(l,f);xb(f);f=17;break y}e=N()|0;break l}f=16;if((y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))!=263){break y}x[a+1074308>>2]=16777395;x[114409]=0;f=O(2,d+168|0,9133)|0;k=x[114409];x[114409]=0;if((k|0)!=1){Eb(l,f);xb(f);f=17;break y}e=N()|0;break l}if(y[d+219|0]|y[d+220|0]<<8){break y}if(!(!(f&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))!=263)){f=f|16;break y}if(!(!(f&256)|(y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))==29)){f=f&-257;break y}if(!(f&160)){break y}f=(y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))==33?f:0}x[114409]=0;k=U(427,a|0,m&65535,0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break r}if(!k){break s}k=((e<<2)+a|0)+900380|0;e=x[k>>2];x[114409]=0;P(1085,d+192|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break r}e=y[d+218|0];z:{if((i|0)==-1){i=e;break z}if(!(f&32)|(e|0)==(i|0)){break z}f=f&-161|128}if(!(y[d+219|0]|y[d+220|0]<<8)){break s}e=y[d+433|0];h=y[d+434|0];o=y[d+435|0]|y[d+436|0]<<8;n=y[d+439|0];r=y[d+219|0]|y[d+220|0]<<8;x[114409]=0;T(1086,d+156|0,a|0,r|0);r=x[114409];x[114409]=0;if((r|0)==1){break x}f=n|(o|(e|h))?f&-4:f;e=12;while(1){h=z[fd(x[k>>2]+236|0,e)>>1];if(rc(d+156|0)>>>0>h>>>0){h=z[vc(d+156|0,z[fd(x[k>>2]+236|0,e)>>1])>>1];G=fd(x[k>>2]+236|0,e),H=h,w[G>>1]=H}e=e+1|0;if((e|0)!=108){continue}break}if((y[d+538|0]|y[d+539|0]<<8)>>>0>259){Lb(g);xP(g);sg(g)}e=y[d+219|0]|y[d+220|0]<<8;x[114409]=0;k=O(1087,d+144|0,e|0)|0;e=x[114409];x[114409]=0;A:{if((e|0)!=1){e=0;if(y[d+219|0]|y[d+220|0]<<8){break A}break w}e=N()|0;break u}B:{C:{D:{E:{while(1){x[114409]=0;O(1088,b|0,d+104|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break B}x[114409]=0;P(1089,d+92|0,d+104|0);h=x[114409];x[114409]=0;F:{if((h|0)==1){break F}x[114409]=0;P(1090,g|0,d+92|0);h=x[114409];x[114409]=0;if((h|0)==1){break F}h=y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24);G=Pb(k,e),H=h,x[G>>2]=H;o=y[d+121|0];if(rc(d+156|0)>>>0>e>>>0){h=z[vc(d+156|0,e)>>1];x[114409]=0;n=(D(h,104)+a|0)+484380|0;P(1091,d+104|0,n|0);r=x[114409];x[114409]=0;if((r|0)==1){break E}x[114409]=0;P(1092,F|0,n|0);n=x[114409];x[114409]=0;if((n|0)==1){break E}x[114409]=0;T(587,d+80|0,3,E|0);n=x[114409];x[114409]=0;if((n|0)==1){break D}x[114409]=0;P(370,d+92|0,d+80|0);n=x[114409];x[114409]=0;if((n|0)==1){break D}x[114409]=0;O(348,((h<<5)+a|0)+946304|0,d+92|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break C}xb(d+92|0);f=(y[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}s=o|s;e=e+1|0;if(e>>>0>=(y[d+219|0]|y[d+220|0]<<8)>>>0){break w}continue}break}e=N()|0;break v}e=N()|0;break v}e=N()|0;break v}e=N()|0;xb(d+92|0);break v}e=N()|0;break v}e=N()|0;break l}e=N()|0;break l}if((y[d+538|0]|y[d+539|0]<<8)>>>0<260){break t}e=0;if(!(y[d+219|0]|y[d+220|0]<<8)){break t}G:{while(1){H:{o=y[Pb(g,e)+3|0];h=x[Pb(k,e)>>2];x[114409]=0;T(316,d+104|0,b|0,((o|0)==11?(h+1>>>1|0)+16|0:h)|0);h=x[114409];x[114409]=0;if((h|0)==1){break H}if(!(!C|rc(d+156|0)>>>0<=e>>>0)){o=z[vc(d+156|0,e)>>1];h=Pb(g,e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[114409]=0;x[d+76>>2]=h;x[d+12>>2]=h;h=Z(1093,(D(o,104)+a|0)+484380|0,d+12|0,d+104|0,d+455|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break G}u=h^1|u}Ab(d+104|0);e=e+1|0;if(e>>>0<(y[d+219|0]|y[d+220|0]<<8)>>>0){continue}break t}break}e=N()|0;break v}e=N()|0;Ab(d+104|0)}Me(k)}vf(d+156|0);break l}Me(k);vf(d+156|0)}m=m+1|0;e=m&65535;if(e>>>0<=z[a+480192>>1]){continue}break m}break}e=N()|0;break l}if(!(!(f&2)|s&255)){f=Yq(t,0,20)?f|16:f}I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((y[d+538|0]|y[d+539|0]<<8)>>>0>259){break _}if(c&3){x[114409]=0;T(1083,b|0,d+480|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break Z}}if(!(c&2)|!z[a+480190>>1]){break _}c=1;while(1){e=c&65535;k=Pb(g,e-1|0);x[114409]=0;U(376,k|0,(D(e,104)+a|0)+484380|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Y}c=c+1|0;if(z[a+480190>>1]>=(c&65535)>>>0){continue}break}}if(u&1){x[114409]=0;c=O(2,d+104|0,12503)|0;e=x[114409];x[114409]=0;if((e|0)==1){break X}x[114409]=0;T(655,a|0,2,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break W}xb(c)}x[114409]=0;c=O(628,b|0,2044)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Z}if(c){x[114409]=0;c=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Z}x[114409]=0;Z(584,a+1304424|0,b|0,c|0,0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Z}f=f|16}x[114409]=0;k=O(628,b|0,9870)|0;c=x[114409];x[114409]=0;if((c|0)==1){break I}if(k){x[114409]=0;c=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break I}x[114409]=0;e=a+901404|0;U(1094,b|0,e|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break I}x[114409]=0;V(642,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break I}f=f|16}x[114409]=0;c=O(628,b|0,9651)|0;e=x[114409];x[114409]=0;if((e|0)==1){break I}if(c){x[114409]=0;c=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break V}w[d+192>>1]=c>>>5;e=a+484344|0;c=Ne(e);x[114409]=0;w[d+156>>1]=c;c=O(457,d+192|0,d+156|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break U}m=z[c>>1];if(m){c=0;while(1){x[114409]=0;U(891,b|0,d+192|0,32)|0;h=x[114409];x[114409]=0;if((h|0)==1){break T}h=Zb(e,c);x[114409]=0;O(892,h|0,d+192|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break T}c=c+1|0;if((m|0)!=(c|0)){continue}break}}f=f|16}x[114409]=0;c=O(628,b|0,9656)|0;e=x[114409];x[114409]=0;if((e|0)==1){break I}if(c){x[114409]=0;c=S(413,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break S}w[d+192>>1]=(c>>>0)/20;c=z[a+480188>>1];x[114409]=0;w[d+156>>1]=c;c=O(457,d+192|0,d+156|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break R}c=z[c>>1];if(c){e=0;while(1){x[114409]=0;U(644,b|0,((e<<5)+a|0)+480289|0,20)|0;m=x[114409];x[114409]=0;if((m|0)==1){break N}e=e+1|0;if((c|0)!=(e|0)){continue}break}}f=f|16}x[114409]=0;c=O(231,b|0,8)|0;e=x[114409];x[114409]=0;if((e|0)==1){break I}if(c){c=x[b+8>>2];x[114409]=0;O(645,a|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break M}f=(c|0)==x[b+8>>2]?f:f|16}if(!(f&16)){break O}if(!(f&4)){break P}x[a+1074308>>2]=17367040;x[114409]=0;c=O(2,d+192|0,10231)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Q}Eb(l,c);xb(c);break O}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;xb(c);break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}if(!(f&2)){break O}x[a+1074308>>2]=18219008;x[114409]=0;c=O(2,d+192|0,10370)|0;e=x[114409];x[114409]=0;if((e|0)==1){break L}Eb(l,c);xb(c)}$:{if((y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))==1852141647&(y[j+4|0]|y[j+5|0]<<8|(y[j+6|0]<<16|y[j+7|0]<<24))==542396493){x[114409]=0;f=U(1095,d+156|0,d+526|0,12)|0;c=x[114409];x[114409]=0;aa:{ba:{ca:{if((c|0)!=1){x[114409]=0;T(13,d+92|0,1,f|0);c=x[114409];x[114409]=0;if((c|0)==1){break ca}x[114409]=0;e=S(1096,d+92|0)|0;j=x[114409];x[114409]=0;c=1;if((j|0)==1){break ba}x[a+1074308>>2]=e;xb(d+92|0);x[a+1074372>>2]=A[a+1074308>>2]<19007257?4:5;xb(f);e=a+1074308|0;f=24;break $}e=N()|0;break l}e=N()|0;break aa}e=N()|0;xb(d+92|0)}xb(f);break l}if(!(!x[a+1074308>>2]|f&8)){x[a+1074372>>2]=0;zu(a+1074312|0)}e=a+1074308|0;c=1;if(!(f&32)){break $}x[a+1074372>>2]=5;if(!k){x[114409]=0;V(643,a+901404|0);c=x[114409];x[114409]=0;if((c|0)==1){break I}}c=0;if((y[d+538|0]|y[d+539|0]<<8)>>>0<260){break $}x[114409]=0;U(458,a+1074312|0,4,1)|0;j=x[114409];x[114409]=0;if((j|0)==1){break I}}da:{if(!Yc(l)){break da}if(!(!(f&256)|s&255|i+1>>>0>1)){x[114409]=0;c=O(2,d+92|0,4497)|0;i=x[114409];x[114409]=0;if((i|0)!=1){Eb(l,c);xb(c);break da}e=N()|0;break l}if(!c){x[114409]=0;c=O(2,d+92|0,7913)|0;i=x[114409];x[114409]=0;if((i|0)!=1){Eb(l,c);xb(c);break da}e=N()|0;break l}x[114409]=0;c=O(2,d+92|0,5662)|0;i=x[114409];x[114409]=0;if((i|0)==1){break K}Eb(l,c);xb(c)}v[d+75|0]=0;ea:{if(z[a+480192>>1]){x[114409]=0;c=O(661,a|0,b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break ea}v[d+75|0]=c}x[114409]=0;W(662,a|0,b|0,1,d+75|0);b=x[114409];x[114409]=0;if((b|0)==1){break ea}if(!(!y[d+75|0]|A[e>>2]>=18284544)){x[e>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{b=x[e>>2];if(b>>>0>=18284544){x[114409]=0;b=O(2,d+60|0,13386)|0;c=x[114409];x[114409]=0;if((c|0)==1){break ta}x[114409]=0;P(1097,d+48|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break sa}x[114409]=0;T(3,d+80|0,b|0,d+48|0);c=x[114409];x[114409]=0;if((c|0)==1){break ra}c=d+80|0;Eb(l,c);xb(c);xb(d+48|0);xb(b);b=x[e>>2]}ua:{if(!b|A[e>>2]>=19005954){break ua}x[114409]=0;b=a+484344|0;c=O(414,b|0,254)|0;i=x[114409];x[114409]=0;if((i|0)==1){break ea}if(!c){c=Wb(q);x[114409]=0;P(1098,c|0,254);c=x[114409];x[114409]=0;if((c|0)==1){break ea}}x[114409]=0;b=O(414,b|0,255)|0;c=x[114409];x[114409]=0;if((c|0)==1){break ea}if(b){break ua}b=Wb(q);x[114409]=0;c=$(989)|0;i=x[114409];x[114409]=0;if((i|0)==1){break ea}x[114409]=0;T(1099,b|0,255,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break ea}}x[114409]=0;b=O(2,d+36|0,10859)|0;c=x[114409];x[114409]=0;if((c|0)==1){break pa}x[114409]=0;P(192,d+48|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break oa}x[d+32>>2]=y[d+539|0];c=y[d+538|0];x[114409]=0;x[d+16>>2]=c;P(669,d+20|0,d+16|0);c=x[114409];x[114409]=0;if((c|0)==1){break na}x[114409]=0;W(654,d+80|0,d+48|0,d+32|0,d+20|0);c=x[114409];x[114409]=0;if((c|0)==1){break ma}c=a+1304436|0;i=d+80|0;Eb(c,i);xb(i);xb(d+20|0);Gb(d+48|0);xb(b);Eb(a+1304460|0,l);x[a+1304496>>2]=B?7:x[a+1074308>>2]?7:4;if(!y[d+455|0]){break ga}Eb(a+1304472|0,c);x[114409]=0;b=O(2,d+80|0,11111)|0;i=x[114409];x[114409]=0;if((i|0)==1){break ja}Eb(c,b);xb(b);x[114409]=0;b=O(2,d+48|0,6082)|0;c=x[114409];x[114409]=0;if((c|0)==1){break ia}Eb(a+1304448|0,b);xb(b);x[114409]=0;c=O(2,d+20|0,6083)|0;b=x[114409];x[114409]=0;if((b|0)==1){break ha}Eb(a+1304484|0,c);break fa}e=N()|0;break l}e=N()|0;break qa}e=N()|0;xb(d+48|0)}xb(b);break l}e=N()|0;break l}e=N()|0;break ka}e=N()|0;break la}e=N()|0;xb(d+20|0)}Gb(d+48|0)}xb(b);break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}x[114409]=0;c=O(2,d+80|0,6083)|0;b=x[114409];x[114409]=0;if((b|0)==1){break J}Eb(a+1304448|0,c)}xb(c);zP(g);xb(l);break b}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0}zP(g);break c}e=N()|0}xb(l);Q(e|0);p()}e=1}hb=d+560|0;return e|0}function Mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,V=0,W=0,X=0;e=hb-480|0;hb=e;Nc(b);n=hb-16|0;hb=n;k=n+8|0;h=e+276|0;NP(k,h);f=Fb(k);k=nc(b,ac(n,k));if((f|0)==(k|0)){cc(b,Fb(n+8|0))}hb=n+16|0;n=(f|0)==(k|0);if(!n){OP(h)}a:{if(!n){break a}if(!WP(e+276|0)){break a}if(!c){d=1;break a}Pd(a,134217728);n=Vb(e+264|0,11316);x[114409]=0;P(192,e+4|0,n|0);d=x[114409];x[114409]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){x[114409]=0;T(1045,e+112|0,e+4|0,e+280|0);d=x[114409];x[114409]=0;if((d|0)==1){break q}d=e+112|0;Eb(a+1304436|0,d);xb(d);Gb(e+4|0);xb(n);d=Vb(d,5095);Eb(a+1304448|0,d);xb(d);x[a+480188>>2]=4;x[a+1304496>>2]=2;d=y[e+412|0]|y[e+413|0]<<8;x[a+480196>>2]=(d<<8|d>>>8)&65535;d=y[e+416|0]|y[e+417|0]<<8;d=VP((d<<8|d>>>8)&65535);x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=d;Uj(Wb(a+484360|0),e+284|0,y[e+282|0],65535,65535);r=a+480190|0;n=hb-16|0;hb=n;d=e+252|0;x[d>>2]=0;x[d+4>>2]=0;x[114409]=0;x[n+12>>2]=0;U(1059,d+8|0,n+12|0,n+11|0)|0;k=x[114409];x[114409]=0;r:{if((k|0)!=1){hb=n+16|0;break r}R(0)|0;zb();p()}n=d;q=pm(e+240|0);if(y[e+476|0]|y[e+477|0]<<8){break o}break n}d=N()|0;break p}d=N()|0;Gb(e+4|0)}xb(n);break d}k=0;while(1){x[114409]=0;d=S(464,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}w[e+220>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}d=y[e+478|0]|y[e+479|0]<<8;if((y[e+280|0]|y[e+281|0]<<8)!=512){d=(d<<8|d>>>8)&65535}else{x[114409]=0;d=S(474,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break j}d=d-2|0}x[114409]=0;T(316,e+4|0,b|0,d|0);d=x[114409];x[114409]=0;s:{t:{u:{if((d|0)!=1){x[114409]=0;d=O(424,r|0,e+220|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break u}u=z[d>>1];w[a+480190>>1]=u;x[114409]=0;d=D(z[e+220>>1],104)+a|0;f=d+484380|0;P(472,f|0,1);h=x[114409];x[114409]=0;v:{if((h|0)==1){break v}h=y[e+280|0]|y[e+281|0]<<8;if(((h<<8|h>>>8)&65535)>>>0>1){break t}x[114409]=0;U(1046,e+4|0,d+484423|0,31)|0;h=x[114409];x[114409]=0;if((h|0)==1){break v}x[114409]=0;O(313,e+4|0,1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break v}x[114409]=0;U(1047,e+4|0,((z[e+220>>1]<<5)+a|0)+946304|0,30)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break s}}d=N()|0;break f}d=N()|0;break e}d=N()|0;break f}h=Xb(e+112|0);x[114409]=0;U(596,e+4|0,h|0,257)|0;g=x[114409];x[114409]=0;w:{x:{if((g|0)==1){break x}x[114409]=0;O(350,d+484423|0,h|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break x}x[114409]=0;O(313,e+4|0,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break x}x[114409]=0;U(596,e+4|0,h|0,31)|0;g=x[114409];x[114409]=0;if((g|0)==1){break x}x[114409]=0;O(348,((z[e+220>>1]<<5)+a|0)+946304|0,h|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break x}if(!(x[e+12>>2]&1)){break w}x[114409]=0;O(313,e+4|0,1)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break w}}d=N()|0;xb(h);break f}xb(h)}x[114409]=0;O(1048,e+4|0,e+112|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break m}x[114409]=0;P(1049,e+112|0,f|0);h=x[114409];x[114409]=0;if((h|0)==1){break m}if((y[e+280|0]|y[e+281|0]<<8)==512){v[d+484417|0]=y[e+130|0]<<3}y:{if(!(y[e+280|0]|y[e+281|0]<<8)){break y}x[114409]=0;P(364,q|0,u|0);h=x[114409];x[114409]=0;if((h|0)==1){break m}x[114409]=0;P(1050,n|0,u|0);h=x[114409];x[114409]=0;if((h|0)==1){break m}h=ud(n,z[e+220>>1]-1|0);Ac(h);SP(h);Vt(h);x[114409]=0;g=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}x[114409]=0;f=O(231,b|0,g<<3)|0;j=x[114409];x[114409]=0;if((j|0)==1){break g}if(!f){Ab(e+4|0);break c}x[114409]=0;P(1051,h|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break g}f=0;x[e+236>>2]=0;if(!g){if(!(y[d+484414|0]&2)){break y}f=x[d+484384>>2];x[e+228>>2]=f;d=x[d+484388>>2];x[114409]=0;x[e+232>>2]=d-f;P(1052,h|0,e+228|0);d=x[114409];x[114409]=0;if((d|0)!=1){break y}d=N()|0;break f}while(1){x[114409]=0;d=S(474,b|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break k}x[114409]=0;x[e+228>>2]=d;d=S(474,b|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break k}x[114409]=0;x[e+232>>2]=d;P(1052,h|0,e+228|0);d=x[114409];x[114409]=0;if((d|0)==1){break k}f=f+1|0;if(g>>>0>(f&65535)>>>0){continue}break}}Ab(e+4|0);k=k+1|0;d=y[e+476|0]|y[e+477|0]<<8;if((k&65535)>>>0<((d<<8|d>>>8)&65535)>>>0){continue}break}}B=128;if(y[e+280|0]|y[e+281|0]<<8){break l}x[114409]=0;B=S(464,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break l}d=N()|0;break e}d=N()|0;break f}d=a+480188|0;E=y[e+283|0];w[e+226>>1]=4;z:{A:{if(y[e+280|0]|y[e+281|0]<<8){h=x[b+8>>2];B:{if(!B){break B}while(1){x[114409]=0;k=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break A}if((k|0)==65535){break B}x[114409]=0;E=S(464,b|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break A}x[114409]=0;k=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break A}w[e+226>>1]=k;if(k>>>0>127){break c}x[114409]=0;k=O(424,d|0,e+226|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break A}w[d>>1]=z[k>>1];x[114409]=0;O(313,b|0,D(z[e+226>>1],E)<<2)|0;k=x[114409];x[114409]=0;if((k|0)==1){break A}o=o+1|0;if((o&65535)>>>0<B>>>0){continue}break}}x[114409]=0;O(229,b|0,h|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break z}}d=z[d>>1];x[114409]=0;G=O(1053,e+228|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){C:{if(!B){break C}K=a+484344|0;V=c&1;H=y[e+415|0];h=0;k=0;while(1){D:{if(!(y[e+280|0]|y[e+281|0]<<8)){f=z[e+226>>1];d=k;break D}x[114409]=0;d=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}if((d|0)==65535){break C}x[114409]=0;E=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}x[114409]=0;f=S(464,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break h}w[e+226>>1]=f}x[114409]=0;g=f&65535;F=E&65535;f=F<<2;g=O(231,b|0,D(g,f)|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break h}if(!g){break C}E:{F:{if(!V){break F}x[114409]=0;L=d&65535;d=U(378,K|0,L|0,F|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break h}if(!d){break F}if(!F){break E}s=0;while(1){d=Zb(K,L);x[114409]=0;j=O(477,d|0,s|0)|0;d=x[114409];x[114409]=0;G:{if((d|0)!=1){f=0;t=0;H:{I:{switch((H&3)-1|0){case 0:t=!(s&3);break H;case 1:t=!(s&1);break H;case 2:break I;default:break H}}t=(s&3)!=3}I=0;if(!z[e+226>>1]){break G}while(1){d=x[G>>2];x[114409]=0;P(594,e+220|0,b|0);g=x[114409];x[114409]=0;if((g|0)==1){break h}g=D(f,9)+d|0;d=e+220|0;l=ed(d);C=wf(d);i=fi(d);m=D(f,6)+j|0;v[m+1|0]=y[d|0];d=y[l|0];v[m|0]=d;i=y[i|0];v[m+5|0]=i;l=m+5|0;if(d){v[m|0]=d+25;v[g+8|0]=0;v[g|0]=0;v[g+1|0]=0;v[g+2|0]=0;v[g+3|0]=0;v[g+4|0]=0;v[g+5|0]=0;v[g+6|0]=0;v[g+7|0]=0;i=y[l|0]}o=i&255;C=y[C|0];J:{if(C>>>0>=240){d=(C&15)<<8|o;if(d){x[114409]=0;d=S(1054,d|0)|0;i=x[114409];x[114409]=0;K:{if((i|0)==1){break K}x[114409]=0;d=na(1055,+(+(d>>>0)*1e-4))|0;i=x[114409];x[114409]=0;if((i|0)==1){break K}v[l|0]=d;v[m+3|0]=17;break J}break h}v[m+3|0]=0;break J}J=o>>>4|0;M=o<<4;d=J|M;L:{switch(C|0){case 0:d=D(f,6)+j|0;if(i&255){v[d+3|0]=1;break J}v[d+3|0]=0;break J;case 1:v[(D(f,6)+j|0)+3|0]=2;break J;case 2:v[(D(f,6)+j|0)+3|0]=3;break J;case 3:x[114409]=0;v[e+216|0]=15;d=O(431,l|0,e+216|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[g|0]=y[d|0]|16;v[g+7|0]=0;v[g+1|0]=0;v[g+2|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 4:x[114409]=0;v[e+216|0]=15;d=O(431,l|0,e+216|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[g|0]=y[d|0]|32;v[g+7|0]=0;v[g+1|0]=0;v[g+2|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 5:v[g+7|0]=0;v[g+2|0]=0;v[g+1|0]=i;v[g|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 6:v[g+7|0]=0;v[g+2|0]=i;v[g|0]=0;v[g+1|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 7:v[(D(f,6)+j|0)+3|0]=23;h=0;break J;case 8:v[(D(f,6)+j|0)+3|0]=0;h=d;break J;case 9:v[(D(f,6)+j|0)+3|0]=19;x[114409]=0;v[e+216|0]=15;d=O(431,l|0,e+216|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[l|0]=y[d|0]|16;break J}break h;case 10:v[(D(f,6)+j|0)+3|0]=19;x[114409]=0;v[e+216|0]=15;d=O(431,l|0,e+216|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[l|0]=y[d|0]|32;break J}break h;case 11:v[g+3|0]=d;v[(D(f,6)+j|0)+3|0]=0;break J;case 12:d=D(f,6)+j|0;v[d+4|0]=i;v[d+2|0]=1;v[g+3|0]=0;v[d+3|0]=0;break J;case 13:M:{N:{if((i&255)>>>0>=16){v[(D(f,6)+j|0)+2|0]=4;i=(i&240)>>>4|0;break N}if(!(o&15)){break M}v[(D(f,6)+j|0)+2|0]=3}v[(D(f,6)+j|0)+4|0]=i}v[g+3|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 14:v[(D(f,6)+j|0)+3|0]=19;v[l|0]=!(i&255);break J;case 15:v[(D(f,6)+j|0)+3|0]=16;v[l|0]=(i&240)>>>4;H=i&15;break J;case 16:v[g+5|0]=0;v[g+4|0]=i;v[(D(f,6)+j|0)+3|0]=0;break J;case 17:v[g+6|0]=o&15?i:0;v[(D(f,6)+j|0)+3|0]=0;break J;case 18:v[(D(f,6)+j|0)+3|0]=14;break J;case 19:v[g+8|0]=0;v[g+7|0]=i;v[g+2|0]=0;v[g|0]=0;v[g+1|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 20:v[(D(f,6)+j|0)+3|0]=12;break J;case 22:O:{d=y[m+1|0];P:{if(!d){break P}if(Ac(n)>>>0<d>>>0){break P}d=ud(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;x[114409]=0;O(1056,e+112|0,0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break h}x[e+216>>2]=9;d=Ac(d);x[114409]=0;x[e+108>>2]=d;d=O(36,e+216|0,e+108|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break O}if(A[d>>2]<=(i&255)>>>0){break P}d=D(f,6)+j|0;v[d+2|0]=15;v[d+4|0]=y[l|0]}v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 23:d=y[m+1|0];Q:{if(!d){break Q}if(Ac(n)>>>0<d>>>0){break Q}d=ud(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;if(Ac(d)>>>0<=(i&255)>>>0){break Q}R:{if(z[ud(d,y[l|0])+8>>1]){break R}if(!ho(a)){break R}i=z[r>>1]+1|0;w[r>>1]=i;W=ud(d,y[l|0]),X=i,w[W+8>>1]=X}W=m,X=y[ud(d,y[l|0])+8|0],v[W+1|0]=X}v[(D(f,6)+j|0)+3|0]=0;break J;case 24:S:{d=y[m+1|0];T:{if(!d){break T}if(Ac(n)>>>0<d>>>0){break T}d=ud(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;x[114409]=0;O(1056,e+4|0,0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break h}x[e+216>>2]=9;d=Ac(d);x[114409]=0;x[e+108>>2]=d;d=O(36,e+216|0,e+108|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break S}if(A[d>>2]>(i&255)>>>0){d=D(f,6)+j|0;v[d+2|0]=15;v[d+4|0]=y[l|0]}U:{if(z[vc(q,y[m+1|0]-1|0)>>1]){break U}if(!ho(a)){break U}d=z[r>>1]+1|0;w[r>>1]=d;W=vc(q,y[m+1|0]-1|0),X=d,w[W>>1]=X}W=m,X=y[vc(q,y[m+1|0]-1|0)|0],v[W+1|0]=X}v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 25:d=y[m+1|0];V:{if(!d){break V}if(Ac(n)>>>0<d>>>0){break V}d=ud(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;if(Ac(d)>>>0<=(i&255)>>>0){break V}W:{if(z[ud(d,y[l|0])+10>>1]){break W}if(!ho(a)){break W}i=z[r>>1]+1|0;w[r>>1]=i;W=ud(d,y[l|0]),X=i,w[W+10>>1]=X}W=m,X=y[ud(d,y[l|0])+10|0],v[W+1|0]=X}v[(D(f,6)+j|0)+3|0]=0;break J;case 29:v[(D(f,6)+j|0)+3|0]=11;v[l|0]=d;if(o&15){v[l|0]=M|15;break J}if((i&255)>>>0<16){break J}v[l|0]=J|240;break J;case 32:if((i&255)>>>0>=16){v[g+3|0]=J;v[(D(f,6)+j|0)+3|0]=0;break J}v[(D(f,6)+j|0)+3|0]=19;v[l|0]=i|192;break J;case 33:v[(D(f,6)+j|0)+3|0]=19;x[114409]=0;v[e+216|0]=15;d=O(431,l|0,e+216|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[l|0]=y[d|0]|208;break J}break h;case 34:v[(D(f,6)+j|0)+3|0]=19;x[114409]=0;v[e+216|0]=15;d=O(431,l|0,e+216|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[l|0]=y[d|0]|144;break J}break h;case 73:v[(D(f,6)+j|0)+3|0]=10;break J;case 78:if((i&112|128)==224){v[(D(f,6)+j|0)+3|0]=19;break J}v[(D(f,6)+j|0)+3|0]=0;break J;case 79:d=D(f,6)+j|0;if((i&255)>>>0<=31){v[d+3|0]=16;H=0;break J}v[d+3|0]=17;break J;default:break L}}v[(D(f,6)+j|0)+3|0]=0}o=0;i=y[g+3|0];if(!(y[m+2|0]|!i)){X:{if(i>>>0>=16){v[m+2|0]=5;i=i>>>4|0;break X}v[m+2|0]=6}v[m+4|0]=i;o=1}Y:{if(y[m+3|0]){break Y}d=y[g+1|0];Z:{if(d){v[m+3|0]=2;break Z}d=y[g+2|0];if(d){v[m+3|0]=3;break Z}d=y[g|0];if(d){v[m+3|0]=19;break Z}d=y[g+7|0];if(d){v[m+3|0]=4;v[g+8|0]=d;break Z}d=y[g+4|0];if(d){v[m+3|0]=5;v[g+5|0]=d;break Z}d=y[g+3|0];if(!(!d|o)){v[m+3|0]=11;v[l|0]=d;if(d&15){d=d|-16;break Z}if(d>>>0<16){break Y}d=d|15;break Z}d=y[g+6|0];if(d){v[m+3|0]=8;break Z}if(t){v[m+3|0]=20;t=0;d=97;break Z}t=0;d=h&255;if(!d|I){break Y}v[m+3|0]=24;v[l|0]=h;if(h&15){d=h|-16}else{I=1;if(d>>>0<16){break Y}d=h|15}I=1}v[l|0]=d}f=f+1|0;if(f>>>0<z[e+226>>1]){continue}break}break G}break h}s=s+1|0;if((F|0)!=(s|0)){continue}break}break E}x[114409]=0;O(313,b|0,D(f,z[e+226>>1])|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break E}break h}k=k+1|0;if((k&65535)>>>0<B>>>0){continue}break}}x[a+480228>>2]=256/z[a+480188>>1];x[114409]=0;P(421,a|0,1);d=x[114409];x[114409]=0;if((d|0)==1){break h}if(y[e+280|0]|y[e+281|0]<<8){_:{while(1){x[114409]=0;d=O(231,b|0,2)|0;k=x[114409];x[114409]=0;if((k|0)==1){break h}if(!d){break _}x[114409]=0;d=S(464,b|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break h}if((d|0)==65535){break _}x[114409]=0;O(313,b|0,2)|0;d=x[114409];x[114409]=0;if((d|0)==1){break h}x[114409]=0;d=S(474,b|0)|0;k=x[114409];x[114409]=0;if((k|0)!=1){x[114409]=0;O(313,b|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}}break}break h}x[114409]=0;O(313,b|0,34)|0;d=x[114409];x[114409]=0;if((d|0)==1){break h}}$:{if(!(!(c&2)|!u)){d=1;k=1;while(1){c=(D(d,104)+a|0)+484380|0;aa:{if(!x[c>>2]){break aa}h=cd(e+220|0,8,1,0,0);x[114409]=0;U(376,h|0,c|0,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break $}if(Ac(n)>>>0<d>>>0){break aa}d=d-1|0;h=ud(n,d);x[114409]=0;P(1057,c|0,h|0);h=x[114409];x[114409]=0;ba:{if((h|0)!=1){if(!z[vc(q,d)>>1]){break ba}h=z[vc(q,d)>>1];f=x[c>>2];x[114409]=0;ba(1058,c|0,(D(h,104)+a|0)+484380|0,0,f|0,0);h=x[114409];x[114409]=0;if((h|0)!=1){break ba}}break h}d=ud(n,d);W=e,X=bc(d),x[W+220>>2]=X;W=e,X=dc(d),x[W+216>>2]=X;if(!Hb(e+220|0,e+216|0)){break aa}while(1){d=x[e+220>>2];h=z[d+8>>1];if(h){f=x[d+4>>2];g=x[d>>2];x[114409]=0;ba(1058,c|0,(D(h,104)+a|0)+484380|0,g|0,f|0,1);h=x[114409];x[114409]=0;if((h|0)==1){break h}}h=z[d+10>>1];if(h){f=x[d+4>>2];d=x[d>>2];x[114409]=0;ba(1058,c|0,(D(h,104)+a|0)+484380|0,d|0,f|0,0);d=x[114409];x[114409]=0;if((d|0)==1){break h}}d=e+220|0;dk(d);if(Hb(d,e+216|0)){continue}break}}k=k+1|0;d=k&65535;if(u>>>0>=d>>>0){continue}break}}UP(G);d=1;break b}break h}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}d=N()|0;break f}d=N()|0;break e}d=N()|0;break e}d=N()|0;UP(G);break e}d=N()|0}Ab(e+4|0)}vf(q);TP(n)}Q(d|0);p()}d=0}vf(q);TP(n)}hb=e+480|0;return d|0}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-320|0;hb=d;Nc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!_t(b,d+224|0)){break h}if(!dQ(d+224|0)){break h}if(!Qb(b,id(cQ(d+224|0),lb))){break h}if(!c){t=1;break h}Pd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;k=gd(d+212|0);i:{j:{k:{l:{m:{n:{o:{switch(((y[d+264|0]|y[d+265|0]<<8)&61440)-4096>>>12|0){case 0:p:{if(y[d+286|0]|y[d+287|0]<<8|(y[d+264|0]|y[d+265|0]<<8)!=4896|(y[d+276|0]|y[d+256|0]&15)){break p}if((y[d+262|0]|y[d+263|0]<<8)&65455){break p}q:{if(v[d+275|0]<0){x[a+1074308>>2]=18219008;x[114409]=0;f=O(2,d+200|0,10301)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break q}e=N()|0;break a}x[a+1074308>>2]=16777216;x[114409]=0;f=O(2,d+200|0,9209)|0;e=x[114409];x[114409]=0;if((e|0)==1){break n}}Eb(k,f);xb(f);x[114409]=0;e=1;U(458,a+1074312|0,81,1)|0;g=x[114409];x[114409]=0;f=1;if((g|0)!=1){break i}break b}r:{if(y[d+286|0]|y[d+287|0]<<8|(y[d+264|0]|y[d+265|0]<<8)!=4896|(y[d+276|0]|(y[d+262|0]|y[d+263|0]<<8))){break r}if(y[d+277|0]){break r}x[114409]=0;f=O(2,d+200|0,5433)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Eb(k,f);break j}e=N()|0;break a}x[114409]=0;e=O(2,d+200|0,4713)|0;j=x[114409];x[114409]=0;h=1;if((j|0)!=1){Eb(k,e);xb(e);break k}e=N()|0;break a;case 1:x[114409]=0;e=O(2,d+200|0,3098)|0;j=x[114409];x[114409]=0;f=1;if((j|0)!=1){Eb(k,e);xb(e);break k}e=N()|0;break a;case 2:s:{t:{u:{v:{w:{g=y[d+264|0]|y[d+265|0]<<8;x:{if(g>>>0<=12820){x[114409]=0;f=O(2,d+200|0,4760)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Eb(k,f);break x}e=N()|0;break a}x[114409]=0;f=O(2,d+188|0,11356)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}x[114409]=0;P(192,d+200|0,f|0);e=x[114409];x[114409]=0;if((e|0)==1){break v}e=y[d+264|0]|y[d+265|0]<<8;x[114409]=0;x[d+176>>2]=e-12820;T(218,d+32|0,d+200|0,d+176|0);e=x[114409];x[114409]=0;if((e|0)==1){break u}e=d+32|0;Eb(k,e);xb(e);Gb(d+200|0)}xb(f);if((y[d+264|0]|y[d+265|0]<<8)>>>0<12807){break l}if(y[d+280|0]|y[d+281|0]<<8|(y[d+282|0]<<16|y[d+283|0]<<24)){break s}break l}e=N()|0;break a}e=N()|0;break t}e=N()|0;Gb(d+200|0)}xb(f);break a}f=y[d+264|0]|y[d+265|0]<<8;e=y[d+280|0]|y[d+281|0]<<8|(y[d+282|0]<<16|y[d+283|0]<<24);x[114409]=0;f=O(670,f|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}e=Hq(d+32|0);x[e+44>>2]=f;x[114409]=0;P(671,a+1304500|0,e|0);f=x[114409];x[114409]=0;if((f|0)!=1){break l}e=N()|0;break a;case 3:if((y[d+264|0]|y[d+265|0]<<8)==16640){x[114409]=0;h=O(2,d+200|0,4545)|0;j=x[114409];x[114409]=0;f=1;if((j|0)!=1){Eb(k,h);xb(h);x[114409]=0;U(458,a+1074312|0,81,1)|0;g=x[114409];x[114409]=0;h=0;j=0;if((g|0)==1){break b}break i}e=N()|0;break a}f=y[d+264|0]|y[d+265|0]<<8;h=y[d+278|0]|y[d+279|0]<<8;x[114409]=0;T(672,d+32|0,f|0,h|0);h=x[114409];x[114409]=0;f=1;if((h|0)!=1){h=d+32|0;Eb(k,h);xb(h);x[a+480260>>2]=1;g=y[d+264|0]|y[d+265|0]<<8;h=0;j=1;if((tT(16384)|0)>(g|0)){break i}x[114409]=0;U(458,a+1074312|0,38,1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}break i}e=N()|0;break a;case 4:if((y[d+264|0]|y[d+265|0]<<8)!=21575){e=(y[d+264|0]|y[d+265|0]<<8)&4095;f=e<<16;if(e>>>0>=297){f=f|(y[d+278|0]|y[d+279|0]<<8)}x[a+1074308>>2]=f;x[114409]=0;f=O(2,d+200|0,13386)|0;e=x[114409];x[114409]=0;y:{z:{A:{if((e|0)!=1){x[114409]=0;P(215,d+176|0,a+1074308|0);e=x[114409];x[114409]=0;if((e|0)==1){break A}e=0;x[114409]=0;T(3,d+32|0,f|0,d+176|0);h=x[114409];x[114409]=0;if((h|0)==1){break z}h=d+32|0;Eb(k,h);xb(h);xb(d+176|0);break j}e=N()|0;break a}e=N()|0;break y}e=N()|0;xb(d+176|0)}xb(f);break a}x[114409]=0;f=O(2,d+200|0,4744)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Eb(k,f);break j}e=N()|0;break a;case 5:x[114409]=0;f=O(2,d+200|0,4545)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Eb(k,f);xb(f);x[114409]=0;U(458,a+1074312|0,81,1)|0;g=x[114409];x[114409]=0;f=0;h=0;if((g|0)==1){break b}break i}e=N()|0;break a;case 6:x[114409]=0;f=O(2,d+200|0,4571)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Eb(k,f);break j}e=N()|0;break a;default:break o}}if((y[d+264|0]|y[d+265|0]<<8)!=51712){break i}x[114409]=0;f=O(2,d+200|0,5246)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Eb(k,f);break j}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}x[114409]=0;e=a+1074312|0;U(458,e|0,23,1)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;U(458,e|0,38,1)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;f=1;U(458,e|0,107,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}x[a+480260>>2]=1;e=0;if(g>>>0>12820){break i}}x[114409]=0;j=O(2,d+164|0,10649)|0;e=x[114409];x[114409]=0;B:{C:{D:{E:{F:{if((e|0)!=1){x[114409]=0;P(192,d+176|0,j|0);e=x[114409];x[114409]=0;if((e|0)==1){break F}x[d+140>>2]=y[d+265|0]&15;e=y[d+264|0];x[114409]=0;x[d+124>>2]=e;P(669,d+152|0,d+124|0);e=x[114409];x[114409]=0;if((e|0)==1){break E}x[114409]=0;ba(1038,d+32|0,d+176|0,k|0,d+140|0,d+152|0);e=x[114409];x[114409]=0;if((e|0)==1){break D}e=d+32|0;Eb(k,e);xb(e);xb(d+152|0);Gb(d+176|0);xb(j);e=0;j=0;break i}e=N()|0;break a}e=N()|0;break B}e=N()|0;break C}e=N()|0;xb(d+152|0)}Gb(d+176|0)}xb(j);break a}xb(f);f=0;h=0}x[114409]=0;g=O(2,d+176|0,10682)|0;i=x[114409];x[114409]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((i|0)!=1){Eb(a+1304436|0,g);xb(g);x[114409]=0;g=O(2,d+152|0,6455)|0;i=x[114409];x[114409]=0;if((i|0)==1){break V}Eb(a+1304448|0,g);xb(g);Eb(a+1304460|0,k);x[a+1304496>>2]=x[a+1074308>>2]?7:4;if(f){x[114409]=0;f=a+1074312|0;O(459,f|0,77)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}x[114409]=0;O(459,f|0,78)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}x[114409]=0;O(459,f|0,79)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}x[114409]=0;O(459,f|0,80)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}x[114409]=0;O(459,f|0,82)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}x[114409]=0;O(459,f|0,96)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}}f=y[d+264|0]|y[d+265|0]<<8;g=f&61440;e=g>>>0<4097|(g|0)==12288&f>>>0<12820?e:1;x[114409]=0;f=a+901404|0;V(1039,f|0);g=x[114409];x[114409]=0;if((g|0)==1){break b}if(!e){x[114409]=0;V(643,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}}x[114409]=0;T(576,d+140|0,1,d+224|0);f=x[114409];x[114409]=0;if((f|0)==1){break U}x[114409]=0;P(370,d+32|0,d+140|0);f=x[114409];x[114409]=0;if((f|0)==1){break U}f=d+32|0;Eb(a+1304400|0,f);xb(f);if(y[d+262|0]&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(v[d+262|0]&1){x[a+480208>>2]=x[a+480208>>2]|131072}if(!(!(y[d+262|0]&64)&(y[d+264|0]|y[d+265|0]<<8)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}f=y[d+273|0];x[a+480196>>2]=f;if(!(!h|(f|0)!=255?f:0)){x[a+480196>>2]=6}x[a+480204>>2]=D(y[d+274|0],1e4);if(y[d+274|0]<=32){x[a+480204>>2]=h?125e4:32e4}f=y[d+272|0];x[114409]=0;v[d+32|0]=f;v[d+140|0]=64;f=O(431,d+32|0,d+140|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Q}f=y[f|0];x[a+480200>>2]=f<<2;if(!((y[d+264|0]|y[d+265|0]<<8)>>>0>4895|f)){x[a+480200>>2]=256}if((y[d+266|0]|y[d+267|0]<<8)!=1|y[d+275|0]>7){break S}f=y[d+275|0];x[114409]=0;x[d+32>>2]=(f<<4)+16;x[d+140>>2]=127;f=O(436,d+32|0,d+140|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break T}x[a+480228>>2]=x[f>>2];break R}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}if(!(y[d+275|0]!=2&y[d+275|0]!=18)){x[a+480228>>2]=32;break R}if(!(y[d+275|0]&127)){x[a+480228>>2]=48;break R}f=y[d+275|0];x[114409]=0;x[d+32>>2]=f&127;x[d+140>>2]=16;f=O(545,d+32|0,d+140|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break P}x[a+480228>>2]=x[f>>2]}n=x[a+1074308>>2]!=0|v[d+275|0]<0;if(!n){f=x[a+480228>>2];x[114409]=0;f=cg(761,vqa(f<<3|5,f>>>29|0,11,0),lb);e=x[114409];x[114409]=0;if((e|0)==1){break O}x[a+480228>>2]=f}x[a+480232>>2]=36;if(!(!j|(y[d+264|0]|y[d+265|0]<<8)>>>0>=19763)){x[a+480232>>2]=64}w[a+480188>>1]=4;j=Zc(d+136|0);e=0;while(1){x[114409]=0;f=(e<<5)+a|0;l=f+480280|0;V(403,l|0);g=x[114409];x[114409]=0;if((g|0)==1){break N}g=d+e|0;i=y[g+288|0];W:{if(y[g+288|0]==255){break W}w[a+480188>>1]=e+1;if(!n){break W}w[f+480284>>1]=i&8?204:51}if(v[g+288|0]<0){x[l>>2]=1024}if(((i&126)-16&255)>>>0<=13){w[f+480284>>1]=128;f=d+32|0;tl(f,j,e);le(f,1)}e=e+1|0;if((e|0)!=32){continue}break}if(!z[a+480188>>1]){w[a+480188>>1]=1}f=Wb(a+484360|0);e=y[d+256|0]|y[d+257|0]<<8;x[114409]=0;aa(580,f|0,b|0,e|0,255,254)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}r=Oq(d+140|0);f=y[d+258|0]|y[d+259|0]<<8;x[114409]=0;U(373,b|0,r|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}n=Oq(d+124|0);f=y[d+260|0]|y[d+261|0]<<8;x[114409]=0;U(373,b|0,n|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){if(y[d+277|0]==252){e=0;x[114409]=0;O(1040,b|0,d+32|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}while(1){g=(d+32|0)+e|0;f=y[g|0];X:{if(!(f&32)){break X}i=((e<<5)+a|0)+480284|0;if(h){f=d+20|0;tl(f,j,e);if(Ib(f)){break X}f=y[g|0]}w[i>>1]=(((f&15)<<8|8)>>>0)/15}e=e+1|0;if((e|0)!=32){continue}break}}f=y[d+258|0]|y[d+259|0]<<8;x[114409]=0;w[d+32>>1]=f;w[d+20>>1]=3999;f=O(457,d+32|0,d+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break M}f=z[f>>1];w[a+480190>>1]=f;if(f){f=c&2;j=d+80|0;e=0;while(1){g=vc(r,e);g=y[g|0]|y[g+1|0]<<8;x[114409]=0;g=O(229,b|0,g<<4)|0;i=x[114409];x[114409]=0;if((i|0)==1){break L}Y:{if(!g){break Y}x[114409]=0;g=O(1041,b|0,d+32|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break L}if(!g){break Y}x[114409]=0;g=e+1|0;i=(D(g,104)+a|0)+484380|0;T(1042,d+32|0,i|0,h|0);l=x[114409];x[114409]=0;if((l|0)==1){break L}x[114409]=0;T(576,d+8|0,1,j|0);l=x[114409];x[114409]=0;Z:{_:{$:{if((l|0)==1){break $}x[114409]=0;P(370,d+20|0,d+8|0);l=x[114409];x[114409]=0;if((l|0)==1){break $}x[114409]=0;O(348,((g<<5)+a|0)+946304|0,d+20|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break _}xb(d+20|0);if(!(y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24))|(!f|y[d+32|0]>1)){break Y}g=y[d+46|0];l=y[d+47|0];o=y[d+45|0];x[114409]=0;g=O(229,b|0,l<<12|g<<4|o<<20)|0;l=x[114409];x[114409]=0;if((l|0)==1){break Z}if(!g){break Y}g=y[d+266|0]|y[d+267|0]<<8;x[114409]=0;T(1043,d+20|0,d+32|0,(g|0)==1|0);g=x[114409];x[114409]=0;if((g|0)!=1){x[114409]=0;U(376,d+20|0,i|0,b|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break Y}}e=N()|0;break f}e=N()|0;break f}e=N()|0;xb(d+20|0);break f}e=N()|0;break f}e=e+1|0;if(e>>>0<z[a+480190>>1]){continue}break}}t=1;if(!(c&1)){break G}f=y[d+264|0]|y[d+265|0]<<8;c=y[d+260|0]|y[d+261|0]<<8;x[114409]=0;w[d+32>>1]=c;w[d+20>>1]=255;c=O(457,d+32|0,d+20|0)|0;e=x[114409];x[114409]=0;aa:{ba:{if((e|0)!=1){s=z[c>>1];x[114409]=0;c=a+484344|0;P(377,c|0,s|0);e=x[114409];x[114409]=0;if((e|0)==1){break ba}u=f>>>0<4896;if(s){break aa}l=0;o=0;break H}e=N()|0;break f}e=N()|0;break f}C=d+37|0;E=d+35|0;A=d+36|0;F=d+34|0;G=d+33|0;f=0;o=0;l=0;while(1){x[114409]=0;e=U(378,c|0,f&65535,64)|0;h=x[114409];x[114409]=0;if((h|0)==1){break K}ca:{if(!e){break ca}e=vc(n,f);if(!(y[e|0]|y[e+1|0]<<8)){break ca}e=vc(n,f);e=y[e|0]|y[e+1|0]<<8;x[114409]=0;e=O(229,b|0,e<<4)|0;h=x[114409];x[114409]=0;if((h|0)==1){break K}if(!e){break ca}x[114409]=0;O(313,b|0,2)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}j=0;e=Zb(c,f);x[114409]=0;h=O(477,e|0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break J}while(1){x[114409]=0;e=S(425,b|0)|0;g=x[114409];x[114409]=0;da:{ea:{if((g|0)!=1){q=e<<24>>24;if(q){break ea}if((j|0)==63){break ca}e=Zb(c,f);x[114409]=0;j=j+1|0;h=O(477,e|0,j|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break da}}e=N()|0;break f}g=q&31;e=D(g,6)+h|0;i=ei(d+32|0);g=g>>>0<z[a+480188>>1];B=g?e:i;m=q&255;if(m&32){x[114409]=0;P(452,d+20|0,b|0);i=x[114409];x[114409]=0;fa:{ga:{ha:{if((i|0)!=1){H=ed(d+20|0);i=y[d+20|0];if(i>>>0>239){break ha}i=Ku((D(i>>>4|0,12)+(i&15)|0)+13|0);break ga}e=N()|0;break f}ia:{switch(i-254|0){case 0:break ga;case 1:break ia;default:break fa}}i=0}v[B|0]=i}v[(g?e+1|0:G)|0]=y[H|0]}ja:{if(!(m&64)){break ja}x[114409]=0;m=S(425,b|0)|0;i=x[114409];x[114409]=0;ka:{if((i|0)!=1){i=g?e+2|0:F;m=m<<24>>24;v[d+20|0]=m;if((m|0)>-64){break ka}v[i|0]=2;v[(g?e+4|0:A)|0]=y[d+20|0]^128;break ja}e=N()|0;break f}v[i|0]=1;x[114409]=0;v[d+8|0]=64;i=O(431,d+20|0,d+8|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break I}v[(g?e+4|0:A)|0]=y[i|0]}if((q|0)>=0){break da}x[114409]=0;P(452,d+20|0,b|0);i=x[114409];x[114409]=0;la:{ma:{if((i|0)!=1){q=d+20|0;m=ed(q);i=g?e+3|0:E;v[i|0]=y[q|0];g=g?e+5|0:C;v[g|0]=y[m|0];Iz(B,0);na:{e=y[i|0];if((e|0)==20){if((y[g|0]&240)!=160){break da}if((y[d+264|0]|y[d+265|0]<<8)>>>0<4896){break na}e=y[i|0]}if((e|0)==10){break la}if((e|0)!=31){break da}e=y[g|0];if(e>>>0<=15){break ma}u=0;break da}v[g|0]=y[g|0]&15^136;break da}e=N()|0;break f}if(e>>>0<=7){o=o+1|0;break da}l=((e|0)!=8)+l|0;break da}if(y[g|0]|(y[d+264|0]|y[d+265|0]<<8)>>>0>4865){break da}v[i|0]=42}if(j>>>0<64){continue}break}}f=f+1|0;if((s|0)!=(f|0)){continue}break}break H}e=N()|0;break f}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}if(!u){break G}a=z[a+480188>>1];if((a|0)>(l+o|0)|(a|0)<=(l-o|0)){break G}f=Ne(c)-1&65535;a=0;e=0;if(Ne(c)>>>0>f>>>0){while(1){if(Ah(Ye(c,a))){b=bc(Ye(c,a));h=dc(Ye(c,a));a=hb-16|0;hb=a;x[a+8>>2]=h;x[a+12>>2]=b;if(Hb(a+12|0,a+8|0)){while(1){h=a+12|0;b=x[h>>2];if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}Sj(h);if(Hb(h,a+8|0)){continue}break}}hb=a+16|0}e=e+1|0;a=e&65535;if(f>>>0>=a>>>0){continue}break}}}Rj(n);Rj(r);xb(k)}hb=d+320|0;return t|0}e=N()|0}Rj(n);break d}e=N()|0}Rj(r);break a}e=N()|0;break a}e=N()|0}xb(k);Q(e|0);p()}function VH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;O=hb-144|0;hb=O;a:{b:{if(d>>>0<=e>>>0){E=x[f>>2]+e|0;P=g&4;M=P?-1:E+(d^-1)|0;C=M+1|0;if(!(C&M)){break b}}x[f>>2]=0;x[c>>2]=0;m=-3;break a}F=x[c>>2];u=F+b|0;G=x[a+60>>2];s=x[a+40>>2];j=x[a+36>>2];t=x[a+32>>2];l=x[a+56>>2];i=x[a+4>>2];k=b;q=e;m=-1;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{r=x[a>>2];switch(r|0){case 17:break i;case 21:break j;case 37:break k;case 34:break l;case 42:break p;case 41:break q;case 53:break r;case 52:break s;case 51:break t;case 38:break u;case 27:break v;case 26:break w;case 25:break x;case 24:break y;case 23:break z;case 18:break A;case 16:break B;case 14:break C;case 11:break D;case 9:break E;case 7:break F;case 6:break G;case 3:break H;case 32:break I;case 5:break J;case 2:break L;case 1:break M;case 0:break N;case 36:break e;case 39:break f;case 10:break g;case 35:break h;default:break c}}x[a+28>>2]=1;l=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=1;s=0;j=0;t=0;i=0;if(g&1){break M}break K}if((F|0)<=0){x[a>>2]=1;break d}x[a+8>>2]=y[b|0];k=b+1|0}if(k>>>0>=u>>>0){x[a>>2]=2;m=g&2?1:-4;break c}j=y[k|0];x[a+12>>2]=j;h=x[a+8>>2];n=(((j|h<<8)>>>0)%31|j&32)!=0|(h&15)!=8;j=1;k=k+1|0;if(!P){r=36;h=256<<(h>>>4);if(!(n|(h>>>0>32768|h>>>0>C>>>0))){break K}break e}r=36;if(n){break e}}h=0;break o}if((F|0)<=0){x[a>>2]=5;break d}H=i+8|0;k=b+1|0;l=y[b|0]<<i|l;h=2;break o}if((F|0)<=0){x[a>>2]=32;break d}i=i+8|0;k=b+1|0;B=j;break n}h=1;break o}h=4;break o}h=3;break o}h=7;break o}h=9;break o}h=10;break o}h=11;break o}h=12;break o}h=13;break o}h=14;break o}h=15;break o}h=16;break o}h=17;break o}h=8;break o}h=5;break o}h=6;break o}h=18;break o}o=2;break m}o=1;break m}O:while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:j=B;if(i>>>0>2){break Ca}h=1;continue;case 17:break ka;case 16:break la;case 15:break ma;case 14:break na;case 13:break oa;case 12:break pa;case 11:break qa;case 10:break ra;case 9:break sa;case 8:break ua;case 7:break va;case 6:break wa;case 5:break xa;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ja}}while(1){if(k>>>0>=u>>>0){x[a>>2]=3;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(i>>>0<3){continue}break}B=j}n=l&7;x[a+20>>2]=n;h=n>>>1|0;x[a+24>>2]=h;i=i-3|0;l=l>>>3|0;if(n>>>0>=2){break ta}H=i;break ia}i=H&-8;l=l>>>(H&7)|0;j=0;h=0;break ga}if(k>>>0<u>>>0){break ya}x[a>>2]=7;m=g&2?1:-4;break c}while(1){if(k>>>0>=u>>>0){x[a>>2]=6;m=g&2?1:-4;break c}l=y[k|0]<<i|l;h=i>>>0>4294967287;k=k+1|0;i=i+8|0;if(h){continue}break}h=1;break ga}v[(a+j|0)+10528|0]=y[k|0];k=k+1|0;h=2;break ga}while(1){if(k>>>0>=u>>>0){x[a>>2]=51;m=g&2?1:-4;break c}l=y[k|0]<<i|l;h=i>>>0>4294967287;k=k+1|0;i=i+8|0;if(h){continue}break}break S}if(q>>>0<E>>>0){v[q|0]=t;j=j-1|0;q=q+1|0;break T}m=2;r=52;break e}if(q>>>0<E>>>0){break ha}m=2;r=9;break e}if(k>>>0<u>>>0){n=E-q|0;h=u-k|0;h=h>>>0>n>>>0?n:h;h=h>>>0<j>>>0?h:j;j=j-h|0;q=sc(q,k,h)+h|0;k=h+k|0;break R}x[a>>2]=38;m=g&2?1:-4;break c}m=0;j=B;Ea:{switch(h-1|0){case 0:break Ea;case 2:break g;default:break fa}}x[a+44>>2]=288;x[a+48>>2]=32;h=a+3552|0;x[h>>2]=84215045;x[h+4>>2]=84215045;h=a+3560|0;x[h>>2]=84215045;x[h+4>>2]=84215045;h=a+3568|0;x[h>>2]=84215045;x[h+4>>2]=84215045;h=a+3576|0;x[h>>2]=84215045;x[h+4>>2]=84215045;Sb(a- -64|0,8,144);Sb(a+208|0,9,112);v[a+336|0]=7;v[a+337|0]=7;v[a+338|0]=7;v[a+339|0]=7;v[a+340|0]=7;v[a+341|0]=7;v[a+342|0]=7;v[a+343|0]=7;v[a+328|0]=7;v[a+329|0]=7;v[a+330|0]=7;v[a+331|0]=7;v[a+332|0]=7;v[a+333|0]=7;v[a+334|0]=7;v[a+335|0]=7;v[a+320|0]=7;v[a+321|0]=7;v[a+322|0]=7;v[a+323|0]=7;v[a+324|0]=7;v[a+325|0]=7;v[a+326|0]=7;v[a+327|0]=7;v[a+344|0]=8;v[a+345|0]=8;v[a+346|0]=8;v[a+347|0]=8;v[a+348|0]=8;v[a+349|0]=8;v[a+350|0]=8;v[a+351|0]=8;I=1;break X}while(1){if(k>>>0>=u>>>0){x[a>>2]=11;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;J=v[j+17374|0];if(i>>>0<J>>>0){continue}break}m=j;j=1;break Z}while(1){if(k>>>0>=u>>>0){x[a>>2]=14;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(i>>>0<3){continue}break}h=1;break Y}if(k>>>0>=u>>>0){x[a>>2]=16;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(i>>>0<15){break ea}break da}while(1){if(k>>>0>=u>>>0){x[a>>2]=18;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(s>>>0>i>>>0){continue}break}Q=t-16|0;h=3;break W}if(k>>>0>=u>>>0){x[a>>2]=23;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(i>>>0<15){break ca}break ba}if(q>>>0>=E>>>0){m=2;r=24;break e}v[q|0]=j;q=q+1|0;o=l;break V}while(1){if(k>>>0>=u>>>0){x[a>>2]=25;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(s>>>0>i>>>0){continue}break}h=3;break U}if(k>>>0>=u>>>0){x[a>>2]=26;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(i>>>0<15){break aa}break $}while(1){if(k>>>0>=u>>>0){x[a>>2]=27;m=g&2?1:-4;break c}l=y[k|0]<<i|l;k=k+1|0;i=i+8|0;if(s>>>0>i>>>0){continue}break}h=6;break U}if(q>>>0>=E>>>0){m=2;r=53;break e}v[q|0]=y[(G-t&M)+d|0];q=q+1|0;G=G+1|0;break _}h=2;continue}h=8;continue}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{switch(h|0){case 0:if(j>>>0>3){break Ia}if(!i){i=0;h=3;continue O}if(i>>>0>7){break Ga}h=4;continue O;case 1:v[(a+j|0)+10528|0]=l;i=i-8|0;l=l>>>8|0;break Fa;default:break Ja}}j=j+1|0;break Ha}j=z[a+10528>>1];if((j|0)==(z[a+10530>>1]^65535)){break T}break f}h=0;continue}h=1;continue}h=2;continue}}j=0;break Z}h=1;break W}h=2;break W}h=0;break U}h=1;break U}h=4;break U}h=5;break U}h=7;break U}while(1){Ka:{La:{Ma:{if(!j){if(m>>>0>2){break Ma}j=m;J=v[j+17374|0];if(J>>>0<=i>>>0){break Ka}h=9;continue O}j=m<<2;x[(j+a|0)+44>>2]=x[j+39344>>2]+((-1<<J^-1)&l);m=m+1|0;i=i-J|0;l=l>>>J|0;break La}j=0;Sb(a+7040|0,0,288);h=0;break Y}j=0;continue}j=1;continue}}while(1){Na:{Oa:{Pa:{if(!h){if(A[a+52>>2]<=j>>>0){break Pa}if(i>>>0>2){break Na}h=10;continue O}v[(y[j+39360|0]+a|0)+7040|0]=l&7;j=j+1|0;i=i-3|0;l=l>>>3|0;break Oa}x[a+52>>2]=19;I=x[a+24>>2];B=j;break X}h=0;continue}h=1;continue}}h=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(h|0){case 0:j=0;if((I|0)<0){o=l;j=B;break V}K=Sb(O,0,64);h=D(I,3488)+a|0;Sb(h+352|0,0,3200);F=h- -64|0;r=x[a+24>>2];C=x[((r<<2)+a|0)+44>>2];if(C){while(1){h=K+(y[j+F|0]<<2)|0;x[h>>2]=x[h>>2]+1;j=j+1|0;if((C|0)!=(j|0)){continue}break}}x[K+64>>2]=0;x[K+68>>2]=0;m=0;n=0;j=1;while(1){h=j<<2;j=j+1|0;h=x[h+K>>2];m=h+m<<1;x[(K- -64|0)+(j<<2)>>2]=m;n=h+n|0;if((j|0)!=16){continue}break};if(!((m|0)==65536|n>>>0<=1)){j=B;break h}if(C){h=-1;L=0;N=D(I,3488)+a|0;while(1){r=y[F+L|0];Za:{if(!r){break Za}n=(K- -64|0)+(r<<2)|0;j=x[n>>2];x[n>>2]=j+1;m=0;n=r;while(1){C=m<<1;m=C|j&1;j=j>>>1|0;n=n-1|0;if(n){continue}break}if(r>>>0<=10){if(m>>>0>1023){break Za}n=r<<9|L;j=1<<r;while(1){w[((m<<1)+N|0)+352>>1]=n;m=j+m|0;if(m>>>0<1024){continue}break}break Za}n=((m&1023)<<1)+N|0;j=w[n+352>>1];_a:{if(j){m=h;h=j;break _a}w[n+352>>1]=h;m=h-2|0}j=C>>>9|0;if(r>>>0>=12){while(1){j=j>>>1|0;n=(((j&1)+(h^-1)<<1)+N|0)+2400|0;h=w[n>>1];if(!h){w[n>>1]=m;h=m;m=h-2|0}r=r-1|0;if(r>>>0>11){continue}break}}w[(((j>>>1&1)+(h^-1)<<1)+N|0)+2400>>1]=L;h=m}L=L+1|0;r=x[a+24>>2];if(L>>>0<A[((r<<2)+a|0)+44>>2]){continue}break}}j=0;if((r|0)!=2){break Ra}break Va;case 1:h=w[(((l&1023)<<1)+a|0)+7328>>1];$a:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break $a}break Ua}if(i>>>0<11){break $a}m=10;while(1){h=w[(((l>>>m&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<0){n=m+2|0;m=m+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break Ua}}h=11;continue O;case 2:t=w[(((l&1023)<<1)+a|0)+7328>>1];if((t|0)>=0){break Xa}h=10;while(1){n=l>>>h|0;h=h+1|0;t=w[(((n&1)+(t^-1)<<1)+a|0)+9376>>1];if((t|0)<0){continue}break};break Wa;default:break Ya}}m=v[Q+13680|0]+((-1<<s^-1)&l)|0;i=i-s|0;l=l>>>s|0;n=a+j|0;Sb(n+10532|0,(t|0)==16?y[n+10531|0]:0,m);j=j+m|0;break Va}h=t>>>9|0;t=t&511}i=i-h|0;l=l>>>h|0;if(t>>>0>15){break Ta}v[(a+j|0)+10532|0]=t;j=j+1|0}n=x[a+48>>2];m=x[a+44>>2];h=n+m|0;if(h>>>0<=j>>>0){break Sa}if(i>>>0>14){break Ua}if((u-k|0)<=1){h=1;continue}l=y[k|0]<<i|y[k+1|0]<<i+8|l;i=i+16|0;k=k+2|0}h=2;continue}if(!((t|0)!=16|j)){j=0;t=16;break i}Q=t-16|0;s=v[Q+17365|0];if(s>>>0<=i>>>0){break Qa}h=12;continue O}if((h|0)!=(j|0)){break j}h=a+10532|0;sc(a- -64|0,h,m);sc(a+3552|0,h+m|0,n);r=x[a+24>>2];B=j}I=r-1|0;x[a+24>>2]=I;h=0;continue}h=3;continue}}h=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(h|0){case 0:h=w[(((l&1023)<<1)+a|0)+352>>1];qb:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break qb}break bb}if(i>>>0<11){break qb}m=10;while(1){h=w[(((l>>>m&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){n=m+2|0;m=m+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break bb}}h=13;continue O;case 1:j=w[(((l&1023)<<1)+a|0)+352>>1];if((j|0)>=0){break ob}h=10;while(1){n=l>>>h|0;h=h+1|0;j=w[(((n&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break};break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){l=u-k|0;if(!((E-q|0)>1&(l|0)>=4)){if(i>>>0>14){l=o;break bb}if((l|0)<=1){l=o;h=0;continue ab}l=y[k|0]<<i|y[k+1|0]<<i+8|o;i=i+16|0;k=k+2|0;break bb}if(i>>>0>14){h=k}else{o=(y[k|0]|y[k+1|0]<<8)<<i|o;i=i+16|0;h=k+2|0}j=w[(((o&1023)<<1)+a|0)+352>>1];rb:{if((j|0)<0){k=10;while(1){l=o>>>k|0;k=k+1|0;j=w[(((l&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break rb}k=j>>>9|0}i=i-k|0;l=o>>>k|0;if(j&256){k=h;break mb}if(!(i>>>0>14)){l=(y[h|0]|y[h+1|0]<<8)<<i|l;h=h+2|0;i=i+16|0}m=i;k=h;h=w[(((l&1023)<<1)+a|0)+352>>1];sb:{if((h|0)<0){o=10;while(1){n=l>>>o|0;o=o+1|0;h=w[(((n&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break sb}o=h>>>9|0}v[q|0]=j;i=m-o|0;o=l>>>o|0;if(!(h&256)){v[q+1|0]=h;q=q+2|0;continue}break}q=q+1|0;l=o;j=h;break mb}h=j>>>9|0;j=j&511}i=i-h|0;l=l>>>h|0;if(j>>>0>255){break mb}h=14;continue O}B=256;n=j&511;if((n|0)==256){break Q}h=n-257<<2;j=x[h+38832>>2];s=0;if(n-285>>>0<4294967276){break db}s=x[h+38960>>2];if(s>>>0>i>>>0){h=15;continue O}h=3;continue}if(!j){o=l;j=-1;break hb}j=j-1|0;h=18;continue O}i=i-s|0;o=l>>>s|0;t=((-1<<s^-1)&l)+t|0;break ib}h=w[(((l&1023)<<1)+a|0)+3840>>1];tb:{if((h|0)<0){s=10;while(1){n=l>>>s|0;s=s+1|0;h=w[(((n&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){continue}break}break tb}s=h>>>9|0;h=h&511}n=h<<2;t=x[n+39088>>2];i=i-s|0;l=l>>>s|0;s=0;if(h-30>>>0<4294967270){o=l;break ib}s=x[n+39216>>2];if(s>>>0<=i>>>0){break gb}h=17;continue O}G=q-d|0;if(!(!P|G>>>0>t-1>>>0)){l=o;break k}h=(G-t&M)+d|0;if((h>>>0<q>>>0?q:h)+j>>>0>E>>>0){l=o;h=7;continue}if(j>>>0>2){while(1){v[q|0]=y[h|0];v[q+1|0]=y[h+1|0];v[q+2|0]=y[h+2|0];h=h+3|0;q=q+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break hb}v[q|0]=y[h|0];if((j|0)!=1){v[q+1|0]=y[h+1|0]}q=j+q|0}h=2;continue}h=6;continue}h=w[(((l&1023)<<1)+a|0)+3840>>1];ub:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break ub}break cb}if(i>>>0<11){break ub}m=10;while(1){h=w[(((l>>>m&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){n=m+2|0;m=m+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break cb}}h=16;continue O}i=i-s|0;j=((-1<<s^-1)&l)+j|0;l=l>>>s|0}if(i>>>0>14){break cb}if((u-k|0)<=1){h=4;continue}l=l|(y[k|0]<<i|y[k+1|0]<<i+8);i=i+16|0;k=k+2|0}h=5;continue}h=1;continue}}if(!j|!i){break R}if(i>>>0>7){break S}h=5;continue}i=i-8|0;t=l&255;l=l>>>8|0;h=6;continue}if(j){break P}B=0}if(v[a+20|0]&1){break n}h=0;continue}h=7;continue}}i=i&-8;if(!(!i|b>>>0>=k>>>0)){l=i-8|0;j=l>>>3|0;d=(b^-1)+k|0;d=d>>>0>j>>>0?j:d;k=(d^-1)+k|0;i=l-(d<<3)|0}if(!i){l=0;n=0;h=0;j=B;i=0;if(!(g&1)){break l}o=0;break m}ea(3164,9027,2797,3174);p()}while(1){vb:{wb:{xb:{yb:{zb:{Ab:{switch(o|0){case 0:if(n>>>0>3){j=n;i=h;break l}i=0;if(h){break zb}j=n;o=1;continue;case 1:break Ab;default:break yb}}if(k>>>0<u>>>0){break wb}x[a>>2]=42;m=g&2?1:-4;break c}j=n;i=h;if(h>>>0>7){break xb}o=2;continue}while(1){if(k>>>0>=u>>>0){x[a>>2]=41;m=g&2?1:-4;break c}l=y[k|0]<<i|l;d=i>>>0>4294967287;k=k+1|0;h=i+8|0;i=h;if(d){continue}break}n=j}o=l&255;l=l>>>8|0;h=h-8|0;break vb}o=y[k|0];k=k+1|0;n=j;h=i}x[a+16>>2]=x[a+16>>2]<<8|o;n=n+1|0;o=0;continue}}m=0;r=34;break e}r=37;m=-1;break e}r=21;m=-1;break e}r=17;m=-1;break e}r=35;m=-1;break e}r=10;m=-1;break e}r=39;m=-1}x[a>>2]=r;if(!(i>>>0<8|b>>>0>=k>>>0)){B=i-8|0;h=B>>>3|0;d=(b^-1)+k|0;d=d>>>0>h>>>0?h:d;k=(d^-1)+k|0;i=B-(d<<3)|0}break c}m=g&2?1:-4}x[a+4>>2]=i;x[a+60>>2]=G;x[a+40>>2]=s;x[a+36>>2]=j;x[a+32>>2]=t;x[a+56>>2]=(((i&63)>>>0<32?-1<<i:0)^-1)&l;x[c>>2]=k-b;h=q-e|0;x[f>>2]=h;if(!(g&9)|(m|0)<0){break a}b=x[a+28>>2];k=b>>>16|0;i=b&65535;if(h){o=(h>>>0)%5552|0;while(1){j=0;if(o>>>0>=8){j=o&8184;l=0;while(1){H=y[e|0]+i|0;n=H+y[e+1|0]|0;B=n+y[e+2|0]|0;f=B+y[e+3|0]|0;d=f+y[e+4|0]|0;c=d+y[e+5|0]|0;b=c+y[e+6|0]|0;i=b+y[e+7|0]|0;k=i+(b+(c+(d+(f+(B+(n+(k+H|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;l=l+8|0;if((l|7)>>>0<o>>>0){continue}break}}if(j>>>0<o>>>0){b=o-j|0;l=e;while(1){i=y[l|0]+i|0;k=k+i|0;l=l+1|0;j=j+1|0;if((o|0)!=(j|0)){continue}break}e=b+e|0}h=h-o|0;k=(k>>>0)%65521|0;i=(i>>>0)%65521|0;o=5552;if(h){continue}break}}b=k<<16|i;x[a+28>>2]=b;if(m){break a}m=0;if(!(g&1)){break a}m=(b|0)!=x[a+16>>2]?-2:0}hb=O+144|0;return m}function xfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=E(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=0,R=0,S=0,T=0,U=E(0),V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=E(0);j=b;n=hb-17152|0;hb=n;x[n+17148>>2]=0;a:{b:{c:{if(y[a+6152|0]!=255|(c|0)<5){break c}if(!sp(a+6152|0,j)){break c}b=ox(j,x[a+6148>>2])+rp(j)|0;x[n+17148>>2]=b;if((b|0)==(c|0)){b=c;break b}d:{if((b+4|0)<=(c|0)){if(sp(j,b+j|0)){break d}}x[n+17148>>2]=0;break c}if(b){break b}}f=j;H=Sb(a,0,6668)+6148|0;r=n+17148|0;e:{if((c|0)>=5){N=c-4|0;while(1){if(RH(f)){q=ox(f,x[H>>2]);b=q+rp(f)|0;k=0;f:{g:{if(q){break g}g=4;m=h+4|0;while(1){if((N|0)<=((g<<1)+h|0)){break f}q=0;o=f+g|0;h:{if(!sp(f,o)){break h}l=g-rp(f)|0;L=rp(o)+l|0;if((L+(g+m|0)|0)>(c|0)){break h}if(!sp(f,o+L|0)){break h}x[H>>2]=l;q=l;b=g}k=!q;if(q){break g}l=g>>>0<2303;g=g+1|0;if(l){continue}break}}if((b+h|0)>(c|0)|k){break f}l=c-h|0;g=0;k=0;i:{while(1){p=g;g=f+g|0;g=(p+ox(g,q)|0)+rp(g)|0;p=(k|0)!=0;if((l|0)<(g+4|0)){break i}p=0;if(!sp(f,f+g|0)){break i}k=k+1|0;if((k|0)!=10){continue}break}p=1}if(p){break e}}if(!((b|0)!=(c|0)|h)){h=0;b=c;break e}x[H>>2]=0}f=f+1|0;h=h+1|0;if((N|0)!=(h|0)){continue}break}}b=0;h=c}x[r>>2]=b;b=x[n+17148>>2];f=h;if((f+b|0)<=(c|0)?b:0){break b}x[e>>2]=f;f=0;break a}s=f+j|0;x[a+6152>>2]=y[s|0]|y[s+1|0]<<8|(y[s+2|0]<<16|y[s+3|0]<<24);x[e+4>>2]=f;x[e>>2]=b+f;x[e+8>>2]=y[s+3|0]>191?1:2;_=e,$=UH(s),x[_+12>>2]=$;x[e+16>>2]=4-(y[s+1|0]>>>1&3);_=e,$=nx(s),x[_+20>>2]=$;if(!d){f=mx(s);break a}TH(n+17136|0,s+4|0,b-4|0);if(!(v[s+1|0]&1)){Vd(n+17136|0,16)}j:{if(x[e+16>>2]==3){f=0;o=n+17136|0;X=n+3728|0;b=X;g=0;l=y[s+1|0];c=D((l>>>3&1)+(l>>>4&1)|0,3)+(y[s+2|0]>>>2&3)|0;j=c-((c|0)!=0)|0;h=y[s+3|0]>191?1:2;k:{if(l&8){k=Vd(o,9);h=h<<1;g=Vd(o,h+7|0);break k}k=Vd(o,h|8)>>>h|0}c=D(j,40);r=c+39680|0;m=c+4e4|0;L=D(j,23)+39488|0;i=-1;H=0;l:{while(1){l=y[s+3|0];j=Vd(o,12);w[b+4>>1]=j;c=Vd(o,9);w[b+6>>1]=c;if((c&65535)>>>0>288){break l}q=l>>>0>191?g<<4:g;_=b,$=Vd(o,8),v[_+10|0]=$;c=Vd(o,y[s+1|0]&8?4:9);v[b+13|0]=22;v[b+14|0]=0;x[b>>2]=L;w[b+8>>1]=c;m:{if(Vd(o,1)){c=Vd(o,2);v[b+11|0]=c;if(!(c&255)){break l}c=Vd(o,1);w[b+18>>1]=65287;v[b+12|0]=c;if(y[b+11|0]==2){n:{if(!(c&255)){x[b>>2]=r;v[b+18|0]=8;g=0;c=39;break n}x[b>>2]=m;g=y[s+1|0]&8?8:6;c=30}v[b+14|0]=c;v[b+13|0]=g;q=q&3855}c=Vd(o,10);_=b,$=Vd(o,3),v[_+21|0]=$;_=b,$=Vd(o,3),v[_+22|0]=$;_=b,$=Vd(o,3),v[_+23|0]=$;g=c<<5;break m}v[b+11|0]=0;v[b+12|0]=0;g=Vd(o,15);_=b,$=Vd(o,4),v[_+18|0]=$;c=Vd(o,3);v[b+20|0]=255;v[b+19|0]=c}v[b+17|0]=g&31;v[b+15|0]=g>>>10;v[b+16|0]=g>>>5&31;H=(j&65535)+H|0;o:{if(y[s+1|0]&8){c=Vd(o,1);break o}c=z[b+8>>1]>499}v[b+24|0]=c;_=b,$=Vd(o,1),v[_+25|0]=$;c=Vd(o,1);v[b+27|0]=q>>>12&15;v[b+26|0]=c;b=b+28|0;g=q<<4;h=h-1|0;if(h){continue}break}i=(x[o+4>>2]+H|0)>(x[o+8>>2]+(k<<3)|0)?-1:k}if(!((i|0)<0|x[n+17140>>2]>x[n+17144>>2])){l=n+17136|0;h=x[l+4>>2];f=x[l+8>>2];c=n+900|0;g=x[a+6144>>2];b=g-i|0;j=(g|0)<(i|0)?g:i;g=sc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,j);b=(f-h|0)/8|0;sc(g+j|0,x[l>>2]+(x[l+4>>2]/8|0)|0,b);TH(c,g,b+j|0);V=x[a+6144>>2]>=(i|0);p:{if(!V){break p}Y=a+2304|0;f=x[e+8>>2];Z=n+8608|0;H=n+3840|0;b=1;h=0;while(1){N=Sb(H,0,4608);I=n+900|0;K=D(D(f,h),28)+X|0;q=0;L=f;if((f|0)>0){l=I+7548|0;W=a+6152|0;while(1){C=D(q,28)+K|0;o=z[C+4>>1];r=x[I+4>>2];f=(I+D(q,39)|0)+16156|0;j=hb-48|0;hb=j;p=D(!y[C+13|0]+(y[C+14|0]!=0)|0,28)+40320|0;O=y[C+25|0];q:{if(y[W+1|0]&8){i=y[C+27|0];h=y[z[C+8>>1]+40416|0];c=h&3;v[j+47|0]=c;v[j+46|0]=c;c=h>>>2|0;v[j+45|0]=c;v[j+44|0]=c;break q}c=(y[W+3|0]&16)>>>4&(q|0)!=0;h=c?12:0;i=z[C+8>>1]>>>c|0;while(1){k=1;g=3;while(1){c=g;m=y[(c+h|0)+40432|0];v[c+(j+44|0)|0]=((i|0)/(k|0)|0)%(m|0);k=D(k,m);g=c-1|0;if(c){continue}break}h=h+4|0;i=i-k|0;if((i|0)>=0){continue}break}p=h+p|0;i=-16}h=f;f=j;g=f+44|0;k=0;while(1){t=y[k+p|0];if(t){r:{if(i&8){sc(f,h,t);break r}A=y[g+k|0];if(!A){Sb(f,0,t);Sb(h,0,t);break r}c=(i|0)>=0?-1:-1<<A^-1;G=0;while(1){m=Vd(I,A);v[h+G|0]=(c|0)==(m|0)?-1:m;v[f+G|0]=m;G=G+1|0;if((t|0)!=(G|0)){continue}break}}i=i<<1;f=f+t|0;h=h+t|0;k=k+1|0;if((k|0)!=4){continue}}break}v[f+2|0]=0;v[f|0]=0;v[f+1|0]=0;m=y[C+14|0];s:{if(m){c=2-O|0;g=y[C+23|0]<<c;h=y[C+22|0]<<c;f=y[C+21|0]<<c;c=y[C+13|0];k=0;while(1){A=j+(c+k|0)|0;v[A|0]=f+y[A|0];v[A+1|0]=h+y[A+1|0];v[A+2|0]=g+y[A+2|0];k=k+3|0;if(m>>>0>k>>>0){continue}break}break s}if(!y[C+24|0]){break s}i=0;while(1){c=i+j|0;v[c+11|0]=y[c+11|0]+y[i+40456|0];i=i+1|0;if((i|0)!=10){continue}break}}F=lx(E(2048),((((y[W+3|0]&224)==96)<<1)-y[C+10|0]|0)+258|0);i=0;if((m|0)!=(0-y[C+13|0]|0)){c=O+1|0;while(1){_=l+(i<<2)|0,aa=lx(F,y[i+j|0]<<c),B[_>>2]=aa;i=i+1|0;if(i>>>0<y[C+14|0]+y[C+13|0]>>>0){continue}break}}hb=j+48|0;j=(I+D(q,2304)|0)+2940|0;g=l;A=o+r|0;u=E(0);h=0;c=x[I+4>>2];m=x[I>>2]+((c|0)/8|0)|0;f=y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24);f=(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))<<(c&7);i=c|-8;G=m+4|0;M=x[C>>2];J=z[C+6>>1];t:{if(!J){J=0;break t}while(1){c=h+C|0;m=y[c+15|0];T=(w[(m<<1)+44880>>1]<<1)+40496|0;R=y[c+18|0];u:{if(m>>>0>=16){o=y[m+44944|0];m=32-o|0;while(1){r=y[M|0]>>>1|0;Q=(r|0)>(J|0)?J:r;u=B[g>>2];while(1){p=w[T+(f>>>26&62)>>1];if((p|0)<0){c=5;while(1){i=c+i|0;f=f<<c;c=p&7;p=w[T+((f>>>32-c|0)-(p>>3)<<1)>>1];if((p|0)<0){continue}break}}c=p>>>8|0;i=c+i|0;f=f<<c;S=1;while(1){k=p&15;v:{if((k|0)==15){c=f<<o;k=(f>>>m|0)+15|0;i=i+o|0;if((i|0)>=0){while(1){c=y[G|0]<<i|c;f=i>>>0>7;i=i-8|0;G=G+1|0;if(f){continue}break}}P=E(u*E(c>>31|1));if((k|0)<=128){F=B[(k<<2)+45040>>2]}else{f=k>>>0<1024;t=f?k<<3:k;O=t<<1&64;F=E(E((t&63)-O|0)/E((t&-64)+O|0));F=E(E(E(E(E(E(F*E(.2222222238779068))+E(1.3333333730697632))*F)+E(1))*(f?E(16):E(256)))*B[(t+O>>6<<2)+45040>>2])}F=E(P*F);break v}c=f;F=E(B[(((c>>>27&16|k)^16)<<2)+44976>>2]*u)}B[j>>2]=F;p=p>>>4|0;j=j+4|0;f=(k|0)!=0;i=f+i|0;f=c<<f;c=S&1;S=0;if(c){continue}break}if((i|0)>=0){while(1){f=y[G|0]<<i|f;c=i>>>0>7;i=i-8|0;G=G+1|0;if(c){continue}break}}Q=Q-1|0;if(Q){continue}break}g=g+4|0;M=M+1|0;J=J-r|0;if((J|0)<=0){break u}c=(R|0)>0;R=R-1|0;if(c){continue}break}break u}while(1){r=y[M|0]>>>1|0;S=(r|0)>(J|0)?J:r;u=B[g>>2];while(1){c=w[T+(f>>>26&62)>>1];if((c|0)<0){p=5;while(1){i=i+p|0;f=f<<p;p=c&7;c=w[T+((f>>>32-p|0)-(c>>3)<<1)>>1];if((c|0)<0){continue}break}}m=c>>>8|0;i=m+i|0;f=f<<m;p=1;while(1){m=c&15;B[j>>2]=B[(((m|f>>>27&16)^16)<<2)+44976>>2]*u;c=c>>>4|0;j=j+4|0;m=(m|0)!=0;i=m+i|0;f=f<<m;m=p&1;p=0;if(m){continue}break}if((i|0)>=0){while(1){f=y[G|0]<<i|f;c=i>>>0>7;i=i-8|0;G=G+1|0;if(c){continue}break}}S=S-1|0;if(S){continue}break}g=g+4|0;M=M+1|0;J=J-r|0;if((J|0)<=0){break u}c=(R|0)>0;R=R-1|0;if(c){continue}break}}h=h+1|0;if((J|0)>0){continue}break}}p=1-J|0;while(1){w:{h=y[C+26|0]?44864:44832;c=y[h+(f>>>28|0)|0];if(!(c&8)){c=y[h+((f<<4>>>32-(c&3))+(c>>>3)|0)|0]}m=c&7;i=m+i|0;if(((i+(G-x[I>>2]<<3)|0)-24|0)>(A|0)){break w}p=p-1|0;if(!p){h=y[M|0];if(h>>>0<2){break w}p=h>>>1|0;M=M+1|0;u=B[g>>2];g=g+4|0}f=f<<m;if(c>>>0>=128){B[j>>2]=(f|0)<0?E(-u):u;i=i+1|0;f=f<<1}if(c&64){B[j+4>>2]=(f|0)<0?E(-u):u;i=i+1|0;f=f<<1}p=p-1|0;if(!p){h=y[M|0];if(h>>>0<2){break w}p=h>>>1|0;M=M+1|0;u=B[g>>2];g=g+4|0}if(c&32){B[j+8>>2]=(f|0)<0?E(-u):u;i=i+1|0;f=f<<1}if(c&16){B[j+12>>2]=(f|0)<0?E(-u):u;i=i+1|0;f=f<<1}if((i|0)>=0){while(1){f=y[G|0]<<i|f;c=i>>>0>7;i=i-8|0;G=G+1|0;if(c){continue}break}}j=j+16|0;continue}break}x[I+4>>2]=A;q=q+1|0;if((L|0)!=(q|0)){continue}break}}c=y[a+6155|0];x:{if(c&16){t=hb-16|0;hb=t;c=I+2940|0;h=c+2304|0;r=x[K>>2];m=y[K+14|0];q=y[K+13|0];A=m+q|0;f=0;o=t+4|0;x[o+8>>2]=-1;x[o>>2]=-1;x[o+4>>2]=-1;if(A){while(1){i=0;l=f+r|0;g=y[l|0];j=0;y:{if(!g){break y}z:{while(1){j=i<<2;if(B[j+h>>2]!=E(0)|B[(j|4)+h>>2]!=E(0)){break z}i=i+2|0;if(g>>>0>i>>>0){continue}break}j=g;break y}x[o+((f>>>0)%3<<2)>>2]=f;j=y[l|0]}h=((j&255)<<2)+h|0;f=f+1|0;if((A|0)!=(f|0)){continue}break}}if(q){h=x[t+4>>2];f=x[t+8>>2];h=(f|0)<(h|0)?h:f;f=x[t+12>>2];f=(f|0)<(h|0)?h:f;x[t+12>>2]=f;x[t+8>>2]=f;x[t+4>>2]=f}h=I+16195|0;O=a+6152|0;l=m?3:1;j=A-l|0;i=0;while(1){g=i+j|0;f=g-l|0;if((f|0)<=x[(t+4|0)+(i<<2)>>2]){f=y[O+1|0]<<28>>31&3}else{f=y[f+h|0]}v[g+h|0]=f;i=i+1|0;if((l|0)!=(i|0)){continue}break}r=w[K+36>>1]&1;q=0;g=x[K>>2];k=y[g|0];if(k){m=t+4|0;l=y[O+1|0]&8?7:64;f=g;while(1){o=y[O+3|0]&32;A:{B:{if(x[m+((q>>>0)%3<<2)>>2]>=(q|0)){break B}j=y[h+q|0];if(j>>>0>=l>>>0){break B}C:{if(y[O+1|0]&8){j=(j<<3)+45568|0;u=B[j>>2];P=B[j+4>>2];break C}F=lx(E(1),j+1>>>1<<r);j=j&1;P=j?E(1):F;u=j?F:E(1)}A=0;if(k){F=o?E(1.4142135381698608):E(1);U=E(u*F);F=E(P*F);while(1){j=(A<<2)+c|0;P=B[j>>2];B[j+2304>>2]=P*F;B[j>>2]=P*U;A=A+1|0;if((A|0)!=(k|0)){continue}break}}break A}if(!o){break A}QH(c,k)}c=(y[f|0]<<2)+c|0;q=q+1|0;f=g+q|0;k=y[f|0];if(k){continue}break}}hb=t+16|0;break x}if((c&224)!=96){break x}QH(I+2940|0,576)}if((L|0)>0){j=I+7708|0;q=0;while(1){c=y[a+6153|0];r=(y[K+12|0]!=0)<<1<<((D((c>>>3&1)+(c>>>4&1)|0,3)+(y[a+6154|0]>>>2&3)|0)==2);g=(I+D(q,2304)|0)+2940|0;p=g;if(y[K+14|0]){f=((I+D(q,2304)|0)+D(r,72)|0)+2940|0;h=j;k=x[K>>2]+y[K+13|0]|0;i=y[k|0];if(i){c=f;while(1){m=i<<1;Q=0;while(1){B[h>>2]=B[c>>2];B[h+4>>2]=B[(i<<2)+c>>2];l=m<<2;B[h+8>>2]=B[l+c>>2];c=c+4|0;h=h+12|0;Q=Q+1|0;if((Q|0)!=(i|0)){continue}break}c=c+l|0;i=y[k+3|0];k=k+3|0;if(i){continue}break}}sc(f,j,h-j|0);f=r-1|0}else{f=31}if((f|0)>0){while(1){i=0;while(1){c=i<<2;h=c+p|0;c=c+45632|0;u=B[c>>2];P=B[h+72>>2];U=B[c+32>>2];c=(17-i<<2)+p|0;F=B[c>>2];B[h+72>>2]=E(u*P)-E(U*F);B[c>>2]=E(U*P)+E(u*F);i=i+1|0;if((i|0)!=8){continue}break}p=p+72|0;c=(f|0)>1;f=f-1|0;if(c){continue}break}}c=g;f=D(q,1152)+a|0;h=y[K+11|0];if(r){PH(c,f,45696,r);f=D(r,36)+f|0;c=D(r,72)+c|0}D:{if((h|0)==2){o=hb-80|0;hb=o;i=32-r|0;if((i|0)>0){r=o|8;m=o|4;while(1){l=sc(o,c,72);h=x[f+20>>2];x[c+16>>2]=x[f+16>>2];x[c+20>>2]=h;h=x[f+12>>2];x[c+8>>2]=x[f+8>>2];x[c+12>>2]=h;h=x[f+4>>2];x[c>>2]=x[f>>2];x[c+4>>2]=h;h=f+24|0;kx(l,c+24|0,h);kx(m,c+48|0,h);kx(r,f,h);c=c+72|0;f=f+36|0;h=i>>>0>1;i=i-1|0;if(h){continue}break}}hb=o+80|0;break D}PH(c,f,D((h|0)==3,72)+45696|0,32-r|0)}f=0;h=g+72|0;while(1){c=1;while(1){g=(c<<2)+h|0;B[g>>2]=-B[g>>2];g=c>>>0<16;c=c+2|0;if(g){continue}break}h=h+144|0;c=f>>>0<30;f=f+2|0;if(c){continue}break}K=K+28|0;q=q+1|0;if((L|0)!=(q|0)){continue}break}}SH(Y,N,18,x[e+8>>2],d,Z);if(!(y[s+1|0]&8)){break p}f=x[e+8>>2];d=D(f,1152)+d|0;c=b&1;b=0;h=1;if(c){continue}break}}e=n+900|0;c=x[e+8>>2]>>>3|0;b=x[e+4>>2]+7>>>3|0;f=c-b|0;d=(f|0)>=511?511:f;if((f|0)>0){vk(a+6156|0,(e+(f>>>0>511?c-511|0:b)|0)+12|0,d)}x[a+6144>>2]=d;break j}px(a);break a}r=n+17136|0;g=0;f=0;k=0;H=0;E:{F:{G:{b=y[s+3|0];c=b>>>6|0;switch(c-1|0){case 2:break E;case 0:break G;default:break F}}f=(b>>>2&12)+4|0;break E}f=32}b=y[s+1|0];H:{if((b&6)==6){c=47100;b=32;break H}if(!(b&8)){c=47103;b=30;break H}h=y[s+2|0]>>>2&3;b=nx(s)>>>((c|0)!=3)|0;b=b?b:192;if(b>>>0<=55){c=47124;b=(h|0)==2?12:8;break H}c=47112;b=b>>>0<=95?27:(h|0)!=1?30:27}v[n+768|0]=b;v[n+769|0]=(b|0)>(f|0)?f:b;b=c;I:{if(!y[n+768|0]){b=0;break I}h=47008;while(1){if((g|0)==(k|0)){h=y[b|0]+47008|0;k=y[b+2|0]+k|0;H=y[b+1|0];b=b+3|0}j=g<<1;f=y[Vd(r,H)+h|0];v[(j+n|0)+770|0]=f;c=y[n+769|0];if(g>>>0<c>>>0){f=y[Vd(r,H)+h|0];c=y[n+769|0]}v[((j|1)+n|0)+770|0]=c?f:0;f=y[n+768|0];g=g+1|0;if(f>>>0>g>>>0){continue}break}if(!f){b=f<<1;break I}g=0;while(1){c=g+n|0;J:{if(!y[c+770|0]){b=6;break J}b=2;if((y[s+1|0]&6)==6){break J}b=Vd(r,2);f=y[n+768|0]}v[c+834|0]=b;b=f<<1&510;g=g+1|0;if(b>>>0>g>>>0){continue}break}}f=n+770|0;c=n;h=0;if((b|0)>0){q=n+834|0;while(1){g=y[f|0];j=g?19>>>y[h+q|0]&3|4:0;f=f+1|0;L=D(g,3)-6|0;g=4;u=E(0);while(1){if(g&j){l=Vd(r,6);m=(l|0)/3|0;u=E(B[(L+(l-D(m,3)|0)<<2)+47136>>2]*E(2097152>>>m|0))}B[c>>2]=u;c=c+4|0;l=g>>>0>1;g=g>>>1|0;if(l){continue}break}h=h+1|0;if((h|0)!=(b|0)){continue}break}}g=y[n+769|0];b=y[n+768|0];if(g>>>0<b>>>0){while(1){v[((g<<1)+n|0)+771|0]=0;g=g+1|0;if((b|0)!=(g|0)){continue}break}}h=0;j=Sb(n+3840|0,0,4608);m=a+2304|0;q=n+8608|0;c=0;K:{while(1){L=j+(c<<2)|0;o=n+17136|0;N=x[e+16>>2]|1;H=0;f=y[n+768|0];b=576;while(1){L:{if(!(f&255)){f=0;break L}k=L+(D(H,N)<<2)|0;i=0;while(1){g=b;l=y[(i+n|0)+770|0];M:{if(!l){break M}if(l>>>0<=16){if((N|0)<=0){break M}f=(-1<<l-1)+1|0;b=0;while(1){_=(b<<2)+k|0,aa=E(Vd(o,l)+f|0),B[_>>2]=aa;b=b+1|0;if((N|0)!=(b|0)){continue}break}break M}f=2<<l-17;b=Vd(o,(f-(f>>>3|0)|0)+3|0);if((N|0)<=0){break M}r=f|1;l=f>>>1|0;f=0;while(1){p=b;b=(b>>>0)/(r>>>0)|0;B[(f<<2)+k>>2]=(p-D(r,b)|0)-l|0;f=f+1|0;if((N|0)!=(f|0)){continue}break}}b=18-g|0;k=(g<<2)+k|0;i=i+1|0;f=y[n+768|0];if(i>>>0<f<<1>>>0){continue}break}}H=H+1|0;if((H|0)!=4){continue}break}c=(N<<2)+c|0;if((c|0)==12){c=(h<<2)+n|0;b=j;g=y[n+769|0];f=b+D(g,72)|0;sc(f+2304|0,f,D(y[n+768|0]-g|0,72));if(y[n+768|0]){f=0;while(1){g=0;while(1){l=(g<<2)+b|0;B[l>>2]=B[l>>2]*B[c>>2];l=l+2304|0;B[l>>2]=B[l>>2]*B[c+12>>2];g=g+1|0;if((g|0)!=12){continue}break}c=c+24|0;b=b+72|0;f=f+1|0;if(f>>>0<y[n+768|0]){continue}break}}SH(m,j,12,x[e+8>>2],d,q);Sb(j,0,4608);d=D(x[e+8>>2],768)+d|0;c=0}if(x[n+17140>>2]<=x[n+17144>>2]){h=h+1|0;if((h|0)==3){break K}continue}break}px(a);f=0;break a}V=1}f=D(mx(a+6152|0),V)}hb=n+17152|0;return f|0}function f6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;a:{b:{c:{d:{e:{f:{if(Rd(b,17381)){Xb(a);break f}if(Rd(b,5867)){b=hb-112|0;hb=b;d=Xb(a);x[114409]=0;V(209,b+80|0);a=x[114409];x[114409]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[114409]=0;x[b+56>>2]=0;P(2241,b+68|0,b+56|0);a=x[114409];x[114409]=0;if((a|0)==1){break p}x[114409]=0;O(1328,d|0,b+68|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break o}xb(b+68|0);x[114409]=0;O(2119,d|0,12710)|0;a=x[114409];x[114409]=0;q:{if((a|0)==1){break q}x[114409]=0;x[b+56>>2]=5;P(2241,b+68|0,b+56|0);a=x[114409];x[114409]=0;if((a|0)==1){break n}x[114409]=0;O(1328,d|0,b+68|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break m}xb(b+68|0);x[114409]=0;O(2119,d|0,12710)|0;a=x[114409];x[114409]=0;if((a|0)==1){break q}x[114409]=0;x[b+56>>2]=25;P(2241,b+68|0,b+56|0);a=x[114409];x[114409]=0;if((a|0)==1){break l}x[114409]=0;O(1328,d|0,b+68|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break k}a=b+68|0;xb(a);x[114409]=0;a=O(122,a|0,17381)|0;c=x[114409];x[114409]=0;if((c|0)==1){break j}c=Cb(a);xb(a);if(!c){break i}x[114409]=0;O(2119,d|0,17381)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break i}}a=N()|0;break h}a=N()|0;break c}a=N()|0;break h}a=N()|0;xb(b+68|0);break h}a=N()|0;break h}a=N()|0;xb(b+68|0);break h}a=N()|0;break h}a=N()|0;xb(b+68|0);break h}a=N()|0;break h}c=sh(b+56|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(x[b+92>>2]){a=x[b+92>>2];x[114409]=0;x[b+20>>2]=a;P(2241,b+32|0,b+20|0);a=x[114409];x[114409]=0;if((a|0)==1){break D}x[114409]=0;T(2242,b+44|0,5085,b+32|0);a=x[114409];x[114409]=0;if((a|0)==1){break C}x[114409]=0;P(1631,c|0,b+44|0);a=x[114409];x[114409]=0;if((a|0)==1){break B}xb(b+44|0);xb(b+32|0)}if(!y[b+96|0]){break x}x[114409]=0;f=O(122,b+44|0,8610)|0;a=x[114409];x[114409]=0;if((a|0)==1){break z}x[114409]=0;P(1631,c|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break y}xb(f);break w}a=N()|0;break r}a=N()|0;break A}a=N()|0;xb(b+44|0)}xb(b+32|0);break r}a=N()|0;break r}a=N()|0;xb(f);break r}if(!y[b+97|0]){break w}x[114409]=0;f=O(122,b+44|0,8356)|0;a=x[114409];x[114409]=0;if((a|0)==1){break v}x[114409]=0;P(1631,c|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break u}xb(f)}if(y[b+98|0]){break t}break s}a=N()|0;break r}a=N()|0;xb(f);break r}x[114409]=0;f=O(122,b+32|0,7007)|0;a=x[114409];x[114409]=0;E:{if((a|0)!=1){x[114409]=0;P(1631,c|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break E}xb(f);break s}a=N()|0;break r}a=N()|0;xb(f);break r}if(kd(c)){break g}x[114409]=0;O(2119,d|0,12740)|0;a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;f=O(122,b+8|0,12710)|0;a=x[114409];x[114409]=0;F:{G:{H:{if((a|0)!=1){x[114409]=0;T(2243,b+20|0,c|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break H}x[114409]=0;O(1328,d|0,b+20|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break G}xb(b+20|0);xb(f);break g}a=N()|0;break r}a=N()|0;break F}a=N()|0;xb(b+20|0)}xb(f);break r}a=N()|0}pd(c)}jf(b+80|0);break c}pd(c);jf(b+80|0);hb=b+112|0;break f}if(Rd(b,4337)){x[g>>2]=0;Ls(a,g);break f}if(Rd(b,4315)){x[g>>2]=5;Ls(a,g);break f}if(Rd(b,6793)){x[g>>2]=25;Ls(a,g);break f}if(Rd(b,6577)){c=hb-16|0;hb=c;b=hb-16|0;hb=b;x[b+12>>2]=17381;Vb(a,x[b+12>>2]);hb=b+16|0;hb=c+16|0;break f}if(Rd(b,7283)){b=Vb(g,17381);c=Cb(b);x[114409]=0;O(122,a|0,(c?11796:11558)|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break e}xb(b);break f}if(Rd(b,3624)){b=hb-48|0;hb=b;LD(b+24|0);x[114409]=0;c=O(2,b+12|0,17360)|0;d=x[114409];x[114409]=0;I:{J:{K:{L:{if((d|0)!=1){x[114409]=0;T(224,b+36|0,b+24|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break L}x[114409]=0;T(9,a|0,0,b+36|0);a=x[114409];x[114409]=0;if((a|0)==1){break K}xb(b+36|0);xb(c);xb(b+24|0);hb=b+48|0;break f}a=N()|0;break I}a=N()|0;break J}a=N()|0;xb(b+36|0)}xb(c)}xb(b+24|0);break a}if(Rd(b,5895)){b=hb-16|0;hb=b;h=hb-16|0;hb=h;x[h+12>>2]=53;j=b+4|0;c=hb-144|0;hb=c;f=Gw(c+132|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=x[h+12>>2];if(d&1){x[114409]=0;x[c+120>>2]=19469602;P(215,c+76|0,c+120|0);d=x[114409];x[114409]=0;if((d|0)==1){break $}x[114409]=0;P(170,f|0,c+76|0);d=x[114409];x[114409]=0;if((d|0)==1){break _}xb(c+76|0);d=x[h+12>>2]}if(!(d&4)){break Y}x[114409]=0;d=$(216)|0;e=x[114409];x[114409]=0;if((e|0)==1){break X}if(!d){break Z}break Y}a=N()|0;break N}a=N()|0;xb(c+76|0);break N}x[114409]=0;V(217,c+76|0);d=x[114409];x[114409]=0;aa:{if((d|0)!=1){x[114409]=0;P(170,f|0,c+76|0);d=x[114409];x[114409]=0;if((d|0)==1){break aa}xb(c+76|0);break Y}a=N()|0;break N}a=N()|0;xb(c+76|0);break N}ba:{d=x[h+12>>2];if(!(d&8)){break ba}x[114409]=0;d=O(2,c+108|0,2508)|0;e=x[114409];x[114409]=0;ca:{da:{ea:{fa:{ga:{if((e|0)!=1){x[114409]=0;P(192,c+120|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break ga}x[114409]=0;T(218,c+76|0,c+120|0,22724);e=x[114409];x[114409]=0;if((e|0)==1){break fa}x[114409]=0;P(170,f|0,c+76|0);e=x[114409];x[114409]=0;if((e|0)==1){break ea}xb(c+76|0);Gb(c+120|0);xb(d);d=x[h+12>>2];break ba}a=N()|0;break N}a=N()|0;break ca}a=N()|0;break da}a=N()|0;xb(c+76|0)}Gb(c+120|0)}xb(d);break N}ha:{if(!(d&16)){break ha}x[114409]=0;V(209,c+76|0);d=x[114409];x[114409]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((d|0)!=1){x[114409]=0;P(219,c+120|0,c+76|0);d=x[114409];x[114409]=0;if((d|0)==1){break ja}d=c+120|0;e=Yc(d);xb(d);if(!e){x[114409]=0;d=O(2,c+52|0,11556)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Ga}x[114409]=0;P(192,c- -64|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break Fa}x[114409]=0;P(219,c+40|0,c+76|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ea}x[114409]=0;T(220,c+120|0,c- -64|0,c+40|0);e=x[114409];x[114409]=0;if((e|0)==1){break Da}x[114409]=0;P(170,f|0,c+120|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ca}xb(c+120|0);xb(c+40|0);Gb(c- -64|0);xb(d)}if(!Yc(fh(c+76|0))){x[114409]=0;d=O(2,c+28|0,13154)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ya}x[114409]=0;P(192,c- -64|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break xa}e=fh(c+76|0);x[114409]=0;T(220,c+120|0,c- -64|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break wa}x[114409]=0;P(170,f|0,c+120|0);e=x[114409];x[114409]=0;if((e|0)==1){break va}xb(c+120|0);Gb(c- -64|0);xb(d)}x[114409]=0;P(221,c+120|0,c+76|0);d=x[114409];x[114409]=0;if((d|0)==1){break sa}d=c+120|0;e=Yc(d);xb(d);if(!e){x[114409]=0;d=O(2,c+16|0,11556)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ra}x[114409]=0;P(192,c- -64|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break qa}x[114409]=0;P(221,c+40|0,c+76|0);e=x[114409];x[114409]=0;if((e|0)==1){break pa}x[114409]=0;T(220,c+120|0,c- -64|0,c+40|0);e=x[114409];x[114409]=0;if((e|0)==1){break oa}x[114409]=0;P(170,f|0,c+120|0);e=x[114409];x[114409]=0;if((e|0)==1){break na}xb(c+120|0);xb(c+40|0);Gb(c- -64|0);xb(d)}jf(c+76|0);d=x[h+12>>2];break ha}a=N()|0;break N}a=N()|0;break ia}a=N()|0;break za}a=N()|0;break Aa}a=N()|0;break Ba}a=N()|0;xb(c+120|0)}xb(c+40|0)}Gb(c- -64|0)}xb(d);break ia}a=N()|0;break ia}a=N()|0;break ta}a=N()|0;break ua}a=N()|0;xb(c+120|0)}Gb(c- -64|0)}xb(d);break ia}a=N()|0;break ia}a=N()|0;break ia}a=N()|0;break ka}a=N()|0;break la}a=N()|0;break ma}a=N()|0;xb(c+120|0)}xb(c+40|0)}Gb(c- -64|0)}xb(d);break ia}a=N()|0}jf(c+76|0);break N}Ha:{if(!(d&32)){break Ha}x[114409]=0;d=$(216)|0;e=x[114409];x[114409]=0;if((e|0)==1){break X}if(d){break Ha}d=c+76|0;gd(d);x[114409]=0;P(170,f|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break O}xb(c+76|0)}if(y[h+12|0]&64){x[114409]=0;V(222,c+76|0);d=x[114409];x[114409]=0;if((d|0)==1){break W}x[114409]=0;P(170,f|0,c+76|0);d=x[114409];x[114409]=0;if((d|0)==1){break V}xb(c+76|0)}x[114409]=0;d=O(2,c+76|0,17381)|0;e=x[114409];x[114409]=0;if((e|0)==1){break U}x[114409]=0;T(223,c+4|0,f|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break T}x[114409]=0;e=O(2,c+120|0,17360)|0;i=x[114409];x[114409]=0;if((i|0)==1){break S}x[114409]=0;T(224,j|0,c+4|0,e|0);i=x[114409];x[114409]=0;if((i|0)==1){break R}xb(e);xb(c+4|0);xb(d);Al(f);hb=c+144|0;break M}a=N()|0;break N}a=N()|0;break N}a=N()|0;xb(c+76|0);break N}a=N()|0;break N}a=N()|0;break P}a=N()|0;break Q}a=N()|0;xb(e)}xb(c+4|0)}xb(d);break N}a=N()|0;xb(c+76|0)}Al(f);break a}hb=h+16|0;x[114409]=0;T(9,a|0,0,j|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,6506)){b=hb-48|0;hb=b;c=b+4|0;vr(c);x[114409]=0;P(219,b+36|0,c|0);c=x[114409];x[114409]=0;Ia:{Ja:{if((c|0)!=1){x[114409]=0;T(9,a|0,0,b+36|0);a=x[114409];x[114409]=0;if((a|0)==1){break Ja}xb(b+36|0);jf(b+4|0);hb=b+48|0;break f}a=N()|0;break Ia}a=N()|0;xb(b+36|0)}jf(b+4|0);break a}if(Rd(b,7246)){b=hb-32|0;hb=b;vr(b);c=fh(b);x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){jf(b);hb=b+32|0;break f}a=N()|0;jf(b);break a}if(Rd(b,5908)){b=hb-48|0;hb=b;vr(b+16|0);Ka:{if(x[b+28>>2]){c=x[b+28>>2];x[114409]=0;x[b+12>>2]=c;P(2241,a|0,b+12|0);a=x[114409];x[114409]=0;if((a|0)!=1){break Ka}a=N()|0;jf(b+16|0);break a}Xb(a)}jf(b+16|0);hb=b+48|0;break f}if(Rd(b,8600)){vr(g);b=y[g+16|0];x[114409]=0;O(122,a|0,(b?11558:11796)|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){jf(g);break f}a=N()|0;jf(g);break a}if(Rd(b,5924)){vr(g);b=y[g+17|0];x[114409]=0;O(122,a|0,(b?11558:11796)|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){jf(g);break f}a=N()|0;jf(g);break a}if(Rd(b,8047)){vr(g);b=y[g+18|0];x[114409]=0;O(122,a|0,(b?11558:11796)|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){jf(g);break f}a=N()|0;jf(g);break a}if(Rd(b,8330)){b=hb-16|0;hb=b;c=hb-32|0;hb=c;f=b+4|0;d=gd(f);x[114409]=0;V(209,c|0);h=x[114409];x[114409]=0;La:{Ma:{Na:{if((h|0)!=1){h=fh(c);x[114409]=0;O(210,d|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break Na}jf(c);hb=c+32|0;break La}a=N()|0;break Ma}a=N()|0;jf(c)}xb(d);break a}x[114409]=0;T(9,a|0,0,f|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,4458)){b=hb-16|0;hb=b;c=hb-48|0;hb=c;h=b+4|0;f=gd(h);x[114409]=0;d=O(2,c+12|0,10619)|0;e=x[114409];x[114409]=0;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((e|0)!=1){x[114409]=0;P(192,c+24|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ua}x[114409]=0;x[c+8>>2]=17;x[c+4>>2]=0;x[c>>2]=0;ba(212,c+36|0,c+24|0,c+8|0,c+4|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break Ta}x[114409]=0;O(164,f|0,c+36|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break Sa}xb(c+36|0);Gb(c+24|0);xb(d);hb=c+48|0;break Oa}a=N()|0;break Pa}a=N()|0;break Qa}a=N()|0;break Ra}a=N()|0;xb(c+36|0)}Gb(c+24|0)}xb(d)}xb(f);break a}x[114409]=0;T(9,a|0,0,h|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,3147)){b=hb-16|0;hb=b;c=b+4|0;go(c,0,15364);x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,2809)){b=hb-48|0;hb=b;d=Vb(b+24|0,13511);x[114409]=0;P(2244,b+12|0,2);c=x[114409];x[114409]=0;Va:{Wa:{Xa:{Ya:{if((c|0)!=1){x[114409]=0;T(3,b+36|0,d|0,b+12|0);c=x[114409];x[114409]=0;if((c|0)==1){break Ya}x[114409]=0;T(9,a|0,0,b+36|0);a=x[114409];x[114409]=0;if((a|0)==1){break Xa}xb(b+36|0);xb(b+12|0);xb(d);hb=b+48|0;break f}a=N()|0;break Va}a=N()|0;break Wa}a=N()|0;xb(b+36|0)}xb(b+12|0)}break c}if(Rd(b,7269)){b=hb-16|0;hb=b;c=b+4|0;go(c,0,13827);x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,6513)){b=hb-16|0;hb=b;c=b+4|0;tr(c,0);x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,6488)){b=hb-16|0;hb=b;c=b+4|0;tr(c,2);x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}if(Rd(b,6473)){b=hb-16|0;hb=b;c=b+4|0;tr(c,3);x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break f}break b}Xb(a)}hb=g+32|0;break d}a=N()|0;xb(b);break a}return}xb(d);break a}a=N()|0;xb(b+4|0)}Q(a|0);p()}function AV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=hb-288|0;hb=e;Nc(b);a:{if(yB(b,13668)){n=Xb(e+276|0);x[114409]=0;f=U(401,b|0,n|0,-1)|0;g=x[114409];x[114409]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((g|0)!=1){if(!f){break b}x[114409]=0;f=O(417,b|0,e+269|0)|0;g=x[114409];x[114409]=0;s:{if((g|0)==1){break s}if(!f){break b}if(!xB(e+269|0)){break b}d=wB(e+269|0);x[114409]=0;d=cg(418,d,lb);f=x[114409];x[114409]=0;if((f|0)==1){break s}x[114409]=0;f=O(231,b|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break s}d=0;if(!f){break b}if(!c){break c}x[114409]=0;P(419,a|0,4096);d=x[114409];x[114409]=0;if((d|0)==1){break s}x[114409]=0;O(420,a+1304400|0,n|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break s}d=y[e+271|0];w[a+480188>>1]=32;w[a+480192>>1]=d;x[114409]=0;P(421,a|0,1);d=x[114409];x[114409]=0;if((d|0)==1){break s}x[114409]=0;d=O(2,e+256|0,5433)|0;f=x[114409];x[114409]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){Eb(a+1304436|0,d);xb(d);x[114409]=0;d=O(2,e+244|0,3356)|0;f=x[114409];x[114409]=0;if((f|0)==1){break D}Eb(a+1304448|0,d);xb(d);x[114409]=0;d=O(2,e+232|0,11064)|0;f=x[114409];x[114409]=0;if((f|0)==1){break C}x[114409]=0;P(192,e+36|0,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break B}v[e+208|0]=y[e+270|0];f=y[e+269|0];x[114409]=0;v[e+8|0]=f;P(422,e+220|0,e+8|0);f=x[114409];x[114409]=0;if((f|0)==1){break A}x[114409]=0;W(423,e+80|0,e+36|0,e+208|0,e+220|0);f=x[114409];x[114409]=0;if((f|0)==1){break z}f=e+80|0;Eb(a+1304460|0,f);xb(f);xb(e+220|0);Gb(e+36|0);xb(d);x[a+1304496>>2]=4;if(y[e+269|0]<2){break u}x[114409]=0;w[e+80>>1]=8192;d=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break w}x[114409]=0;w[e+36>>1]=d;d=O(424,e+80|0,e+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break w}x[a+480204>>2]=D(z[d>>1],1e4)>>>8;x[114409]=0;v[e+80|0]=1;d=S(425,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break v}x[114409]=0;v[e+36|0]=d;d=O(426,e+80|0,e+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break v}x[a+480196>>2]=y[d|0];x[114409]=0;O(313,b|0,3)|0;d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;d=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break t}}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break x}b=N()|0;break y}b=N()|0;xb(e+220|0)}Gb(e+36|0)}xb(d);break d}b=N()|0;break d}b=N()|0;break d}x[114409]=0;v[e+80|0]=32;d=S(425,b|0)|0;f=x[114409];x[114409]=0;E:{F:{if((f|0)==1){break F}x[114409]=0;v[e+36|0]=d;d=O(426,e+80|0,e+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break F}x[a+480204>>2]=D(y[d|0],1e4);x[114409]=0;v[e+80|0]=1;d=S(425,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break E}x[114409]=0;v[e+36|0]=d;d=O(426,e+80|0,e+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break E}x[a+480196>>2]=y[d|0];x[114409]=0;d=S(425,b|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break t}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}x[a+480208>>2]=d>>>2&16|12;m=pm(e+220|0);l=pm(e+208|0);G:{H:{I:{J:{K:{L:{M:{if(!z[a+480192>>1]){break M}q=e+80|12;h=1;while(1){x[114409]=0;f=U(427,a|0,h&65535,0)|0;d=x[114409];x[114409]=0;N:{O:{P:{if((d|0)==1){break P}if(!f){break M}x[114409]=0;d=U(402,b|0,f+492|0,-1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break P}if(!d){break M}x[114409]=0;i=S(425,b|0)|0;d=x[114409];x[114409]=0;Q:{R:{S:{T:{if((d|0)!=1){Sb(e+80|0,0,120);if(!i){break N}if(y[e+269|0]){x[114409]=0;d=O(428,b|0,e+80|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break T}if(!d){break N}}if(!y[e+269|0]){x[114409]=0;d=U(234,b|0,q|0,96)|0;g=x[114409];x[114409]=0;if((g|0)==1){break T}if(!d){break N}}g=f+236|0;d=0;while(1){j=y[(e+80|0)+d|0];k=z[a+480190>>1];r=fd(g,d),s=(j+k|0)+1|0,w[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}x[114409]=0;d=f+48|0;T(429,e+8|0,d|0,b|0);g=x[114409];x[114409]=0;if((g|0)==1){break S}x[114409]=0;g=f+68|0;T(429,e+25|0,g|0,b|0);j=x[114409];x[114409]=0;if((j|0)==1){break S}x[114409]=0;j=f+88|0;T(429,e+72|0,j|0,b|0);k=x[114409];x[114409]=0;if((k|0)==1){break S}x[114409]=0;O(430,b|0,e- -64|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break R}x[f>>2]=(y[e+65|0]|y[e+66|0]<<8)&4095;k=y[e+65|0]|y[e+66|0]<<8;f=e- -64|0;uB(f,d,0);uB(f,g,1);uB(f,j,2);r=e,s=bc(d),x[r+36>>2]=s;r=e,s=dc(d),x[r+60>>2]=s;if(Hb(e+36|0,e+60|0)){break Q}break O}b=N()|0;break e}b=N()|0;break e}b=N()|0;break e}b=N()|0;break e}while(1){U:{d=x[e+36>>2];v[e+56|0]=64;f=y[d+2|0];x[114409]=0;v[e+59|0]=((f<<6)- -64>>>0)/127;f=O(431,e+56|0,e+59|0)|0;o=x[114409];x[114409]=0;if((o|0)==1){break U}v[d+2|0]=y[f|0];d=e+36|0;je(d);if(Hb(d,e+60|0)){continue}break O}break}b=N()|0;break e}b=N()|0;break e}r=e,s=bc(g),x[r+36>>2]=s;r=e,s=dc(g),x[r+60>>2]=s;V:{if(!Hb(e+36|0,e+60|0)){break V}while(1){W:{d=x[e+36>>2];v[e+56|0]=64;f=y[d+2|0];x[114409]=0;v[e+59|0]=((f<<6)+128>>>0)/255;f=O(431,e+56|0,e+59|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break W}v[d+2|0]=y[f|0];d=e+36|0;je(d);if(Hb(d,e+60|0)){continue}break V}break}b=N()|0;break e}r=e,s=bc(j),x[r+36>>2]=s;r=e,s=dc(j),x[r+60>>2]=s;if(Hb(e+36|0,e+60|0)){f=k>>>12&3;while(1){k=x[e+36>>2];d=v[k+2|0];o=d>>31^-1;j=d^-128;g=f&31;if((f&63)>>>0>=32){d=j<<g;g=0}else{d=(1<<g)-1&j>>>32-g|o<<g;g=j<<g}X:{if((d|0)>=-1&g>>>0>=4294967292|(d|0)>=0){g=g+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break X}d=0-((g>>>0>3)+d|0)|0;g=3-g|0;g=((d&7)<<29|g>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}x[114409]=0;d=cg(432,d,g);g=x[114409];x[114409]=0;if((g|0)==1){break f}v[k+2|0]=d^128;d=e+36|0;je(d);if(Hb(d,e+60|0)){continue}break}}w[e+56>>1]=z[a+480190>>1]+1;f=0;d=0;while(1){Y:{g=z[e+56>>1]+f|0;if(g>>>0>=4e3){x[114409]=0;O(313,b|0,20)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break Y}b=N()|0;break e}x[114409]=0;U(402,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break G}x[114409]=0;O(433,b|0,e+36|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break L}x[114409]=0;P(434,e+36|0,(D(z[e+56>>1]+f|0,104)+a|0)+484380|0);f=x[114409];x[114409]=0;if((f|0)==1){break L}f=y[e- -64|0];g=y[e+55|0];x[114409]=0;w[e+60>>1]=f|d<<8&32512|((g&3)!=0)<<15;P(435,l|0,e+60|0);f=x[114409];x[114409]=0;if((f|0)==1){break K}d=d+1|0;f=d&65535;if(i>>>0>f>>>0){continue}}break}x[114409]=0;P(435,m|0,e+56|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}x[e+36>>2]=3999;d=z[a+480190>>1];x[114409]=0;x[e+60>>2]=d+i;d=O(436,e+36|0,e+60|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break H}w[a+480190>>1]=x[d>>2]}h=h+1|0;if(z[a+480192>>1]>=(h&65535)>>>0){continue}break}}d=Xb(e+80|0);x[114409]=0;f=U(401,b|0,d|0,-1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break n}if(f){x[114409]=0;T(13,e+36|0,6,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break n}f=e+36|0;Eb(a+1304412|0,f);xb(f)}xb(d);f=0;while(1){x[114409]=0;d=(f<<5)+a|0;V(403,d+480280|0);g=x[114409];x[114409]=0;if((g|0)==1){break J}x[114409]=0;U(404,b|0,d+480289|0,-1)|0;d=x[114409];x[114409]=0;if((d|0)==1){break J}f=f+1|0;if((f|0)!=32){continue}break}x[114409]=0;d=O(437,b|0,e+25|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break l}if(!d){break i}if((y[e+25|0]|y[e+26|0]<<8|(y[e+27|0]<<16|y[e+28|0]<<24))>>>0<12){break m}d=y[e+25|0]|y[e+26|0]<<8|(y[e+27|0]<<16|y[e+28|0]<<24);x[114409]=0;d=O(231,b|0,d-11|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break l}if(d){break I}break m}b=N()|0;break e}b=N()|0;break e}b=N()|0;break e}x[e+72>>2]=(y[e+25|0]|y[e+26|0]<<8|(y[e+27|0]<<16|y[e+28|0]<<24))-11;h=br(e+80|0);x[114409]=0;U(407,b|0,h|0,x[e+72>>2])|0;d=x[114409];x[114409]=0;if((d|0)==1){break p}x[114409]=0;x[e+36>>2]=50529027;d=O(306,e+72|0,e+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break q}x[e+64>>2]=D(x[d>>2],85);g=Xb(e+36|0);d=y[e+29|0]|y[e+30|0]<<8|(y[e+31|0]<<16|y[e+32|0]<<24);x[114409]=0;x[e+8>>2]=d;d=O(306,e- -64|0,e+8|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break r}d=x[d>>2];x[114409]=0;P(112,g|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break r}if(x[e+72>>2]){f=0;while(1){Z:{i=y[Cc(h,f)|0];d=f+1|0;if(!((i|0)!=255|x[e+72>>2]-d>>>0<2)){d=v[Cc(h,d)|0];i=y[Cc(h,f+2|0)|0];r=e,s=nf(g),x[r+8>>2]=s;j=x[rd(e+20|0,e+8|0)>>2];x[114409]=0;Z(408,g|0,j|0,i|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){d=f+3|0;break Z}break r}x[114409]=0;P(111,g|0,i<<24>>24);f=x[114409];x[114409]=0;if((f|0)!=1){break Z}break r}f=d;if(A[e+72>>2]>d>>>0){continue}break}}x[114409]=0;W(409,e+8|0,4,6,g|0);d=x[114409];x[114409]=0;_:{if((d|0)!=1){d=e+8|0;Eb(g,d);xb(d);d=Rb(g);x[114409]=0;d=S(410,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break _}f=Cb(g);x[114409]=0;aa(411,a+1304424|0,d|0,f|0,74,0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break _}xb(g);de(h);break m}break r}break r}b=N()|0;break e}b=N()|0;break e}b=N()|0;break d}b=N()|0;break d}b=N()|0;xb(g);break o}b=N()|0;break o}b=N()|0}de(h);break e}b=N()|0;xb(d);break e}d=Wb(a+484360|0);f=y[e+274|0]|y[e+275|0]<<8;x[114409]=0;aa(412,d|0,b|0,f|0,65535,65535)|0;d=x[114409];x[114409]=0;if((d|0)==1){break l}g=c&1;if(g){d=y[e+272|0]|y[e+273|0]<<8;x[114409]=0;P(377,a+484344|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break l}}if(!(y[e+272|0]|y[e+273|0]<<8)){break j}d=a+484344|0;f=0;while(1){x[114409]=0;h=O(231,b|0,4)|0;i=x[114409];x[114409]=0;$:{if((i|0)!=1){if(h){break $}break j}b=N()|0;break e}x[114409]=0;h=S(413,b|0)|0;i=x[114409];x[114409]=0;aa:{ba:{ca:{da:{if((i|0)!=1){x[114409]=0;T(316,e+80|0,b|0,h|0);h=x[114409];x[114409]=0;if((h|0)==1){break da}if(!g){break ba}x[114409]=0;h=S(425,e+80|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break aa}x[114409]=0;O(313,e+80|0,1)|0;i=x[114409];x[114409]=0;if((i|0)==1){break aa}x[114409]=0;h=U(378,d|0,f&65535,h+1|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break aa}if(!h){break ba}x[114409]=0;h=U(405,e+80|0,e+36|0,-1)|0;i=x[114409];x[114409]=0;if((i|0)==1){break k}if(!h){break ca}h=Zb(d,f);x[114409]=0;O(406,h|0,e+36|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break ca}break k}b=N()|0;break e}b=N()|0;break e}h=Zb(d,f);x[114409]=0;T(415,h|0,1,e+80|0);h=x[114409];x[114409]=0;if((h|0)==1){break k}}Ab(e+80|0);f=f+1|0;if(f>>>0<(y[e+272|0]|y[e+273|0]<<8)>>>0){continue}break j}break}break k}b=N()|0;break e}b=N()|0;Ab(e+80|0);break e}if(!(c&2)){break i}ea:{if(!z[a+480190>>1]){break ea}d=0;while(1){fa:{if(y[vc(l,d)|0]){c=d+1|0}else{c=d+1|0;f=D(c,104)+a|0;d=cd(e+80|0,w[f+484414>>1]&1?16:8,1,0,w[vc(l,d)>>1]<0?6:0);x[114409]=0;U(376,d|0,f+484380|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break fa}}d=c;if(d>>>0<z[a+480190>>1]){continue}break ea}break}b=N()|0;break e}if(!z[a+480190>>1]){break i}b=0;while(1){c=y[vc(l,b)|0];ga:{if(!c){break ga}c=c-1&65535;if(rc(m)>>>0<=c>>>0){break ga}c=(y[vc(l,b)+1|0]&127)+z[vc(m,c)>>1]&65535;if(c>>>0>z[a+480190>>1]){break ga}f=D(c,104);g=f+a|0;d=g+484380|0;if(!He(d)){break ga}h=a+484380|0;i=D(b+1|0,104);c=h+i|0;w[c+34>>1]=z[c+34>>1]&65534|w[(f+h|0)+34>>1]&1;x[c>>2]=x[d>>2];x[114409]=0;c=S(438,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}if(!c){break ga}c=x[(a+i|0)+484400>>2];x[114409]=0;c=S(439,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}f=x[g+484400>>2];x[114409]=0;f=S(439,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}sc(c,f,el(d))}b=b+1|0;if(b>>>0<z[a+480190>>1]){continue}break}}vf(l);vf(m);break c}b=N()|0;break e}b=N()|0;break e}b=N()|0}vf(l);vf(m)}xb(n);Q(b|0);p()}d=1}xb(n)}hb=e+288|0;return d|0}R(0)|0;zb();p()}function rpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;f=hb-160|0;hb=f;Nc(a);a:{b:{if(b>>>0<=2){C=f,E=te(a),v[C+152|0]=E;cc(a,2);b=tg(a);v[f+154|0]=b;v[f+155|0]=b>>>8;b=Kf(a);v[f+156|0]=b;v[f+157|0]=b>>>8;v[f+158|0]=b>>>16;v[f+159|0]=b>>>24;break b}Mf(a,f+152|0);if(b>>>0>5){break a}}v[f+153|0]=0}c:{n=d+484344|0;s=Md(y[f+154|0]|y[f+155|0]<<8,1,1024);m=by(n,s,0);if((m|0)!=65535){g=tm(Zb(n,m),0);w[f+100>>1]=z[d+480188>>1]-1;w[f+84>>1]=y[f+152|0];t=z[Gf(f+100|0,f+84|0)>>1];e=t+1|0;if(z[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){v[g+D(b,6)|0]=254;b=b+1|0;if(b>>>0<z[d+480188>>1]){continue}break}}v[c+13|0]=y[f+153|0]>>>4;b=y[c+12|0];v[f+100|0]=0;o=Lu(f+140|0,e,f+100|0);if(s){b=(b|0)!=0;while(1){d:{e:{f:{if(!y[Cc(o,0)|0]){x[114409]=0;e=S(425,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break c}e=e<<24>>24;if((e|0)<0){x[114409]=0;g=S(425,a|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break c}C=Cc(o,0),E=g,v[C|0]=E}v[f+136|0]=0;g:{e=e&63;if(!e){break g}x[114409]=0;j=S(425,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break c}v[f+136|0]=j;h:{i:{switch(e-1|0){case 0:v[c+12|0]=0;x[114409]=0;v[f+132|0]=1;b=O(426,f+132|0,f+136|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){v[c+14|0]=y[b|0];v[c+15|0]=0;break h}break c;case 1:if(!j){break g}v[c+15|0]=j;v[c+12|0]=1;b=y[c+13|0];if(!b){break h}v[c+14|0]=D(D(b,j),15);break h;case 2:v[c+13|0]=j>>>4;if(j>>>0<16){break f}b=y[c+12|0];j=0;x[f+136>>2]=0;x[f+132>>2]=0;q=0;if(b){break e}break d;case 3:q=0;x[f+136>>2]=0;x[f+132>>2]=0;if(b&1){break e}break d;case 5:if(!j){break g}e=(y[c+12|0]?15:14)+c|0;b=y[e|0];v[e|0]=b>>>0>=256-j>>>0?-1:b+j|0;break h;case 6:break i;default:break g}}if(!j){break g}e=(y[c+12|0]?15:14)+c|0;b=y[e|0];v[e|0]=b>>>0<=j+1>>>0?1:b-j|0}j=0;x[f+136>>2]=0;x[f+132>>2]=0;break e}j=0;x[f+136>>2]=0;x[f+132>>2]=0;q=0;if(b&1){break e}break d}j=0;e=Cc(o,0);v[e|0]=y[e|0]-1;x[f+136>>2]=0;x[f+132>>2]=0;q=0;if(!(b&1)){break d}break e}j=0;v[c+12|0]=0;x[f+136>>2]=0;x[f+132>>2]=0;q=0;if(b&1){break e}break d}b=y[c+13|0];e=y[c+12|0];if(e){q=0;if(!b){break d}}j:{if(e){x[f+128>>2]=1;e=y[c+15|0];x[114409]=0;x[f+124>>2]=D(b,e)<<1;b=O(545,f+128|0,f+124|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}e=x[b>>2];break j}e=D(y[c+14|0],30)+30|0}b=255;k:{while(1){g=D(b,e);if(g-1536>>>0<10752){e=g;break k}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}x[f+136>>2]=b;x[f+132>>2]=(e|0)/48;ce(f+132|0,32,255);x[114409]=0;x[f+128>>2]=1;b=O(545,f+128|0,f+136|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){v[c+16|0]=x[b>>2];q=1;break d}break c}b=Zb(n,m);x[114409]=0;b=U(451,b|0,l|0,1)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}if(t){u=l-1|0;g=1;r=1;while(1){l:{m:{n:{o:{if(!y[Cc(o,g)|0]){x[114409]=0;e=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}e=e<<24>>24;if((e|0)<0){x[114409]=0;h=S(425,a|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break c}C=Cc(o,g),E=h,v[C|0]=E}A=1;k=e&255;if(k&64){x[114409]=0;e=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[b+1|0]=e;A=!e}if(!(k&32)){break o}x[114409]=0;e=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[b|0]=e;if((e-1&255)>>>0<=107){e=Ku(e+24|0);v[b|0]=e;C=Sc(c,g),E=e,v[C+1|0]=E;break o}if((e+127&255)>>>0<=107){e=Ku((e&127)+24|0);v[b|0]=e;C=Sc(c,g),E=e,v[C|0]=E;v[b|0]=0;break n}if((e|0)!=255){break o}v[b|0]=254;break m}e=Cc(o,g);v[e|0]=y[e|0]-1;break l}if(y[b|0]){break m}}if(!y[b+1|0]){break m}e=y[Sc(c,g)+1|0];v[b+1|0]=0;v[b|0]=e}x[114409]=0;e=S(546,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}if(e){C=Sc(c,g),E=0,v[C+5|0]=E}v[f+123|0]=0;v[f+122|0]=0;v[f+121|0]=0;v[f+120|0]=0;v[f+119|0]=0;v[f+118|0]=0;if(k&16){v[b+2|0]=1;x[114409]=0;e=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[b+4|0]=e+2>>>2}p:{if(!(k&8)){break p}x[114409]=0;e=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}x[114409]=0;v[f+123|0]=e;e=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[f+120|0]=e;q:{r:{s:{t:{u:{v:{w:{x:{h=y[f+123|0];switch(h-1|0){case 0:break r;case 9:break s;case 5:case 6:case 7:case 8:break t;case 4:break u;case 3:break v;case 2:break w;case 1:break x;default:break q}}v[b|0]=255;break q}C=b,E=y[Sc(c,g)+1|0],v[C|0]=E;C=Sc(c,g),E=0,v[C+5|0]=E;break q}e=Ju(e,y[c+16|0]);v[f+123|0]=e?20:0;v[f+120|0]=e?e|208:0;if(y[b|0]){break p}C=b,E=y[Sc(c,g)+1|0],v[C|0]=E;C=Sc(c,g),E=0,v[C+5|0]=E;break p}v[f+128|0]=1;e=Ju(e,y[c+16|0]);x[114409]=0;v[f+124|0]=e;e=O(426,f+128|0,f+124|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){v[f+120|0]=y[e|0];v[f+123|0]=15;C=Sc(c,g),E=0,v[C+5|0]=E;break p}break c}y:{if(!l){break y}if((h|0)==y[Sc(c,g)+4|0]){break y}e=Zb(n,m);x[114409]=0;h=U(478,f+100|0,20,(y[f+123|0]+122|160)&255)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}h=lo(ko(Oe(h,u),r&65535));x[114409]=0;e=O(479,e|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}if(!e){break y}e=y[f+123|0];C=Sc(c,g),E=e,v[C+4|0]=E}v[f+123|0]=10;if(!y[b|0]){C=b,E=y[Sc(c,g)+1|0],v[C|0]=E}C=Sc(c,g),E=0,v[C+5|0]=E;break p}v[f+123|0]=20;C=f,E=y[Sc(c,g)+5|0]?-98:-97,v[C+120|0]=E;e=y[Sc(c,g)+5|0];C=Sc(c,g),E=e^1,v[C+5|0]=E;break p}v[b|0]=254}v[f+123|0]=0}h=0;e=0;z:{if(!(k&4)){break z}x[114409]=0;e=S(425,a|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}x[114409]=0;v[f+122|0]=e;e=S(425,a|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}e=e<<24>>24;v[f+119|0]=e;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{i=y[f+122|0];switch(i-1|0){case 11:break C;case 10:break D;case 7:case 8:case 9:break E;case 6:break F;case 5:break G;case 3:case 4:break H;case 2:break I;case 1:break J;case 0:break K;default:break B}}i=(e|0)>=0;v[f+122|0]=i?2:3;if(!i){e=0-e|0;v[f+119|0]=e}L:{if((e&255)>>>0<16){break L}x[114409]=0;e=S(546,b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}if(!e){break L}M:{if(y[f+122|0]==2){e=y[b|0];x[114409]=0;x[f+128>>2]=e+(y[f+119|0]>>>4|0);x[f+124>>2]=120;e=O(436,f+128|0,f+124|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){break M}break c}e=y[b|0];x[114409]=0;x[f+128>>2]=e-(y[f+119|0]>>>4|0);x[f+124>>2]=1;e=O(545,f+128|0,f+124|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}}v[b|0]=x[e>>2];v[f+119|0]=y[f+119|0]&15}x[114409]=0;v[f+128|0]=15;e=O(431,f+128|0,f+119|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){v[f+119|0]=y[e|0]|240;e=0;break z}break c}e=Ju(e&255,y[c+16|0]);v[f+119|0]=e;if(e){v[f+122|0]=20;v[f+119|0]=e|208;e=1;break z}v[f+122|0]=0;e=1;break z}e=1;break A}i=y[c+16|0];x[114409]=0;e=U(547,e&255,i|0,1)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}v[f+119|0]=e;v[f+122|0]=y[f+122|0]==4?2:3;e=1;break z}if(!y[b|0]){C=b,E=y[Sc(c,g)|0],v[C|0]=E;e=y[f+119|0]}i=y[c+16|0];x[114409]=0;e=U(547,e&255,i|0,0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}v[f+122|0]=4;v[f+119|0]=e;e=1;break z}C=b,E=Ku((e&255)+25|0),v[C|0]=E;v[f+119|0]=255;v[f+122|0]=4;e=1;break z}N:{if(!l){break N}if((i|0)==y[Sc(c,g)+2|0]){break N}e=Zb(n,m);x[114409]=0;i=U(478,f+84|0,20,(y[f+122|0]-8|48)&255)|0;B=x[114409];x[114409]=0;if((B|0)==1){break c}i=lo(ko(Oe(i,u),r&65535));x[114409]=0;e=O(479,e|0,i|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}if(!e){break N}e=y[f+122|0];C=Sc(c,g),E=e,v[C+2|0]=E}v[f+122|0]=5;e=y[c+16|0];x[114409]=0;e=O(548,y[f+119|0],e|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}v[f+119|0]=e;e=1;break z}e=wU(e&255,y[c+16|0]);v[f+122|0]=18;v[f+119|0]=e;e=1;break z}e=Ju(e&255,y[c+16|0]);v[f+119|0]=e;if(e){v[f+122|0]=20;v[f+119|0]=e|192;e=1;break z}v[f+122|0]=0;v[b|0]=254;e=1;break z}e=0}v[f+122|0]=e}O:{if(!(k&2)){break O}x[114409]=0;k=S(425,a|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}x[114409]=0;v[f+121|0]=k;k=S(425,a|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}v[f+118|0]=k;P:{Q:{R:{S:{T:{U:{V:{i=y[f+121|0];switch(i-1|0){case 9:break Q;case 7:case 8:break R;case 6:break S;case 3:case 4:case 5:break T;case 2:break U;case 0:case 1:break V;default:break P}}g=y[c+16|0];x[114409]=0;g=U(549,k|0,g|0,(i|0)==1|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[f+121|0]=11;v[f+118|0]=g;h=1;break O}g=wU(k,y[c+16|0]);v[f+121|0]=18;v[f+118|0]=g;h=1;break O}W:{if(!l){break W}if((i|0)==y[Sc(c,g)+3|0]){break W}h=Zb(n,m);x[114409]=0;k=U(478,f+68|0,20,(y[f+121|0]-4|64)&255)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}k=lo(ko(Oe(k,u),r&65535));x[114409]=0;h=O(479,h|0,k|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break c}if(!h){break W}h=y[f+121|0];C=Sc(c,g),E=h,v[C+3|0]=E}v[f+121|0]=8;g=y[c+16|0];x[114409]=0;g=O(548,y[f+118|0],g|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[f+118|0]=g;h=1;break O}v[f+121|0]=9;break O}g=y[c+16|0];x[114409]=0;g=U(549,k|0,g|0,(i|0)==8|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[f+121|0]=29;v[f+118|0]=g;h=1;break O}v[f+121|0]=27;g=y[c+16|0];x[114409]=0;g=O(548,k|0,g|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}v[f+118|0]=g;h=1;break O}v[f+121|0]=0}if(e){vU(b,l,z[d+480188>>1],y[f+122|0],f+119|0)}if(h){vU(b,l,z[d+480188>>1],y[f+121|0],f+118|0)}X:{if(!A){break X}x[114409]=0;e=S(546,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break c}if(!e){break X}e=y[f+122|0];if(!e){v[f+119|0]=255;v[f+122|0]=4;break X}if(y[f+121|0]|(e|0)==4){break X}v[f+118|0]=255;v[f+121|0]=4}Y:{if(y[b+2|0]!=1){break Y}Z:{if(!y[f+122|0]){v[f+122|0]=13;v[f+119|0]=y[b+4|0];break Z}if(y[f+121|0]){break Y}v[f+121|0]=13;v[f+118|0]=y[b+4|0]}v[b+2|0]=0}x[114409]=0;ba(480,f+128|0,f+122|0,f+119|0,f+121|0,f+118|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}_:{if(y[b+2|0]){break _}e=y[f+122|0];if(!e){break _}v[b+2|0]=e;v[b+4|0]=y[f+119|0]}$:{if(y[f+123|0]){x[114409]=0;ba(480,f+128|0,f+121|0,f+118|0,f+123|0,f+120|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}aa:{if(y[b+2|0]){break aa}e=y[f+121|0];if(!e){break aa}v[b+2|0]=e;v[b+4|0]=y[f+118|0]}g=f+120|0;e=y[f+123|0];break $}g=f+118|0;e=y[f+121|0];if(!e){break l}}v[b+3|0]=e;v[b+5|0]=y[g|0]}b=b+6|0;r=r+1|0;g=r&65535;if(t>>>0>=g>>>0){continue}break}}ba:{if(!q){break ba}b=Zb(n,m);x[114409]=0;e=U(478,f+52|0,17,y[f+132|0])|0;g=x[114409];x[114409]=0;if((g|0)==1){break c}e=gi(ko(Oe(e,l),0));x[114409]=0;O(479,b|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}b=Zb(n,m);x[114409]=0;e=U(478,f+36|0,16,y[f+136|0])|0;g=x[114409];x[114409]=0;if((g|0)!=1){e=gi(Oe(e,l));x[114409]=0;O(479,b|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break ba}}break c}ca:{if(j>>>0<16){break ca}b=Zb(n,m);x[114409]=0;e=U(478,f+20|0,20,j>>>4|224)|0;g=x[114409];x[114409]=0;if((g|0)!=1){e=uU(Oe(e,l));x[114409]=0;O(479,b|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break ca}}break c}da:{b=j&15;if(!b){break da}e=y[c+16|0];g=Zb(n,m);b=Md((D(b,e)>>>0)/15&255,1,15);x[114409]=0;b=U(478,f+4|0,20,b|96)|0;e=x[114409];x[114409]=0;if((e|0)!=1){b=uU(Oe(b,l));x[114409]=0;O(479,g|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break da}}break c}b=0;l=l+1|0;if((s|0)!=(l|0)){continue}break}}de(o)}hb=f+160|0;return m|0}a=N()|0;de(o);Q(a|0);p()}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=hb-48|0;hb=f;e=Vb(f+36|0,7480);d=Df(c,e);xb(e);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(d){zj(a,0,x[b+24>>2]+1304448|0);break k}e=Vb(f+36|0,6945);d=Df(c,e);xb(e);if(d){zj(a,0,x[b+24>>2]+1304436|0);break k}e=Vb(f+36|0,7310);d=Df(c,e);xb(e);if(d){zj(a,0,x[b+24>>2]+1304484|0);break k}e=Vb(f+36|0,6937);d=Df(c,e);xb(e);if(d){zj(a,0,x[b+24>>2]+1304472|0);break k}e=Vb(f+36|0,4448);d=Df(c,e);xb(e);if(d){c=f+36|0;e=x[x[b+24>>2]+480184>>2];b=77712;l:{m:{while(1){if((e|0)==x[b>>2]){break m}b=b+12|0;if((b|0)!=77760){continue}break}gd(c);break l}go(c,0,x[b+8>>2])}x[114409]=0;T(9,a|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break j}xb(f+36|0);break k}e=Vb(f+36|0,6922);d=Df(c,e);xb(e);if(d){g=f+36|0;j=x[x[b+24>>2]+480184>>2];e=hb-48|0;hb=e;b=77712;i=hb-16|0;hb=i;h=i+15|0;d=hb-16|0;hb=d;x[114409]=0;c=e+36|0;S(1621,c+4|0)|0;k=x[114409];x[114409]=0;n:{o:{if((k|0)==1){break o}x[114409]=0;x[d+12>>2]=0;U(1622,c+8|0,d+12|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break o}r=c,s=mc(c),x[r>>2]=s;hb=d+16|0;break n}R(0)|0;zb();p()}hb=i+16|0;d=gd(g);while(1){if(x[b>>2]==(j|0)){x[114409]=0;i=O(2,e+24|0,x[b+4>>2])|0;h=x[114409];x[114409]=0;p:{q:{r:{s:{t:{u:{if((h|0)!=1){x[114409]=0;T(1620,e+16|0,c|0,i|0);h=x[114409];x[114409]=0;if((h|0)==1){break s}if(!y[e+20|0]){break p}if(!Yc(d)){x[114409]=0;h=O(2,e+4|0,13622)|0;k=x[114409];x[114409]=0;if((k|0)==1){break u}x[114409]=0;O(164,d|0,h|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break t}xb(h)}x[114409]=0;O(164,d|0,i|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break p}b=N()|0;break r}b=N()|0;break q}b=N()|0;break r}b=N()|0;xb(h);break r}b=N()|0}xb(i)}xb(d);WL(c);Q(b|0);p()}xb(i)}b=b+12|0;if((b|0)!=77760){continue}break}WL(c);hb=e+48|0;x[114409]=0;T(9,a|0,0,g|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(f+36|0);break k}c=N()|0;xb(f+36|0);break a}e=Vb(f+36|0,4514);d=Df(c,e);xb(e);if(d){zj(a,0,x[b+24>>2]+1304460|0);break k}e=Vb(f+36|0,2106);d=Df(c,e);xb(e);if(d){zj(a,0,x[b+24>>2]+1304412|0);break k}e=Vb(f+36|0,7848);d=Df(c,e);xb(e);if(d){c=f+36|0;Zf(c,x[b+24>>2]+1304400|0);x[114409]=0;T(2309,a|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(f+36|0);break k}c=N()|0;xb(f+36|0);break a}e=Vb(f+36|0,7253);d=Df(c,e);xb(e);if(d){v:{if(!kd(Ax(x[b+24>>2]))){if(x[RI(Ax(x[b+24>>2]))+12>>2]){break v}}Xb(a);break k}b=RI(Ax(x[b+24>>2]));j=hb-144|0;hb=j;sc(j+100|0,b,44);i=x[b+44>>2];if(i){sc(j+44|0,b,44);c=hb-16|0;hb=c;h=c+8|0;b=Rw(x[j+64>>2]+1900|0,x[j+60>>2]+1|0,x[j+56>>2])-Rw(1970,1,1)|0;b=sqa(b,b>>31,86400,0);e=D(x[j+52>>2],3600);b=b+e|0;d=lb+(e>>31)|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=D(x[j+48>>2],60);g=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<g>>>0?b+1|0:b;d=x[j+44>>2];g=d;e=d+e|0;d=(d>>31)+b|0;b=VG(h,e,e>>>0<g>>>0?d+1|0:d);e=x[b>>2];b=x[b+4>>2];hb=c+16|0;x[j+88>>2]=e;x[j+92>>2]=b;k=j+100|0;e=j+88|0;h=x[j+88>>2];d=x[j+92>>2];c=2147483647;m=Td(+(i>>>0)*.054945054945054944);g=-1;w:{if(!(m<0x8000000000000000)){break w}c=-2147483648;g=0;if(!(m>-0x8000000000000000)){break w}if(F(m)<0x8000000000000000){c=F(m)>=1?~~(m>0?H(J(m*2.3283064365386963e-10),4294967295):K((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;g=~~m>>>0;break w}g=0}b=g;d=c+d|0;b=b+h|0;d=g>>>0>b>>>0?d+1|0:d;b=VG(e,b,d);c=hb-16|0;hb=c;h=x[b>>2];b=x[b+4>>2];o=b;x[c+12>>2]=0;x[c+8>>2]=0;x[c+4>>2]=0;i=Rw(1970,1,1)+tqa(h,b,86400,0)|0;g=i>>31;e=sqa(i,g,1e4,0);b=lb;e=e+14780|0;b=e>>>0<14780?b+1|0:b;l=tqa(e,b,-14609700,-1);d=g+lb|0;l=i+l|0;d=l>>>0<i>>>0?d+1|0:d;n=tqa(e,b,365242500,0);l=n+l|0;d=lb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=tqa(e,b,-146097e4,-1);l=n+l|0;d=lb+d|0;d=l>>>0<n>>>0?d+1|0:d;b=tqa(e,b,3652425,0);e=lb;n=e;q=l;l=sqa(b,e,-365,-1);e=q+l|0;d=lb+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){e=b-1|0;b=sqa(e,n-!b|0,-365,-1);d=g+lb|0;b=b+i|0;d=b>>>0<i>>>0?d+1|0:d;g=b;b=e;i=(b|0)/-4|0;e=g+i|0;d=(i>>31)+d|0;d=e>>>0<i>>>0?d+1|0:d;i=(b|0)/100|0;e=i+e|0;d=(i>>31)+d|0;d=e>>>0<i>>>0?d+1|0:d;i=(b|0)/-400|0;e=i+e|0;d=(i>>31)+d|0;d=e>>>0<i>>>0?d+1|0:d}i=b;d=sqa(e,d,100,0);b=lb;d=d+52|0;b=d>>>0<52?b+1|0:b;g=i;b=tqa(d,b,3060,0);d=b+2|0;i=(d|0)/12|0;x[c+12>>2]=g+i;x[c+8>>2]=(d-D(i,12)|0)+1;b=sqa(b,lb,306,0);d=lb;b=b+5|0;d=b>>>0<5?d+1|0:d;b=tqa(b,d,-10,-1)+e|0;x[c+4>>2]=b+1;OG(k);x[k+20>>2]=x[c+12>>2]-1900;x[k+16>>2]=x[c+8>>2]-1;b=x[c+4>>2];r=k,s=uqa(tqa(h,o,3600,0),lb,24),x[r+8>>2]=s;x[k+12>>2]=b;b=tqa(h,o,60,0);e=lb;r=k,s=uqa(b,e,60),x[r+4>>2]=s;r=k,s=h-sqa(b,e,60,0)|0,x[r>>2]=s;hb=c+16|0}i=f+36|0;c=sc(j,j+100|0,44);b=hb-144|0;hb=b;e=gd(b+132|0);x[114409]=0;d=O(2,b+120|0,9325)|0;h=x[114409];x[114409]=0;x:{y:{z:{A:{B:{if((h|0)!=1){h=x[c+20>>2];if(!h){break y}x[114409]=0;x[b+96>>2]=h+1900;P(163,b+108|0,b+96|0);h=x[114409];x[114409]=0;if((h|0)!=1){x[114409]=0;O(164,e|0,b+108|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break B}xb(b+108|0);if(A[c+16>>2]>11){break y}x[114409]=0;h=O(2,b+96|0,12738)|0;g=x[114409];x[114409]=0;C:{D:{E:{F:{G:{H:{if((g|0)!=1){g=x[c+16>>2];x[114409]=0;x[b+72>>2]=g+1;P(165,b+84|0,b+72|0);g=x[114409];x[114409]=0;if((g|0)==1){break H}x[114409]=0;T(3,b+108|0,h|0,b+84|0);g=x[114409];x[114409]=0;if((g|0)==1){break G}x[114409]=0;O(164,e|0,b+108|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break F}xb(b+108|0);xb(b+84|0);xb(h);if(x[c+12>>2]-32>>>0>=4294967265){break C}break y}a=N()|0;break A}a=N()|0;break D}a=N()|0;break E}a=N()|0;xb(b+108|0)}xb(b+84|0)}xb(h);break A}x[114409]=0;h=O(2,b+84|0,12738)|0;g=x[114409];x[114409]=0;I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((g|0)!=1){x[114409]=0;P(165,b+72|0,c+12|0);g=x[114409];x[114409]=0;if((g|0)==1){break fa}x[114409]=0;T(3,b+108|0,h|0,b+72|0);g=x[114409];x[114409]=0;if((g|0)==1){break ea}x[114409]=0;O(164,e|0,b+108|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break da}xb(b+108|0);xb(b+72|0);xb(h);h=x[c+8>>2];g=x[c+4>>2];if(!(x[c>>2]|(h|g))|h>>>0>23|g>>>0>59){break y}x[114409]=0;h=O(2,b+108|0,9486)|0;g=x[114409];x[114409]=0;if((g|0)==1){break aa}x[114409]=0;O(164,e|0,h|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break $}xb(h);if(x[c+32>>2]>0){x[114409]=0;h=O(2,b+72|0,11624)|0;g=x[114409];x[114409]=0;if((g|0)==1){break _}Eb(d,h);xb(h)}x[114409]=0;P(165,b+36|0,c+8|0);h=x[114409];x[114409]=0;if((h|0)==1){break Z}x[114409]=0;h=O(2,b+24|0,10181)|0;g=x[114409];x[114409]=0;if((g|0)==1){break Y}x[114409]=0;T(3,b+48|0,b+36|0,h|0);g=x[114409];x[114409]=0;if((g|0)==1){break X}x[114409]=0;P(165,b+12|0,c+4|0);g=x[114409];x[114409]=0;if((g|0)==1){break W}x[114409]=0;T(3,b+60|0,b+48|0,b+12|0);g=x[114409];x[114409]=0;if((g|0)==1){break V}x[114409]=0;O(164,e|0,b+60|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break U}xb(b+60|0);xb(b+12|0);xb(b+48|0);xb(h);xb(b+36|0);if(A[c>>2]<62){break P}x[114409]=0;T(166,i|0,e|0,d|0);h=x[114409];x[114409]=0;if((h|0)==1){break O}break x}a=N()|0;break A}a=N()|0;break ba}a=N()|0;break ca}a=N()|0;xb(b+108|0)}xb(b+72|0)}xb(h);break A}a=N()|0;break A}a=N()|0;xb(h);break A}a=N()|0;break A}a=N()|0;break A}a=N()|0;break Q}a=N()|0;break R}a=N()|0;break S}a=N()|0;break T}a=N()|0;xb(b+60|0)}xb(b+12|0)}xb(b+48|0)}xb(h)}xb(b+36|0);break A}x[114409]=0;h=O(2,b+48|0,10181)|0;g=x[114409];x[114409]=0;if((g|0)==1){break N}x[114409]=0;P(165,b+36|0,c|0);g=x[114409];x[114409]=0;if((g|0)==1){break M}x[114409]=0;T(3,b+60|0,h|0,b+36|0);g=x[114409];x[114409]=0;if((g|0)==1){break L}x[114409]=0;O(164,e|0,b+60|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break K}xb(b+60|0);xb(b+36|0);xb(h);x[114409]=0;O(164,e|0,d|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break y}}a=N()|0;break A}a=N()|0;break A}a=N()|0;break I}a=N()|0;break J}a=N()|0;xb(b+60|0)}xb(b+36|0)}xb(h);break A}a=N()|0;break A}a=N()|0;break z}a=N()|0;xb(b+108|0)}xb(d)}xb(e);Q(a|0);p()}Jd(i,e)}xb(d);xb(e);hb=b+144|0;hb=c+144|0;x[114409]=0;T(9,a|0,0,i|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(f+36|0);break k}c=N()|0;xb(f+36|0);break a}e=Vb(f+36|0,8039);d=Df(c,e);xb(e);if(d){c=f+36|0;pP(c,x[b+24>>2]+1304424|0);ga:{ha:{ia:{if(!Yc(c)){break ia}c=x[b+24>>2];x[114409]=0;c=S(2310,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break ga}ja:{switch(c|0){case 0:x[114409]=0;P(2311,f+24|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=f+24|0;Eb(f+36|0,c);xb(c);break ia}c=N()|0;break b;case 1:x[114409]=0;P(2312,f+24|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=f+24|0;Eb(f+36|0,c);xb(c);break ia}c=N()|0;break b;case 2:if(Yc(f+36|0)){x[114409]=0;P(2311,f+24|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break i}c=f+24|0;Eb(f+36|0,c);xb(c)}if(!Yc(f+36|0)){break ia}x[114409]=0;P(2312,f+24|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=f+24|0;Eb(f+36|0,c);xb(c);break ia}c=N()|0;break b;case 3:if(Yc(f+36|0)){x[114409]=0;P(2312,f+24|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break h}c=f+24|0;Eb(f+36|0,c);xb(c)}if(!Yc(f+36|0)){break ia}x[114409]=0;P(2311,f+24|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=f+24|0;Eb(f+36|0,c);xb(c);break ia}c=N()|0;break b;case 4:x[114409]=0;P(2311,f+24|0,b|0);c=x[114409];x[114409]=0;ka:{la:{if((c|0)!=1){x[114409]=0;P(2312,f+12|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break ka}if(Yc(f+24|0)){break la}x[114409]=0;O(1328,f+36|0,f+24|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break la}break d}c=N()|0;break b}if(!Yc(f+12|0)){x[114409]=0;O(1328,f+36|0,f+12|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break d}}xb(f+12|0);xb(f+24|0);break ia}c=N()|0;break c;case 5:break ja;default:break ia}}x[114409]=0;P(2311,f+24|0,b|0);c=x[114409];x[114409]=0;ma:{if((c|0)!=1){x[114409]=0;P(2312,f+12|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break ha}if(Yc(f+12|0)){break ma}x[114409]=0;O(1328,f+36|0,f+12|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break ma}break f}c=N()|0;break b}if(!Yc(f+24|0)){x[114409]=0;O(1328,f+36|0,f+24|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}}xb(f+12|0);xb(f+24|0)}x[114409]=0;T(2309,a|0,b|0,f+36|0);a=x[114409];x[114409]=0;if((a|0)==1){break ga}xb(f+36|0);break k}c=N()|0;break e}c=N()|0;break b}e=Vb(f+36|0,1958);d=Df(c,e);xb(e);if(d){c=f+36|0;pP(c,x[b+24>>2]+1304424|0);x[114409]=0;T(2309,a|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(f+36|0);break k}c=N()|0;xb(f+36|0);break a}e=c;c=Vb(f+36|0,3559);e=Df(e,c);xb(c);if(e){a=Xb(a);b=b+68|0;r=f,s=bc(b),x[r+36>>2]=s;r=f,s=dc(b),x[r+24>>2]=s;if(!Hb(f+36|0,f+24|0)){break k}c=1;while(1){b=x[f+36>>2];if(!(c&1)){x[114409]=0;O(2119,a|0,17358)|0;c=x[114409];x[114409]=0;if((c|0)==1){break g}}x[114409]=0;O(1328,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}b=f+36|0;dk(b);c=0;if(Hb(b,f+24|0)){continue}break}break k}Vb(a,17381)}hb=f+48|0;return}c=N()|0;xb(f+36|0);break a}c=N()|0;break b}c=N()|0;break b}c=N()|0;xb(a);break a}c=N()|0;xb(f+12|0)}xb(f+24|0);break b}c=N()|0;xb(f+12|0)}xb(f+24|0)}xb(f+36|0)}Q(c|0);p()}function Fca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=E(0),G=0,H=0,I=0,J=0,K=E(0),L=0,M=0;g=hb-48|0;hb=g;if(!(x[a+1074308>>2]==18284544|A[a+1074308>>2]>=18285126)){Kg(a+1074312|0,0)}b=g+36|0;i=a+1074312|0;Kb(b,i,0);if(Ib(b)){u=(x[a+480180>>2]&16777248)!=0}b=g+36|0;Kb(b,i,0);if(Ib(b)){J=x[a+480180>>2]==4}if(A[a+1074308>>2]<18874368){a:{if(!z[a+480192>>1]){break a}c=1;while(1){b:{b=x[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}x[g+36>>2]=D(y[b+20|0],100)>>>6;x[g+24>>2]=100;L=b,M=x[Mb(g+36|0,g+24|0)>>2],v[L+20|0]=M;c:{d:{if(u){if(A[a+1074308>>2]<18350080){e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2}if(A[a+1074308>>2]<18285314){break d}break c}e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2}zz(oC(b,2),4,x[a+480180>>2])}e:{if(!y[b+34|0]|(A[a+1074308>>2]<18284544|A[a+1074308>>2]>=18285136)){break e}if(!Ri(b)){break e}Nb(i,2,1)}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))|A[a+1074308>>2]>=18285136){break b}Nb(i,1,1);break a}c=c+1|0;if(z[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!z[a+480190>>1]|(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>=18285314&u))){b=1;while(1){c=D(b&65535,104)+a|0;e=c+484419|0;if(!(y[e|0]|!(y[c+484421|0]|y[c+484420|0]))){v[e|0]=255}b=b+1|0;if(z[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;h=sP(b);if((b|0)!=(h|0)){while(1){f=0;c=b;while(1){e=y[c|0];f:{g:{if((e-97&255)>>>0<=5){d=e-32|0;break g}d=99;h:{if(e>>>0<=106){if(e-88>>>0<2){break h}if((e|0)==75){break g}break f}if(e-120>>>0<2){break h}if((e|0)==107){break g}break f}d=122}v[c|0]=d}f=f+1|0;c=f+b|0;if((f|0)!=32){continue}break}b=b+32|0;if((h|0)!=(b|0)){continue}break}}}i:{if(x[a+1074308>>2]==18874368|A[a+1074308>>2]>=18874896|(!(x[a+480180>>2]&16777252)|!z[a+480192>>1])){break i}b=1;c=0;while(1){j:{e=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(y[e+31|0]?e:0)){b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break j}break i}v[e+33|0]=13;c=1;b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}}break}Nb(i,3,1)}k:{if(!(x[a+480180>>2]&16777248)|(x[a+1074308>>2]==19005440|A[a+1074308>>2]>=19006226)){break k}b=g+36|0;Kb(b,i,0);if(!Ib(b)){b=g+24|0;Kb(b,i,1);if(!Ib(b)){break k}}if(!z[a+480192>>1]){break k}b=1;while(1){c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}l:{m:{n:{if(A[a+1074308>>2]<19007233){e=a+946300|0;b=a+906300|0;while(1){c=hb-16|0;hb=c;d=c+4|0;h=b+80|0;Qu(d,1,h);k=g+24|0;Kc(k,d);hb=c+16|0;x[114409]=0;W(409,g+36|0,0,7,k|0);c=x[114409];x[114409]=0;if((c|0)==1){break m}xb(g+24|0);x[114409]=0;O(487,h|0,g+36|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break n}xb(g+36|0);b=b+160|0;if((e|0)!=(b|0)){continue}break}}if(!(x[a+480180>>2]!=4|A[a+1074308>>2]<19007257|(x[a+1074372>>2]!=4|A[a+1074308>>2]>=19071236))){Jy(a,5)}if(!(!z[a+480192>>1]|(x[a+1074308>>2]==19202048|A[a+1074308>>2]>=19202055))){c=1;while(1){d=(((c&65535)<<2)+a|0)+900380|0;b=x[d>>2];o:{if(!b|!y[b+20|0]|!y[b+31|0]){break o}b=b+236|0;e=St(b);if((b|0)!=(e|0)){while(1){if(z[b>>1]){break o}b=b+2|0;if((e|0)!=(b|0)){continue}break}}v[x[d>>2]+20|0]=0}c=c+1|0;if(z[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!z[a+480192>>1]|A[a+1074308>>2]>=19267584)){c=1;while(1){b=x[(((c&65535)<<2)+a|0)+900380>>2];p:{if(!b){break p}e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2;if(A[a+1074308>>2]>=18350080&u){break p}v[b+19|0]=y[b+19|0]+3>>>2}c=c+1|0;if(z[a+480192>>1]>=(c&65535)>>>0){continue}break}}q:{if(!z[a+480192>>1]|A[a+1074308>>2]>=19398674){break q}b=1;while(1){c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|y[c+65|0]==255)){Nb(i,94,1);break q}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}r:{if(!z[a+480192>>1]|A[a+1074308>>2]>=19399428){break r}b=1;while(1){c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|y[c+36|0]>1)){Nb(i,101,1);break r}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=hb-16|0;hb=b;w[g+20>>1]=0;x[g+16>>2]=a;c=b+8|0;Kb(c,a+1074312|0,0);L=g,M=Ib(c),v[L+22|0]=M;hb=b+16|0;b=x[g+20>>2];x[g+8>>2]=x[g+16>>2];x[g+12>>2]=b;m=hb-16|0;hb=m;o=a+484344|0;e=Ne(o);c=x[g+12>>2];b=x[g+8>>2];x[m>>2]=b;x[m+4>>2]=c;x[m+8>>2]=b;x[m+12>>2]=c;b=hb-32|0;hb=b;G=e-1&65535;if(Ne(o)>>>0>G>>>0){e=x[m>>2];H=x[m+4>>2];while(1){c=B&65535;if(Ah(Ye(o,c))){d=bc(Ye(o,c));c=dc(Ye(o,c));x[b+24>>2]=e;x[b+28>>2]=H;x[b+8>>2]=e;x[b+12>>2]=H;k=b+8|0;n=hb-16|0;hb=n;x[n+8>>2]=c;x[n+12>>2]=d;if(Hb(n+12|0,n+8|0)){while(1){C=n+12|0;d=x[C>>2];s=z[k+4>>1];c=s+1|0;w[k+4>>1]=c;if(z[x[k>>2]+480188>>1]<=(c&65535)>>>0){w[k+4>>1]=0}s:{if(Hn(d)){break s}c=x[k>>2];h=x[c+1074308>>2];t=x[c+480180>>2];t:{if((t|0)==2){if(y[d+3|0]!=23|h>>>0>=18415616){break t}df(d+5|0,64);break t}if(t&16777248){u:{if(y[k+6|0]|h>>>0>=18874368?h>>>0>=18285314:0){break u}v:{switch(y[d+3|0]-20|0){case 3:df(d+5|0,128);break u;case 0:break v;default:break u}}c=y[d+5|0];if((c|0)!=208){if((c|0)!=192){break u}v[d|0]=254;v[d+3|0]=0;break u}v[d+3|0]=0}w:{if(h>>>0>=18350080){c=0;if(y[k+6|0]|h>>>0>=18874368){break w}}f=y[d+3|0];c=0;if(f>>>0>29){break w}c=536873152>>>f&1}if(h>>>0<18874368){f=y[d+3|0];f=(f|0)==24|(f|0)==22}else{f=0}x:{if(!(f|c)){break x}f=y[d+5|0];c=f&15;if(!c|(c|0)==15){break x}f=f&240;if(!f|(f|0)==240){break x}v[d+5|0]=y[d+3|0]==24?f:c}if(!(!z[x[k>>2]+480192>>1]|((h|0)==19005440|h>>>0>=19005700)|(y[k+6|0]|z[x[k>>2]+480192>>1]>=y[d+1|0]))){v[d+4|0]=0;v[d+2|0]=1}if(y[d+5|0]!=17|h>>>0>=19468802|y[d+3|0]!=18){break t}if(!$b(x[k>>2]+1074312|0,22)|y[x[k>>2]+480208|0]&4){break t}v[d+5|0]=0;break t}if((t|0)!=4){break t}y:{if(!(y[k+6|0]?h>>>0>=18285314:0)&h>>>0<18874368|(y[d+3|0]!=23|h>>>0>=19137026)){break y}if(y[d+5|0]<65){break y}v[d+3|0]=0}if(!(y[d+3|0]!=10|(y[k+6|0]|h>>>0>=18874368?h>>>0>=18415616:0)|y[d+2|0]!=11)){v[d+3|0]=0}z:{if(y[d+2|0]!=11|h>>>0>=18874640|y[d+3|0]!=4){break z}c=y[d+4|0];if(!(c|y[k+6|0])){break z}f=y[d+5|0];if(!f){break z}v[d+2|0]=0;L=d,M=jS(f+(c<<4)|0),v[L+5|0]=M}if(y[d+5|0]|(y[d+3|0]!=16|h>>>0>=19007241)){break t}v[d+3|0]=0}A:{if(h>>>0>=18874368){break A}f=y[d+3|0];c=y[d+5|0]&240;B:{C:{if((f|0)!=28|(c|0)!=96){I=0}else{if(!y[k+6|0]|(t|0)!=4){break C}I=h>>>0<18350080}if(!(I|(f|0)==20&(c|0)==96)){break B}}if(!s){break B}f=d+D(s,-6)|0;while(1){if(!((y[f+3|0]|8)!=28|(y[f+5|0]&240)!=96)){v[f+3|0]=0}f=f+6|0;if(d>>>0>f>>>0){continue}break}}if(!s|(y[d+5|0]&240)!=224|y[d+3|0]!=20){break A}f=d+D(s,-6)|0;while(1){if(!(y[f+3|0]!=20|(y[f+5|0]&240)!=224)){v[f+3|0]=0}f=f+6|0;if(d>>>0>f>>>0){continue}break}}D:{if(y[d+2|0]!=8|h>>>0>=19333175|(h|0)==19333120){break D}h=y[d+4|0];c=y[d+3|0];if(!(!h|(c|0)!=7)){v[d+3|0]=11;break D}E:{F:{switch(c-5|0){default:if((c|0)!=26){break D}break;case 1:break D;case 2:break E;case 0:break F}}f=y[d+5|0];if(!(f&15)){v[d+2|0]=0;v[d+3|0]=5;v[d+5|0]=f|h&15;break D}G:{switch(c-5|0){case 1:break D;case 0:case 2:break E;default:break G}}if((c|0)!=26){break D}}v[d+2|0]=0}if(y[d+3|0]|((t|0)==16777216|y[d+2|0]!=15)){break s}v[d+2|0]=0;v[d+3|0]=10;v[d+5|0]=y[d+4|0]<<3}Sj(C);if(Hb(C,n+8|0)){continue}break}}c=x[k+4>>2];x[b+16>>2]=x[k>>2];x[b+20>>2]=c;hb=n+16|0}B=B+1|0;if((B&65535)>>>0<=G>>>0){continue}break}}c=x[m+4>>2];x[g+36>>2]=x[m>>2];x[g+40>>2]=c;hb=b+32|0;hb=m+16|0;H:{if(!(!u|A[a+1074308>>2]>=19267584)){b=35040;while(1){c=x[a+1074308>>2];e=x[b+4>>2];Nb(i,x[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=35384){continue}break}break H}if(!J|A[a+1074308>>2]>=19267584){break H}b=35392;while(1){Nb(i,x[b>>2],A[a+1074308>>2]>=A[b+4>>2]);b=b+8|0;if((b|0)!=35632){continue}break}}I:{if(x[a+480180>>2]&16777248){b=35632;while(1){c=x[a+1074308>>2];e=x[b+4>>2];d=e&-65536;if(!(c>>>0>=d>>>0&(c>>>0<=d>>>0|c>>>0>=e>>>0))){Kg(i,x[b>>2])}b=b+8|0;if((b|0)!=35680){continue}break}break I}if(x[a+480180>>2]==4){b=35680;while(1){if(A[a+1074308>>2]<A[b+4>>2]){Kg(i,x[b>>2])}b=b+8|0;if((b|0)!=35736){continue}break}break I}if(x[a+480180>>2]!=2){break I}b=35744;while(1){if(A[a+1074308>>2]<A[b+4>>2]){Kg(i,x[b>>2])}b=b+8|0;if((b|0)!=35824){continue}break}}if(!(x[a+480180>>2]!=4|A[a+1074308>>2]>=18415616)){Nb(i,98,1)}if(!(A[a+1074308>>2]<19333159|A[a+1074308>>2]>=19333193)){b=0;while(1){c=g+36|0;e=b+77|0;Kb(c,i,e);Nb(i,b+86|0,Ib(c));Kg(i,e);b=b+1|0;if((b|0)!=5){continue}break}}c=8;J:{if(A[a+1074308>>2]>=18284544){if(A[a+1074308>>2]<18284544|A[a+1074308>>2]>18874627){break J}c=6;if(x[a+1074308>>2]==18874368){break J}}Nb(i,c,1)}K:{if(A[a+1074308>>2]<19136512){Kg(i,7);break K}if(!(x[a+480180>>2]&16777248)|(A[a+1074308>>2]<19136512|A[a+1074308>>2]>=19267584)){break K}Nb(i,7,1)}b=g+36|0;Kb(b,i,31);L:{if(!Ib(b)|A[a+1074308>>2]<19071234|(!z[a+480192>>1]|A[a+1074308>>2]>=19398723)){break L}b=1;while(1){M:{c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break M}e=y[c+65|0];if(!(y[c+60|0]&4)|(e|0)==255|e>>>0<=y[c- -64|0]){break M}Nb(i,97,1);break L}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}N:{if(!(x[a+480180>>2]&16777218)|!z[a+480190>>1]){break N}b=1;while(1){if(!(y[(D(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(z[a+480190>>1]>=(b&65535)>>>0){continue}break N}break}if(!(!z[a+480192>>1]|x[a+480180>>2]!=16777216|(A[a+1074308>>2]<19398688|A[a+1074308>>2]>19464277))){Nb(i,109,1)}if(!(x[a+480180>>2]!=2|A[a+1074308>>2]>=19464192)){Nb(i,108,1);break N}if(x[a+480180>>2]==2){break N}Kg(i,108)}if(!(!(x[a+480180>>2]&16777252)|(A[a+1074308>>2]<19333120|A[a+1074308>>2]>=19924480))){e=a+946300|0;a=a+906300|0;while(1){O:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break O}if((xc(a+4|0)|0)!=24){break O}b=x[a+4>>2];F=(l(2,y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24)),r());b=x[a+4>>2];K=rf(E(E((l(2,y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24)),r())*E(1.0005003213882446))+E(-.0005002501420676708)),E(0));F=rf(E(E(F*E(1.0005003213882446))+E(-.0005002501420676708)),E(0));b=x[a+4>>2];c=(q(K),j(2));v[b+12|0]=c;v[b+13|0]=c>>>8;v[b+14|0]=c>>>16;v[b+15|0]=c>>>24;b=x[a+4>>2];c=(q(F),j(2));v[b+16|0]=c;v[b+17|0]=c>>>8;v[b+18|0]=c>>>16;v[b+19|0]=c>>>24}a=a+160|0;if((e|0)!=(a|0)){continue}break}}hb=g+48|0;return}a=N()|0;xb(g+36|0);break l}a=N()|0;xb(g+24|0)}Q(a|0);p()}function rW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=ej(b,9630);a:{if(!l){break a}if(!Qb(b,6)){break a}while(1){b:{e=Kf(b);c:{if((e|0)==(Vj(9493)|0)){break c}d=y[17369]|y[17370]<<8|(y[17371]<<16|y[17372]<<24);if(!(e&1616928864)|e&-2139062144){break c}if((d|0)!=(e|0)){break b}}rg(b,4);break a}k=1;c=tg(b);if(z[a+480192>>1]){while(1){f=x[(((k&65535)<<2)+a|0)+900380>>2];if(f){d:{if((Vj(12694)|0)==(e|0)){cc(b,c);break d}d=0;g=hb-32|0;hb=g;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+23|0]=n;d=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+18|0]=n;d=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Qb(b,c)){break n}m=f,n=hv(b,c),x[m>>2]=n;d=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+21|0]=n;d=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}h=f+236|0;Ad(g+16|0,b,c);while(1){x[114409]=0;i=S(353,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break F}m=fd(h,d),n=i,w[m>>1]=n;d=d+1|0;if(d>>>0<128){continue}break}Ab(g+16|0);d=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+31|0]=n;d=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+34|0]=n;d=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+16|0]=n;d=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}x[g+16>>2]=240;m=g,n=yo(b,c),x[m+4>>2]=n;Qg(f+68|0,x[Mb(g+16|0,g+4|0)>>2]);d=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}Ad(g+16|0,b,c);x[114409]=0;h=O(354,f|0,1)|0;i=x[114409];x[114409]=0;if((i|0)==1){break k}if(Lb(h)){while(1){x[114409]=0;i=S(355,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break k}m=Pb(h,d),n=i,v[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+82|0]=n;d=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+27|0]=n;d=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}Ad(g+16|0,b,c);x[114409]=0;h=O(354,f|0,1)|0;i=x[114409];x[114409]=0;if((i|0)==1){break h}if(Lb(h)){while(1){x[114409]=0;i=S(353,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break h}m=Pb(h,d),n=i,w[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+83|0]=n;d=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}m=f,n=D(gv(b,c),1e4)+(A[f+40>>2]%1e4|0)|0,x[m+40>>2]=n;d=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+36|0]=n;d=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}Ad(g+16|0,b,c);x[114409]=0;h=O(354,f|0,2)|0;i=x[114409];x[114409]=0;if((i|0)==1){break l}if(Lb(h)){while(1){x[114409]=0;i=S(355,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break l}m=Pb(h,d),n=i,v[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}Ad(g+16|0,b,c);x[114409]=0;h=O(354,f|0,2)|0;i=x[114409];x[114409]=0;if((i|0)==1){break i}if(Lb(h)){while(1){x[114409]=0;i=S(353,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break i}m=Pb(h,d),n=i,w[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+24|0]=n;d=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}Ad(g+16|0,b,c);x[114409]=0;h=O(354,f|0,0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break j}if(Lb(h)){while(1){x[114409]=0;i=S(355,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break j}m=Pb(h,d),n=i,v[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+62|0]=n;d=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}Ad(g+16|0,b,c);x[114409]=0;h=O(354,f|0,0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}if(Lb(h)){while(1){x[114409]=0;i=S(353,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break g}m=Pb(h,d),n=i,w[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+63|0]=n;d=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+15|0]=n;d=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}Ad(g+16|0,b,c);h=Xb(g+4|0);if(c){while(1){x[114409]=0;i=S(356,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break E}x[114409]=0;O(357,h|0,i|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}x[114409]=0;O(348,f+492|0,h|0)|0;i=x[114409];x[114409]=0;d=1;if((i|0)==1){break E}xb(h);Ab(g+16|0);break n}if(c>>>0>4){break n}if(!Qb(b,c)){break n}m=f,n=hv(b,c),x[m+4>>2]=n;d=1;break n}if(c>>>0>4){break n}if(!Qb(b,c)){break n}m=f,n=hv(b,c),x[m+8>>2]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+61|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f- -64|0,n=md(b,c),v[m|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+81|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+84|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+101|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+102|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+103|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+104|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+17|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+19|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+20|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+22|0]=n;d=1;break n}if(c>>>0>2){break n}if(!Qb(b,c)){break n}m=f,n=nC(b,c),w[m+28>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+30|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=mC(b,c),v[m+26|0]=n;d=1;break n}if(c>>>0>128){break n}h=f+108|0;Ad(g+16|0,b,c);while(1){x[114409]=0;i=S(355,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break p}m=fc(h,d),n=i,v[m|0]=n;d=d+1|0;if(d>>>0<128){continue}break}Ab(g+16|0);d=1;break n}d=N()|0;break f}d=N()|0;xb(h);break f}if(c>>>0>32){break n}Ad(g+16|0,b,c);h=Xb(g+4|0);if(c){while(1){x[114409]=0;i=S(356,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break m}x[114409]=0;O(357,h|0,i|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}x[114409]=0;O(348,f+524|0,h|0)|0;i=x[114409];x[114409]=0;d=1;if((i|0)!=1){xb(h);Ab(g+16|0);break n}break m}if(c>>>0>2){break n}if(!Qb(b,c)){break n}m=f,n=nC(b,c),w[m+12>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+25|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+35|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+105|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+85|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+65|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+100|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+80|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+60|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=mC(b,c),v[m+33|0]=n;d=1;break n}d=1;h=yo(b,c);if(!xo(h)){break n}v[f+14|0]=h;break n}x[g+16>>2]=240;m=g,n=yo(b,c),x[m+4>>2]=n;Qg(f+48|0,x[Mb(g+16|0,g+4|0)>>2]);d=1;break n}x[g+16>>2]=240;m=g,n=yo(b,c),x[m+4>>2]=n;Qg(f+88|0,x[Mb(g+16|0,g+4|0)>>2]);d=1;break n}d=N()|0;break f}h=(gv(b,c)>>>0)%1e4|0;d=x[f+40>>2];x[f+40>>2]=h+d-(d>>>0)%1e4;d=1}hb=g+32|0;break e}d=N()|0;xb(h);break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0}Ab(g+16|0);Q(d|0);p()}if(!d){cc(b,c);break d}if((Vj(12699)|0)==(e|0)){d=y[f+15|0];v[f+15|0]=0;v[f+100|0]=y[f+100|0]&224|(d>>>5&4|d>>>6&1);v[f+60|0]=d>>>1&2|(d<<1&4|(y[f+60|0]&240|d&1));v[f+80|0]=y[f+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}k=k+1|0;if(z[a+480192>>1]>=(k&65535)>>>0){continue}break}}if(Qb(b,6)){continue}break}}return l|0}function xd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(a>>>0<=244){g=x[114285];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+457180|0;d=x[a+457188>>2];a=x[d+8>>2];o:{if((b|0)==(a|0)){m=457140,n=wqa(-2,c)&g,x[m>>2]=n;break o}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[114287];if(k>>>0>=h>>>0){break n}if(b){a=2<<c;a=(0-a|a)&b<<c;d=rqa(0-a&a);a=d<<3;b=a+457180|0;e=x[a+457188>>2];a=x[e+8>>2];p:{if((b|0)==(a|0)){g=wqa(-2,d)&g;x[114285]=g;break p}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+457180|0;f=x[114290];a=1<<(k>>>3);q:{if(!(a&g)){x[114285]=a|g;a=b;break q}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[114290]=c;x[114287]=d;break a}j=x[114286];if(!j){break n}c=x[(rqa(0-j&j)<<2)+457444>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){r:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break r}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break m}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break n}a=a+11|0;h=a&-8;j=x[114286];if(!j){break n}f=0-h|0;g=0;s:{if(h>>>0<256){break s}g=31;if(h>>>0>16777215){break s}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+457444>>2];t:{u:{v:{if(!b){a=0;break v}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){w:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break w}d=b;f=e;if(e){break w}f=0;a=b;break u}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break n}a=x[(rqa(a&0-a)<<2)+457444>>2]}if(!a){break t}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[114287]-h>>>0<=f>>>0){break n}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break l}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[114287];if(a>>>0>=h>>>0){d=x[114290];b=a-h|0;x:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break x}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[114287]=b;x[114290]=c;a=d+8|0;break a}i=x[114288];if(i>>>0>h>>>0){b=i-h|0;x[114288]=b;c=x[114291];a=c+h|0;x[114291]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[114403]){c=x[114405]}else{x[114406]=-1;x[114407]=-1;x[114404]=4096;x[114405]=4096;x[114403]=l+12&-16^1431655768;x[114408]=0;x[114396]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[114395];if(d){c=x[114393];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}y:{if(!(y[457584]&4)){z:{A:{B:{C:{d=x[114291];if(d){a=457588;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break C}a=x[a+8>>2];if(a){continue}break}}c=jn(0);if((c|0)==-1){break z}g=b;d=x[114404];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break z}d=x[114395];if(d){a=x[114393];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break z}}a=jn(g);if((c|0)!=(a|0)){break B}break y}g=f&e-i;c=jn(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break A}a=c}if((a|0)==-1){break z}if(h+48>>>0<=g>>>0){c=a;break y}c=x[114405];c=c+(j-g|0)&0-c;if((jn(c)|0)==-1){break z}g=c+g|0;c=a;break y}if((c|0)!=-1){break y}}x[114396]=x[114396]|4}c=jn(b);a=jn(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break i}g=a-c|0;if(g>>>0<=h+40>>>0){break i}}a=x[114393]+g|0;x[114393]=a;if(a>>>0>A[114394]){x[114394]=a}D:{e=x[114291];if(e){a=457588;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break D}a=x[a+8>>2];if(a){continue}break}break k}a=x[114289];if(!(a>>>0<=c>>>0?a:0)){x[114289]=c}a=0;x[114398]=g;x[114397]=c;x[114293]=-1;x[114294]=x[114403];x[114400]=0;while(1){d=a<<3;b=d+457180|0;x[d+457188>>2]=b;x[d+457192>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[114288]=b;a=a+c|0;x[114291]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[114292]=x[114407];break j}if(x[a+12>>2]&8|(c>>>0<=e>>>0|d>>>0>e>>>0)){break k}x[a+4>>2]=b+g;a=e+8&7?-8-e&7:0;c=a+e|0;x[114291]=c;b=x[114288]+g|0;a=b-a|0;x[114288]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[114292]=x[114407];break j}d=0;break b}c=0;break c}if(A[114289]>c>>>0){x[114289]=c}b=c+g|0;a=457588;E:{F:{G:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break G}break}if(!(y[a+12|0]&8)){break F}}a=457588;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break E}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;g=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[114291]=i;a=x[114288]+a|0;x[114288]=a;x[i+4>>2]=a|1;break d}if(x[114290]==(g|0)){x[114290]=i;a=x[114287]+a|0;x[114287]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break d}f=x[g+4>>2];if((f&3)!=1){break e}e=f&-8;if(f>>>0<=255){c=x[g+12>>2];b=x[g+8>>2];if((c|0)==(b|0)){m=457140,n=x[114285]&wqa(-2,f>>>3|0),x[m>>2]=n;break f}x[b+12>>2]=c;x[c+8>>2]=b;break f}h=x[g+24>>2];c=x[g+12>>2];if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break g}b=g+20|0;f=x[b>>2];if(!f){f=x[g+16>>2];if(!f){break h}b=g+16|0}while(1){d=b;c=f;b=c+20|0;f=x[b>>2];if(f){continue}b=c+16|0;f=x[c+16>>2];if(f){continue}break}x[d>>2]=0;break g}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[114288]=b;a=a+c|0;x[114291]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[114292]=x[114407];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[114400];x[d+16>>2]=x[114399];x[d+20>>2]=a;a=x[114398];x[d+8>>2]=x[114397];x[d+12>>2]=a;x[114399]=d+8;x[114398]=g;x[114397]=c;x[114400]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break j}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+457180|0;c=x[114285];a=1<<(f>>>3);H:{if(!(c&a)){x[114285]=a|c;a=b;break H}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break j}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+457444|0;I:{d=x[114286];c=1<<a;J:{if(!(d&c)){x[114286]=c|d;x[b>>2]=e;break J}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break I}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break j}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[114288];if(a>>>0<=h>>>0){break i}b=a-h|0;x[114288]=b;c=x[114291];a=c+h|0;x[114291]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[114232]=48;a=0;break a}c=0}if(!h){break f}d=x[g+28>>2];b=(d<<2)+457444|0;K:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break K}m=457144,n=x[114286]&wqa(-2,d),x[m>>2]=n;break f}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break f}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break f}x[c+20>>2]=b;x[b+24>>2]=c}a=a+e|0;g=e+g|0;f=x[g+4>>2]}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+457180|0;c=x[114285];a=1<<(a>>>3);L:{if(!(c&a)){x[114285]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break d}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+457444|0;M:{d=x[114286];c=1<<f;N:{if(!(d&c)){x[114286]=c|d;x[b>>2]=i;break N}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break M}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break d}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}O:{if(!g){break O}b=x[d+28>>2];a=(b<<2)+457444|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=wqa(-2,b)&j;x[114286]=j;break O}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+457180|0;c=x[114285];a=1<<(f>>>3);R:{if(!(c&a)){x[114285]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+457444|0;S:{c=1<<a;T:{if(!(c&j)){x[114286]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+457444|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=457144,n=wqa(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+457180|0;e=x[114290];a=1<<(k>>>3);X:{if(!(a&g)){x[114285]=a|g;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[114290]=d;x[114287]=f}a=c+8|0}hb=l+16|0;return a}function zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=hb-704|0;hb=d;Nc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!Mf(b,d+696|0)){break k}if(!ML(d+696|0)){break k}if(!yu(b,d+692|0)){break k}if(!LL(d+692|0)){break k}j=y[d+692|0]|y[d+693|0]<<8|(y[d+694|0]<<16|y[d+695|0]<<24);l:{if((j|0)==1179012417){g=1;e=1313423693;break l}if((j|0)!=538987841){break k}g=2;e=1414090313}k=km(d+676|0,b);h=my(d+664|0);m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!c){x[114409]=0;W(1632,d+108|0,k|0,g|0,e|0);b=x[114409];x[114409]=0;if((b|0)!=1){break u}a=N()|0;break a}x[114409]=0;T(1633,d+108|0,k|0,g|0);b=x[114409];x[114409]=0;if((b|0)==1){break t}}if(x[h>>2]){vd(h);IL(h);kq(h);Lf(yb(h),x[h>>2],ff(h));m=yb(h),n=0,x[m>>2]=n;x[h>>2]=0;x[h+4>>2]=0}b=d+108|0;$l(h,b);x[h>>2]=x[b>>2];x[h+4>>2]=x[b+4>>2];g=x[yb(b)>>2];m=yb(h),n=g,x[m>>2]=n;m=yb(b),n=0,x[m>>2]=n;x[b>>2]=0;x[b+4>>2]=0;Rl(b);x[114409]=0;T(1634,d+648|0,h|0,e|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;b=S(312,d+648|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}g=0;if(!b){break m}x[114409]=0;b=O(1635,d+648|0,d+575|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}if(!b|!y[d+640|0]){break m}b=y[d+640|0];x[114409]=0;g=O(231,d+648|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break o}if(!((c|0)!=0&g)){break m}x[114409]=0;P(419,a|0,8388608);b=x[114409];x[114409]=0;if((b|0)==1){break o}x[a+480208>>2]=12;x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+639|0]^-1)<<4&16;b=y[d+640|0];x[114409]=0;w[d+108>>1]=b;w[d+464>>1]=127;b=O(457,d+108|0,d+464|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}w[a+480188>>1]=z[b>>1];x[a+480196>>2]=y[d+641|0];x[a+480204>>2]=D(y[d+642|0],1e4);x[a+480200>>2]=y[d+647|0]<<1;x[114409]=0;O(211,a+1304436|0,((j|0)!=1179012417?12809:12843)|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break o}x[114409]=0;b=O(2,d+560|0,9118)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}Eb(a+1304448|0,b);xb(b);x[a+1304496>>2]=4;x[114409]=0;T(1636,d+464|0,2,d+575|0);b=x[114409];x[114409]=0;if((b|0)==1){break r}x[114409]=0;P(370,d+108|0,d+464|0);b=x[114409];x[114409]=0;if((b|0)==1){break r}b=d+108|0;Eb(a+1304400|0,b);xb(b);if(!z[a+480188>>1]){break p}b=0;f=(j|0)==1179012417;while(1){x[114409]=0;g=(b<<5)+a|0;i=g+480280|0;V(403,i|0);e=x[114409];x[114409]=0;v:{w:{x:{y:{z:{if((e|0)!=1){x[114409]=0;e=S(425,d+648|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break z}if(f){break y}if(e>>>0<129){break x}break w}a=N()|0;break b}a=N()|0;break b}if(e<<24>>24<0){break w}x[114409]=0;x[d+108>>2]=e<<2;x[d+464>>2]=256;e=O(436,d+108|0,d+464|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){w[g+480284>>1]=x[e>>2];break v}a=N()|0;break b}w[g+480284>>1]=e<<1;break v}x[i>>2]=1024}b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}break p}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}x[114409]=0;b=O(1637,h|0,1380209231)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break n}}a=N()|0;break b}if(b){x[114409]=0;T(1634,d+108|0,h|0,1380209231);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;b=S(425,d+108|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}e=Wb(a+484360|0);x[114409]=0;aa(580,e|0,d+108|0,b+1&255,255,254)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}Ab(d+108|0)}if(c&1){x[114409]=0;w[d+48>>1]=0;T(1638,d+464|0,h|0,1414807888);b=x[114409];x[114409]=0;if((b|0)==1){break e}b=qd(d+464|0);x[114409]=0;e=a+484344|0;P(377,e|0,b&65535);b=x[114409];x[114409]=0;if((b|0)==1){break h}b=d+464|0;m=d,n=bc(b),x[m+528>>2]=n;m=d,n=dc(b),x[m+72>>2]=n;if(Hb(d+528|0,d+72|0)){g=(j|0)!=1179012417;while(1){b=hf(d+108|0,x[d+528>>2]);x[114409]=0;f=S(425,b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}x[114409]=0;w[d+452>>1]=f;f=S(413,b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}x[114409]=0;T(316,d+544|0,b|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break g}x[114409]=0;f=x[d+556>>2];x[d+16>>2]=x[d+552>>2];x[d+20>>2]=f;f=x[d+548>>2];x[d+8>>2]=x[d+544>>2];x[d+12>>2]=f;W(1639,d+8|0,z[d+452>>1],g|0,a|0);f=x[114409];x[114409]=0;if((f|0)==1){break g}x[114409]=0;f=O(424,d+48|0,d+452|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}w[d+48>>1]=z[f>>1];Ab(b);b=d+528|0;sf(b);if(Hb(b,d+72|0)){continue}break}}if(z[d+48>>1]){b=0;while(1){x[114409]=0;g=b&65535;f=O(414,e|0,g|0)|0;i=x[114409];x[114409]=0;A:{if((i|0)!=1){if(f){break A}x[114409]=0;U(378,e|0,g|0,64)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break A}}a=N()|0;break f}b=b+1|0;if(z[d+48>>1]>(b&65535)>>>0){continue}break}}hd(d+464|0)}B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{if((j|0)==1179012417){x[114409]=0;T(1638,d+72|0,h|0,1414745673);b=x[114409];x[114409]=0;if((b|0)==1){break Q}b=d+72|0;m=d,n=bc(b),x[m+96>>2]=n;m=d,n=dc(b),x[m+36>>2]=n;R:{if(Hb(d+96|0,d+36|0)){g=c&2;j=d+472|0;while(1){c=hf(d+528|0,x[d+96>>2]);x[114409]=0;b=O(1640,c|0,d+108|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break R}S:{if(!b){break S}b=y[d+109|0];if((b|0)==255){break S}x[114409]=0;b=U(427,a|0,b+1|0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break P}if(!b){break S}e=z[a+480190>>1];x[114409]=0;T(1641,d+108|0,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break P}b=0;if(!y[d+138|0]){break S}while(1){T:{if(!ho(a)){break T}x[114409]=0;e=O(1642,c|0,d+464|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break O}if(!e){break T}e=z[a+480190>>1]+1|0;w[a+480190>>1]=e;if((y[d+464|0]|y[d+465|0]<<8|(y[d+466|0]<<16|y[d+467|0]<<24))!=1347240275){break T}x[114409]=0;T(576,d+452|0,2,j|0);f=x[114409];x[114409]=0;U:{V:{W:{if((f|0)==1){break W}x[114409]=0;P(370,d+48|0,d+452|0);f=x[114409];x[114409]=0;if((f|0)==1){break W}x[114409]=0;e=e&65535;O(348,((e<<5)+a|0)+946304|0,d+48|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break V}xb(d+48|0);x[114409]=0;e=(D(e,104)+a|0)+484380|0;T(1643,d+464|0,d+108|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break j}if(!g){break U}x[114409]=0;P(1644,d+48|0,d+464|0);f=x[114409];x[114409]=0;if((f|0)!=1){x[114409]=0;U(376,d+48|0,e|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break T}}a=N()|0;break i}a=N()|0;break i}a=N()|0;xb(d+48|0);break i}e=el(e);x[114409]=0;O(313,c|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break j}}b=b+1|0;if(b>>>0<y[d+138|0]){continue}break}}Ab(c);b=d+96|0;sf(b);if(Hb(b,d+36|0)){continue}break}}hd(d+72|0);break B}a=N()|0;break i}x[114409]=0;T(1638,d+452|0,h|0,1179011410);b=x[114409];x[114409]=0;if((b|0)==1){break N}b=d+452|0;m=d,n=bc(b),x[m+448>>2]=n;m=d,n=dc(b),x[m+444>>2]=n;X:{if(Hb(d+448|0,d+444|0)){g=c&2;j=d+468|0;while(1){c=km(d+528|0,x[d+448>>2]);x[114409]=0;b=S(413,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break M}Y:{if((b|0)!=538986817){break Y}x[114409]=0;b=O(1645,c|0,d+436|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break L}if(!b|(y[d+436|0]|y[d+437|0]<<8|(y[d+438|0]<<16|y[d+439|0]<<24))!=1414745673){break Y}x[114409]=0;b=O(1646,c|0,d+108|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}if(!b){break Y}b=y[d+113|0];if((b|0)==255){break Y}x[114409]=0;b=U(427,a|0,b+1|0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break J}if(!b){break Y}e=z[a+480190>>1];x[114409]=0;T(1647,d+108|0,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break J}x[114409]=0;T(1633,d+464|0,c|0,2);b=x[114409];x[114409]=0;if((b|0)==1){break X}x[114409]=0;T(1638,d+96|0,d+464|0,1179011410);b=x[114409];x[114409]=0;if((b|0)==1){break I}Rl(d+464|0);b=d+96|0;m=d,n=bc(b),x[m+92>>2]=n;m=d,n=dc(b),x[m+88>>2]=n;Z:{if(!Hb(d+92|0,d+88|0)){break Z}_:{while(1){b=hf(d+72|0,x[d+92>>2]);x[114409]=0;e=S(413,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break H}$:{aa:{if((e|0)!=538989377){break aa}if(!ho(a)){break aa}e=y[d+432|0]|y[d+433|0]<<8;f=e-1|0;v[d+432|0]=f;v[d+433|0]=f>>>8;if(!e){Ab(b);break Z}f=z[a+480190>>1]+1|0;w[a+480190>>1]=f;x[114409]=0;e=O(1645,b|0,d- -64|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break G}if(!e){break _}e=d- -64|0;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))!=1347240275){break _}e=y[d+68|0]|y[d+69|0]<<8|(y[d+70|0]<<16|y[d+71|0]<<24);x[114409]=0;T(316,d+48|0,b|0,e|0);e=x[114409];x[114409]=0;ba:{ca:{if((e|0)!=1){x[114409]=0;e=O(1648,d+48|0,d+464|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break $}if(!e){break ba}x[114409]=0;T(369,d+24|0,2,j|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;P(370,d+36|0,d+24|0);e=x[114409];x[114409]=0;if((e|0)!=1){break ca}}a=N()|0;break E}a=N()|0;break D}x[114409]=0;e=f&65535;O(348,((e<<5)+a|0)+946304|0,d+36|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break F}xb(d+36|0);x[114409]=0;e=(D(e,104)+a|0)+484380|0;T(1649,d+464|0,d+108|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break $}da:{if(!g){break da}f=y[d+464|0]|y[d+465|0]<<8|(y[d+466|0]<<16|y[d+467|0]<<24);x[114409]=0;O(229,d+48|0,f+4|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break $}x[114409]=0;P(1650,d+36|0,d+464|0);f=x[114409];x[114409]=0;if((f|0)!=1){x[114409]=0;U(376,d+36|0,e|0,d+48|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break da}}a=N()|0;break E}Ab(d+48|0);break aa}Ab(d+48|0);Ab(b);break Z}Ab(b);b=d+92|0;sf(b);if(Hb(b,d+88|0)){continue}break Z}break}a=N()|0;break E}Ab(b)}hd(d+96|0)}Ab(c);b=d+448|0;sf(b);if(Hb(b,d+444|0)){continue}break}}hd(d+452|0);break B}a=N()|0;break C}a=N()|0;break b}a=N()|0;break i}a=N()|0;break i}a=N()|0;break b}a=N()|0;break C}a=N()|0;break C}a=N()|0;break C}a=N()|0;break C}a=N()|0;Rl(d+464|0);break C}a=N()|0;break D}a=N()|0;break D}a=N()|0;xb(d+36|0)}Ab(d+48|0)}Ab(b);hd(d+96|0)}Ab(c);hd(d+452|0);break b}g=1}Ab(d+648|0);Rl(h);Ab(k)}hb=d+704|0;return g|0}a=N()|0}Ab(c);hd(d+72|0);break b}a=N()|0;break f}a=N()|0;Ab(b)}hd(d+464|0);break b}a=N()|0;break b}a=N()|0;Ab(d+108|0);break b}a=N()|0}Ab(d+648|0)}Rl(h);Ab(k);Q(a|0);p()}function bG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=E(0),H=0;d=hb-144|0;hb=d;e=Sb(d,0,144);x[e+76>>2]=-1;x[e+44>>2]=a;x[e+32>>2]=2574;x[e+84>>2]=a;d=b;t=c;a=0;j=hb-304|0;hb=j;a:{b:{c:{d:{if(x[e+4>>2]){break d}Tw(e);if(x[e+4>>2]){break d}break c}b=y[d|0];if(!b){break a}e:{f:{g:{h:{while(1){i:{j:{if(qk(b&255)){while(1){b=d;d=d+1|0;if(qk(y[b+1|0])){continue}break}Oh(e,0,0);while(1){c=x[e+4>>2];k:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break k}c=_c(e)}if(qk(c)){continue}break}d=x[e+4>>2];c=x[e+116>>2];if((c|0)>0|(c|0)>=0){d=d-1|0;x[e+4>>2]=d}c=d-x[e+44>>2]|0;g=c;i=l+x[e+124>>2]|0;f=m+x[e+120>>2]|0;c=(c>>31)+(f>>>0<m>>>0?i+1|0:i)|0;m=f+g|0;l=m>>>0<f>>>0?c+1|0:c;break j}l:{m:{n:{if(y[d|0]==37){b=y[d+1|0];if((b|0)==42){break n}if((b|0)!=37){break m}}Oh(e,0,0);o:{if(y[d|0]==37){while(1){b=x[e+4>>2];p:{if((b|0)!=x[e+104>>2]){x[e+4>>2]=b+1;b=y[b|0];break p}b=_c(e)}if(qk(b)){continue}break}d=d+1|0;break o}b=x[e+4>>2];if((b|0)!=x[e+104>>2]){x[e+4>>2]=b+1;b=y[b|0];break o}b=_c(e)}if(y[d|0]!=(b|0)){c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}if((b|0)>=0){break a}h=0;if(u){break a}break c}b=x[e+4>>2]-x[e+44>>2]|0;g=b;l=l+x[e+124>>2]|0;c=b>>31;b=m+x[e+120>>2]|0;h=c+(b>>>0<m>>>0?l+1|0:l)|0;m=b+g|0;l=m>>>0<b>>>0?h+1|0:h;b=d;break j}k=0;b=d+2|0;break l}if(!(!nh(b)|y[d+2|0]!=36)){c=y[d+1|0]-48|0;b=hb-16|0;x[b+12>>2]=t;g=b;b=(c>>>0>1?(c<<2)-4|0:0)+t|0;x[g+8>>2]=b+4;k=x[b>>2];b=d+3|0;break l}k=x[t>>2];t=t+4|0;b=d+1|0}s=0;d=0;if(nh(y[b|0])){while(1){d=(y[b|0]+D(d,10)|0)-48|0;c=y[b+1|0];b=b+1|0;if(nh(c)){continue}break}}p=y[b|0];if((p|0)==109){q=0;s=(k|0)!=0;p=y[b+1|0];a=0;b=b+1|0}c=b;b=c+1|0;f=3;h=s;q:{r:{switch(p-65|0){case 39:g=c+2|0;c=y[c+1|0]==104;b=c?g:b;f=c?-2:-1;break q;case 43:g=c+2|0;c=y[c+1|0]==108;b=c?g:b;f=c?3:1;break q;case 51:case 57:f=1;break q;case 11:f=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}f=0;b=c}g=y[b|0];c=(g&47)==3;z=c?1:f;r=c?g|32:g;s:{if((r|0)==91){break s}t:{if((r|0)!=110){if((r|0)!=99){break t}d=(d|0)<=1?1:d;break s}cG(k,z,m,l);break j}Oh(e,0,0);while(1){c=x[e+4>>2];u:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break u}c=_c(e)}if(qk(c)){continue}break}c=x[e+4>>2];g=x[e+116>>2];if((g|0)>0|(g|0)>=0){c=c-1|0;x[e+4>>2]=c}c=c-x[e+44>>2]|0;f=c;i=l+x[e+124>>2]|0;g=c>>31;c=m+x[e+120>>2]|0;l=g+(c>>>0<m>>>0?i+1|0:i)|0;m=c+f|0;l=m>>>0<c>>>0?l+1|0:l}g=d;o=d>>31;Oh(e,d,o);c=x[e+4>>2];v:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;break v}if((_c(e)|0)<0){break f}}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}c=16;w:{x:{y:{z:{A:{switch(r-88|0){default:c=r-65|0;if(c>>>0>6|!(1<<c&113)){break w}case 9:case 13:case 14:case 15:fG(j+8|0,e,z,0);d=x[e+4>>2]-x[e+44>>2]|0;if(x[e+120>>2]!=(0-d|0)|x[e+124>>2]!=(0-((d>>31)+((d|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((r|16)==115){Sb(j+32|0,-1,257);v[j+32|0]=0;if((r|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}h=y[b+1|0];f=(h|0)==94;Sb(j+32|0,f,257);v[j+32|0]=0;c=f?b+2|0:b+1|0;B:{C:{D:{b=y[(f?2:1)+b|0];if((b|0)!=45){if((b|0)==93){break D}f=(h|0)!=94;b=c;break B}f=(h|0)!=94;v[j+78|0]=f;break C}f=(h|0)!=94;v[j+126|0]=f}b=c+1|0}while(1){c=y[b|0];E:{if((c|0)!=45){if(!c){break f}if((c|0)==93){break x}break E}c=45;i=y[b+1|0];if(!i|(i|0)==93){break E}h=b+1|0;b=y[b-1|0];F:{if(i>>>0<=b>>>0){c=i;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=f;c=y[h|0];if(c>>>0>b>>>0){continue}break}}b=h}v[(c+j|0)+33|0]=f;b=b+1|0;continue};case 23:c=8;break z;case 12:case 29:c=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}c=0}g=0;i=0;f=0;h=0;p=0;A=hb-16|0;hb=A;G:{if(!((c|0)!=1&c>>>0<=36)){x[114232]=28;break G}while(1){d=x[e+4>>2];H:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break H}d=_c(e)}if(qk(d)){continue}break}I:{J:{switch(d-43|0){case 0:case 2:break J;default:break I}}p=(d|0)==45?-1:0;d=x[e+4>>2];if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break I}d=_c(e)}K:{L:{M:{N:{if(!((c|0)!=0&(c|0)!=16|(d|0)!=48)){d=x[e+4>>2];O:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break O}d=_c(e)}if((d&-33)==88){c=16;d=x[e+4>>2];P:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break P}d=_c(e)}if(y[d+61137|0]<16){break M}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}Oh(e,0,0);break G}if(c){break N}c=8;break M}c=c?c:10;if(c>>>0>y[d+61137|0]){break N}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}Oh(e,0,0);x[114232]=28;break G}if((c|0)!=10){break M}f=d-48|0;if(f>>>0<=9){c=0;while(1){c=D(c,10)+f|0;g=c>>>0<429496729;d=x[e+4>>2];Q:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break Q}d=_c(e)}f=d-48|0;if(g&f>>>0<=9){continue}break}g=c}R:{if(f>>>0>9){break R}h=sqa(g,0,10,0);c=lb;n=f;while(1){g=h+n|0;i=g>>>0<n>>>0?c+1|0:c;c=(i|0)==429496729&g>>>0>=2576980378|i>>>0>429496729;d=x[e+4>>2];S:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break S}d=_c(e)}f=d-48|0;if(c|f>>>0>9){break R}h=sqa(g,i,10,0);n=f;c=lb;if((c|0)==-1&(f^-1)>>>0>=h>>>0|(c|0)!=-1){continue}break}c=10;break L}c=10;if(f>>>0<=9){break L}break K}if(c-1&c){h=y[d+61137|0];if(h>>>0<c>>>0){while(1){f=D(c,f)+h|0;g=f>>>0<119304647;d=x[e+4>>2];T:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break T}d=_c(e)}h=y[d+61137|0];if(g&h>>>0<c>>>0){continue}break}g=f}if(c>>>0<=h>>>0){break L}o=c;while(1){f=sqa(g,i,o,0);n=lb;h=h&255;if((n|0)==-1&(h^-1)>>>0<f>>>0){break L}i=n;g=f+h|0;i=g>>>0<h>>>0?i+1|0:i;d=x[e+4>>2];U:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break U}d=_c(e)}h=y[d+61137|0];if(c>>>0<=h>>>0){break L}$e(A,o,0,0,0,g,i,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break L}n=v[(D(c,23)>>>5&7)+61393|0];f=y[d+61137|0];if(f>>>0<c>>>0){while(1){h=h<<n|f;g=h>>>0<134217728;d=x[e+4>>2];V:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break V}d=_c(e)}f=y[d+61137|0];if(g&f>>>0<c>>>0){continue}break}g=h}if(c>>>0<=f>>>0){break L}o=n&31;if((n&63)>>>0>=32){h=0;o=-1>>>o|0}else{h=-1>>>o|0;o=h|(1<<o)-1<<32-o}if(!h&g>>>0>o>>>0){break L}while(1){d=g;g=n&31;if((n&63)>>>0>=32){i=d<<g;d=0}else{i=(1<<g)-1&d>>>32-g|i<<g;d=d<<g}g=d|f&255;d=x[e+4>>2];W:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break W}d=_c(e)}f=y[d+61137|0];if(c>>>0<=f>>>0){break L}if((h|0)==(i|0)&g>>>0<=o>>>0|h>>>0>i>>>0){continue}break}}if(y[d+61137|0]>=c>>>0){break K}while(1){d=x[e+4>>2];X:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break X}d=_c(e)}if(y[d+61137|0]<c>>>0){continue}break}x[114232]=68;p=0;g=-1;i=-1}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}if(!(p|1)&(g&i)==-1){x[114232]=68;g=-2;i=-1;break G}d=g^p;g=d-p|0;c=p>>31;i=(c^i)-((d>>>0<p>>>0)+c|0)|0}hb=A+16|0;d=x[e+4>>2]-x[e+44>>2]|0;if(x[e+120>>2]==(0-d|0)&x[e+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break g}if(!(!k|(r|0)!=112)){x[k>>2]=g;break w}cG(k,z,g,i);break w}if(!k){break w}d=x[j+16>>2];f=x[j+20>>2];c=x[j+8>>2];g=x[j+12>>2];Y:{switch(z|0){case 0:F=k,G=dG(c,g,d,f),B[F>>2]=G;break w;case 1:F=k,H=Uw(c,g,d,f),C[F>>3]=H;break w;case 2:break Y;default:break w}}x[k>>2]=c;x[k+4>>2]=g;x[k+8>>2]=d;x[k+12>>2]=f;break w}n=(r|0)!=99;f=n?31:d+1|0;Z:{if((z|0)==1){c=k;if(s){c=xd(f<<2);if(!c){break h}}x[j+296>>2]=0;x[j+300>>2]=0;d=0;while(1){a=c;_:{while(1){c=x[e+4>>2];$:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break $}c=_c(e)}if(!y[(c+j|0)+33|0]){break _}v[j+27|0]=c;c=jp(j+28|0,j+27|0,1,j+296|0);if((c|0)==-2){continue}q=0;if((c|0)==-1){break f}if(a){x[(d<<2)+a>>2]=x[j+28>>2];d=d+1|0}if(!s|(d|0)!=(f|0)){continue}break}h=1;f=f<<1|1;c=ls(a,f<<2);if(c){continue}break e}break}q=0;f=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(s){d=0;c=xd(f);if(!c){break h}while(1){a=c;while(1){c=x[e+4>>2];aa:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break aa}c=_c(e)}if(!y[(c+j|0)+33|0]){f=0;q=a;break Z}v[a+d|0]=c;d=d+1|0;if((f|0)!=(d|0)){continue}break}h=1;f=f<<1|1;c=ls(a,f);if(c){continue}break}q=a;a=0;break e}d=0;if(k){while(1){a=x[e+4>>2];ba:{if((a|0)!=x[e+104>>2]){x[e+4>>2]=a+1;a=y[a|0];break ba}a=_c(e)}if(y[(a+j|0)+33|0]){v[d+k|0]=a;d=d+1|0;continue}else{f=0;a=k;q=a;break Z}}}while(1){a=x[e+4>>2];ca:{if((a|0)!=x[e+104>>2]){x[e+4>>2]=a+1;a=y[a|0];break ca}a=_c(e)}if(y[(a+j|0)+33|0]){continue}break}a=0;q=0;f=0}c=x[e+4>>2];h=x[e+116>>2];if((h|0)>0|(h|0)>=0){c=c-1|0;x[e+4>>2]=c}c=c-x[e+44>>2]|0;h=c+x[e+120>>2]|0;i=x[e+124>>2]+(c>>31)|0;i=c>>>0>h>>>0?i+1|0:i;if(!(i|h)|!(n|(g|0)==(h|0)&(i|0)==(o|0))){break i}if(s){x[k>>2]=a}da:{if((r|0)==99){break da}if(f){x[(d<<2)+f>>2]=0}if(!q){q=0;break da}v[d+q|0]=0}a=f}c=x[e+4>>2]-x[e+44>>2]|0;g=c;l=l+x[e+124>>2]|0;f=m+x[e+120>>2]|0;c=(c>>31)+(f>>>0<m>>>0?l+1|0:l)|0;m=f+g|0;l=m>>>0<f>>>0?c+1|0:c;u=((k|0)!=0)+u|0}d=b+1|0;b=y[b+1|0];if(b){continue}break a}break}a=f;break g}h=1;q=0;a=0;break e}h=s;break b}h=s}if(u){break b}}u=-1}if(!h){break a}_b(q);_b(a)}hb=j+304|0;hb=e+144|0;return u}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=hb-288|0;hb=d;Nc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!_t(b,d+192|0)){break j}if(!QQ(d+192|0)){break j}if(!Qb(b,id(PQ(d+192|0),lb))){break j}if(!c){k=1;break j}if(!Tc(b,y[d+196|0])){break j}Pd(a,268435456);Ni(a);x[a+480208>>2]=4;f=d+84|0;h=Vb(f,11161);Eb(a+1304436|0,h);xb(h);h=Vb(f,6263);Eb(a+1304448|0,h);xb(h);x[a+1304496>>2]=4;h=d+16|0;gf(h,d+198|0,48,3);Kc(f,h);Eb(a+1304400|0,f);xb(f);w[a+480188>>1]=y[d+246|0]+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];if(y[d+246|0]){f=0;while(1){w[((f<<5)+a|0)+480284>>1]=D(y[(d+f|0)+252|0],17);f=f+1|0;if(f>>>0<y[d+246|0]){continue}break}}w[a+480190>>1]=y[d+284|0];h=y[d+286|0]|y[d+287|0]<<8;f=hb-16|0;hb=f;j=d+180|0;x[j>>2]=0;x[j+4>>2]=0;x[f+4>>2]=0;Zc(j+8|0);Yd(f+4|0,x[Bb(f,j)>>2]);k:{if(!h){break k}x[114409]=0;P(972,j|0,h|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;P(973,j|0,h|0);h=x[114409];x[114409]=0;if((h|0)!=1){break k}}a=N()|0;MQ(f+4|0);Q(a|0);p()}h=f+4|0;Xd(h);MQ(h);hb=f+16|0;f=y[d+286|0]|y[d+287|0]<<8;x[114409]=0;U(964,b|0,j|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break i}r=Aq(d+168|0);o=Aq(d+156|0);f=y[d+285|0];x[114409]=0;U(637,b|0,r|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}f=y[d+284|0];x[114409]=0;U(637,b|0,o|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}if(y[d+284|0]){q=c&2;m=d+122|0;n=d+90|0;f=0;while(1){x[114409]=0;h=f;f=f+1|0;i=D(f,104)+a|0;g=i+484380|0;P(472,g|0,0);e=x[114409];x[114409]=0;l:{m:{if((e|0)!=1){e=Pb(o,h);if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break l}e=Pb(o,h);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;e=O(229,b|0,e|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break c}if(!e){break l}x[114409]=0;e=O(965,b|0,d+84|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break c}if(!e){break l}x[114409]=0;T(369,d+72|0,2,n|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;P(370,d+16|0,d+72|0);e=x[114409];x[114409]=0;if((e|0)!=1){break m}}f=N()|0;break b}f=N()|0;break b}x[114409]=0;O(348,((f<<5)+a|0)+946304|0,d+16|0)|0;e=x[114409];x[114409]=0;n:{o:{p:{q:{r:{if((e|0)!=1){xb(d+16|0);x[114409]=0;T(966,d+72|0,2,m|0);e=x[114409];x[114409]=0;if((e|0)==1){break r}x[114409]=0;P(370,d+16|0,d+72|0);e=x[114409];x[114409]=0;if((e|0)==1){break r}x[114409]=0;O(350,i+484423|0,d+16|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}xb(d+16|0);if(y[d+134|0]<=15){e=i+484414|0;w[e>>1]=z[e>>1]|32;w[i+484408>>1]=D(y[d+134|0],17)}e=y[d+135|0];x[114409]=0;v[d+16|0]=e;v[d+72|0]=64;e=O(431,d+16|0,d+72|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break p}w[i+484412>>1]=y[e|0];x[i+484404>>2]=y[d+137|0]|y[d+138|0]<<8;e=i+484384|0;x[e>>2]=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);l=i+484388|0;x[l>>2]=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[g>>2]=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);if(v[d+136|0]&1){break o}k=x[e>>2];e=x[l>>2];break n}f=N()|0;xb(d+16|0);break b}f=N()|0;break b}f=N()|0;xb(d+16|0);break b}f=N()|0;break b}k=x[e>>2]>>>1|0;x[e>>2]=k;e=x[l>>2]>>>1|0;x[l>>2]=e;x[g>>2]=x[g>>2]>>>1}s:{if(e>>>0<=k>>>0){break s}e=i+484414|0;w[e>>1]=z[e>>1]|2;if(!(y[d+136|0]&2)){break s}w[e>>1]=z[e>>1]|4}x[114409]=0;V(967,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}if(!q){break l}h=Pb(o,h);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);e=y[d+88|0];x[114409]=0;O(229,b|0,e+h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break c}h=cd(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[114409]=0;U(376,h|0,g|0,b|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){break l}f=N()|0;break b}if(y[d+284|0]>f>>>0){continue}break}}k=1;t:{if(!(c&1)){break t}x[d+68>>2]=0;i=a+484360|0;Kq(Wb(i));E=d,F=bc(j),x[E+64>>2]=F;E=d,F=dc(j),x[E+60>>2]=F;if(Hb(d- -64|0,d+60|0)){l=a+484344|0;while(1){h=x[d- -64>>2];c=h;u:{if(y[c+3|0]>=y[d+285|0]|y[c+2|0]>y[d+246|0]){break u}c=Pb(r,y[c+3|0]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114409]=0;c=O(229,b|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}if(!c){break u}x[114409]=0;O(968,b|0,d+84|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break h}if(!y[d+88|0]){break u}f=y[h|0]|y[h+1|0]<<8;c=f;v[d+16|0]=y[d+89|0];e=y[d+246|0];g=y[h+2|0];x[114409]=0;v[d+72|0]=e-g;e=O(431,d+16|0,d+72|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}q=y[e|0];e=y[h|0]|y[h+1|0]<<8;g=y[d+88|0];x[114409]=0;x[d+56>>2]=e+g;e=O(969,d+68|0,d+56|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}x[d+68>>2]=x[e>>2];x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;if(!y[d+88|0]){break u}s=c>>>6|0;e=f&63;u=0;while(1){v:{w:{x:{y:{z:{A:{B:{f=e>>>0>63;s=f+s|0;c=s&65535;if(rc(Wb(i))>>>0<=c>>>0){g=Wb(i);x[114409]=0;P(955,g|0,s+1&65535);g=x[114409];x[114409]=0;if((g|0)==1){break B}x[114409]=0;g=U(832,l|0,64,0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break B}E=vc(Wb(i),c),F=g,w[E>>1]=F}m=z[vc(Wb(i),c)>>1];x[114409]=0;c=O(414,l|0,m|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break z}if(!c){break u}c=Zb(l,m);g=y[h+2|0];x[114409]=0;t=f?0:e;f=U(451,c|0,t|0,g|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break w}n=0;if(q){break A}break x}f=N()|0;break b}while(1){x[114409]=0;P(970,d+72|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break y}c=d+72|0;g=ed(c);B=wf(c);A=fi(c);C=mc(c);e=0;c=y[c|0];if((c-1&255)>>>0<=142){e=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+n|0]=e}v[f|0]=e;c=y[g|0];v[f+2|0]=1;v[f+1|0]=c;c=y[B|0];C:{if((c|0)!=255){v[f+4|0]=c;break C}v[f+2|0]=0}c=y[A|0];D:{if(c>>>0>22){break D}v[f+3|0]=y[c+23968|0];g=y[C|0];v[f+5|0]=g;c=f+5|0;E:{switch(y[A|0]-4|0){case 3:v[c|0]=g&3|64;break D;case 4:v[c|0]=g&3|48;break D;case 7:if(Lb(j)>>>0<=g>>>0){break D}g=c;c=Pb(j,y[c|0]);e=y[c|0]|y[c+1|0]<<8;v[g|0]=e>>>6;c=Zb(l,m);g=z[a+480188>>1];x[114409]=0;c=U(451,c|0,t|0,g-1&65535)|0;g=x[114409];x[114409]=0;if((g|0)!=1){v[c+3|0]=14;v[c+5|0]=e&63;break D}f=N()|0;break b;case 8:v[c|0]=x[d+56>>2]>>>6;c=Zb(l,m);e=z[a+480188>>1];x[114409]=0;c=U(451,c|0,t|0,e-1&65535)|0;e=x[114409];x[114409]=0;if((e|0)!=1){v[c+3|0]=14;v[c+5|0]=y[d+56|0]&63;break D}f=N()|0;break b;case 10:v[c|0]=g&15|128;break D;case 12:x[114409]=0;v[d+15|0]=15;e=O(431,c|0,d+15|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){v[c|0]=y[e|0]|208;break D}f=N()|0;break b;case 13:x[114409]=0;v[d+15|0]=15;e=O(431,c|0,d+15|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){v[c|0]=y[e|0]|192;break D}f=N()|0;break b;case 14:x[114409]=0;v[d+15|0]=15;e=O(431,c|0,d+15|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){v[c|0]=y[e|0]|224;break D}f=N()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}e=g&240;if(!e|(e|0)==240){break D}v[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(e&255){break D}v[f|0]=y[(d+16|0)+n|0]}f=f+6|0;n=n+1|0;if((q|0)!=(n|0)){continue}break}break x}f=N()|0;break b}f=N()|0;break b}if(q>>>0>=y[d+89|0]){break v}c=y[d+89|0];x[114409]=0;O(313,b|0,D(c-q|0,5)|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break v}}f=N()|0;break b}e=t+1|0;u=u+1|0;if(u>>>0<y[d+88|0]){continue}break}}c=d- -64|0;je(c);if(Hb(c,d+60|0)){continue}break}}F:{b=x[d+68>>2];c=b&63;if(!c){break F}f=Wb(i);x[114409]=0;b=b>>>6|0;f=O(539,f|0,b&65535)|0;h=x[114409];x[114409]=0;if((h|0)!=1){if(!f){break F}b=Zb(a+484344|0,z[vc(Wb(i),b&65535)>>1]);x[114409]=0;Z(971,b|0,c|0,0,1)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break F}}f=N()|0;break b}b=Wb(i);E=d,F=bc(b),x[E+84>>2]=F;E=d,F=dc(b),x[E+16>>2]=F;if(!Hb(d+84|0,d+16|0)){break t}a=a+484344|0;e=65535;while(1){b=x[d+84>>2];if(z[b>>1]==65535){G:{if((e&65535)!=65535){break G}x[114409]=0;e=U(832,a|0,64,0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break G}f=N()|0;break b}w[b>>1]=e}b=d+84|0;ke(b);if(Hb(b,d+16|0)){continue}break}}_i(o);_i(r);OQ(j)}hb=d+288|0;return k|0}f=N()|0;break a}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0}_i(o);_i(r)}OQ(j);Q(f|0);p()}function xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-272|0;hb=e;Nc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!cB(b,e+206|0)){break j}if(!CU(e+206|0)){break j}if(!c){d=1;break j}Pd(a,131072);f=Vb(e+192|0,11293);x[114409]=0;P(192,e+80|0,f|0);h=x[114409];x[114409]=0;k:{l:{m:{n:{o:{p:{q:{if((h|0)!=1){x[114409]=0;T(530,e+144|0,e+80|0,e+210|0);h=x[114409];x[114409]=0;if((h|0)==1){break q}h=e+144|0;Eb(a+1304436|0,h);xb(h);d=e+80|0;Gb(d);xb(f);f=Vb(h,7019);Eb(a+1304448|0,f);xb(f);x[a+1304496>>2]=4;XU(d,3,e+219|0);Kc(h,d);Eb(a+1304400|0,h);xb(h);f=e+116|0;mo(f,3,e+249|0);Kc(d,f);x[114409]=0;T(13,h|0,4,d|0);h=x[114409];x[114409]=0;if((h|0)==1){break i}h=e+144|0;Eb(a+1304412|0,h);xb(h);xb(e+80|0);h=Hq(h);m=h,n=Md(y[e+269|0],1,31),x[m+12>>2]=n;m=h,n=Md(y[e+270|0],1,12)-1|0,x[m+16>>2]=n;x[h+20>>2]=y[e+271|0];d=a+1304500|0;bB(d);BU(d,h);d=hb-16|0;hb=d;h=e+132|0;x[h>>2]=0;x[h+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(553,h+8|0,d+12|0,d+11|0)|0;f=x[114409];x[114409]=0;r:{if((f|0)!=1){hb=d+16|0;break r}R(0)|0;zb();p()}while(1){x[114409]=0;d=O(231,b|0,8)|0;f=x[114409];x[114409]=0;if((f|0)==1){break o}if(!d){break k}x[114409]=0;O(531,b|0,e+116|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break n}f=y[e+120|0]|y[e+121|0]<<8|(y[e+122|0]<<16|y[e+123|0]<<24);d=y[e+210|0];s:{if((d|0)==3){g=2;if((y[e+116|0]|y[e+117|0]<<8|(y[e+118|0]<<16|y[e+119|0]<<24))==1431389523){break s}d=y[e+210|0]}if((d&255)==4){g=4;if((y[e+116|0]|y[e+117|0]<<8|(y[e+118|0]<<16|y[e+119|0]<<24))==1431389523){break s}d=y[e+210|0]}g=0;if((d&255)>>>0>7){break s}f=(y[e+116|0]|y[e+117|0]<<8|(y[e+118|0]<<16|y[e+119|0]<<24))==1146113363?-1:f}x[114409]=0;T(316,e+80|0,b|0,f|0);d=x[114409];x[114409]=0;if((d|0)==1){break m}x[114409]=0;U(532,h|0,e+116|0,e+80|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break l}Ab(e+80|0);x[114409]=0;O(313,b|0,g|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}d=N()|0;break b}d=N()|0;break p}d=N()|0;Gb(e+80|0)}xb(f);break a}d=N()|0;break b}d=N()|0;break b}d=N()|0;break b}d=N()|0;Ab(e+80|0);break b}x[114409]=0;b=S(247,e+116|0)|0;d=x[114409];x[114409]=0;t:{u:{v:{if((d|0)!=1){x[114409]=0;T(533,e+80|0,h|0,1431389523);d=x[114409];x[114409]=0;if((d|0)==1){break v}d=e+80|0;Zd(b,d);Ab(d);w[e+114>>1]=0;w[e+112>>1]=65534;if(y[e+210|0]<3){break t}x[114409]=0;d=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break u}break d}d=N()|0;break b}d=N()|0;break c}w[e+114>>1]=d;if(y[e+210|0]<4){break t}x[114409]=0;d=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}w[e+112>>1]=y[e+210|0]==4?d?d:-2:d}d=a+484360|0;f=Wb(d);x[114409]=0;g=S(305,b|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break d}x[114409]=0;aa(412,f|0,b|0,g>>>1|0,65535,65535)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}f=Wb(d);x[114409]=0;f=S(534,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}dg(e+114|0,f);f=Wb(d);x[114409]=0;f=S(534,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}dg(e+112|0,f);x[114409]=0;T(533,e+80|0,h|0,1414807888);f=x[114409];x[114409]=0;w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){f=e+80|0;Zd(b,f);Ab(f);x[114409]=0;f=S(312,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(!(c&1)|f^1){break w}x[114409]=0;O(535,b|0,e+32|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break D}m=a,n=Md(y[e+34|0],1,32)+1|0,w[m+480188>>1]=n;f=y[e+32|0]|y[e+33|0]<<8;x[114409]=0;f=O(375,e+100|0,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break C}m=e,n=bc(f),x[m+64>>2]=n;m=e,n=dc(f),x[m+48>>2]=n;if(Hb(e- -64|0,e+48|0)){while(1){j=x[e- -64>>2];x[114409]=0;g=y[e+210|0]<3?9:8;O(313,b|0,g-4|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break B}x[114409]=0;i=S(413,b|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break A}rg(b,g);x[114409]=0;T(316,e+80|0,b|0,g+i|0);g=x[114409];x[114409]=0;if((g|0)==1){break z}g=e+80|0;Zd(j,g);Ab(g);g=e- -64|0;sf(g);if(Hb(g,e+48|0)){continue}break}}g=z[a+480188>>1];x[114409]=0;g=O(536,e+80|0,g|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break y}j=Wb(d);x[114409]=0;i=S(537,j|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break f}x[114409]=0;j=a+484344|0;P(377,j|0,i|0);i=x[114409];x[114409]=0;if((i|0)==1){break f}i=Wb(d);m=e,n=bc(i),x[m+64>>2]=n;m=e,n=dc(i),x[m+48>>2]=n;if(Hb(e- -64|0,e+48|0)){while(1){i=x[e- -64>>2];k=z[i>>1];if(qd(f)>>>0>k>>>0){k=wc(f,z[i>>1]);x[114409]=0;k=Z(538,k|0,y[e+210|0],g|0,a|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break f}w[i>>1]=k}i=e- -64|0;ke(i);if(Hb(i,e+48|0)){continue}break}}i=Wb(d);x[114409]=0;i=O(539,i|0,z[e+112>>1])|0;k=x[114409];x[114409]=0;if((k|0)==1){break f}if(!i){break x}if(!z[e+114>>1]){i=z[e+112>>1];k=Wb(d);x[114409]=0;k=S(534,k|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break f}if(i>>>0>=k>>>0){break x}}d=z[vc(Wb(d),z[e+112>>1])>>1];i=Zb(j,d);x[114409]=0;k=U(478,e- -64|0,12,y[e+114|0])|0;l=x[114409];x[114409]=0;if((l|0)!=1){d=lo(Oe(k,x[Zb(j,d)+12>>2]-1|0));x[114409]=0;O(479,i|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break x}}break f}d=N()|0;break c}d=N()|0;break c}d=N()|0;break c}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}tU(g);hd(f)}x[114409]=0;T(533,e+48|0,h|0,1196641603);d=x[114409];x[114409]=0;if((d|0)==1){break h}d=e+48|0;Zd(b,d);Ab(d);x[114409]=0;d=S(312,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}if(d){x[114409]=0;O(313,b|0,1)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;d=S(305,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;aa(540,a+1304424|0,b|0,d|0,40,0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}}x[114409]=0;T(533,e+48|0,h|0,1146113363);d=x[114409];x[114409]=0;if((d|0)==1){break g}x[114409]=0;T(533,e+32|0,h|0,1229999443);d=x[114409];x[114409]=0;E:{F:{if((d|0)!=1){d=e+32|0;Zd(b,d);Ab(d);x[114409]=0;d=S(425,b|0)|0;f=x[114409];x[114409]=0;G:{if((f|0)!=1){w[a+480190>>1]=d;if(z[a+480190>>1]){j=!(c&2);d=1;c=1;while(1){g=30;H:{I:{J:{if(y[e+210|0]>=2){x[114409]=0;g=S(425,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break J}}x[114409]=0;U(541,b|0,((d<<5)+a|0)+946304|0,g|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break J}x[114409]=0;O(542,b|0,e+32|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break I}x[114409]=0;d=D(d,104)+a|0;g=d+484380|0;P(543,e+32|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break I}f=y[e+210|0];if(f>>>0>=8){x[114409]=0;U(544,b|0,d+484423|0,8)|0;f=x[114409];x[114409]=0;if((f|0)==1){break I}f=y[e+210|0]}x[114409]=0;O(313,b|0,((f&255)>>>0>1?6:2)|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break I}x[114409]=0;f=S(413,e+48|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){x[114409]=0;T(316,e+16|0,e+48|0,f|0);f=x[114409];x[114409]=0;if((f|0)!=1){break H}}d=N()|0;break F}d=N()|0;break F}d=N()|0;break F}x[114409]=0;f=S(312,e+16|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break G}K:{if(j|f^1){break K}d=cd(e+12|0,w[d+484414>>1]&1?16:8,1,0,(y[e+47|0]&12)==4?7:0);x[114409]=0;U(376,d|0,g|0,e+16|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break K}break G}Ab(e+16|0);c=c+1|0;d=c&65535;if(d>>>0<=z[a+480190>>1]){continue}break}}x[114409]=0;V(456,a|0);c=x[114409];x[114409]=0;d=1;if((c|0)!=1){break E}}d=N()|0;break F}d=N()|0;Ab(e+16|0);break F}d=N()|0}Ab(e+48|0);break c}x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;Ab(e+48|0);Ab(b);AU(h)}hb=e+272|0;return d|0}d=N()|0;xb(e+80|0);break a}d=N()|0;break c}d=N()|0;break c}d=N()|0;tU(g)}hd(f);break c}d=N()|0}Ab(b)}AU(h)}Q(d|0);p()}function MI(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-208|0;hb=h;a:{b:{if(g){Qj(h+196|0,f,32);x[114409]=0;U(820,h+184|0,f|0,32)|0;i=x[114409];x[114409]=0;if((i|0)!=1){break b}c=N()|0;break a}Xb(h+196|0);Xb(h+184|0)}c:{d:{e:{f:{g:{h:{if(Fs(c)){i=b+24|0;b=x[i>>2];x[114409]=0;b=O(414,b+484344|0,c&65535)|0;j=x[114409];x[114409]=0;if((j|0)==1){break h}if(b){break g}}x[114409]=0;T(2319,a|0,h+196|0,h+184|0);a=x[114409];x[114409]=0;if((a|0)!=1){break f}}c=N()|0;break c}b=Zb(x[i>>2]+484344|0,c);if(!(!((e|0)<0|x[b+12>>2]<=(d|0)|(d|0)<0)&z[x[i>>2]+480188>>1]>e>>>0)){x[114409]=0;T(2319,a|0,h+196|0,h+184|0);a=x[114409];x[114409]=0;if((a|0)!=1){break f}c=N()|0;break c}x[114409]=0;c=U(2320,b|0,d|0,e&65535)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}Xe(h+196|0);Xe(h+184|0);x[114409]=0;b=S(546,c|0)|0;d=x[114409];x[114409]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((d|0)!=1){A:{B:{if(!b){if(!ct(c)){break B}}b=x[i>>2];d=y[c+1|0];e=y[c|0];x[114409]=0;W(2321,h+160|0,b|0,e|0,d|0);d=x[114409];x[114409]=0;b=1;if((d|0)==1){break z}x[114409]=0;T(9,h+172|0,0,h+160|0);d=x[114409];x[114409]=0;if((d|0)!=1){break A}c=N()|0;break w}b=0;x[114409]=0;O(122,h+172|0,12704)|0;d=x[114409];x[114409]=0;if((d|0)==1){break y}}x[114409]=0;O(1328,h+196|0,h+172|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}xb(h+172|0);if(b){xb(h+160|0)}x[114409]=0;b=S(546,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break v}if(b){b=5954}else{b=ct(c)?6259:12704}x[114409]=0;b=O(122,h+172|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break v}x[114409]=0;O(1328,h+184|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break u}xb(b);if(f-6>>>0>4294967290){break m}x[114409]=0;b=O(122,h+148|0,13666)|0;d=x[114409];x[114409]=0;if((d|0)==1){break t}x[114409]=0;O(1328,h+196|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break s}xb(b);x[114409]=0;b=O(122,h+136|0,13666)|0;d=x[114409];x[114409]=0;if((d|0)==1){break r}x[114409]=0;O(1328,h+184|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break q}xb(b);b=c+1|0;C:{if(y[c+1|0]){x[114409]=0;P(860,h+124|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){break C}break d}x[114409]=0;O(122,h+124|0,12709)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}}x[114409]=0;O(1328,h+196|0,h+124|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break p}d=h+124|0;xb(d);b=y[b|0];x[114409]=0;b=O(122,d|0,(b?6741:12709)|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break o}x[114409]=0;O(1328,h+184|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break n}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;xb(h+172|0);if(!b){break c}}xb(h+160|0);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;xb(h+124|0);break c}c=N()|0;break c}xb(b);if(f-9>>>0>4294967287){break m}x[114409]=0;b=S(1422,c|0)|0;d=x[114409];x[114409]=0;D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((d|0)!=1){O:{if(b){x[114409]=0;e=O(122,h+100|0,13666)|0;d=x[114409];x[114409]=0;if((d|0)==1){break N}x[114409]=0;j=S(1424,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break M}d=0;x[114409]=0;x[h+76>>2]=j&255;P(859,h+88|0,h+76|0);j=x[114409];x[114409]=0;if((j|0)==1){break M}x[114409]=0;T(141,h+112|0,e|0,h+88|0);e=x[114409];x[114409]=0;if((e|0)!=1){break O}c=N()|0;break H}if(y[c+2|0]){d=x[x[i>>2]+8>>2];e=y[c+2|0];x[114409]=0;d=O(2322,d|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break F}x[114409]=0;e=U(820,h+100|0,1,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break F}x[114409]=0;P(860,h+88|0,c+4|0);j=x[114409];x[114409]=0;d=1;if((j|0)==1){break L}x[114409]=0;T(141,h+112|0,e|0,h+88|0);e=x[114409];x[114409]=0;if((e|0)!=1){break O}c=N()|0;break J}d=0;x[114409]=0;O(122,h+112|0,12708)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}}x[114409]=0;O(1328,h+196|0,h+112|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break K}xb(h+112|0);if(d){xb(h+88|0);xb(h+100|0)}if(b){xb(h+88|0);xb(h+100|0)}x[114409]=0;b=S(1422,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break E}b=b?1974:y[c+2|0]?1970:12708;x[114409]=0;b=O(122,h+112|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break E}x[114409]=0;O(1328,h+184|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break D}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;break G}c=N()|0;xb(e);break c}c=N()|0;xb(h+112|0);if(!d){break I}}xb(h+88|0);xb(h+100|0)}if(!b){break c}}xb(h+88|0)}xb(h+100|0);break c}c=N()|0;break c}c=N()|0;break c}xb(b);if(f-13>>>0>4294967283){break m}x[114409]=0;b=O(122,h+76|0,13666)|0;d=x[114409];x[114409]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((d|0)!=1){x[114409]=0;O(1328,h+196|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break _}xb(b);x[114409]=0;b=O(122,h- -64|0,13666)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Z}x[114409]=0;O(1328,h+184|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Y}xb(b);x[114409]=0;b=S(1422,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break X}$:{if(b){b=0;x[114409]=0;d=S(1423,c|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;x[h+16>>2]=d&4095;P(1111,h+52|0,h+16|0);d=x[114409];x[114409]=0;if((d|0)!=1){break $}}c=N()|0;break c}if(y[c+3|0]){b=x[x[i>>2]+8>>2];d=y[c+3|0];x[114409]=0;b=O(2323,b|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break W}x[114409]=0;d=U(820,h+40|0,1,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break W}x[114409]=0;P(860,h+28|0,c+5|0);e=x[114409];x[114409]=0;b=1;if((e|0)==1){break V}x[114409]=0;T(141,h+52|0,d|0,h+28|0);d=x[114409];x[114409]=0;if((d|0)!=1){break $}c=N()|0;break S}b=0;x[114409]=0;O(122,h+52|0,12704)|0;d=x[114409];x[114409]=0;if((d|0)==1){break U}}x[114409]=0;O(1328,h+196|0,h+52|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break T}xb(h+52|0);if(b){xb(h+28|0);xb(h+40|0)}x[114409]=0;b=S(1422,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break Q}b=b?7027:y[c+3|0]?7027:12704;x[114409]=0;b=O(122,h+52|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break Q}x[114409]=0;O(1328,h+184|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break P}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;break R}c=N()|0;break c}c=N()|0;xb(h+52|0);if(!b){break c}}xb(h+28|0)}xb(h+40|0);break c}c=N()|0;break c}xb(b);if(!f){break i}}aa:{ba:{if(Cb(h+196|0)>>>0>f>>>0){x[114409]=0;W(205,h+16|0,h+196|0,0,f|0);b=x[114409];x[114409]=0;if((b|0)!=1){break ba}c=N()|0;break c}if(g){b=Cb(h+196|0);x[114409]=0;b=U(820,h+16|0,f-b|0,32)|0;c=x[114409];x[114409]=0;if((c|0)==1){break k}x[114409]=0;O(1328,h+196|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){c=N()|0;xb(b);break c}xb(b);if(Cb(h+184|0)>>>0>f>>>0){break j}break aa}if(Cb(h+184|0)>>>0<=f>>>0){break i}break j}b=h+16|0;Eb(h+196|0,b);xb(b);if(Cb(h+184|0)>>>0>f>>>0){break j}if(!g){break i}}b=Cb(h+184|0);x[114409]=0;b=U(820,h+4|0,f-b|0,32)|0;c=x[114409];x[114409]=0;ca:{if((c|0)!=1){x[114409]=0;O(1328,h+184|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break ca}xb(b);break i}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}x[114409]=0;W(205,h+4|0,h+184|0,0,f|0);b=x[114409];x[114409]=0;if((b|0)!=1){b=h+4|0;Eb(h+184|0,b);xb(b);break i}c=N()|0;break c}x[114409]=0;T(2319,a|0,h+196|0,h+184|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}}xb(h+184|0);xb(h+196|0);hb=h+208|0;return}c=N()|0;break c}c=N()|0}xb(h+184|0)}xb(h+196|0);Q(c|0);p()}function hG(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=hb-336|0;hb=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;lf(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;lf(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;$e(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];$e(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;$e(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];$e(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;$e(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];$e(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;$e(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];$e(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;$e(k+160|0,i,d,0,0,h,e,0,0);d=h;$e(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;$e(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);$e(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=sqa(y,l,j,0);j=lb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=sqa(s,p,y,q);d=j+H|0;h=lb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=sqa(e,j,E,w);o=e+d|0;j=lb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=sqa(F,p,y,q);d=e+d|0;j=lb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=sqa(F,p,B,w);m=lb;h=e;e=sqa(E,w,y,q);l=h+e|0;j=lb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=sqa(i,0,E,w);h=lb;e=d;i=sqa(z,r,s,r);d=d+i|0;j=lb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=sqa(B,w,J,0);n=e+d|0;j=lb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=sqa(F,p,H,r);I=lb;F=d;h=sqa(y,q,J,r);d=d+h|0;j=lb+I|0;o=d;p=sqa(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+lb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=sqa(s,r,B,w);p=l+j|0;l=lb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=sqa(z,r,J,r);z=lb;m=d;h=sqa(s,r,H,r);d=d+h|0;j=lb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;$e(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;$e(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Fl(k- -64|0,d,e,h,i,1-b|0);lf(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];$e(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;$e(k+16|0,f,g,D,C,3,0,0,0);$e(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;hb=k+336|0}function voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-272|0;hb=e;Nc(b);f=hb-16|0;hb=f;g=f+8|0;j=e+115|0;FT(g,j);h=Fb(g);g=nc(b,ac(f,g));if((h|0)==(g|0)){cc(b,Fb(f+8|0))}hb=f+16|0;f=(g|0)==(h|0);if(!f){GT(j)}a:{b:{c:{d:{e:{f:{g:{if(!f){break g}if(!IT(e+115|0)){break g}if(!c){d=1;break g}Pd(a,x[((y[e+231|0]|y[e+232|0]<<8)<<2)+23504>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;d=e+24|0;f=Vb(d,8972);Eb(a+1304436|0,f);xb(f);d=Vb(d,6294);Eb(a+1304448|0,d);xb(d);g=Vb(e+88|0,11095);x[114409]=0;P(192,e+100|0,g|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;W(398,e+24|0,e+100|0,e+194|0,e+191|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}d=e+24|0;Eb(a+1304460|0,d);xb(d);f=e+100|0;Gb(f);xb(g);Rc(a+1304484|0,((y[e+231|0]|y[e+232|0]<<8)<<2)+23552|0);Rc(a+1304472|0,x[((y[e+231|0]|y[e+232|0]<<8)<<2)+76240>>2]);x[a+1304496>>2]=4;Ng(f,2,e+119|0);Kc(d,f);Eb(a+1304400|0,d);xb(d);Ng(f,2,e+151|0);Kc(d,f);h:{i:{j:{if(RA(d,5662)){x[114409]=0;T(13,e+100|0,4,e+24|0);d=x[114409];x[114409]=0;if((d|0)==1){break j}d=e+100|0;Eb(a+1304412|0,d);xb(d)}xb(e+24|0);w[a+480188>>1]=32;f=0;k:{while(1){g=(f<<5)+a|0;j=g+480280|0;Pg(j);l:{d=e+f|0;if(y[d+196|0]<=15){x[e+24>>2]=y[d+196|0]<<4|8;x[e+100>>2]=256;s=g+480284|0,t=x[fe(e+24|0,e+100|0)>>2],w[s>>1]=t;break l}if(y[d+196|0]==16){w[g+480284>>1]=128;x[j>>2]=256;break l}if(y[d+196|0]!=255){break l}w[a+480188>>1]=f;break k}f=f+1|0;if((f|0)!=32){continue}break}f=z[a+480188>>1]}d=0;if(!(f&65535)){break g}x[e+24>>2]=y[e+228|0]<<2;x[e+100>>2]=256;s=a,t=x[Mb(e+24|0,e+100|0)>>2],x[s+480200>>2]=t;x[a+480196>>2]=y[e+229|0];x[a+480204>>2]=D(y[e+230|0],1e4);if(Tc(b,y[e+233|0]|y[e+234|0]<<8|(y[e+235|0]<<16|y[e+236|0]<<24))){Dq(Wb(a+484360|0),b,y[e+237|0]+1|0,255,254)}if(!Tc(b,y[e+243|0]|y[e+244|0]<<8|(y[e+245|0]<<16|y[e+246|0]<<24))){break g}w[a+480190>>1]=y[e+251|0]+1;h=e+56|0;f=1;j=1;while(1){d=hb-16|0;hb=d;i=hb-16|0;hb=i;g=d+8|0;k=e+24|0;jc(g,k,62);hb=i+16|0;i=Fb(g);g=nc(b,ac(d,g));if((i|0)==(g|0)){cc(b,Fb(d+8|0))}hb=d+16|0;d=(g|0)==(i|0);if(!d){g=hb-16|0;hb=g;Sb(k,0,62);hb=g+16|0}if(d){d=D(f,104)+a|0;g=d+484380|0;zd(g,0);i=e+12|0;Ng(i,2,e+24|0);k=e+100|0;Kc(k,i);x[114409]=0;O(348,((f<<5)+a|0)+946304|0,k|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}f=e+100|0;xb(f);i=e+12|0;$k(i,2,h);Kc(f,i);x[114409]=0;O(350,d+484423|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}xb(e+100|0);f=d+484404|0;x[f>>2]=y[e+82|0]|y[e+83|0]<<8;m:{if(!Bq(a)){break m}i=x[f>>2];f=0;while(1){if((i|0)==z[(f<<1)+23600>>1]){v[d+484417|0]=f<<4;break m}f=f+1|0;if((f|0)!=16){continue}break}}w[d+484412>>1]=64;x[g>>2]=y[e+69|0]|y[e+70|0]<<8|(y[e+71|0]<<16|y[e+72|0]<<24);if(y[e+81|0]&2){f=d+484414|0;w[f>>1]=z[f>>1]|1;x[g>>2]=x[g>>2]>>>1}x[d+484384>>2]=y[e+73|0]|y[e+74|0]<<8|(y[e+75|0]<<16|y[e+76|0]<<24);x[d+484388>>2]=(y[e+77|0]|y[e+78|0]<<8|(y[e+79|0]<<16|y[e+80|0]<<24))-1;if(v[e+81|0]&1){f=d+484414|0;w[f>>1]=z[f>>1]|2}n:{if(y[e+81|0]&4){v[e+100|0]=y[e+84|0];v[e+12|0]=64;s=d+484410|0,t=y[tc(e+100|0,e+12|0)|0]<<2,w[s>>1]=t;break n}f=d+484414|0;w[f>>1]=z[f>>1]|32768}o:{if(!(y[e+81|0]&8)){w[d+484408>>1]=128;break o}f=d+484414|0;w[f>>1]=z[f>>1]|32;m=d+484408|0;if(y[e+85|0]<=15){d=y[e+85|0];x[e+12>>2]=256;x[e+100>>2]=d<<4|8;d=x[fe(e+100|0,e+12|0)>>2]}else{d=128}w[m>>1]=d;w[f>>1]=z[f>>1]&65279|(y[e+85|0]==16)<<8}j=j+1|0;f=j&65535;if(f>>>0<=z[a+480190>>1]){continue}}break}p:{if(!(c&2)){break p}if(!Tc(b,y[e+247|0]|y[e+248|0]<<8|(y[e+249|0]<<16|y[e+250|0]<<24))|!z[a+480190>>1]){break p}f=1;while(1){d=D(f&65535,104)+a|0;Fg(cd(e+24|0,w[d+484414>>1]&1?16:8,1,0,1),d+484380|0,b);f=f+1|0;if(z[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=a+484344|0;ig(n,y[e+242|0]+1|0);f=Jp(a);d=hb-16|0;hb=d;x[d+12>>2]=0;gt(d+12|0,f);i=x[d+12>>2];hb=d+16|0;Tc(b,y[e+238|0]|y[e+239|0]<<8|(y[e+240|0]<<16|y[e+241|0]<<24));q=c&1;j=0;k=1;while(1){c=tg(b);if(c>>>0>=3){Ad(e+24|0,b,c-2|0);q:{if(!q){break q}x[114409]=0;c=S(312,e+24|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break i}if(!c){break q}x[114409]=0;c=U(378,n|0,j&65535,64)|0;d=x[114409];x[114409]=0;if((d|0)==1){break i}l=0;if(!c){break q}while(1){c=Zb(n,j);x[114409]=0;r=O(477,c|0,l|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}r:{s:while(1){t:{x[114409]=0;c=S(425,e+24|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break t}if(!c){break r}d=c&31;if(d>>>0>=z[a+480188>>1]){break r}f=D(d,6)+r|0;if(c&32){x[114409]=0;P(452,e+100|0,e+24|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}g=ed(e+100|0);d=y[e+100|0];if(d){d=(d&127)-1|0;v[e+100|0]=d;v[f|0]=(D((d&240)>>>4|0,12)+(d&15)|0)+13;x[114409]=0;d=S(621,f|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}k=d&k}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;g=f+5|0;while(1){x[114409]=0;c=O(231,e+24|0,2)|0;d=x[114409];x[114409]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){if(!c){continue s}o=y[f+5|0];c=y[f+3|0];x[114409]=0;P(452,e+100|0,e+24|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}d=e+100|0;m=d;h=y[ed(d)|0];v[g|0]=h;d=y[(y[d|0]&31)+23632|0];v[f+3|0]=d;switch(d-2|0){case 4:case 5:break y;case 18:break z;case 13:break A;case 17:break B;case 11:break C;case 1:break D;case 0:break E;default:break w}}break i}if(h>>>0<224){break u}break v}if(h>>>0>=224){break v}break u}x[114409]=0;v[e+12|0]=64;d=O(431,g|0,e+12|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){v[g|0]=y[d|0];x[114409]=0;d=O(622,i|0,1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}if(!d){break x}v[f+2|0]=1;v[f+4|0]=y[g|0];v[f+3|0]=c;v[g|0]=o;d=c;break w}break i}F:{switch(((h&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[g|0]=h&15|224;break u;case 1:v[f+3|0]=3;v[g|0]=h&15|224;break u;default:break F}}x[114409]=0;d=O(623,i|0,19)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}if(d){break x}x[114409]=0;V(624,f|0);d=x[114409];x[114409]=0;if((d|0)!=1){break x}break i}x[114409]=0;d=O(623,i|0,15)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}if(d){break x}x[114409]=0;d=O(623,i|0,19)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}if(!d){break x}v[f+3|0]=19;v[g|0]=y[g|0]&15|144;break u}if((h|0)==1){v[g|0]=145;break u}if((h&240)==128){x[114409]=0;d=O(623,i|0,20)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}if(d){break x}v[f+3|0]=19;break u}v[f+3|0]=0;break u}d=h&240;if(!d){break u}v[g|0]=d}d=y[f+3|0]}if((d&255)!=20){break u}d=y[g|0];if(y[f+2|0]|(d&240)!=128){break u}v[f+2|0]=2;v[f+4|0]=(((d&15)<<6|8)>>>0)/15;v[f+3|0]=c;v[g|0]=o;break u}v[g|0]=223}if(y[m|0]&32){continue}break}continue}break}break i}l=l+1|0;if((l|0)!=64){continue}break}}Ab(e+24|0)}c=y[e+242|0]>j>>>0;j=j+1|0;if(c){continue}break}break h}d=N()|0;xb(e+24|0);break a}d=N()|0;Ab(e+24|0);break a}if(x[a+480180>>2]!=1){c=x[a+480208>>2]&-8454145}else{c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?k&1?8454144:0:0)}x[a+480208>>2]=c;d=1;if(!(y[e+256|0]|y[e+257|0]<<8|(y[e+258|0]<<16|y[e+259|0]<<24))){break g}if(!Tc(b,y[e+252|0]|y[e+253|0]<<8|(y[e+254|0]<<16|y[e+255|0]<<24))){break g}Dz(a+1304424|0,b,y[e+256|0]|y[e+257|0]<<8|(y[e+258|0]<<16|y[e+259|0]<<24),4)}hb=e+272|0;return d|0}d=N()|0;xb(e+100|0);break a}d=N()|0;xb(e+100|0);break a}d=N()|0;Gb(e+100|0);break b}d=N()|0}xb(g)}Q(d|0);p()}function Hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=hb-320|0;hb=d;a:{if(!Tc(b,1080)){break a}if(!eo(b,d+316|0)){break a}l=GR(d+300|0);if(!FR(d+316|0,l)){break a}e=z[l+10>>1];if(!e|e>>>0>127){break a}b:{if(!c){break b}I=1;Pd(a,1);h=z[l+10>>1];w[a+480188>>1]=h;o=y[l+14|0];K=y[l+13|0];e=y[l+12|0];if(!Wd(d+316|0,23928)){I=Wd(d+316|0,23933)}if(y[l+15|0]){Nb(a+1074312|0,5,1);h=z[a+480188>>1]}f=d+316|0;r=Wd(f,12596);i=1;if(!Wd(f,13263)){i=Wd(d+316|0,9453)}s=h&65535;Tc(b,0);LA(b,a+1304400|0,20);w[a+480190>>1]=31;m=(e|0)!=0;h=1;g=r;e=0;while(1){n=D(h,104)+a|0;f=n+484380|0;t=dA(b,d+170|0,f,((h<<5)+a|0)+946304|0,z[a+480188>>1]==4);f=x[f>>2];c:{if(i){v[n+484417|0]=0-(y[d+194|0]<<3);break c}m=f>>>0<65536&m}d:{if(!(!(y[d+192|0]|y[d+193|0]<<8)|(y[d+198|0]|y[d+199|0]<<8))){_=1;break d}if(y[d+192|0]|y[d+193|0]<<8){break d}L=y[d+195|0]==64|L}n=g&1;g=0;e:{if(!n){break e}u=j;j=y[d+192|0]|y[d+193|0]<<8;j=u+(((j<<8|j>>>8)&65535)<<1)|0;if(y[d+194|0]){break e}if(!(y[d+192|0]|y[d+193|0]<<8)){g=1;break e}g=y[d+195|0]==64}e=e+t|0;k=f+k|0;h=h+1|0;if((h|0)!=32){continue}break}h=0;if(A[l+4>>2]<e>>>0){break a}t=a+480188|0;s=(s|0)==8&(K|0)!=0;cA(b,d+170|0);Tc(b,z[l+8>>1]);e=y[d+171|0];f=128;i=a+484360|0;Uj(Wb(i),d+172|0,128,65535,65535);h=!e&g;j=h?j:0;e=y[d+170|0];f:{if(e>>>0>128){break f}f=e;if(e){break f}g=128;while(1){e=g-1|0;if(!z[vc(Wb(i),e)>>1]){f=1;g=e;if(e>>>0>1){continue}break f}break}f=g}E=(o|0)!=0;n=DR(b,Wb(i),f&65535,k,t,j,0);if(!(!h|z[a+480188>>1]!=8)){x[l>>2]=7143;E=1}g:{if(!s){break g}e=Wb(i);aa=d,ba=bc(e),x[aa+156>>2]=ba;aa=d,ba=dc(e),x[aa+144>>2]=ba;if(!Hb(d+156|0,d+144|0)){break g}while(1){e=d+156|0;g=x[e>>2];w[g>>1]=z[g>>1]>>>1;ke(e);if(Hb(e,d+144|0)){continue}break}}Pe(Wb(i),y[d+171|0]);M=f-1&65535;h:{if(M>>>0>=y[d+171|0]){h=z[t>>1];if(y[d+171|0]!=120|(h|0)!=4){break h}}Pe(Wb(i),0);h=z[t>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;e=Yb(256/((h&65535)>>>0)|0,32,128);x[a+480208>>2]=0;x[a+480228>>2]=e;Cj(a,0);v[d+169|0]=0;F=1;O=1;if(!(m&1)){i:{if(!n){e=r;f=0;break i}h=d+161|0;m=0;e=r;j=0;i=0;while(1){f=0;o=0;while(1){g=ei(d+156|0);gu(b,g);G=HT(g);j:{k:{l:{m:{k=y[d+159|0];if((k-7&255)>>>0<3){e=0;break m}g=y[d+161|0];if(!((k|0)!=14|g>>>0<=1)){e=0;break l}if(!((k|0)==15&(g&255)>>>0>31)){e=G?e:0;if((k|0)!=13){break m}o=o+1|0;if((o&65535)>>>0<2){break j}}e=0;break j}if((k|0)==8){break k}if((k|0)!=14){break j}g=y[d+161|0]}if((g&240)!=128){break j}v[d+144|0]=g<<4;aa=d,ba=y[ah(d+169|0,d+144|0)|0],v[aa+169|0]=ba;break j}aa=d,ba=y[ah(d+169|0,h)|0],v[aa+169|0]=ba;g=v[d+161|0];if((g|0)>=0){i=1;break j}j=(g|0)!=-92&g>>>0>4294967183|j}F=G&F;f=f+1|0;if((f|0)!=256){continue}break}m=m+1|0;if(n>>>0>(m&65535)>>>0){continue}break}f=0;if((i^-1|j)&1){break i}f=y[d+169|0]>47}O=e&1;G=f}Tc(b,z[l+8>>1]);e=z[a+480188>>1];B=a+484344|0;f=n+s|0;g=f&65535;ig(B,g);R=s?4:e;n:{o:{if(!g){j=0;i=0;o=0;break o}V=R&65535;W=f&65535;$=a+1074312|0;u=c&1;m=0;o=0;i=0;j=0;p:{while(1){f=!u;q:{if(s){e=(m&65534)>>>1|0;g=m&1;if(!g){if(!Zg(B,e,64)){break o}}e=Hf(Zb(B,e),0,g<<2);break q}if(!Zg(B,m&65535,64)){break o}e=Hf(Zb(B,m),0,0)}k=e;if(f|!k){break o}e=z[a+480188>>1];v[d+84|0]=0;f=e;e=d+84|0;n=Lu(d+156|0,f,e);f=z[a+480188>>1];x[114409]=0;v[d+84|0]=0;H=U(908,d+144|0,f|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){J=0;while(1){e=0;X=0;h=0;if(V){while(1){x[114409]=0;g=D(h,6)+k|0;P(909,b|0,g|0);f=x[114409];x[114409]=0;r:{s:{t:{if((f|0)==1){break t}f=y[g+3|0];u:{v:{w:{if(!f){if(y[g+5|0]){break w}break v}if(!K){break w}x:{switch(f-14|0){case 0:v[g+3|0]=0;v[g+5|0]=0;break w;case 1:break x;default:break w}}if(y[g+5|0]<32){break w}v[g+5|0]=31}Mj(g);f=1;y:{z:{A:{q=y[g+3|0];switch(q-14|0){case 2:break u;case 0:break z;case 3:break A;default:break y}}j=y[g+5|0]<100|j;X=1;break v}if(!O){break v}v[g+5|0]=0;break v}if((q|0)==9&G){f=y[g+5|0];if((f|0)==164){v[g+3|0]=20;v[g+5|0]=145;break v}x[114409]=0;f=S(910,f<<1)|0;q=x[114409];x[114409]=0;if((q|0)==1){break t}v[g+5|0]=f;break v}if((q|0)!=19){break v}f=y[g+5|0];if(f>>>0>15){break v}q=!(f&1);f=(q^Y)&1;Y=f?q:Y;o=f+o|0}f=e}if(y[g|0]){break s}if(s|!y[g+1|0]){break r}if(!y[Cc(n,h)|0]){break r}if(y[Cc(n,h)|0]==y[g+1|0]){break r}q=Cc(H,h);e=y[q|0]+1|0;v[q|0]=e;if((e&255)>>>0<4){break r}x[114409]=0;U(458,$|0,85,1)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break r}}h=N()|0;de(H);break p}aa=Cc(H,h),ba=0,v[aa|0]=ba}e=y[g+1|0];if(e){aa=Cc(n,h),ba=e,v[aa|0]=ba}e=f;h=h+1|0;if((V|0)!=(h|0)){continue}break}}i=e&X|i;k=D(z[t>>1],6)+k|0;J=J+1|0;if((J|0)!=64){continue}break}de(H);de(n);m=m+1|0;if((W|0)==(m|0)){break o}continue}break}h=N()|0}de(n);break n}B:{C:{D:{f=F^1;if((f|_)&1){break D}E:{if(Wd(d+316|0,12596)){break E}if(Wd(d+316|0,13268)){break E}if(!Wd(d+316|0,9448)){break D}}x[a+480208>>2]=x[a+480208>>2]|2162688;e=a+1074312|0;Nb(e,85,1);Nb(e,91,1);Nb(e,92,1);F:{if(y[d+169|0]>47){break F}Nb(e,84,1);if(y[d+171|0]==127){break F}Nb(e,83,1)}if(!((o|0)>6|E)){break C}break B}if(!F){if(r^1|y[d+171|0]!=127|y[d+171|0]+1>>>0<M>>>0){break B}x[l>>2]=4557;break B}if((o|0)>6|E){break B}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((r|E)==1){Nb(a+1074312|0,89,1)}if(I){Nb(a+1074312|0,84,1)}if(c&2){Tc(b,z[l+8>>1]+(D(R&65535,W)<<8)|0);f=(f|r^1|L)&1;h=1;while(1){g=D(h,104)+a|0;c=g+484380|0;if(x[c>>2]){e=d+156|0;if(I){u=2}else{u=CR(b,9645)?11:0}e=cd(e,8,1,0,u);k=x[b+8>>2]+xT(e,x[c>>2])|0;if(!f){aa=c,ba=x[$c(c,g+484388|0)>>2],x[aa>>2]=ba}Fg(e,c,b);Tc(b,k)}h=h+1|0;if((h|0)!=32){continue}break}}G:{H:{if(!r){if(!((Wd(d+316|0,13268)&j^-1|i)&1)){break H}break G}if((j^-1|i)&1){break G}}b=BR(d+120|0,0);c=x[b+20>>2];x[d+40>>2]=x[b+16>>2];x[d+44>>2]=c;c=x[b+12>>2];x[d+32>>2]=x[b+8>>2];x[d+36>>2]=c;c=x[b+4>>2];x[d+24>>2]=x[b>>2];x[d+28>>2]=c;b=d+156|0;st(b,a,0,d+24|0);Z=C[x[b>>2]>>3];em(b);if(Z<480){break G}c=a+1074312|0;Nb(c,5,1);b=zR(d+96|0,Z);e=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=e;e=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=e;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=d+156|0;st(b,a,0,d);e=y[x[b>>2]+26|0];em(b);if(e){Kg(c,5);break G}x[l>>2]=12952}c=d+316|0;b=c;e=mc(b);if((b|0)!=(e|0)){while(1){f=y[c|0];v[b|0]=f>>>0<=32?32:f;b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}b=Vb(d+72|0,13140);x[114409]=0;P(192,d+84|0,b|0);c=x[114409];x[114409]=0;I:{J:{K:{L:{M:{N:{if((c|0)!=1){c=d+316|0;e=mc(c);x[114409]=0;c=U(911,d+48|0,c|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break N}x[114409]=0;T(13,d+60|0,1,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break M}x[114409]=0;T(220,d+156|0,d+84|0,d+60|0);e=x[114409];x[114409]=0;if((e|0)==1){break L}e=d+156|0;Eb(a+1304436|0,e);xb(e);xb(d+60|0);xb(c);Gb(d+84|0);xb(b);b=Vb(e,8133);Eb(a+1304448|0,b);xb(b);b=x[l>>2];if(b){Rc(a+1304460|0,b)}x[a+1304496>>2]=2;break b}h=N()|0;break I}h=N()|0;break J}h=N()|0;break K}h=N()|0;xb(d+60|0)}xb(c)}Gb(d+84|0)}xb(b)}Q(h|0);p()}h=1}hb=d+320|0;return h|0}function gW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-192|0;hb=e;Nc(b);a:{b:{c:{d:{e:{if(!ZB(b,e+151|0)){break e}if(!_B(e+151|0)){break e}if(!c){n=1;break e}Pd(a,2048);Ni(a);d=Vb(e+124|0,11307);x[114409]=0;P(192,e+136|0,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break c}x[114409]=0;T(363,e+48|0,e+136|0,e+154|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}f=e+48|0;Eb(a+1304436|0,f);xb(f);g=e+136|0;Gb(g);xb(d);d=Vb(f,7023);Eb(a+1304448|0,d);xb(d);x[a+1304496>>2]=4;w[a+480188>>1]=y[e+191|0];w[a+480190>>1]=y[e+187|0];Ng(g,2,e+155|0);Kc(f,g);Eb(a+1304400|0,f);xb(f);if(y[e+154|0]<=8){w[a+480188>>1]=4;rg(b,1);Cj(a,1)}f=y[e+154|0];f:{if(y[e+154|0]>=11){f=f>>>0>11?32:16;d=0;while(1){g=fv(b);g:{if((g|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break g}x[e+48>>2]=(g<<1)+128;x[e+136>>2]=0;x[e+36>>2]=256;t=((d<<5)+a|0)+480284|0,u=x[gl(e+48|0,e+136|0,e+36|0)>>2],w[t>>1]=u}d=d+1|0;if((f|0)!=(d|0)){continue}break}break f}if(f>>>0<9){break f}YB(b,e+48|0);d=0;while(1){w[((d<<5)+a|0)+480284>>1]=v[(e+48|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}h:{if(y[e+154|0]>=13){d=e+48|0;av(d,b);g=ed(d);f=y[d|0];if(f>>>0<=31){v[d|0]=125;f=125}x[a+480204>>2]=D(f,1e4);x[a+480196>>2]=y[g|0];break h}x[a+480196>>2]=6;x[a+480204>>2]=125e4}f=a+484360|0;Og(Wb(f),y[e+188|0]);k=pm(e+136|0);o=x[b+8>>2];q=y[e+154|0];i:{j:{k:{l:{if(y[e+154|0]<14){break l}d=y[e+188|0];x[114409]=0;P(364,k|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){break l}a=N()|0;break k}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(y[e+188|0]){d=0;while(1){t=vc(Wb(f),d),u=d,w[t>>1]=u;if(y[e+154|0]>=14){x[114409]=0;g=S(335,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break u}t=vc(k,d),u=g,w[t>>1]=u}g=z[a+480188>>1];x[114409]=0;O(313,b|0,g<<1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break u}d=d+1|0;if(d>>>0<y[e+188|0]){continue}break}}f=0;v:{w:{if(y[e+154|0]==10){l=x[b+8>>2];f=0;x:{if(!z[a+480190>>1]){break x}g=1;while(1){x[114409]=0;f=O(365,b|0,e+48|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break w}y:{if(!f){break y}j=y[e+187|0];h=0;d=e+48|0;z:{if(y[d|0]>1){break z}f=d+46|0;if(j>>>0<(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0){break z}f=d+50|0;if((y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0>1048576|y[d+56|0]>64){break z}j=d+57|0;if((y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))>>>0>(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0){break z}d=d+61|0;h=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0<=(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0}if(h){break y}f=1;break x}g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}f=0}x[114409]=0;O(229,b|0,l|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break v}}d=z[a+480190>>1];x[114409]=0;x[e+48>>2]=0;l=U(366,e+36|0,d|0,e+48|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){if(z[a+480190>>1]){j=f?59:65;h=e+49|0;d=1;g=1;while(1){A:{if(y[e+154|0]<=9){x[114409]=0;O(367,b|0,e+48|0)|0;i=x[114409];x[114409]=0;B:{C:{D:{if((i|0)==1){break D}x[114409]=0;P(368,e+48|0,(D(d,104)+a|0)+484380|0);i=x[114409];x[114409]=0;if((i|0)==1){break D}x[114409]=0;T(369,e+12|0,2,h|0);i=x[114409];x[114409]=0;if((i|0)==1){break C}x[114409]=0;P(370,e+24|0,e+12|0);i=x[114409];x[114409]=0;if((i|0)==1){break C}x[114409]=0;O(348,((d<<5)+a|0)+946304|0,e+24|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break B}break A}a=N()|0;break m}a=N()|0;break m}a=N()|0;xb(e+24|0);break m}x[114409]=0;U(371,b|0,e+48|0,j|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break n}x[114409]=0;T(372,e+48|0,(D(d,104)+a|0)+484380|0,f|0);i=x[114409];x[114409]=0;if((i|0)==1){break n}x[114409]=0;T(369,e+12|0,2,h|0);i=x[114409];x[114409]=0;if((i|0)==1){break o}x[114409]=0;P(370,e+24|0,e+12|0);i=x[114409];x[114409]=0;if((i|0)==1){break o}x[114409]=0;O(348,((d<<5)+a|0)+946304|0,e+24|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break p}}xb(e+24|0);i=y[e+94|0]|y[e+95|0]<<8|(y[e+96|0]<<16|y[e+97|0]<<24);t=Pb(l,d-1|0),u=i,x[t>>2]=u;g=g+1|0;d=g&65535;if(d>>>0<=z[a+480190>>1]){continue}break}}j=Oq(e+24|0);f=y[e+189|0]|y[e+190|0]<<8;x[114409]=0;n=U(373,b|0,j|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break t}if(!n){break i}f=0;E:{if(!kd(j)){f=bc(j);d=dc(j);x[114409]=0;f=O(374,f|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break E}x[e+48>>2]=f;f=x[e+48>>2];f=y[f|0]|y[f+1|0]<<8}x[114409]=0;i=O(375,e+12|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){F:{if(f){g=0;while(1){x[114409]=0;d=S(335,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break s}x[114409]=0;O(313,b|0,1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break s}if(d){h=y[e+154|0];x[114409]=0;T(316,e+48|0,b|0,D(d,3)+((h|0)==1?3:0)|0);d=x[114409];x[114409]=0;if((d|0)==1){break F}d=e+48|0;Zd(wc(i,g),d);Ab(d)}g=g+1|0;if((f|0)!=(g|0)){continue}break}}G:{if(!(c&2)){break G}h=1;m=cd(e+48|0,8,1,0,1);if(!z[a+480190>>1]){break G}g=1;while(1){x[114409]=0;d=O(231,b|0,1)|0;r=x[114409];x[114409]=0;H:{I:{if((r|0)!=1){if(!d){break G}d=0;if(!z[a+480190>>1]){break H}r=x[b+8>>2];while(1){J:{if(x[Pb(l,d)>>2]!=(h|0)){d=d+1|0;break J}x[114409]=0;O(229,b|0,r|0)|0;s=x[114409];x[114409]=0;if((s|0)==1){break I}x[114409]=0;d=d+1|0;U(376,m|0,(D(d,104)+a|0)+484380|0,b|0)|0;s=x[114409];x[114409]=0;if((s|0)==1){break I}}if(z[a+480190>>1]>d>>>0){continue}break}break H}a=N()|0;break r}a=N()|0;break r}g=g+1|0;h=g&65535;if(h>>>0<=z[a+480190>>1]){continue}break}}if(!(c&1)){break j}c=y[e+188|0];h=0;x[114409]=0;m=a+484344|0;P(377,m|0,c|0);c=x[114409];x[114409]=0;K:{if((c|0)!=1){if(!y[e+188|0]){break j}o=o+((q>>>0>13)<<1)|0;while(1){L:{g=64;if(rc(k)>>>0>h>>>0){g=z[vc(k,h)>>1]}x[114409]=0;c=U(378,m|0,h&65535,g&65535)|0;d=x[114409];x[114409]=0;if((d|0)==1){break K}M:{if(c){c=z[a+480188>>1];d=y[e+154|0];x[114409]=0;O(229,b|0,o+D(((d>>>0>13)<<1)+(c<<1)|0,h)|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break K}c=Oq(e+48|0);d=z[a+480188>>1];x[114409]=0;d=U(373,b|0,c|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break M}N:{if(!d){break N}d=0;if(!z[a+480188>>1]){break N}while(1){O:{g=vc(c,d);if(!(y[g|0]|y[g+1|0]<<8)){break O}g=vc(c,d);if((y[g|0]|y[g+1|0]<<8)>>>0>(y[e+189|0]|y[e+190|0]<<8)>>>0){break O}g=vc(c,d);g=vc(j,(y[g|0]|y[g+1|0]<<8)-1|0);g=(y[g|0]|y[g+1|0]<<8)-1&65535;if(g>>>0>=f>>>0){break O}q=Zb(m,h);g=wc(i,g);x[114409]=0;T(379,q|0,d&65535,g|0);g=x[114409];x[114409]=0;if((g|0)!=1){break O}break L}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}}Rj(c)}h=h+1|0;if(h>>>0>=y[e+188|0]){break j}continue}}break}a=N()|0;Rj(c);break r}a=N()|0;break r}a=N()|0;break r}a=N()|0;break r}a=N()|0;break q}a=N()|0;break q}a=N()|0;break k}a=N()|0;break k}a=N()|0;break k}a=N()|0;break k}a=N()|0;break q}a=N()|0}hd(i)}Rj(j);break m}a=N()|0;xb(e+24|0);break m}a=N()|0;break m}a=N()|0}Me(l)}vf(k);break a}hd(i)}Rj(j);Me(l);vf(k)}hb=e+192|0;return n|0}a=N()|0;Gb(e+136|0);break b}a=N()|0}xb(d)}Q(a|0);p()}function vka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-256|0;hb=d;Nc(b);e=hb-16|0;hb=e;h=e+8|0;i=d+110|0;iQ(h,i);f=Fb(h);h=nc(b,ac(e,h));if((f|0)==(h|0)){cc(b,Fb(e+8|0))}hb=e+16|0;e=(f|0)==(h|0);if(!e){jQ(i)}a:{b:{c:{d:{e:{if(!e){break e}if(!AQ(d+110|0)){break e}if(!c){g=1;break e}Pd(a,4194304);e=d+28|0;g=Vb(e,12911);Eb(a+1304436|0,g);xb(g);g=Vb(e,6118);Eb(a+1304448|0,g);xb(g);x[a+1304496>>2]=4;l=a,m=Md(y[d+188|0]|y[d+189|0]<<8,y[d+190|0]|y[d+191|0]<<8,127),w[l+480188>>1]=m;g=y[d+179|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[d+177|0];x[a+480204>>2]=D(y[d+178|0],1e4);g=d+92|0;gf(g,d+114|0,59,3);Kc(e,g);Eb(a+1304400|0,e);xb(e);f:{if((y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))>>>0<5){break f}if(!Tc(b,(y[d+192|0]|y[d+193|0]<<8|(y[d+194|0]<<16|y[d+195|0]<<24))-4|0)){break f}if(!ej(b,9948)){break f}Dq(Wb(a+484360|0),b,y[d+182|0]|y[d+183|0]<<8,65535,65535)}g:{if((y[d+196|0]|y[d+197|0]<<8|(y[d+198|0]<<16|y[d+199|0]<<24))>>>0<5){break g}if(!Tc(b,(y[d+196|0]|y[d+197|0]<<8|(y[d+198|0]<<16|y[d+199|0]<<24))-4|0)){break g}if(!ej(b,9604)){break g}g=0;while(1){e=(g<<5)+a|0;Pg(e+480280|0);l=e+480284|0,m=((((te(b)^-1)&15)<<8|8)>>>0)/15|0,w[l>>1]=m;g=g+1|0;if((g|0)!=32){continue}break}}h:{if((y[d+204|0]|y[d+205|0]<<8|(y[d+206|0]<<16|y[d+207|0]<<24))>>>0<5){break h}if(!Tc(b,(y[d+204|0]|y[d+205|0]<<8|(y[d+206|0]<<16|y[d+207|0]<<24))-4|0)){break h}if(!ej(b,9880)){break h}Ad(d+92|0,b,(y[d+186|0]|y[d+187|0]<<8)<<6);i:{if(!(y[d+186|0]|y[d+187|0]<<8)){break i}g=c&2;h=a+480190|0;i=d+41|0;while(1){x[114409]=0;e=O(1009,d+92|0,d+28|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}if(!e){break i}e=y[d+73|0]|y[d+74|0]<<8;w[d+26>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(He((D(e,104)+a|0)+484380|0)){break j}x[114409]=0;e=O(424,h|0,d+26|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}w[a+480190>>1]=z[e>>1];x[114409]=0;P(1010,d+28|0,(D(z[d+26>>1],104)+a|0)+484380|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;T(1011,d|0,1,i|0);e=x[114409];x[114409]=0;k:{l:{if((e|0)==1){break l}x[114409]=0;P(370,d+12|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break l}x[114409]=0;O(348,((z[d+26>>1]<<5)+a|0)+946304|0,d+12|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}xb(d+12|0);if(!g){break j}e=y[d+65|0]|y[d+66|0]<<8|(y[d+67|0]<<16|y[d+68|0]<<24);x[114409]=0;O(229,b|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(1012,d+12|0,d+28|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;U(376,d+12|0,(D(z[d+26>>1],104)+a|0)+484380|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break j}}b=N()|0;break b}b=N()|0;break b}b=N()|0;xb(d+12|0);break b}j=j+1|0;if((j&65535)>>>0<(y[d+186|0]|y[d+187|0]<<8)>>>0){continue}break}}Ab(d+92|0)}g=1;if(!(c&1)){break e}m:{if((y[d+200|0]|y[d+201|0]<<8|(y[d+202|0]<<16|y[d+203|0]<<24))>>>0<5){break m}if(!Tc(b,(y[d+200|0]|y[d+201|0]<<8|(y[d+202|0]<<16|y[d+203|0]<<24))-4|0)){break m}if(!ej(b,9483)){break m}i=a+484344|0;ig(i,y[d+184|0]|y[d+185|0]<<8);if(!(y[d+184|0]|y[d+185|0]<<8)){break m}h=0;while(1){if(!yu(b,d+12|0)){break m}if((y[d+12|0]|y[d+13|0]<<8)>>>0>3){Ad(d+28|0,b,((y[d+12|0]|y[d+13|0]<<8)+15&131056)-4|0);c=y[d+14|0];x[114409]=0;c=U(378,i|0,h&65535,c|0)|0;e=x[114409];x[114409]=0;n:{if((e|0)!=1){o:{j=0;if(!c){break n}while(1){x[114409]=0;c=O(231,d+28|0,1)|0;e=x[114409];x[114409]=0;p:{q:{r:{if((e|0)!=1){if(!c|y[d+14|0]<=j>>>0){break q}x[114409]=0;c=S(425,d+28|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}e=c<<24>>24;if(e){break r}j=j+1|0;continue}break o}c=Zb(i,h);w[d>>1]=e&31;f=z[a+480188>>1];x[114409]=0;w[d+26>>1]=f-1;f=O(457,d|0,d+26|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break o}f=z[f>>1];x[114409]=0;c=U(451,c|0,j|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break o}if((e|0)<0){x[114409]=0;P(452,d|0,d+28|0);f=x[114409];x[114409]=0;if((f|0)==1){break o}f=ed(d);v[c|0]=y[d|0]+36;v[c+1|0]=y[f|0]}e=e&255;if(!(e&64)){break p}v[c+2|0]=1;x[114409]=0;f=S(425,d+28|0)|0;k=x[114409];x[114409]=0;s:{if((k|0)!=1){x[114409]=0;v[d|0]=f;v[d+26|0]=64;f=O(431,d|0,d+26|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break s}v[c+4|0]=y[f|0];break p}break o}break o}if(y[d+14|0]==64){break n}c=Zb(i,h);x[114409]=0;e=U(478,d+92|0,14,0)|0;j=x[114409];x[114409]=0;if((j|0)!=1){e=gi(Oe(e,y[d+14|0]-1|0));x[114409]=0;O(479,c|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}x[114409]=0;P(452,d|0,d+28|0);e=x[114409];x[114409]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){e=y[ed(d)|0];v[c+5|0]=e;switch(y[d|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}v[c+3|0]=11;v[c+5|0]=e<<4|15;continue}v[c+3|0]=11;v[c+5|0]=e<<4;continue}v[c+3|0]=11;v[c+5|0]=e|240;continue}v[c+3|0]=11;v[c+5|0]=e&15;continue}v[c+3|0]=2;v[c+5|0]=e|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=e|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=e|16;continue}v[c+3|0]=6;v[c+5|0]=e<<4;continue}v[c+3|0]=6;v[c+5|0]=e&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=e|48;continue}v[c+3|0]=7;v[c+5|0]=e<<4;continue}v[c+3|0]=7;v[c+5|0]=e&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=e|64;continue}v[c+3|0]=10;x[114409]=0;e=S(425,d+28|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){v[c+5|0]=e;x[114409]=0;O(313,d+28|0,1)|0;c=x[114409];x[114409]=0;if((c|0)!=1){continue}}break o}v[c+3|0]=15;v[c+5|0]=e&15;continue}v[c+3|0]=20;v[c+5|0]=e|192;continue}v[c+3|0]=20;v[c+5|0]=e|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=e|176;continue}v[c+3|0]=20;v[c+5|0]=e|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=e&15|32;continue}v[c+3|0]=20;v[c+5|0]=e&15|128;continue}v[c+3|0]=0;continue}}}b=N()|0;Ab(d+28|0);break a}Ab(d+28|0)}h=h+1|0;if(h>>>0<(y[d+184|0]|y[d+185|0]<<8)>>>0){continue}break}}if(!(y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24))){break e}Tc(b,y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24));Dz(a+1304424|0,b,tg(b),4)}hb=d+256|0;return g|0}b=N()|0;break b}b=N()|0}Ab(d+92|0)}Q(b|0);p()}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-208|0;hb=g;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;RM(a+900380|0);x[114409]=0;V(1481,a+946304|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)==1){break i}d=a+906300|0;e=d;f=d+4e4|0;x[114409]=0;d=S(1476,g+48|0)|0;h=x[114409];x[114409]=0;j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){x[114409]=0;T(1497,e|0,f|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break p}Kp(d);x[114409]=0;d=S(312,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}if(!d){break k}e=0;f=hb-16|0;hb=f;d=g+36|0;x[d>>2]=0;x[d+4>>2]=0;x[114409]=0;x[f+12>>2]=0;U(1512,d+8|0,f+12|0,f+11|0)|0;h=x[114409];x[114409]=0;q:{if((h|0)!=1){hb=f+16|0;break q}break a}f=d;h=0;if(c&16){break n}x[114409]=0;i=(c|0)!=0;h=U(1498,f|0,b|0,i|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break m}d=4;r:{if(h){break r}x[114409]=0;h=U(1499,f|0,b|0,i|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break m}d=5;if(h){break r}x[114409]=0;h=U(1500,f|0,b|0,i|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break m}d=6;if(h){break r}h=0;x[114409]=0;i=U(1501,f|0,b|0,i|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break m}d=3;if(!i){break n}}if(c){break o}e=1;break c}a=N()|0;break d}a=N()|0;Kp(d);break d}if(!kd(f)){sR(b,dv(f,0)+12|0)}h=d}if(c&32){break c}d=76720;s:{t:{while(1){j=x[d+8>>2];i=(j>>1)+a|0;e=x[d+4>>2];e=j&1?x[x[i>>2]+e>>2]:e;x[114409]=0;e=U(e|0,i|0,b|0,c|0)|0;i=x[114409];x[114409]=0;if((i|0)!=1){if(e){break s}d=d+12|0;if((d|0)==77176){break t}continue}break}a=R(74936)|0;break l}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){break c}if(!(x[a+480184>>2]|!h)){x[a+480184>>2]=h}Hy(f);break j}a=R(74936)|0}c=ib;Hy(f);if((ca(74936)|0)!=(c|0)){break d}Y(a|0)|0;x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)==1){a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){break d}R(0)|0;zb()}p()}x[114409]=0;P(419,a|0,0);d=x[114409];x[114409]=0;if((d|0)==1){break i}x[a+1074304>>2]=19469602}d=0;while(1){e=(d<<5)+a|0;dg(e+480286|0,64);f=e+480284|0;if(z[f>>1]>=257){w[f>>1]=128}e=e+480288|0;if(y[e|0]>=251){v[e|0]=0}x[114409]=0;ba(1502,(D(d,896)+a|0)+1074984|0,7,a|0,d&65535,1024);e=x[114409];x[114409]=0;if((e|0)==1){break f}d=d+1|0;if((d|0)!=127){continue}break}if(z[a+480190>>1]){h=a+1304392|0;e=1;while(1){f=D(e&65535,104)+a|0;d=f+484380|0;u:{if(He(d)){x[114409]=0;T(1317,d|0,a|0,0);d=x[114409];x[114409]=0;if((d|0)!=1){break u}break e}i=f+484414|0;j=z[i>>1];if(j&16384){break u}x[d>>2]=0;x[d+4>>2]=0;x[d+16>>2]=0;x[d+8>>2]=0;x[d+12>>2]=0;w[i>>1]=j&65505}d=f+484412|0;if(z[d>>1]>=65){w[d>>1]=64}v:{if(!(y[f+484415|0]&2)){break v}if(!Ij(h)){break v}x[114409]=0;V(1503,a|0);d=x[114409];x[114409]=0;if((d|0)==1){break e}}e=e+1|0;if(z[a+480190>>1]>=(e&65535)>>>0){continue}break}}d=0;e=0;while(1){w:{f=x[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break w}e=x[a+480180>>2];x[114409]=0;P(1504,f|0,e|0);f=x[114409];x[114409]=0;e=d;if((f|0)!=1){break w}a=N()|0;break d}d=d+1|0;if(z[a+480192>>1]>=(d&65535)>>>0){continue}break}w[a+480192>>1]=e;d=a+480204|0;x:{if(A[a+480204>>2]<1e4){x[d>>2]=125e4;break x}zc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}d=a+480220|0;e=x[a+480216>>2];if(e>>>0>A[a+480220>>2]){x[d>>2]=e}e=a+480216|0;zc(e,65536);zc(d,65536);zc(a+480200|0,256);d=a+480248|0;if(!kd(d)){e=x[e>>2];x[114409]=0;T(1505,d|0,e|0,16777216);d=x[114409];x[114409]=0;if((d|0)==1){break g}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];e=x[a+480220>>2];d=a+1074408|0;x[d>>2]=x[a+480216>>2];x[d+4>>2]=e;x[a+1074444>>2]=x[a+480200>>2];Xy(a+1074376|0);x[a+1074440>>2]=-65536;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;d=a+1074432|0;x[d>>2]=0;x[d+4>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;w[a+480276>>1]=0;x[114409]=0;V(1506,a|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}x[114409]=0;P(1296,a+1304360|0,1);d=x[114409];x[114409]=0;if((d|0)==1){break g}d=a+484360|0;k=g,l=bc(d),x[k+36>>2]=l;k=g,l=dc(d),x[k+24>>2]=l;if(Hb(g+36|0,g+24|0)){while(1){d=x[g+36>>2];x[114409]=0;V(1507,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break h}e=z[d+28>>1];if(rc(d)>>>0<=e>>>0){Pe(d,0)}d=g+36|0;Mo(d);if(Hb(d,g+24|0)){continue}break}}e=hb-16|0;hb=e;d=g+36|0;x[d>>2]=0;x[d+4>>2]=0;x[114409]=0;x[e+12>>2]=0;U(1514,d+8|0,e+12|0,e+11|0)|0;f=x[114409];x[114409]=0;y:{if((f|0)!=1){hb=e+16|0;break y}break a}f=d;z:{A:{B:{C:{D:{E:{F:{G:{H:{if((c&12)==12){d=0;while(1){j=D(d,160)+a|0;h=j+906300|0;c=h+16|0;e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=h+20|0;I:{if(!(e|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)))){break I}x[114409]=0;O(1508,h|0,a|0)|0;c=x[114409];x[114409]=0;J:{if((c|0)!=1){c=x[h>>2];if(!c){break J}e=x[j+906448>>2];h=x[x[c>>2]+56>>2];x[114409]=0;P(h|0,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)!=1){break I}}a=N()|0;break z}e=bc(f);i=dc(f);c=hb-16|0;hb=c;x[c+8>>2]=i;x[c+12>>2]=e;x[c+4>>2]=h;K:{if(!Hb(c+12|0,c+8|0)){break K}while(1){e=x[x[c+12>>2]>>2];i=x[c+4>>2];if((y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24))==(y[i+20|0]|y[i+21|0]<<8|(y[i+22|0]<<16|y[i+23|0]<<24))){i=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=x[c+4>>2];e=(i|0)==(y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24))}else{e=0}if(e){break K}e=c+12|0;je(e);if(Hb(e,c+8|0)){continue}break}}hb=c+16|0;x[g+24>>2]=x[c+12>>2];k=g,l=dc(f),x[k>>2]=l;if(Hb(g+24|0,g)){break I}x[114409]=0;x[g+24>>2]=j+906316;P(1509,f|0,g+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break A}x[114409]=0;c=O(2,g+12|0,13551)|0;e=x[114409];x[114409]=0;if((e|0)==1){break H}e=GM(h);x[114409]=0;T(6,g|0,0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break G}x[114409]=0;T(3,g+24|0,c|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break F}x[114409]=0;T(655,a|0,2,g+24|0);e=x[114409];x[114409]=0;if((e|0)==1){break E}xb(g+24|0);xb(g);xb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=x[a+1074372>>2];x[114409]=0;P(1510,a|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break B}c=x[a+480180>>2];L:{if(!c){break L}gt(a+8|0,Jp(a));if(!x[a+1074308>>2]){break L}x[114409]=0;V(1511,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break B}}e=(c|0)!=0;FM(f);break b}a=N()|0;break z}a=N()|0;break C}a=N()|0;break D}a=N()|0;xb(g+24|0)}xb(g)}xb(c);break z}a=N()|0;break z}a=N()|0}FM(f);break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0}Ab(b);Q(a|0);p()}Hy(f)}Ab(b);hb=g+208|0;return e|0}R(0)|0;zb();p()}function LX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=hb-1408|0;hb=f;Nc(b);sr(a);a:{if(!HD(b,f+1398|0)){break a}if(!JD(f+1398|0)){break a}if(!GD(b,f+1384|0)){break a}if(!ID(f+1384|0)){break a}b:{if(!c){break b}q=f+1392|0;c=q;if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>oj(b)>>>0){break a}t=f+1386|0;if((y[q|0]|y[q+1|0]<<8|(y[q+2|0]<<16|y[q+3|0]<<24))+((y[t|0]|y[t+1|0]<<8)<<2)>>>0>oj(b)>>>0){break a}Ov(a);F=f,G=Nv(),x[F+32>>2]=G;c=f+32|0;Mv(eh(a)+28|0,c);rr(c);n=x[eh(a)+28>>2];c=f+1388|0;Tv(n,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));Sb(f+1120|0,0,256);c:{d:{e:{f:{if(y[t|0]|y[t+1|0]<<8){k=f+1104|0;l=f+1116|0;B=f+1118|0;u=f+1114|0;h=f+1112|0;while(1){d=0;if(!Tc(b,(y[q|0]|y[q+1|0]<<8|(y[q+2|0]<<16|y[q+3|0]<<24))+(C<<2)|0)){break a}if(!Qb(b,4)){break a}e=Kf(b);if(!Tc(b,e)){break a}if(!Vo(b,f+1100|0)){break a}d=y[h|0]|y[h+1|0]<<8;c=hb-16|0;hb=c;o=f+1088|0;x[o>>2]=0;x[o+4>>2]=0;x[c+4>>2]=0;Zc(o+8|0);Yd(c+4|0,x[Bb(c,o)>>2]);g:{if(!d){break g}x[114409]=0;P(235,o|0,d|0);i=x[114409];x[114409]=0;if((i|0)!=1){x[114409]=0;P(236,o|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){break g}}a=N()|0;DD(c+4|0);Q(a|0);p()}d=c+4|0;Xd(d);DD(d);hb=c+16|0;c=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if(!(y[h|0]|y[h+1|0]<<8)){break w}while(1){x:{d=ol(o,c);x[114409]=0;d=O(227,b|0,d|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break x}if(!d){break v}c=c+1|0;if(c>>>0<(y[h|0]|y[h+1|0]<<8)>>>0){continue}break w}break}d=N()|0;break c}d=y[h|0]|y[h+1|0]<<8?x[o>>2]:0;c=y[h|0]|y[h+1|0]<<8;x[114409]=0;i=S(228,b|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break u}g=c<<3;c=e+20|0;if(i>>>0<=g+c>>>0){break v}c=c+((y[h|0]|y[h+1|0]<<8)<<3)|0;if(!(v[u|0]&1)){e=0;if(!(y[h|0]|y[h+1|0]<<8)){break h}while(1){if(!d){break v}if(!Uo(n,d)){break v}x[114409]=0;i=O(229,b|0,c|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break t}if(!i){break v}i=Cc(n,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));j=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[114409]=0;i=U(230,b|0,i|0,j|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break t}if((i|0)!=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))){break v}d=d+8|0;e=e+1|0;if(e>>>0<(y[h|0]|y[h+1|0]<<8)>>>0){continue}break}break h}y:{if(y[u|0]&4){if(!d){break v}if(!Uo(n,d)){break v}w=Cc(n,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!r){break v}i=y[B|0]|y[B+1|0]<<8;e=y[l|0]|y[l+1|0]<<8;x[114409]=0;c=O(229,b|0,c+e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}if(!c){break v}c=y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24);e=y[l|0]|y[l+1|0]<<8;x[114409]=0;c=O(231,b|0,c-e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}if(!c){break v}c=y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24);e=y[l|0]|y[l+1|0]<<8;x[114409]=0;T(232,f+16|0,b|0,c-e|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}c=f+16|0;m=Lm(f+32|0,c);Ab(c);A=0;e=0;j=0;if(!(y[h|0]|y[h+1|0]<<8)){break i}while(1){z:{x[114409]=0;c=O(233,m|0,i+1|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break z}g=i&15;s=z[(g<<1)+22768>>1];A:{B:{if(s>>>0<=c>>>0){x[114409]=0;g=y[g+22816|0];D=O(233,m|0,g|0)|0;E=x[114409];x[114409]=0;if((E|0)==1){break k}c=D+(c-s<<g)|0;if((c|0)!=(i|0)){i=c&15;break A}x[114409]=0;c=O(233,m|0,4)|0;g=x[114409];x[114409]=0;if((g|0)==1){break k}if((c|0)==15){x[114409]=0;g=O(233,m|0,1)|0;c=x[114409];x[114409]=0;if((c|0)==1){break k}c=65535;if(!g){break B}break i}c=c+65520|0}if(c>>>0>65535){break A}}c=c&1?0-(c+1>>>1|0)|0:c>>>1|0;g=e+w|0;C:{if(y[u|0]&2){A=c+A|0;c=A;break C}c=y[u+1|0]&2?c:c^32768}v[g|0]=c;v[g+1|0]=c>>>8;e=e+2|0}if(e>>>0>=r>>>0){j=j+1|0;if(j>>>0>=(y[h|0]|y[h+1|0]<<8)>>>0){break i}c=(j<<3)+d|0;if(!Uo(n,c)){break y}r=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!r){break y}w=Cc(n,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));e=0}if((y[h|0]|y[h+1|0]<<8)>>>0>j>>>0){continue}break i}break}d=R(75852)|0;break j}if(!d){break v}if(!Uo(n,d)){break v}A=Cc(n,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);i=y[B|0]|y[B+1|0]<<8;if((y[l|0]|y[l+1|0]<<8)>>>0>256){break v}x[114409]=0;c=O(229,b|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break r}if(!c){break v}c=y[l|0]|y[l+1|0]<<8;x[114409]=0;c=U(234,b|0,f+1120|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break r}if(c>>>0<(y[l|0]|y[l+1|0]<<8)>>>0){break v}c=y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24);e=y[l|0]|y[l+1|0]<<8;x[114409]=0;c=O(231,b|0,c-e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break r}if(!c){break v}c=y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24);e=y[l|0]|y[l+1|0]<<8;x[114409]=0;T(232,f+16|0,b|0,c-e|0);c=x[114409];x[114409]=0;if((c|0)==1){break l}c=f+16|0;m=Lm(f+32|0,c);Ab(c);w=0;e=0;j=0;if(!(y[h|0]|y[h+1|0]<<8)){break o}D:{while(1){E:{x[114409]=0;c=O(233,m|0,i+1|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break E}g=i&7;s=y[g+22800|0];F:{G:{if(s>>>0<=c>>>0){x[114409]=0;g=y[g+22808|0];D=O(233,m|0,g|0)|0;E=x[114409];x[114409]=0;if((E|0)==1){break q}c=D+(c-s<<g)|0;if((c|0)!=(i|0)){i=c&7;break F}x[114409]=0;c=O(233,m|0,3)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}if((c|0)==7){x[114409]=0;g=O(233,m|0,1)|0;c=x[114409];x[114409]=0;if((c|0)==1){break q}c=255;if(!g){break G}break o}c=c+248|0}if(c>>>0>255){break F}}c=y[(f+1120|0)+c|0];g=c+w|0;s=c;c=(y[u|0]|y[u+1|0]<<8)&2;v[e+A|0]=c?g:s;w=c?g:w;e=e+1|0}if(e>>>0>=r>>>0){j=j+1|0;if(j>>>0>=(y[h|0]|y[h+1|0]<<8)>>>0){break o}c=(j<<3)+d|0;if(!Uo(n,c)){break D}r=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);A=Cc(n,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));e=0}if((y[h|0]|y[h+1|0]<<8)>>>0>j>>>0){continue}break o}break}d=R(75852)|0;break p}Ab(m);break v}Ab(m)}Kv(o);d=0;break a}d=N()|0;break c}d=N()|0;break c}d=N()|0;break c}d=N()|0;break c}d=R(75852)|0}if((ib|0)!=(ca(75852)|0)){break m}Y(d|0)|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)==1){break n}}Ab(m);break h}d=N()|0}Ab(m);break c}d=N()|0;break c}d=R(75852)|0}if((ib|0)!=(ca(75852)|0)){break e}Y(d|0)|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)==1){break f}}Ab(m)}Kv(o);C=C+1|0;if(C>>>0<(y[t|0]|y[t+1|0]<<8)>>>0){continue}break}}nj(f,n);b=f+8|0;Jv(b,f);b=To(f+32|0,b,0);Zd(eh(a)+12|0,b);Ab(b);break b}d=N()|0}Ab(m);break c}d=N()|0}Kv(o);Q(d|0);p()}d=1}hb=f+1408|0;return d|0}function toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;d=hb-1328|0;hb=d;Nc(b);m=hb-16|0;hb=m;g=m+8|0;l=d+752|0;AT(g,l);f=Fb(g);g=nc(b,ac(m,g));if((f|0)==(g|0)){cc(b,Fb(m+8|0))}hb=m+16|0;g=(f|0)==(g|0);if(!g){BT(l)}a:{b:{if(!g){break b}if(!ET(d+752|0)){break b}if(!Qb(b,id(DT(d+752|0),lb))){break b}if(!c){s=1;break b}t=Zc(d+748|0);c:{d:{while(1){n=(e<<5)+a|0;m=n+480280|0;Pg(m);l=(d+752|0)+(e<<4)|0;w[n+480284>>1]=((y[l+78|0]<<8&65280)>>>0)/255;f=d+480|0;$k(f,1,l- -64|0);g=d+96|0;Kc(g,f);x[114409]=0;O(358,n+480289|0,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}xb(d+96|0);e:{f:{switch(y[l+79|0]){case 0:o=e+1|0;break e;case 1:x[m>>2]=1024;o=j+1|0;break e;case 2:break f;default:break b}}x[m>>2]=1024;g=d+96|0;tl(g,t,e);le(g,1)}s=e>>>0>30;j=j+1|0;e=e+1|0;if((e|0)!=32){continue}break}Pd(a,33554432);w[a+480188>>1]=o&255;g=d+96|0;e=Vb(g,3098);Eb(a+1304436|0,e);xb(e);e=Vb(g,7015);Eb(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;g:{if(y[d+831|0]){break g}n=1;while(1){if(y[((n<<4)+d|0)+831|0]!=1){break g}e=1;n=n+1|0;if((n|0)!=16){continue}break}while(1){g=((e<<5)+a|0)+480280|0;x[g>>2]=x[g>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}g=d+480|0;Ng(g,1,d+752|0);e=d+96|0;Kc(e,g);Eb(a+1304400|0,e);xb(e);x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+790|0]|y[d+791|0]<<8)<<4&16;x[a+480196>>2]=y[d+800|0];x[a+480204>>2]=D(y[d+801|0],1e4);x[a+480200>>2]=y[d+802|0]<<2;x[a+480228>>2]=y[d+803|0];e=y[d+788|0]|y[d+789|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=e;bv(b,g);Qq(Wb(a+484360|0),g,y[d+784|0]|y[d+785|0]<<8,65535,255);h=c&1;if(h){ig(a+484344|0,y[d+786|0]|y[d+787|0]<<8)}if(y[d+786|0]|y[d+787|0]<<8){u=a+484344|0;o=0;while(1){e=tg(b);r=tg(b);Ad(d+96|0,b,e-4|0);h:{if(!h){break h}x[114409]=0;g=U(378,u|0,o&65535,r|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){i:{if(!g){break h}q=0;g=ei(d+16|0);if(!r){break h}while(1){j:{x[114409]=0;m=S(425,d+96|0)|0;e=x[114409];x[114409]=0;k:{l:{if((e|0)!=1){if(m){break l}q=q+1|0;break k}break i}e=g;k=m&31;if(k>>>0<z[a+480188>>1]){e=Zb(u,o);x[114409]=0;e=U(451,e|0,q|0,k|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break i}}m:{if(!(m&32)){break m}x[114409]=0;P(452,d+32|0,d+96|0);f=x[114409];x[114409]=0;n:{o:{if((f|0)!=1){f=ed(d+32|0);l=y[d+32|0];v[e|0]=l;v[e+1|0]=y[f|0];if((l|0)!=160){break o}f=255;break n}break i}if((l|0)!=255){v[e|0]=(D(l>>>4|0,12)+(l&15)|0)+13;x[114409]=0;l=S(625,e|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){f=0;if(!l){break n}break m}break i}f=0}v[e|0]=f}f=m&192;p:{if(!f){break p}if((f|0)==192){x[114409]=0;P(594,d+32|0,d+96|0);f=x[114409];x[114409]=0;q:{r:{s:{if((f|0)!=1){f=d+32|0;l=f;m=ed(f);n=wf(f);j=fi(f);i=y[f|0];if((i|0)!=12){break s}x[114409]=0;v[d+12|0]=64;l=O(431,m|0,d+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break i}v[e+4|0]=y[l|0];f=1;break r}break i}f=y[n|0];t:{if((f|0)==12){x[114409]=0;v[d+12|0]=64;j=O(431,j|0,d+12|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){v[e+4|0]=y[j|0];f=1;break t}break i}if((i|0)==10){v[e+4|0]=(y[m|0]<<6>>>0)/255;f=2;break r}if((f|0)!=10){break q}v[e+4|0]=(y[j|0]<<6>>>0)/255;f=2}n=l;j=m}v[e+2|0]=f;f=y[n|0]}v[e+3|0]=f;v[e+5|0]=y[j|0];break p}x[114409]=0;P(452,d+32|0,d+96|0);f=x[114409];x[114409]=0;if((f|0)==1){break i}f=ed(d+32|0);v[e+3|0]=y[d+32|0];v[e+5|0]=y[f|0]}if(y[e+3|0]){x[114409]=0;V(626,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break i}}f=d+32|0;tl(f,t,k);if(!Ib(f)){break k}x[114409]=0;l=S(627,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break j}if(!l){break k}v[e+3|0]=0}if(q>>>0<r>>>0){continue}break h}break}}}e=N()|0;Ab(d+96|0);break c}Ab(d+96|0);o=o+1|0;if(o>>>0<(y[d+786|0]|y[d+787|0]<<8)>>>0){continue}break}}if(!z[a+480192>>1]){break b}m=c&2;n=0;o=1;while(1){n=n+1|0;l=n&65535;h=vM(a,l,0);f=!h;i=hb-16|0;hb=i;c=hb-16|0;hb=c;j=i+8|0;g=d+96|0;jc(j,g,384);hb=c+16|0;e=Fb(j);c=nc(b,ac(i,j));if((e|0)==(c|0)){cc(b,Fb(i+8|0))}hb=i+16|0;e=(c|0)==(e|0);if(!e){c=hb-16|0;hb=c;Sb(g,0,384);hb=c+16|0}if(!(!e|f)){g=o&65535;i=hb-32|0;hb=i;e=i+8|0;j=d+96|0;Ng(e,1,j);c=i+20|0;Kc(c,e);x[114409]=0;O(348,h+492|0,c|0)|0;c=x[114409];x[114409]=0;u:{if((c|0)!=1){xb(i+20|0);v:{if(!(y[j+378|0]|y[j+379|0]<<8)){break v}x[i+20>>2]=120;x[i+8>>2]=116;if(!x[Mb(i+20|0,i+8|0)>>2]){break v}e=h+236|0;f=0;while(1){c=y[(f+j|0)+32|0];B=fd(e,f+12|0),C=c+g|0,w[B>>1]=C;x[i+20>>2]=120;x[i+8>>2]=116;f=f+1|0;if(f>>>0<A[Mb(i+20|0,i+8|0)>>2]){continue}break}}x[h>>2]=y[j+376|0]|y[j+377|0]<<8;OA(j,h+48|0,0);OA(j,h+68|0,1);OA(j,h+88|0,2);c=y[h+100|0];if(c&1){v[h+100|0]=c|16}if(!(x[h>>2]|v[h+60|0]&1)){x[h>>2]=32767}hb=i+32|0;break u}break a}e=0;w:{if(!(y[d+474|0]|y[d+475|0]<<8)){break w}while(1){x:{Eq(b,d+32|0);y:{if((y[d+92|0]|y[d+93|0]<<8|(y[d+94|0]<<16|y[d+95|0]<<24))!=808538953){break y}c=e+o|0;j=c&65535;if(j>>>0>3999){break y}w[a+480190>>1]=c;i=hb-32|0;hb=i;f=D(j,104)+a|0;k=f+484380|0;zd(k,0);g=i+8|0;h=d+32|0;Bh(g,1,h);c=i+20|0;Kc(c,g);x[114409]=0;O(350,k+43|0,c|0)|0;c=x[114409];x[114409]=0;z:{if((c|0)!=1){xb(i+20|0);x[k>>2]=y[h+16|0]|y[h+17|0]<<8|(y[h+18|0]<<16|y[h+19|0]<<24);x[k+4>>2]=y[h+20|0]|y[h+21|0]<<8|(y[h+22|0]<<16|y[h+23|0]<<24);x[k+8>>2]=y[h+24|0]|y[h+25|0]<<8|(y[h+26|0]<<16|y[h+27|0]<<24);x[k+24>>2]=y[h+28|0]|y[h+29|0]<<8|(y[h+30|0]<<16|y[h+31|0]<<24);w[k+30>>1]=y[h+32|0]<<2;w[k+28>>1]=y[h+33|0];if(v[h+48|0]&1){w[k+34>>1]=z[k+34>>1]|2}if(y[h+48|0]&2){w[k+34>>1]=z[k+34>>1]|4}if(y[h+48|0]&4){w[k+34>>1]=z[k+34>>1]|1;x[k>>2]=x[k>>2]>>>1;x[k+4>>2]=x[k+4>>2]>>>1;x[k+8>>2]=x[k+8>>2]>>>1}if(y[h+48|0]&8){w[k+34>>1]=z[k+34>>1]|32}hb=i+32|0;break z}break a}c=d+16|0;vC(c,f+484423|0);x[114409]=0;O(348,((j<<5)+a|0)+946304|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break x}xb(d+16|0);if(!(y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24))){break y}Ad(d+16|0,b,y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24));A:{if(!m){break A}c=cd(d+12|0,w[f+484414>>1]&1?16:8,1,0,0);x[114409]=0;U(376,c|0,k|0,d+16|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break A}e=N()|0;Ab(d+16|0);break c}Ab(d+16|0)}e=e+1|0;if(e>>>0<(y[d+474|0]|y[d+475|0]<<8)>>>0){continue}break w}break}e=N()|0;xb(d+16|0);break c}o=(y[d+474|0]|y[d+475|0]<<8)+o|0}if(l>>>0<z[a+480192>>1]){continue}break}break b}e=N()|0;xb(d+96|0)}Q(e|0);p()}hb=d+1328|0;return s|0}a=N()|0;xb(i+20|0);Q(a|0);p()}function N$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0;l=hb-528|0;hb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(mh(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=2638;b=l+72|0;q=Sd(l+104|0,l+112|0,b);k=x[q>>2];x[l+100>>2]=k;x[l+96>>2]=k+400;s=Xb(b);m=Dg(l+60|0);o=Dg(l+48|0);n=Dg(l+36|0);r=Dg(l+24|0);x[114409]=0;ja(2651,c|0,d|0,l+92|0,l+88|0,l+84|0,s|0,m|0,o|0,n|0,l+20|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[j>>2]=x[i>>2];u=e&512;e=0;k=0;while(1){c=k;c:{d:{e:{f:{if((e|0)==4){break f}x[114409]=0;b=O(2611,a|0,l+524|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break d}x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;b=U(2652,h|0,1,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(b){x[114409]=0;T(2653,l+12|0,a|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){b=x[l+12>>2];x[114409]=0;P(113,r|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break e;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break d}}while(1){x[114409]=0;b=O(2611,a|0,l+524|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(b){break d}x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;b=U(2652,h|0,1,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(!b){break d}x[114409]=0;T(2653,l+12|0,a|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){b=x[l+12>>2];x[114409]=0;P(113,r|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Cb(o)){break l}x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if((b|0)!=x[Rb(o)>>2]){break l}x[114409]=0;S(2614,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}v[g|0]=0;k=Cb(o)>>>0>1?o:c;break c}m:{if(!Cb(n)){break m}x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if((b|0)!=x[Rb(n)>>2]){break m}x[114409]=0;S(2614,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}v[g|0]=1;k=Cb(n)>>>0>1?n:c;break c}n:{if(!Cb(o)){break n}if(!Cb(n)){break n}x[f>>2]=x[f>>2]|4;a=0;break e}if(!Cb(o)){if(!Cb(n)){break d}}w=g,z=!Cb(n),v[w|0]=z;break d}if(!(c|e>>>0<2|u)){k=0;if(!((e|0)==2&y[l+95|0]!=0)){break c}}w=l,z=td(m),x[w+8>>2]=z;b=rd(l+12|0,l+8|0);o:{if(!e|y[(e+l|0)+91|0]>1){break o}p:{while(1){w=l,z=lk(m),x[w+8>>2]=z;if(!Hb(b,l+8|0)){break p}d=x[x[b>>2]>>2];x[114409]=0;d=U(2652,h|0,1,d|0)|0;k=x[114409];x[114409]=0;if((k|0)!=1){if(!d){break p}je(b);continue}break}break a}w=l,z=td(m),x[w+8>>2]=z;d=mu(b,l+8|0);if(Cb(r)>>>0>=d>>>0){w=l,z=lk(r),x[w+8>>2]=z;d=eP(l+8|0,d);k=lk(r);t=td(m);x[114409]=0;d=vF(d,k,t);k=x[114409];x[114409]=0;if((k|0)==1){break a}if(d){break o}}w=l,z=td(m),x[w+4>>2]=z;w=b,z=x[rd(l+8|0,l+4|0)>>2],x[w>>2]=z}x[l+8>>2]=x[b>>2];q:{while(1){w=l,z=lk(m),x[w+4>>2]=z;if(!Hb(l+8|0,l+4|0)){break q}x[114409]=0;b=O(2611,a|0,l+524|0)|0;d=x[114409];x[114409]=0;r:{if((d|0)==1){break r}if(b){break q}x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break r}if((b|0)!=x[x[l+8>>2]>>2]){break q}x[114409]=0;S(2614,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}je(l+8|0);continue}break}break a}if(!u){break d}w=l,z=lk(m),x[w+4>>2]=z;if(!Hb(l+8|0,l+4|0)){break d}x[f>>2]=x[f>>2]|4;a=0;break e}s:{while(1){t:{x[114409]=0;d=O(2611,a|0,l+524|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break t}if(d){break s}x[114409]=0;k=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;d=U(2652,h|0,64,k|0)|0;t=x[114409];x[114409]=0;if((t|0)==1){break a}u:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[114409]=0;T(2655,i|0,j|0,l+520|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break u}if(!Cb(s)|!b|(k|0)!=x[l+84>>2]){break s}k=x[l+100>>2];if((k|0)==x[l+96>>2]){x[114409]=0;T(2646,q|0,l+100|0,l+96|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}k=x[l+100>>2]}x[l+100>>2]=k+4;x[k>>2]=b;b=0}x[114409]=0;S(2614,a|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}}break}break a}k=x[l+100>>2];if(!(!b|(k|0)==x[q>>2])){if(x[l+96>>2]==(k|0)){x[114409]=0;T(2646,q|0,l+100|0,l+96|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}k=x[l+100>>2]}x[l+100>>2]=k+4;x[k>>2]=b}v:{if(x[l+20>>2]<=0){break v}x[114409]=0;b=O(2611,a|0,l+524|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}w:{if(!b){x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if((b|0)==x[l+88>>2]){break w}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114409]=0;S(2614,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}while(1){if(x[l+20>>2]<=0){break v}x[114409]=0;b=O(2611,a|0,l+524|0)|0;d=x[114409];x[114409]=0;x:{if((d|0)==1){break x}y:{if(!b){x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}x[114409]=0;b=U(2652,h|0,64,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}if(b){break y}}x[f>>2]=x[f>>2]|4;a=0;break e}if(x[j>>2]==x[l+520>>2]){x[114409]=0;T(2655,i|0,j|0,l+520|0);b=x[114409];x[114409]=0;if((b|0)==1){break x}}x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=b;x[114409]=0;x[l+20>>2]=x[l+20>>2]-1;S(2614,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break a}k=c;if(x[i>>2]!=x[j>>2]){break c}x[f>>2]=x[f>>2]|4;a=0;break e}z:{if(!c){break z}k=1;while(1){if(Cb(c)>>>0<=k>>>0){break z}x[114409]=0;b=O(2611,a|0,l+524|0)|0;d=x[114409];x[114409]=0;A:{if((d|0)==1){break A}B:{if(!b){x[114409]=0;b=S(2612,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break A}if((b|0)==x[yj(c,k)>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114409]=0;S(2614,a|0)|0;b=x[114409];x[114409]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}C:{if(x[q>>2]==x[l+100>>2]){break C}x[l+12>>2]=0;a=x[q>>2];x[114409]=0;Je(s,a,x[l+100>>2],l+12|0);a=x[114409];x[114409]=0;if((a|0)!=1){if(!x[l+12>>2]){break C}x[f>>2]=x[f>>2]|4;a=0;break e}break a}a=1}Pc(r);Pc(n);Pc(o);Pc(m);xb(s);Lc(q);break b}k=c}e=e+1|0;continue}}break a}hb=l+528|0;return a|0}a=N()|0;Pc(r);Pc(n);Pc(o);Pc(m);xb(s);Lc(q);Q(a|0);p()}function U$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0;l=hb-528|0;hb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(Cg(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=2638;b=l+76|0;q=Sd(l+104|0,l+112|0,b);k=x[q>>2];x[l+100>>2]=k;x[l+96>>2]=k+400;s=Xb(b);m=Xb(l- -64|0);o=Xb(l+52|0);n=Xb(l+40|0);r=Xb(l+28|0);x[114409]=0;ja(2641,c|0,d|0,l+92|0,l+91|0,l+90|0,s|0,m|0,o|0,n|0,l+24|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[j>>2]=x[i>>2];u=e&512;e=0;k=0;while(1){c=k;c:{d:{e:{f:{if((e|0)==4){break f}x[114409]=0;b=O(2582,a|0,l+524|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break d}x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;b=Bg(h,1,b);d=x[114409];x[114409]=0;if((d|0)==1){break a}if(b){x[114409]=0;T(2643,l+16|0,a|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){b=v[l+16|0];x[114409]=0;P(111,r|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break e;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break d}}while(1){x[114409]=0;b=O(2582,a|0,l+524|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(b){break d}x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;b=Bg(h,1,b);d=x[114409];x[114409]=0;if((d|0)==1){break a}if(!b){break d}x[114409]=0;T(2643,l+16|0,a|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){b=v[l+16|0];x[114409]=0;P(111,r|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Cb(o)){break l}x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(y[pc(o,0)|0]!=(b&255)){break l}x[114409]=0;S(2585,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}v[g|0]=0;k=Cb(o)>>>0>1?o:c;break c}m:{if(!Cb(n)){break m}x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(y[pc(n,0)|0]!=(b&255)){break m}x[114409]=0;S(2585,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}v[g|0]=1;k=Cb(n)>>>0>1?n:c;break c}n:{if(!Cb(o)){break n}if(!Cb(n)){break n}x[f>>2]=x[f>>2]|4;a=0;break e}if(!Cb(o)){if(!Cb(n)){break d}}w=g,z=!Cb(n),v[w|0]=z;break d}if(!(c|e>>>0<2|u)){k=0;if(!((e|0)==2&y[l+95|0]!=0)){break c}}w=l,z=td(m),x[w+12>>2]=z;b=rd(l+16|0,l+12|0);o:{if(!e|y[(e+l|0)+91|0]>1){break o}p:{while(1){w=l,z=nf(m),x[w+12>>2]=z;if(!Hb(b,l+12|0)){break p}d=v[x[b>>2]];x[114409]=0;d=Bg(h,1,d);k=x[114409];x[114409]=0;if((k|0)!=1){if(!d){break p}gg(b);continue}break}break a}w=l,z=td(m),x[w+12>>2]=z;d=zm(b,l+12|0);if(Cb(r)>>>0>=d>>>0){w=l,z=nf(r),x[w+12>>2]=z;d=hA(l+12|0,d);k=nf(r);t=td(m);x[114409]=0;d=AF(d,k,t);k=x[114409];x[114409]=0;if((k|0)==1){break a}if(d){break o}}w=l,z=td(m),x[w+8>>2]=z;w=b,z=x[rd(l+12|0,l+8|0)>>2],x[w>>2]=z}x[l+12>>2]=x[b>>2];q:{while(1){w=l,z=nf(m),x[w+8>>2]=z;if(!Hb(l+12|0,l+8|0)){break q}x[114409]=0;b=O(2582,a|0,l+524|0)|0;d=x[114409];x[114409]=0;r:{if((d|0)==1){break r}if(b){break q}x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break r}if(y[x[l+12>>2]]!=(b&255)){break q}x[114409]=0;S(2585,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}gg(l+12|0);continue}break}break a}if(!u){break d}w=l,z=nf(m),x[w+8>>2]=z;if(!Hb(l+12|0,l+8|0)){break d}x[f>>2]=x[f>>2]|4;a=0;break e}s:{while(1){t:{x[114409]=0;d=O(2582,a|0,l+524|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break t}if(d){break s}x[114409]=0;k=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;d=Bg(h,64,k);t=x[114409];x[114409]=0;if((t|0)==1){break a}u:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[114409]=0;T(2645,i|0,j|0,l+520|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+1;v[d|0]=k;b=b+1|0;break u}if(!Cb(s)|!b|y[l+90|0]!=(k&255)){break s}k=x[l+100>>2];if((k|0)==x[l+96>>2]){x[114409]=0;T(2646,q|0,l+100|0,l+96|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}k=x[l+100>>2]}x[l+100>>2]=k+4;x[k>>2]=b;b=0}x[114409]=0;S(2585,a|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}}break}break a}k=x[l+100>>2];if(!(!b|(k|0)==x[q>>2])){if(x[l+96>>2]==(k|0)){x[114409]=0;T(2646,q|0,l+100|0,l+96|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}k=x[l+100>>2]}x[l+100>>2]=k+4;x[k>>2]=b}v:{if(x[l+24>>2]<=0){break v}x[114409]=0;b=O(2582,a|0,l+524|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}w:{if(!b){x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(y[l+91|0]==(b&255)){break w}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114409]=0;S(2585,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}while(1){if(x[l+24>>2]<=0){break v}x[114409]=0;b=O(2582,a|0,l+524|0)|0;d=x[114409];x[114409]=0;x:{if((d|0)==1){break x}y:{if(!b){x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}x[114409]=0;b=Bg(h,64,b);d=x[114409];x[114409]=0;if((d|0)==1){break x}if(b){break y}}x[f>>2]=x[f>>2]|4;a=0;break e}if(x[j>>2]==x[l+520>>2]){x[114409]=0;T(2645,i|0,j|0,l+520|0);b=x[114409];x[114409]=0;if((b|0)==1){break x}}x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+1;v[d|0]=b;x[114409]=0;x[l+24>>2]=x[l+24>>2]-1;S(2585,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break a}k=c;if(x[i>>2]!=x[j>>2]){break c}x[f>>2]=x[f>>2]|4;a=0;break e}z:{if(!c){break z}k=1;while(1){if(Cb(c)>>>0<=k>>>0){break z}x[114409]=0;b=O(2582,a|0,l+524|0)|0;d=x[114409];x[114409]=0;A:{if((d|0)==1){break A}B:{if(!b){x[114409]=0;b=S(2583,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break A}if(y[pc(c,k)|0]==(b&255)){break B}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114409]=0;S(2585,a|0)|0;b=x[114409];x[114409]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}C:{if(x[q>>2]==x[l+100>>2]){break C}x[l+16>>2]=0;a=x[q>>2];x[114409]=0;Je(s,a,x[l+100>>2],l+16|0);a=x[114409];x[114409]=0;if((a|0)!=1){if(!x[l+16>>2]){break C}x[f>>2]=x[f>>2]|4;a=0;break e}break a}a=1}xb(r);xb(n);xb(o);xb(m);xb(s);Lc(q);break b}k=c}e=e+1|0;continue}}break a}hb=l+528|0;return a|0}a=N()|0;xb(r);xb(n);xb(o);xb(m);xb(s);Lc(q);Q(a|0);p()}function S8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=0,S=0,T=0,U=0,V=0,W=E(0),X=0,Y=0,Z=0,_=E(0);a:{if(!y[a+5046|0]){break a}j=B[a+4268>>2];PJ(a);if(j==B[a+4268>>2]){break a}Mx(a)}b:{if(!y[a+5045|0]){break b}o=a+44|0;if(!Eh(o)){break b}p=Qd(o,0);t=Qd(o,1);m=ld(o,0);n=ld(o,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[m>>2]=B[a+5036>>2];B[n>>2]=B[a+5040>>2];v[a+5044|0]=0;t=t+4|0;p=p+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}q=k;d:{if(!q){break d}F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;r=a+4888|0;s=a+4864|0;C=a+4504|0;V=a+4960|0;while(1){j=B[p>>2];j=E(E(E(B[a+5008>>2]-j)*B[a+4276>>2])+j);B[a+5008>>2]=j;Z=Gc(s,x[a+4880>>2]),_=j,B[Z>>2]=_;j=B[t>>2];j=E(E(E(B[a+5012>>2]-j)*B[a+4276>>2])+j);B[a+5012>>2]=j;Z=Gc(r,x[a+4904>>2]),_=j,B[Z>>2]=_;j=rh(s,x[a+4356>>2]);f=rh(s,x[a+4360>>2]);e=rh(s,x[a+4364>>2]);g=rh(s,x[a+4368>>2]);j=E(E(E(j*E(.6800000071525574))+E(E(e+rh(s,x[a+4372>>2]))*E(-.6200000047683716)))+E(E(g+f)*E(-.5)));if(v[a+4264|0]&1){f=j;j=E(B[Gc(U,x[a+4836>>2])>>2]+E(f*E(.6180340051651001)));Z=Gc(U,x[a+4832>>2]),_=E(f-E(j*E(.6180340051651001))),B[Z>>2]=_}W=B[a+4280>>2];Z=a,_=E(rh(s,x[a+4352>>2])+B[a+5020>>2]),B[Z+5020>>2]=_;f=E(rh(r,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=f;e=B[a+5020>>2];g=B[a+4980>>2];i=B[Gc(P,x[a+4644>>2])>>2];u=B[a+4444>>2];g=E(B[Gc(P,x[a+4644>>2])>>2]+E(u*E(g-i)));B[a+4980>>2]=g;i=B[a+4272>>2];h=E(e*E(-.7070000171661377));l=E(f*E(.7070000171661377));e=E(h+l);f=E(E(i*e)+E(B[a+4440>>2]*g));Z=Gc(P,x[a+4640>>2]),_=E(e-E(i*f)),B[Z>>2]=_;e=B[a+4976>>2];g=B[Gc(O,x[a+4620>>2])>>2];i=B[a+4436>>2];e=E(B[Gc(O,x[a+4620>>2])>>2]+E(i*E(e-g)));B[a+4976>>2]=e;g=B[a+4272>>2];e=E(E(g*f)+E(B[a+4432>>2]*e));Z=Gc(O,x[a+4616>>2]),_=E(f-E(g*e)),B[Z>>2]=_;u=E(E(f*E(-.15000000596046448))+E(e*E(-.20000000298023224)));if(v[a+4264|0]&1){f=B[a+4972>>2];g=B[Gc(N,x[a+4596>>2])>>2];i=B[a+4428>>2];f=E(B[Gc(N,x[a+4596>>2])>>2]+E(i*E(f-g)));B[a+4972>>2]=f;g=B[a+4272>>2];f=E(E(g*e)+E(B[a+4424>>2]*f));Z=Gc(N,x[a+4592>>2]),_=E(e-E(g*f)),B[Z>>2]=_;e=B[a+4968>>2];g=B[Gc(M,x[a+4572>>2])>>2];i=B[a+4420>>2];e=E(B[Gc(M,x[a+4572>>2])>>2]+E(i*E(e-g)));B[a+4968>>2]=e;g=B[a+4272>>2];e=E(E(g*f)+E(B[a+4416>>2]*e));Z=Gc(M,x[a+4568>>2]),_=E(f-E(g*e)),B[Z>>2]=_;u=E(E(E(f*E(.3499999940395355))+u)+E(e*E(-.3799999952316284)))}Z=Gc(T,x[a+4928>>2]),_=e,B[Z>>2]=_;k=Gc(T,x[a+4932>>2]);f=E(B[a+4496>>2]*B[k>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-f)*B[a+4500>>2])+f;f=B[a+4964>>2];e=B[Gc(L,x[a+4548>>2])>>2];g=B[a+4412>>2];f=E(B[Gc(L,x[a+4548>>2])>>2]+E(g*E(f-e)));B[a+4964>>2]=f;g=E(B[a+4408>>2]*f);f=B[a+4272>>2];e=B[a+5028>>2];g=E(g+E(f*e));Z=Gc(L,x[a+4544>>2]),_=E(e-E(f*g)),B[Z>>2]=_;f=B[a+4960>>2];e=B[Gc(C,x[a+4524>>2])>>2];i=B[a+4404>>2];f=E(B[Gc(C,x[a+4524>>2])>>2]+E(i*E(f-e)));B[a+4960>>2]=f;e=B[a+4272>>2];Q=E(E(e*g)+E(B[a+4400>>2]*f));Z=Gc(C,x[a+4520>>2]),_=E(g-E(e*Q)),B[Z>>2]=_;B[a+5020>>2]=Q;f=rh(r,x[a+4380>>2]);e=rh(r,x[a+4384>>2]);i=rh(r,x[a+4388>>2]);w=rh(r,x[a+4392>>2]);f=E(E(E(f*E(.7070000171661377))+E(E(i+rh(r,x[a+4396>>2]))*E(-.5)))+E(E(w+e)*E(-.6000000238418579)));if(v[a+4264|0]&1){e=f;f=E(B[Gc(S,x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));Z=Gc(S,x[a+4856>>2]),_=E(e-E(f*E(.6180340051651001))),B[Z>>2]=_}w=B[a+4280>>2];e=B[a+5004>>2];i=B[Gc(K,x[a+4788>>2])>>2];D=B[a+4492>>2];e=E(B[Gc(K,x[a+4788>>2])>>2]+E(D*E(e-i)));B[a+5004>>2]=e;D=B[a+4272>>2];h=E(h-l);i=E(E(D*h)+E(B[a+4488>>2]*e));Z=Gc(K,x[a+4784>>2]),_=E(h-E(D*i)),B[Z>>2]=_;e=B[a+5e3>>2];h=B[Gc(J,x[a+4764>>2])>>2];l=B[a+4484>>2];e=E(B[Gc(J,x[a+4764>>2])>>2]+E(l*E(e-h)));B[a+5e3>>2]=e;h=B[a+4272>>2];e=E(E(h*i)+E(B[a+4480>>2]*e));Z=Gc(J,x[a+4760>>2]),_=E(i-E(h*e)),B[Z>>2]=_;i=E(E(e*E(-.20000000298023224))+E(E(g*E(.3799999952316284))+E(i*E(-.15000000596046448))));if(v[a+4264|0]&1){g=B[a+4996>>2];h=B[Gc(I,x[a+4740>>2])>>2];l=B[a+4476>>2];g=E(B[Gc(I,x[a+4740>>2])>>2]+E(l*E(g-h)));B[a+4996>>2]=g;h=B[a+4272>>2];g=E(E(h*e)+E(B[a+4472>>2]*g));Z=Gc(I,x[a+4736>>2]),_=E(e-E(h*g)),B[Z>>2]=_;e=B[a+4992>>2];h=B[Gc(H,x[a+4716>>2])>>2];l=B[a+4468>>2];e=E(B[Gc(H,x[a+4716>>2])>>2]+E(l*E(e-h)));B[a+4992>>2]=e;h=B[a+4272>>2];e=E(E(h*g)+E(B[a+4464>>2]*e));Z=Gc(H,x[a+4712>>2]),_=E(g-E(h*e)),B[Z>>2]=_;i=E(E(E(g*E(.3499999940395355))+i)+E(e*E(-.3799999952316284)))}X=t+4|0;Y=p+4|0;g=E(w*f);Z=Gc(R,x[a+4952>>2]),_=e,B[Z>>2]=_;k=Gc(R,x[a+4956>>2]);f=E(B[a+4496>>2]*B[k>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-f)*B[a+4500>>2])+f;f=B[a+4988>>2];e=B[Gc(G,x[a+4692>>2])>>2];h=B[a+4460>>2];f=E(B[Gc(G,x[a+4692>>2])>>2]+E(h*E(f-e)));B[a+4988>>2]=f;e=B[a+4272>>2];h=B[a+5032>>2];f=E(E(B[a+4456>>2]*f)+E(e*h));Z=Gc(G,x[a+4688>>2]),_=E(h-E(e*f)),B[Z>>2]=_;h=B[a+4284>>2];e=B[a+4984>>2];l=B[Gc(F,x[a+4668>>2])>>2];w=B[a+4452>>2];e=E(B[Gc(F,x[a+4668>>2])>>2]+E(w*E(e-l)));B[a+4984>>2]=e;l=B[a+4272>>2];e=E(E(l*f)+E(B[a+4448>>2]*e));Z=Gc(F,x[a+4664>>2]),_=E(f-E(l*e)),B[Z>>2]=_;B[a+5024>>2]=e;e=E(e*E(.3799999952316284));j=E(E(h*E(E(E(f-Q)*E(.3799999952316284))+u))+E(W*j));f=B[a+4288>>2];k=C;while(1){z=x[k+16>>2];A=z-1|0;x[k+16>>2]=A;if((z|0)<=0){x[k+16>>2]=A+x[k+12>>2]}z=x[k+20>>2];A=z-1|0;x[k+20>>2]=A;if((z|0)<=0){x[k+20>>2]=A+x[k+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}f=E(E(f*E(i-e))+g);e:{f:{if(y[a+4264|0]&2){p=Y;k=X;break f}B[m>>2]=E(B[a+5036>>2]+j)*E(.5);B[n>>2]=E(B[a+5040>>2]+f)*E(.5);B[a+5040>>2]=f;B[a+5036>>2]=j;if((q|0)==1){break e}q=q-1|0;p=p+8|0;n=n+4|0;m=m+4|0;k=t+8|0}t=k;B[m>>2]=j;B[n>>2]=f;n=n+4|0;m=m+4|0;q=q-1|0;if(q){continue}break d}break}v[a+5044|0]=1}Gi(a,b,c,ld(o,0),ld(o,1),d)}}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-272|0;hb=e;Nc(b);a:{if(!cB(b,e+206|0)){break a}if(!YQ(e+206|0)){break a}if(!Qb(b,id(WQ(e+206|0),lb))){break a}b:{if(!c){break b}Pd(a,16);f=e+32|0;mo(f,2,e+210|0);j=e+48|0;Kc(j,f);Eb(a+1304400|0,j);xb(j);w[a+480190>>1]=y[e+236|0];w[a+480188>>1]=y[e+239|0];d=Vb(j,4584);Eb(a+1304436|0,d);xb(d);d=Vb(j,6110);Eb(a+1304448|0,d);xb(d);j=Vb(e+192|0,10917);x[114409]=0;P(192,f|0,j|0);d=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){x[e+12>>2]=y[e+209|0]>>>4;d=y[e+209|0];x[114409]=0;x[e+188>>2]=d&15;W(527,e+48|0,e+32|0,e+12|0,e+188|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}d=e+48|0;Eb(a+1304460|0,d);xb(d);Gb(e+32|0);xb(j);x[a+1304496>>2]=4;if(z[a+480190>>1]){i=1;while(1){g=e+48|0;$B(b,g);f=hb-16|0;hb=f;j=i&65535;h=(D(j,104)+a|0)+484380|0;zd(h,0);w[f+14>>1]=y[g+35|0]<<2;w[f+12>>1]=256;t=h,u=z[Gf(f+14|0,f+12|0)>>1],w[t+30>>1]=u;j:{if((y[g+22|0]|y[g+23|0]<<8|(y[g+24|0]<<16|y[g+25|0]<<24))>>>0<3){break j}x[h>>2]=y[g+22|0]|y[g+23|0]<<8|(y[g+24|0]<<16|y[g+25|0]<<24);x[h+4>>2]=y[g+26|0]|y[g+27|0]<<8|(y[g+28|0]<<16|y[g+29|0]<<24);x[f+8>>2]=y[g+30|0]|y[g+31|0]<<8|(y[g+32|0]<<16|y[g+33|0]<<24);x[f+4>>2]=1;t=h,u=x[$c(f+8|0,f+4|0)>>2]-1|0,x[t+8>>2]=u;zc(h+8|0,x[h>>2]);d=x[h+8>>2];k:{if(d>>>0<=x[h+4>>2]+4>>>0){x[h+4>>2]=0;x[h+8>>2]=0;break k}if(d>>>0<3){break k}w[h+34>>1]=z[h+34>>1]|2}v[h+37|0]=y[g+34|0];t=h,u=Mt(0,v[g+34|0]<<4),x[t+24>>2]=u;if(!(v[g+36|0]&1)){break j}w[h+34>>1]=z[h+34>>1]|1;x[h>>2]=x[h>>2]>>>1;x[h+4>>2]=x[h+4>>2]>>>1;x[h+8>>2]=x[h+8>>2]>>>1}hb=f+16|0;f=e+12|0;rm(f,2,g);d=e+32|0;Kc(d,f);x[114409]=0;O(348,((j<<5)+a|0)+946304|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}xb(e+32|0);i=i+1|0;if(z[a+480190>>1]>=(i&65535)>>>0){continue}break}}if(z[a+480188>>1]){i=0;while(1){d=(i<<5)+a|0;Pg(d+480280|0);w[d+480284>>1]=(y[(e+i|0)+240|0]<<4|8)&248;i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}}h=e+48|0;g=hb-16|0;hb=g;l:{if(Qb(b,128)){d=g+8|0;NS(d,h);Cd(b,d);break l}j=hb-16|0;hb=j;f=0;d=hb-16|0;hb=d;while(1){qf(f+h|0);f=f+1|0;if((f|0)!=128){continue}break}hb=d+16|0;hb=j+16|0}hb=g+16|0;Uj(Wb(a+484360|0),h,y[e+233|0]+1|0,255,254);if(y[e+238|0]){break g}n=64;break f}i=N()|0;break h}i=N()|0;Gb(e+32|0)}xb(j);break c}n=y[e+238|0]}Ad(e+32|0,b,D(y[e+230|0]|y[e+231|0]<<8,192));m:{r=c&1;if(!r){break m}d=y[e+232|0];x[114409]=0;P(377,a+484344|0,d+1|0);d=x[114409];x[114409]=0;if((d|0)!=1){break m}break d}l=a+484344|0;d=0;n:{while(1){o:{p:{if(r){x[114409]=0;j=U(378,l|0,o&65535,n|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}i=0;if(j){break p}}x[114409]=0;O(313,b|0,64)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break o}break d}while(1){x[114409]=0;g=S(335,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}q=i;q:{if(!g|g>>>0>(y[e+230|0]|y[e+231|0]<<8)>>>0){break q}j=q&65535;if(j>>>0>=z[a+480188>>1]){break q}x[114409]=0;O(229,e+32|0,D(g,192)-192|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}f=Zb(l,o);x[114409]=0;i=U(451,f|0,0,j|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break n}k=0;if(!n){break q}while(1){j=d;x[114409]=0;P(827,e+12|0,e+32|0);d=x[114409];x[114409]=0;r:{s:{t:{u:{v:{if((d|0)!=1){g=e+12|0;m=ed(g);f=wf(g);d=y[g|0];if(d>>>0>=4){v[i|0]=(d>>>2|0)+37;d=y[g|0]}v[i+1|0]=d<<4&48|y[m|0]>>>4;d=y[f|0];g=0;h=0;w:{x:{f=y[m|0]&15;switch(f-8|0){case 0:break u;case 2:break w;case 6:break x;default:break v}}f=14;m=(d&240)<<24>>24;if((m|0)<=-17|!(435>>>((m+16&240)>>>4)&1)){break t}break u}d=(d&240?-16:15)&d;f=10;break t}break d}g=f;h=d}d=h;f=g;if(!((d|f)&255)){break s}}v[i+5|0]=d;v[i+3|0]=f;x[114409]=0;V(573,i|0);d=x[114409];x[114409]=0;y:{if((d|0)!=1){d=1;switch(y[i+3|0]-16|0){case 0:break r;case 1:break y;default:break s}}break d}s=1}d=j}i=D(z[a+480188>>1],6)+i|0;k=k+1|0;if((n|0)!=(k|0)){continue}break}}i=q+1|0;if((q&65535)>>>0<31){continue}break}}f=y[e+232|0]>o>>>0;o=o+1|0;if(f){continue}break}z:{if(!(d&s)){break z}t=e,u=bc(l),x[t+12>>2]=u;t=e,u=dc(l),x[t+188>>2]=u;if(Hb(e+12|0,e+188|0)){while(1){k=0;A:{h=x[e+12>>2];if(!x[h+12>>2]){break A}while(1){B:{x[114409]=0;j=O(952,h|0,k|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break B}i=0;g=0;f=0;if(z[a+480188>>1]){while(1){d=1;C:{switch(y[(j+D(i,6)|0)+3|0]-16|0){case 1:g=1;default:d=f;break;case 0:break C}}f=d;i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}if(d&g&1){break z}}k=k+1|0;if(k>>>0<A[h+12>>2]){continue}break A}break}break d}d=e+12|0;dm(d);if(Hb(d,e+188|0)){continue}break}}t=e,u=bc(l),x[t+188>>2]=u;t=e,u=dc(l),x[t+28>>2]=u;if(!Hb(e+188|0,e+28|0)){break z}while(1){h=0;D:{j=x[e+188>>2];if(!x[j+12>>2]){break D}while(1){E:{x[114409]=0;f=O(477,j|0,h|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break E}i=0;F:{if(!z[a+480188>>1]){break F}while(1){d=y[(f+D(i,6)|0)+3|0];if((d&254)==16){x[114409]=0;d=(d|0)==16;f=U(478,e+12|0,(d?17:16)|0,(d?125:6)|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){d=Oe(f,h);x[114409]=0;O(479,j|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break F}}break d}i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}}h=h+1|0;if(h>>>0<A[j+12>>2]){continue}break D}break}break d}d=e+188|0;dm(d);if(Hb(d,e+28|0)){continue}break}}G:{if(!(y[e+234|0]|y[e+235|0]<<8)){break G}d=y[e+234|0]|y[e+235|0]<<8;x[114409]=0;aa(540,a+1304424|0,b|0,d|0,39,1)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break G}break d}H:{if(!(!(c&2)|!z[a+480190>>1])){d=1;while(1){f=D(d&65535,104)+a|0;c=cd(e+188|0,w[f+484414>>1]&1?16:8,1,0,1);x[114409]=0;U(376,c|0,f+484380|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break H}d=d+1|0;if(z[a+480190>>1]>=(d&65535)>>>0){continue}break}}x[a+480260>>2]=64;x[a+480264>>2]=32767;Ab(e+32|0);break b}break d}break d}i=N()|0;xb(e+32|0);break c}i=N()|0;Ab(e+32|0)}Q(i|0);p()}i=1}hb=e+272|0;return i|0}function qt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=hb-16|0;hb=k;x[k+12>>2]=c;a:{if((c|0)<=0){break a}h=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{i=x[b+656>>2];k:{if(!(!i|x[a+480180>>2]!=16777216)){o=x[i+44>>2]!=0;break k}if(!i){break j}}j=i+236|0;l:{if((c|0)>128){j=c;break l}n=c-1|0;j=z[fd(j,n)>>1];m:{if((j-1&65535)>>>0<=3998){h=(D(j,104)+a|0)+484380|0;break m}if(!$b(a+1074312|0,43)){break m}if(!Ej(b)){break a}}j=y[fc(i+108|0,n)|0];x[k+12>>2]=j}if(j>>>0<=120){break h}c=j;break i}l=0;if(c>>>0<121){break g}}n:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Fn(a,b);if(d){break n}if(!$b(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+811|0]){break n}x[b+88>>2]=x[b+88>>2]&-6145;break n}if(!z[a+480192>>1]){break n}x[b+88>>2]=x[b+88>>2]|4096}o:{if((c|0)!=254){break o}p:{c=x[b+88>>2];if(!(c&512)){break p}c=x[b+88>>2];if(x[a+480180>>2]!=2){break p}x[b+88>>2]=c|2048;break o}x[b+88>>2]=c|2101248;q:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break q}if($b(a+1074312|0,50)){break q}}x[b+688>>2]=0}if($b(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!$b(a+1074312|0,20)){break a}v[b+819|0]=0;v[b+824|0]=0;break a}l=0;if(!o){break g}if(d){l=y[b+819|0];if(l){break f}}x[b+708>>2]=0;l=1}j=l;if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!h)){x[b+772>>2]=v[h+36|0];x[b+768>>2]=v[h+37|0];break d}if(h){break d}h=0;o=1;break c}n=x[i+44>>2];w[k+10>>1]=l;w[k+8>>1]=j;x[k+4>>2]=0;j=(x[k+4>>2]+D(w[n+36>>1]+1|0,w[k+8>>1]-w[k+10>>1]|0)|0)-x[b+876>>2]|0;x[b+708>>2]=j;x[b+876>>2]=0-j;j=1}o=!h;l=1;if(Zh(b)){break b}n=a+1074312|0;if($b(n,54)){x[b+700>>2]=0;break a}l=($b(n,39)^-1)&d;break b}o=0;if(!$b(a+1074312|0,24)){break c}x[b+704>>2]=x[h+24>>2]}l=0}r:{if(Bq(a)){x[k+12>>2]=x[k+12>>2]+x[b+772>>2];ce(k+12|0,12,131);break r}gR(k+12|0)}m=a+1074312|0;s:{if($b(m,34)){c=_O(c);break s}c=x[k+12>>2]}v[b+819|0]=c;v[b+872|0]=y[b+872|0]|16;if(!(x[a+480180>>2]&16777250?0:l)){v[b+825|0]=0}p=jg(a,x[k+12>>2],x[b+768>>2],x[b+704>>2]);v[b+851|0]=0;if($b(m,48)){BN(a,b,i,h)}t:{if(l|e^1){break t}x[b+788>>2]=0;x[b+792>>2]=0;if(!i){break t}if($b(m,29)){v[b+820|0]=y[i+16|0]}if(!(y[i+60|0]&8)){Oi(b+724|0)}if(!(y[i+80|0]&8)){Oi(b+736|0)}if(!(y[i+100|0]&8)){Oi(b+748|0)}if(y[i+20|0]){c=((D(mt(En(a)),y[i+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if($b(m,28)){d=x[b+764>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+788>>1]=(D(d,c)|0)/199}v:{if(!y[i+19|0]){break v}q=b,r=(D(mt(En(a)),y[i+19|0])<<16>>16)/32|0,w[q+790>>1]=r;if($b(m,28)|z[b+796>>1]){break v}w[b+796>>1]=z[b+692>>1]+1}n=y[i+23|0];if(n){d=mt(En(a));c=y[b+857|0];v[b+818|0]=c+1;w[b+792>>1]=(D(c,(D(n,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}n=y[i+24|0];if(!n){break t}d=mt(En(a));c=y[b+858|0];v[b+817|0]=c+1;w[b+794>>1]=(D(c,(D(n,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(o){break a}w:{x:{if(!p){h=0;break x}if(!(l&x[b+700>>2]!=0)){x[b+700>>2]=p}y:{z:{if(!j){if(!l){if($b(m,69)){break z}if($b(m,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=p}if(!l){break z}if(x[b+76>>2]|x[a+480180>>2]&2){break y}}x[b+104>>2]=h;c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!$b(m,96)|y[b+811|0]){break B}c=x[b+76>>2];break C}if(y[b+811|0]){break B}}x[k+4>>2]=c-1;q=b,r=x[Mb(b+660|0,k+4|0)>>2],x[q+4>>2]=r;break A}x[b+660>>2]=0}c=z[h+34>>1];j=c&1023;d=j|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[h+12>>2];c=x[h+16>>2];x[b+88>>2]=(j&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(j&2)){break D}x[b+80>>2]=x[h+4>>2];c=x[h+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(q=0,r=$b(m,83),s=x[b+80>>2],s?q:r)){c=x[b+76>>2];break F}c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+842|0]>3){break G}c=b;H:{if(!($b(m,21)|!(x[a+480180>>2]&16777248))){d=16;if(!(y[a+480208|0]&4)){break H}}d=32;if(x[a+480180>>2]==16){break H}if(x[a+480180>>2]&67633152){break G}d=0}v[c+839|0]=d}if($b(m,21)|y[b+845|0]>3){break y}v[b+840|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}h=0;if(!l){break x}h=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}d=1;if(!(y[a+480208|0]&8)){break w}d=1;if(!y[b+811|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Wl(b);if(!$b(m,21)){v[b+838|0]=0;x[b+780>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}if(!(!h|!(y[a+480208|0]&8))){d=1;if(!y[b+811|0]){break w}}if(!(y[b+811|0]?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}d=h}I:{if(!(!d|!$b(m,40)|(y[b+811|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break I}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;J:{if(d){break J}w[b+862>>1]=65535;x[b+88>>2]=c&-6324225|2097152;K:{if($b(m,23)){break K}if($b(m,22)){break K}if($b(m,52)){break K}if($b(m,71)){break K}v[b+859|0]=0;w[b+798>>1]=0}if(e){v[b+838|0]=0;x[b+780>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;c=x[a+480208>>2]&8192;h=!c;L:{if(i){M:{N:{if(!xC(i)){if(pv(i)){break N}if(!c){break M}break L}q=b,r=yC(i),v[q+858|0]=r;if(!pv(i)){break M}}q=b,r=AC(i),v[q+857|0]=r}h=1;c=y[i+25|0];if((c|0)==255){break L}v[b+865|0]=c;break L}x[b+788>>2]=0;x[b+792>>2]=0}O:{if(y[b+857|0]>=127){if($b(m,36)&h){break O}break J}if(!h){break J}}if((Wp(a,b,1,256)|0)<0|!(y[b+89|0]&2)){break J}c=a+1304392|0;if(!yd(c)|(g|0)==65535){break J}bq(x[c>>2],g,y[b+857|0]>>>1|0,1)}c=x[b+88>>2];P:{Q:{R:{if(f){x[b+88>>2]=c&-1025;break R}if(!(c&1024)){break R}if(y[a+24618|0]&16){break Q}}a=x[b+104>>2];if(!a|!(y[a+35|0]&4)|f){a=x[b+656>>2];if(!a|!(y[a+15|0]&2)){break P}}if(f){break P}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}hb=k+16|0}function kM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,A=0,C=0,F=0,G=0,H=0,I=0,J=E(0),K=E(0),L=0,M=0,N=0,O=E(0),P=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{h=D(b,896)+a|0;c=y[h+1075797|0];switch(c-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a;k=b;q=(c|0)==32;h=v[h+1075799|0];if((h|0)>=0){m=((y[(D(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0}else{m=(((h&127)<<5)+a|0)+902204|0}g=h&255;c=0;a=0;i=hb-48|0;hb=i;j=z[e+480192>>1]?x[(D(k,896)+e|0)+1075640>>2]:j;p=e+1074312|0;b=D(k,896)+e|0;o=b+1075805|0;t=b+1075672|0;u=b+1075772|0;r=b+1075748|0;s=b+1075744|0;A=b+1075704|0;C=b+1075676|0;F=b+1075668|0;G=b+1075648|0;H=b+1075792|0;I=b+1075072|0;d=b+1075855|0;J=E(y[d|0]);K=E(g>>>0);n=255;h=1;while(1){b=y[a+m|0];if(b){f=b-48|0;d:{e:{if((f&255)>>>0<10){break e}if((b-65&255)>>>0<=5){f=b-55|0;break e}f:{g:{h:{switch(b-97|0){case 2:i:{b=Ul(e,k,3,0);if((b-1&255)>>>0>249){break i}b=x[(D(b,160)+e|0)+906140>>2];if(!b){break i}b=aw(b,78840,78848);if(!b){break i}f=mb[x[x[b>>2]+184>>2]](b,k)|0;b=(f|0)!=255;f=b?f:0;if(b|!j){break e}break f}if(j){break f}f=0;break e;case 13:b=0;if(!be(y[o|0])){break g}b=y[o|0]-1|0;break g;case 21:b=i+8|0;Kb(b,p,28);j:{if(!Ib(b)){Kb(i,p,1);b=0;if(!Ib(i)){break j}}b=w[u>>1]}f=D(x[r>>2],x[s>>2]);b=D(x[e+1074444>>2],b+x[t>>2]|0);b=Yb((Ec(tqa(sqa(f,f>>31,b,b>>31),lb,1048576,0),lb)|0)/2|0,1,127);break g;case 23:x[i+8>>2]=x[C>>2]/2;x[i>>2]=127;b=x[fe(i+8|0,i)>>2];break g;case 24:x[i+8>>2]=x[F>>2]/2;x[i>>2]=127;b=x[fe(i+8|0,i)>>2];break g;case 0:b=0;if(!j){break g}f=z[j+28>>1];if(!f){break g}b=f-1>>>7&127;break g;case 1:b=0;if(!j){break g}f=z[j+28>>1];if(!f){break g}b=f-1&127;break g;case 14:b=x[G>>2]>>>8|0;break g;case 7:b=(z[e+480188>>1]<=k>>>0?y[H|0]-1|0:k)&127;break g;case 12:b=y[I|0]>>>7|0;break g;case 15:b=0;if(!j){break g}f=y[j+30|0];if(!f){break g}b=f-1&127;break g;case 25:k:{if(!q|v[d|0]<0){break k}l:{if(c>>>0<3){break l}b=(i+16|0)+c|0;if(y[b-3|0]!=240){break l}if(y[b-2|0]>239){break k}}l=Np(e,J,K);m:{if(l<E(4294967296)&l>=E(0)){b=~~l>>>0;break m}b=0}v[d|0]=b;n=128;break g}n=(n&255)==255?g:n;b=g;break g;case 18:b=c;n:{if(!b){b=0;break n}while(1){b=b-1|0;if(y[b+(i+16|0)|0]==240){break n}if(b){continue}break}}if(y[(i+16|0)+b|0]!=240|c-b>>>0<5){break d}f=0;b=b+5|0;if((c|0)!=(b|0)){while(1){f=y[(i+16|0)+b|0]+f|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}b=0-f&127;break g;case 20:break h;default:break d}}b=D(x[r>>2],x[s>>2]);f=b;L=b>>31;b=D(x[e+1074444>>2],x[A>>2]);b=Yb((Ec(tqa(sqa(f,L,b,b>>31),lb,67108864,0),lb)|0)/2|0,1,127)}f=h^-1;h=1;c=(f&1)+c|0;v[c+(i+16|0)|0]=b;c=c+1|0;break d}b=0;o:{if(k>>>0>=256){break o}if(y[j+31|0]==17){b=z[(D(k,896)+e|0)+1075792>>1];b=(b?b-1|0:k)&15;break o}if(!Ri(j)){break o}b=y[j+31|0]-1&15}f=b}b=(i+16|0)+c|0;p:{if(h&1){v[b|0]=f;break p}v[b|0]=y[b|0]<<4|f;c=c+1|0}h=h^1}a=a+1|0;if((a|0)!=31){continue}}break}b=((h^-1)&1)+c|0;if(n<<24>>24>=0){v[d|0]=n}q:{if(!b){break q}f=0;h=0;while(1){d=(i+16|0)+h|0;a=v[d|0];r:{s:{t:{if((a|0)==-16){if(b-h>>>0>=4){a=4;if((y[(i+h|0)+17|0]&254)==240){break s}}a=h;u:{while(1){a=a+1|0;if(b>>>0<=a>>>0){break u}if(y[(i+16|0)+a|0]!=247){continue}break}a=(a-h|0)+1|0;if(a){break s}}v[(i+16|0)+b|0]=247;b=b+1|0;a=b-h|0;break t}if((a|0)>=0){if(f&255){h=h-1|0;v[h+(i+16|0)|0]=f;break r}h=h+1|0;f=0;break r}M=i,N=uP(a&255),x[M+8>>2]=N;x[i>>2]=b-h;a=x[Mb(i+8|0,i)>>2]}if(!a){break q}c=y[d|0];f=c>>>0<240?c:f}g=0;m=hb-16|0;hb=m;x[m+12>>2]=a;v:{if(!a){break v}c=y[d|0];j=c-250|0;if(!(j>>>0>5|!(1<<j&37))){if(z[e+480188>>1]){c=0;while(1){j=(D(c,896)+e|0)+1075841|0;v[j|0]=127;v[j+1|0]=0;c=c+1|0;if(c>>>0<z[e+480188>>1]){continue}break}}c=y[d|0]}w:{if((c&255)!=240){break w}j=y[d+1|0];if((j&254)!=240){break w}if(a>>>0<4){break v}n=(D(k,896)+e|0)+1074984|0;p=y[d+2|0];c=v[d+3|0];o=(j|0)!=241&(c|0)>=0;if(!(p|!o)){d=D(k,896)+e|0;g=d+1075841|0;if(q){c=fN(Np(e,E(y[g|0]),E((c&255)>>>0)))}v[g|0]=c;v[d+1075802|0]=0;g=4;c=d+1075072|0;d=Wp(e,n,!(x[c>>2]&32768),256);if((d|0)<0|!(y[c+1|0]&2)){break v}c=e+1304392|0;if(!yd(c)){break v}bq(x[c>>2],k,d>>>2&255,1);break v}d=p<<24>>24;if(o&(d|0)==1){g=D(k,896)+e|0;d=g+1075842|0;x:{if(!q){break x}l=Np(e,E(y[d|0]),E((c&255)>>>0));if(l<E(4294967296)&l>=E(0)){c=~~l>>>0;break x}c=0}v[d|0]=c;v[g+1075801|0]=0;Wp(e,n,!(x[g+1075072>>2]&32768),256);g=4;break v}o=(j|0)==241;if(!(o|(d|0)!=2)){g=4;if(c>>>0>31){break v}d=D(k,896)+e|0;v[d+1075849|0]=(c&240)>>>4;Wp(e,n,!(x[d+1075072>>2]&32768),256);break v}if(!(o|(d|0)!=3)){g=4;d=Ul(e,k,3,0);if((c|0)<0|(d-1&255)>>>0>249){break v}d=(D(d,160)+e|0)+906284|0;l=E(E(((c^127)&255)>>>0)*E(.007874015718698502));if(!q){B[d>>2]=l;break v}M=d,O=Np(e,B[d>>2],l),B[M>>2]=O;break v}if((j|0)!=241&(d|0)>=0){break v}g=4;d=Ul(e,k,3,0);if((d-1&255)>>>0>249){break v}d=x[(D(d,160)+e|0)+906140>>2];if(!d|(c|0)<0){break v}j=(j|0)!=241?p&127:p+128|0;l=E(E((c&255)>>>0)*E(.007874015718698502));c=x[d>>2];if(!q){mb[x[c+44>>2]](d,j,l);break v}N=d,P=j,O=Np(e,E(mb[x[c+48>>2]](d,j)),l),M=x[x[d>>2]+44>>2],mb[M](N|0,P|0,E(O));break v}y:{z:{A:{if(z[e+480188>>1]>k>>>0){c=k+1|0;break A}c=z[(D(k,896)+e|0)+1075792>>1];if(!c){break z}}if(y[(D(k,896)+e|0)+1075075|0]&4|z[e+480188>>1]<(c&65535)>>>0){break z}c=Ul(e,k,3,0);if((c-1&255)>>>0>249){break z}c=x[(D(c,160)+e|0)+906140>>2];if(!c){break z}g=y[d|0];if((g|0)!=240){break y}g=m+4|0;jc(g,Db(d),a);mb[x[x[c>>2]+72>>2]](c,g)|0}g=a;break v}M=m,P=uP(g),x[M>>2]=P;g=x[Mb(m,m+12|0)>>2];x[m>>2]=0;g=sc(m,d,g);mb[x[x[c>>2]+68>>2]](c,x[g>>2])|0;g=x[g+12>>2]}hb=m+16|0;h=(g?g:a)+h|0}if(b>>>0>h>>>0){continue}break}}hb=i+48|0}}function O2(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0,G=0,H=0;n=hb-560|0;hb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=1782;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=1785;break a}u=e&1;C=u?1788:1783;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;mf(a,32,c,g,e&-65537);af(a,C,u);d=f&32;af(a,b!=b?d?5964:9609:d?7011:9918,3);mf(a,32,c,g,e^8192);p=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=bH(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((l|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;i=s;break f}i=s;d=l;while(1){q=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){k=x[g>>2];B=d;d=q&31;if((q&63)>>>0>=32){p=k<<d;d=0}else{p=(1<<d)-1&k>>>32-d;d=k<<d}B=B+d|0;k=p+r|0;d=vqa(B,d>>>0>B>>>0?k+1|0:k,1e9,0);G=g,H=B-sqa(d,lb,1e9,0)|0,x[G>>2]=H;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-q|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;p=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>p|0;k=-1<<p^-1;d=0;h=i;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>p|0);d=D(q,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=p+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;k=(q|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(k<<2)|0)-4048|0;h=10;p=q-D(k,9)|0;if((p|0)<=7){while(1){h=D(h,10);p=p+1|0;if((p|0)!=8){continue}break}}q=x[l>>2];w=(q>>>0)/(h>>>0)|0;r=q-D(h,w)|0;k=l+4|0;j:{if(!r&(k|0)==(g|0)){break j}k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|i>>>0>=l>>>0)){break k}}b=9007199254740994}t=(g|0)==(k|0)?1:1.5;k=h>>>1|0;t=k>>>0>r>>>0?.5:(k|0)==(r|0)?t:1.5;if(!(y[C|0]!=45|E)){t=-t;b=-b}k=q-r|0;x[l>>2]=k;if(b+t==b){break j}d=h+k|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){k=g;q=g>>>0<=i>>>0;if(!q){g=k-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){l=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(q){break m}l=x[k-4>>2];if(!l){break m}p=10;g=0;if((l>>>0)%10|0){break m}while(1){h=g;g=g+1|0;p=D(p,10);if(!((l>>>0)%(p>>>0)|0)){continue}break}g=h^-1}h=D(k-s>>2,9);if((f&-33)==70){l=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}p=-1;q=l|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=kn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;mf(a,32,c,r,e);af(a,C,u);mf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;l=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=kn(x[i>>2],0,l);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}af(a,g,l-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){af(a,12710,1)}if((m|0)<=0|i>>>0>=k>>>0){break q}while(1){g=kn(x[i>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}af(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(k>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<k>>>0?k:i+4|0;f=n+16|0;d=f|8;k=f|9;h=i;while(1){g=kn(x[h>>2],0,k);if((k|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}af(a,g,1);g=g+1|0;if(!(l|m)){break t}af(a,12710,1)}f=k-g|0;af(a,g,(f|0)>(m|0)?m:f);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}mf(a,48,m+18|0,18,0);af(a,w,z-w|0);break o}g=m}mf(a,48,g+9|0,9,0)}mf(a,32,c,r,e^8192);p=(c|0)<(r|0)?r:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(t+(-b-t));break u}b=b+t-t}g=x[n+44>>2];h=g>>31;g=kn((g^h)-h|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}s=u|2;i=f&32;h=x[n+44>>2];m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){k=~~b}else{k=-2147483648}v[h|0]=i|y[k+59056|0];b=(b-+(k|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}p=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}k=f;f=n+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=k+d|0;mf(a,32,c,h,e);af(a,l,s);mf(a,48,c,h,e^65536);af(a,f,i);mf(a,48,d-i|0,0,0);af(a,m,g);mf(a,32,c,h,e^8192);p=(c|0)<(h|0)?h:c}hb=n+560|0;return p|0}function Sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-368|0;hb=d;a:{b:{c:{if(!Tc(b,60)){break c}if(!Vo(b,d+348|0)){break c}g=15;if(Wt(d+348|0,15)){break b}}if(!Tc(b,124)){break a}if(!Vo(b,d+348|0)){break a}g=31;if(!Wt(d+348|0,31)){break a}}Pd(a,536870912);w[a+480190>>1]=g;Nc(b);d:{if(z[a+480190>>1]){while(1){f=mB(b);x[(d+224|0)+(e<<2)>>2]=f;if(f>>>0>131072){break d}e=e+1|0;if(e>>>0<z[a+480190>>1]){continue}break}}cc(b,20);w[a+480192>>1]=0;w[a+480188>>1]=4;e=y[d+352|0]|y[d+353|0]<<8;e=mg(177693e5/+(((e<<8|e>>>8)&65535)>>>0));x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;x[a+480204>>2]=e;x[a+480228>>2]=64;k=1;Cj(a,1);e:{f:{g:{if(z[a+480190>>1]){o=1;while(1){g=d+68|0;yR(b,g);e=x[((k<<2)+d|0)+220>>2];l=hb-16|0;hb=l;h=(D(k,104)+a|0)+484380|0;zd(h,1);x[h>>2]=e;v[h+37|0]=y[g+24|0]<<4;v[l+15|0]=y[g+25|0];v[l+14|0]=64;q=h,r=y[tc(l+15|0,l+14|0)|0]<<2,w[q+30>>1]=r;e=g+26|0;e=y[e|0]|y[e+1|0]<<8;j=g+28|0;f=x[h>>2];h:{if(!f){break h}i=y[j|0]|y[j+1|0]<<8;j=(e<<8|(e&65280)>>>8)&65535;x[h+4>>2]=j;e=(((i<<8|i>>>8)&65535)<<1)+j|0;x[h+8>>2]=e;if(f>>>0<=j>>>0){j=f-1|0;x[h+4>>2]=j}if(e>>>0>f>>>0){x[h+8>>2]=f;e=f}if(!(!(e>>>0<4|e>>>0<j>>>0)&e-j>>>0>3)){x[h+4>>2]=0;x[h+8>>2]=0;break h}if(e>>>0<=j>>>0){break h}w[h+34>>1]=z[h+34>>1]|2}hb=l+16|0;e=0;while(1){if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;n=n+1|0}e=e+1|0;g=e+(d+68|0)|0;if((e|0)!=22){continue}break}if(n>>>0>=128){break d}e=d+200|0;rm(e,3,d+68|0);f=d+212|0;Kc(f,e);x[114409]=0;O(348,((k<<5)+a|0)+946304|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}xb(d+212|0);o=o+1|0;k=o&65535;if(k>>>0<=z[a+480190>>1]){continue}break}}f=Vb(d+68|0,9788);x[114409]=0;e=a+946336|0;g=O(1044,e|0,f|0)|0;k=x[114409];x[114409]=0;h=1;i:{j:{k:{l:{if((k|0)!=1){if(!g){x[114409]=0;g=O(122,d+212|0,9799)|0;h=x[114409];x[114409]=0;if((h|0)==1){break l}x[114409]=0;h=O(1044,e|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}xb(g)}xb(f);e=0;if(!cA(b,d+68|0)){break a}if(!aQ(d+68|0)){break a}if(c){break i}break e}e=N()|0;break j}e=N()|0;break j}e=N()|0;xb(g)}xb(f);break f}w[d+66>>1]=0;m:{n:{if(!y[d+68|0]){break n}while(1){w[d+200>>1]=y[(d+e|0)+70|0]+1;q=d,r=z[jj(d+66|0,d+200|0)>>1],w[q+66>>1]=r;e=e+1|0;f=y[d+68|0];if(e>>>0<f>>>0){continue}break}if(f>>>0<=y[d+69|0]){break n}Pe(Wb(a+484360|0),y[d+69|0]);break m}Pe(Wb(a+484360|0),0)}Uj(Wb(a+484360|0),d+70|0,y[d+68|0],65535,65535);if(z[a+480190>>1]==31){cc(b,4)}x[d+60>>2]=0;x[d+56>>2]=0;x[d+52>>2]=0;v[d+51|0]=0;l=c&1;if(l){ig(a+484344|0,z[d+66>>1])}if(z[d+66>>1]){j=a+484344|0;k=0;while(1){o:{p:{if(l){n=0;if(Zg(j,k&65535,64)){break p}}cc(b,1024);break o}while(1){o=Hf(Zb(j,k),n,0);e=0;while(1){g=d+200|0;qm(g,b);f=o+D(e,6)|0;q:{r:{if(y[fc(g,0)|0]!=255){break r}v[(d+60|0)+e|0]=0;v[(d+52|0)+e|0]=0;s:{if(!h){break s}if(y[fc(d+200|0,1)|0]!=252){break s}q=fc(d+200|0,1),r=254,v[q|0]=r}t:{switch(y[fc(d+200|0,1)|0]-252|0){case 2:v[f+3|0]=13;break q;case 1:break q;case 0:break t;default:break r}}v[f+3|0]=14;v[d+51|0]=9;break q}g=x[d+200>>2];x[d+44>>2]=g;x[d+12>>2]=g;fu(d+12|0,f);g=y[f|0];u:{if(!g){break u}v[(d+52|0)+e|0]=0;v[(d+60|0)+e|0]=g;if(g>>>0>48){break u}v[d+28|0]=8;q=d,r=y[ah(d+51|0,d+28|0)|0],v[q+51|0]=r}v:{w:{x:{y:{z:{A:{switch(y[f+3|0]){case 1:v[f+3|0]=1;break q;case 2:g=y[f+5|0];if(g>>>0>=16){v[f+3|0]=3;v[f+5|0]=g>>>4;break q}if(g){v[f+3|0]=2;v[f+5|0]=g;break q}v[f+5|0]=0;break w;case 3:if(y[(d+52|0)+e|0]){break x}v[f+3|0]=19;v[f+5|0]=0;break q;case 4:if(y[(d+52|0)+e|0]){break x}v[f+3|0]=19;v[f+5|0]=1;break q;case 5:if(!y[f+1|0]){break x}v[f+3|0]=13;v[d+28|0]=63;v[d+43|0]=y[f+5|0]+(z[(D(y[f+1|0],104)+a|0)+484410>>1]>>>2|0);q=f,r=y[tc(d+28|0,d+43|0)|0],v[q+5|0]=r;if(!y[(d+52|0)+e|0]){break z}v[f+2|0]=1;v[f+4|0]=y[f+5|0];v[f+5|0]=0;break w;case 6:g=y[f+1|0];if(!g){break x}v[f+3|0]=13;g=z[(D(g,104)+a|0)+484410>>1]>>>2|0;i=y[f+5|0];g=g>>>0>=i>>>0?g-i|0:0;v[f+5|0]=g;if(!y[(d+52|0)+e|0]){break z}v[f+4|0]=g;v[f+2|0]=1;v[f+5|0]=0;break w;case 8:i=y[(d+60|0)+e|0];g=y[f+5|0];m=i+(g>>>4|0)|0;v[(d+56|0)+e|0]=m;v[f+3|0]=2;g=g&15;v[(d+52|0)+e|0]=g;q=f,r=$P(g,i,m&255),v[q+5|0]=r;break z;case 9:v[d+28|0]=8;q=d,r=y[ah(d+51|0,d+28|0)|0],v[q+51|0]=r;break w;case 0:break y;case 7:break A;default:break w}}g=y[(d+60|0)+e|0];i=y[f+5|0];m=g-(i>>>4|0)|0;v[(d+56|0)+e|0]=m;v[f+3|0]=3;i=i&15;v[(d+52|0)+e|0]=i;q=f,r=$P(i,m&255,g),v[q+5|0]=r}if(!y[f+3|0]){break v}break q}if(!y[f+5|0]){break v}break w}v[f+5|0]=0}v[f+3|0]=0}i=y[(d+52|0)+e|0];if(!i){break q}m=(d+56|0)+e|0;g=y[m|0];if(g){v[(d+60|0)+e|0]=g;v[f|0]=g;v[f+5|0]=i;v[m|0]=0}v[f+3|0]=4}e=e+1|0;if((e|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}k=k+1|0;if(k>>>0<z[d+66>>1]){continue}break}}g=z[a+480190>>1];B:{C:{D:{E:{F:{G:{H:{if(c&2){if(!(g&65535)){break H}e=1;while(1){c=(D(e&65535,104)+a|0)+484380|0;if(x[c>>2]){Fg(cd(d+200|0,8,1,0,0),c,b);g=z[a+480190>>1]}e=e+1|0;if((e&65535)>>>0<=(g&65535)>>>0){continue}break}}if((g&65535)==15){break G}}x[114409]=0;b=O(2,d+200|0,8137)|0;c=x[114409];x[114409]=0;if((c|0)==1){break D}Eb(a+1304436|0,b);break F}b=Vb(d+16|0,11466);x[114409]=0;P(192,d+28|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break C}x[114409]=0;T(530,d+200|0,d+28|0,d+51|0);c=x[114409];x[114409]=0;if((c|0)==1){break E}c=d+200|0;Eb(a+1304436|0,c);xb(c);Gb(d+28|0)}xb(b);Rc(a+1304448|0,z[a+480190>>1]==15?1768:10765);x[a+1304496>>2]=2;break e}e=N()|0;Gb(d+28|0);break B}e=N()|0;break f}e=N()|0}xb(b);break f}e=N()|0;xb(d+212|0)}Q(e|0);p()}e=1;break a}e=0}hb=d+368|0;return e|0}function YW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=hb-144|0;hb=d;Nc(b);sr(a);a:{if(!yv(b,d+108|0)){break a}if(!PL(d+108|0)){break a}h=d+108|0;j=Bf(8966);if(j){n=x[b+8>>2];if(Tc(b,y[h+16|0]|y[h+17|0]<<8|(y[h+18|0]<<16|y[h+19|0]<<24))){b:{if(!(y[h+12|0]|y[h+13|0]<<8|(y[h+14|0]<<16|y[h+15|0]<<24))){break b}while(1){if(!Qb(b,4)){break b}c:{if((y[h+4|0]|y[h+5|0]<<8)>>>0>=64){if((Xh(b)|0)<=0){break c}}f=0;e=1;while(1){g=te(b);if(g){o=vn(g<<24>>24);k=f>>>0>=j>>>0;g=k&e;if(!(!(e&1)|k)){g=y[f+8966|0]==(o&255)}e=g;f=f+1|0;continue}break}cc(b,4);i=(f|0)==(j|0)?e?1:i:i}l=l+1|0;if(l>>>0<(y[h+12|0]|y[h+13|0]<<8|(y[h+14|0]<<16|y[h+15|0]<<24))>>>0){continue}break}}f=i&1}Tc(b,n)}if(!f){break a}if(!c){m=1;break a}c=hb-16|0;hb=c;g=sh(d+96|0);h=d+108|0;e=h+16|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;e=O(229,b|0,e|0)|0;f=x[114409];x[114409]=0;d:{e:{f:{g:{if((f|0)!=1){if(!e){break d}e=h+12|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114409]=0;x[c>>2]=e;e=S(305,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}x[114409]=0;x[c+12>>2]=(e>>>0)/5;e=O(306,c|0,c+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}e=x[e>>2];x[114409]=0;P(1629,g|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break g}if(!e){break d}h=h+4|0;f=0;h:{while(1){x[114409]=0;i=O(231,b|0,5)|0;j=x[114409];x[114409]=0;i:{if((j|0)!=1){if(i){break i}break d}a=N()|0;break e}i=y[h|0]|y[h+1|0]<<8;x[114409]=0;T(1630,c|0,b|0,i|0);i=x[114409];x[114409]=0;if((i|0)!=1){x[114409]=0;P(1631,g|0,c|0);i=x[114409];x[114409]=0;if((i|0)==1){break h}xb(c);f=f+1|0;if((e|0)!=(f|0)){continue}break d}break}a=N()|0;break e}a=N()|0;xb(c);break e}a=N()|0;break e}a=N()|0;break e}a=N()|0}pd(g);Q(a|0);p()}hb=c+16|0;c=y[d+140|0]|y[d+141|0]<<8|(y[d+142|0]<<16|y[d+143|0]<<24);x[114409]=0;c=O(229,b|0,c|0)|0;g=x[114409];x[114409]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){if(!c){break j}g=hb-16|0;hb=g;c=d+84|0;x[c>>2]=0;x[c+4>>2]=0;x[114409]=0;x[g+12>>2]=0;U(318,c+8|0,g+12|0,g+11|0)|0;e=x[114409];x[114409]=0;r:{if((e|0)!=1){hb=g+16|0;break r}R(0)|0;zb();p()}g=y[d+136|0]|y[d+137|0]<<8|(y[d+138|0]<<16|y[d+139|0]<<24);x[114409]=0;x[d+20>>2]=g;g=S(305,b|0)|0;e=x[114409];x[114409]=0;s:{if((e|0)==1){break s}x[114409]=0;x[d+52>>2]=g>>>2;g=O(306,d+20|0,d+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}e=x[g>>2];x[114409]=0;P(307,c|0,e|0);g=x[114409];x[114409]=0;if((g|0)==1){break p}if(!e){break q}g=0;while(1){x[114409]=0;h=O(231,b|0,4)|0;f=x[114409];x[114409]=0;t:{if((f|0)!=1){if(h){break t}break q}b=N()|0;break n}h=y[d+112|0]|y[d+113|0]<<8;x[114409]=0;h=O(308,b|0,h|0)|0;f=x[114409];x[114409]=0;u:{if((f|0)!=1){x[d+20>>2]=h;if(Ac(d+96|0)>>>0<=h>>>0){break u}x[114409]=0;P(309,c|0,d+20|0);h=x[114409];x[114409]=0;if((h|0)!=1){break u}}b=N()|0;break n}g=g+1|0;if((e|0)!=(g|0)){continue}break}break q}b=N()|0;break n}b=N()|0;break m}g=y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24);x[114409]=0;g=O(229,b|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break o}}b=N()|0;break n}if(!g){break k}if(!(y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))){break l}h=d+32|0;g=0;v:{w:{x:{y:{z:{A:{while(1){x[114409]=0;e=O(231,b|0,4)|0;f=x[114409];x[114409]=0;B:{if((f|0)!=1){if(e){break B}break l}b=N()|0;break n}e=y[d+112|0]|y[d+113|0]<<8;x[114409]=0;ia(310,b|0,d+80|0,d+76|0,d+72|0,d+68|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break y}C:{D:{if(x[d+72>>2]<=0){break D}e=x[d+80>>2];if((e|0)>=0){break D}e=e^-1;x[d+80>>2]=e;if(Lb(c)>>>0<=e>>>0){break D}if(!Rd(ud(d+96|0,x[Pb(c,x[d+80>>2])>>2]),8966)){break D}x[114409]=0;W(311,d+52|0,b|0,x[d+76>>2],x[d+72>>2]);e=x[114409];x[114409]=0;if((e|0)==1){break x}x[114409]=0;e=S(312,d+52|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break w}if(e){if((y[d+112|0]|y[d+113|0]<<8)>>>0<=39){x[114409]=0;O(313,d+52|0,8)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}}if((y[d+112|0]|y[d+113|0]<<8)>>>0<=59){x[114409]=0;O(313,d+52|0,16)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}}x[114409]=0;S(314,d+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}E:{F:{G:{if((y[d+112|0]|y[d+113|0]<<8)>>>0>=120){x[114409]=0;S(314,d+52|0)|0;f=x[114409];x[114409]=0;e=8;break G}H:{if((y[d+112|0]|y[d+113|0]<<8)>>>0>=100){x[114409]=0;O(313,d+52|0,4)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}break H}if((y[d+112|0]|y[d+113|0]<<8)>>>0<62){break F}}x[114409]=0;S(314,d+52|0)|0;f=x[114409];x[114409]=0;e=4}if((f|0)==1){break w}x[114409]=0;O(313,d+52|0,e|0)|0;break E}x[114409]=0;S(314,d+52|0)|0}e=x[114409];x[114409]=0;if((e|0)==1){break w}x[114409]=0;f=S(314,d+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break z}x[114409]=0;e=S(315,d+20|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break C}i=x[d+68>>2];I:{if((i|0)<0){break I}if(Ac(d+96|0)>>>0<=i>>>0){break I}i=ud(d+96|0,x[d+68>>2]);x[114409]=0;T(13,d+4|0,2,i|0);i=x[114409];x[114409]=0;if((i|0)==1){break A}i=d+4|0;Eb(e,i);xb(i)}x[114409]=0;T(316,d+4|0,d+52|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break A}f=d+4|0;Zd(h,f);Ab(f);x[114409]=0;P(317,a|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break A}pr(e)}Ab(d+52|0)}g=g+1|0;if(g>>>0<(y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0){continue}break l}break}b=N()|0;break v}b=N()|0;pr(e);break v}b=N()|0;break v}b=N()|0;break n}b=N()|0;break n}b=N()|0}Ab(d+52|0)}RC(c)}pd(d+96|0);Q(b|0);p()}m=kd(a)^1}RC(c)}pd(d+96|0)}hb=d+144|0;return m|0}function Ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=hb-1824|0;hb=d;Nc(b);e=hb-16|0;hb=e;h=e+8|0;k=d+1224|0;lR(h,k);i=Fb(h);h=nc(b,ac(e,h));if((i|0)==(h|0)){cc(b,Fb(e+8|0))}hb=e+16|0;e=(h|0)==(i|0);if(!e){mR(k)}a:{if(!e){break a}if(!xR(d+1224|0)){break a}if(!bA(b,16,0)){break a}e=d+1240|0;x[d+1216>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=y[d+1228|0]|y[d+1229|0]<<8|(y[d+1230|0]<<16|y[d+1231|0]<<24);x[d+1200>>2]=y[d+1224|0]|y[d+1225|0]<<8|(y[d+1226|0]<<16|y[d+1227|0]<<24);x[d+1204>>2]=e;e=d+1232|0;g=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);x[d+1208>>2]=g;x[d+1212>>2]=e;Pd(a,1);e=a+1074312|0;Kg(e,83);Nb(e,84,1);Nb(e,85,1);w[a+480188>>1]=4;x[d+1196>>2]=0;w[a+480190>>1]=15;Tc(b,20);l=a+480188|0;g=1;k=1;while(1){h=D(g,104)+a|0;i=h+484380|0;e=((g<<5)+a|0)+946304|0;dA(b,d+20|0,i,e,1);n=x[i>>2];b:{if(!y[fc(e,0)|0]){break b}c:{if(dd(e,12712,3)){if(dd(e,12716,3)){break c}}if(y[fc(e,5)|0]==58){break b}}k=0}e=y[d+48|0]|y[d+49|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>=2){e=y[d+46|0]|y[d+47|0]<<8;x[h+484384>>2]=(e<<8|e>>>8)&65535;e=y[d+46|0]|y[d+47|0]<<8;j=(e<<8|e>>>8)&65535;e=y[d+48|0]|y[d+49|0]<<8;x[h+484388>>2]=j+(((e<<8|e>>>8)&65535)<<1);Nn(i)}e=y[d+42|0]|y[d+43|0]<<8;d:{if(((e<<8|e>>>8)&65535)>>>0<=4999){e=y[d+46|0]|y[d+47|0]<<8;if(((e<<8|e>>>8)&65535)>>>0<1e4){break d}}x[d+1064>>2]=5;s=d,t=x[Yf(d+1196|0,d+1064|0)>>2],x[s+1196>>2]=t}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}e=d+1064|0;cA(b,e);o=a+484360|0;Uj(Wb(o),d+1066|0,128,65535,65535);n=DR(b,Wb(o),y[e|0],f,l,0,1);e=d+1065|0;if(!(y[e|0]|n>>>0>1)){g=0;if(!y[d+1064|0]){break a}}f=(n<<10)+f|0;x[d+1060>>2]=f;x[d+20>>2]=65536;g=0;if(!Qb(b,f-x[Mb(d+1060|0,d+20|0)>>2]|0)){break a}if(!c){g=1;break a}if(!y[e|0]){v[e|0]=120}if(!dd(d+1200|0,10446,6)){v[e|0]=120}x[a+480204>>2]=125e4;e:{if(y[e|0]==120){break e}s=a,t=mg(145364549.18032786/+(240-y[e|0]|0)),x[s+480204>>2]=t;if(x[d+1196>>2]>=2){x[d+20>>2]=k&1?4:5;s=d,t=x[Yf(d+1196|0,d+20|0)>>2],x[s+1196>>2]=t;break e}x[d+20>>2]=k&1?1:2;s=d,t=x[Yf(d+1196|0,d+20|0)>>2],x[s+1196>>2]=t}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;e=d+1048|0;mo(e,3,d+1200|0);f=d+20|0;Kc(f,e);Eb(a+1304400|0,f);xb(f);Cj(a,0);q=x[b+8>>2];w[d+1046>>1]=0;f:{g:{if(!n){break g}r=k&1;h=0;k=0;while(1){s=d,t=$z(bc(Wb(o)),dc(Wb(o)),d+1046|0),x[s+20>>2]=t;s=d,t=dc(Wb(o)),x[s+1048>>2]=t;f=d+20|0;e=Hb(f,d+1048|0);vR(b,f);if(e){h=_z(d+20|0,0)+h|0;if(h>>>0>512){break f}}i=0;f=0;l=0;while(1){g=0;while(1){e=f;m=ef(uR(d+20|0,i),g);p=y[fc(m,2)|0]&15;j=y[fc(m,3)|0];f=0;h:{if(!(e&255)|(y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}x[d+1196>>2]=6}i:{j:{k:{switch(p-1|0){case 0:case 1:e=x[d+1196>>2];if((e|0)==1&j>>>0>=32){break j}m=(p|0)!=1;if(!(m|!j|j>>>0>2)){x[d+1048>>2]=2;s=d,t=x[Yf(d+1196|0,d+1048|0)>>2],x[s+1196>>2]=t;break i}if(m|(j|0)!=55&(j|0)!=71){break i}if((e|0)<=2){break j}break i;case 10:x[d+1196>>2]=6;break i;case 11:case 12:case 13:x[d+1048>>2]=2;s=d,t=x[Yf(d+1196|0,d+1048|0)>>2],x[s+1196>>2]=t;if((p|0)!=13){break i}l=((i|j)!=0)+l|0;f=1;break i;case 14:break k;default:break i}}x[d+1048>>2]=3;s=d,t=x[Yf(d+1196|0,d+1048|0)>>2],x[s+1196>>2]=t;break i}x[d+1196>>2]=r}g=g+1|0;if((g|0)!=4){continue}break}i=i+1|0;if((i|0)!=64){continue}break}if((l-1&255)>>>0<2){x[d+1196>>2]=6}k=(l&255)+k|0;f=z[d+1046>>1]+1|0;w[d+1046>>1]=f;if(n>>>0>(f&65535)>>>0){continue}break}if(x[d+1196>>2]!=6|n+32>>>0>=k>>>0){break g}x[d+1196>>2]=5}Tc(b,q);o=c&1;if(o){ig(a+484344|0,n)}if(n){m=a+484344|0;k=0;while(1){vR(b,d+20|0);l:{if(!o){break l}if(!Zg(m,k&65535,64)){break l}x[d+1048>>2]=0;l=0;while(1){p=Hf(Zb(m,k),l,0);h=0;while(1){f=ef(uR(d+20|0,l),h);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[d+12>>2]=f;x[d+16>>2]=f;e=p+D(h,6)|0;fu(d+12|0,e);m:{n:{o:{f=y[e+5|0];if(f){i=e+3|0;j=(d+1048|0)+h|0;g=y[e+3|0];if((g|0)!=14){break o}v[j|0]=0;g=14;break n}v[(d+1048|0)+h|0]=0;g=y[e+3|0];if(!g){break m}i=e+3|0;break n}j=y[j|0];if(!j){break n}if(j>>>0>=16){v[e+2|0]=3;v[e+4|0]=j>>>4;break n}v[e+2|0]=4;v[e+4|0]=j}p:{q:{r:{s:{t:{switch(g-12|0){case 1:j=x[d+1196>>2];if((j|0)==6){break q}g=10;v[i|0]=10;break r;case 0:f=f&127;v[e+5|0]=f;g=12;break s;case 2:if(f>>>0<=1&x[d+1196>>2]>3){break p}g=10;v[i|0]=10;v[(d+1048|0)+h|0]=f;break s;case 3:break t;default:break s}}g=15;f=f&15;v[e+5|0]=f}j=x[d+1196>>2]}if((j|0)>1){break p}u:{v:{w:{switch(g|0){case 0:if(f>>>0>2){break v}break;case 2:break u;case 1:break v;default:break w}}v[i|0]=0;break m}v[i|0]=1;break m}g=f&15;if(g){v[i|0]=2;v[e+5|0]=g;break m}if(f>>>0<16){break m}v[i|0]=3;v[e+5|0]=f>>>4;break m}v[e+5|0]=0}Mj(e)}h=h+1|0;if((h|0)!=4){continue}break}l=l+1|0;if((l|0)!=64){continue}break}}k=k+1|0;if((n|0)!=(k|0)){continue}break}}f=x[d+1196>>2];if(f>>>0>=7){f=17381}else{f=x[(f<<2)+76280>>2]}e=d+20|0;g=Vb(e,4509);Eb(a+1304436|0,g);xb(g);e=Vb(e,6729);Eb(a+1304448|0,e);xb(e);Rc(a+1304460|0,f);x[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=D(h,104)+a|0;f=c+484384|0;cc(b,x[f>>2]);e=x[f>>2];x[f>>2]=0;f=c+484380|0;x[f>>2]=x[f>>2]-e;c=c+484388|0;x[c>>2]=x[c>>2]-e;c=d+20|0;cd(c,8,1,1,0);Fg(c,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}hb=d+1824|0;return g|0}function Xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;e=hb-192|0;hb=e;a:{if(ej(b,9635)){if(d){v[d|0]=1}j=a+1074312|0;zu(j);b:{if(!Qb(b,7)){break b}l=a+480216|0;m=a+480220|0;n=a+480224|0;o=a+1074372|0;q=a+480228|0;r=a+480232|0;s=a+480200|0;t=a+484360|0;k=a+480268|0;u=a+1304412|0;B=a+480248|0;while(1){d=Kf(b);f=tg(b);if((d|0)==(y[17369]|y[17370]<<8|(y[17371]<<16|y[17372]<<24))){rg(b,6);break b}if(!(d&1616928864)|d&-2139062144){break b}if(!Qb(b,f)){break b}Ad(e+176|0,b,f);c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break w}if((d|0)!=1129797166){break c}x[114409]=0;x[e+164>>2]=0;T(681,e+176|0,f|0,e+164|0);d=x[114409];x[114409]=0;if((d|0)==1){break u}x[a+1074304>>2]=x[e+164>>2];break c}if((d|0)==1130917459){break q}if((d|0)!=1145525806){break c}g=s;break e}if((d|0)<=1213486400){if((d|0)==1146367534){break y}if((d|0)!=1196316499|f>>>0<3){break c}x[114409]=0;P(682,e+164|0,e+176|0);d=x[114409];x[114409]=0;if((d|0)==1){break o}x[114409]=0;g=U(683,e+12|0,e+164|0,8)|0;d=x[114409];x[114409]=0;if((d|0)==1){break n}xb(e+164|0);x[114409]=0;d=S(228,e+176|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break m}x[114409]=0;T(684,g|0,B|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break m}Pf(g);break c}if((d|0)==1213486401){break r}if((d|0)==1280530262){break t}if((d|0)!=1297303086){break c}zu(j);g=0;break l}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break v}if((d|0)!=1347244882){break c}x[114409]=0;T(685,e+176|0,f|0,k|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}if(xo(y[k|0])){break c}v[k|0]=5;break c}if((d|0)==1380340804){break x}if((d|0)==1380986414){break s}g=l;if((d|0)==1380991534){break e}break c}if((d|0)<=1397768493){g=m;if((d|0)==1380994350){break e}if((d|0)!=1397052739|f>>>0<3){break c}x[114409]=0;g=S(335,e+176|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}if(!g|g>>>0>z[a+480190>>1]){break c}d=0;f=(D(g,104)+a|0)+484448|0;g=f;while(1){x[114409]=0;h=S(413,e+176|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break p}x[g>>2]=h;d=d+1|0;g=f+(d<<2)|0;if((d|0)!=9){continue}break}break c}g=q;if((d|0)==1397768494){break e}if((d|0)==1414344238){break k}g=r;if((d|0)==1448301654){break e}break c}x[114409]=0;T(681,e+176|0,f|0,e+164|0);d=x[114409];x[114409]=0;if((d|0)==1){break j}x[a+480204>>2]=D(x[e+164>>2],1e4)+(A[a+480204>>2]%1e4|0);break c}x[114409]=0;T(681,e+176|0,f|0,e+164|0);d=x[114409];x[114409]=0;if((d|0)!=1){d=x[a+480204>>2];x[a+480204>>2]=d-((d>>>0)%1e4|0)+A[e+164>>2]%1e4;break c}d=N()|0;break a}if(c){break c}x[114409]=0;w[e+164>>1]=0;T(686,e+176|0,f|0,e+164|0);d=x[114409];x[114409]=0;if((d|0)!=1){C=a,E=Md(z[e+164>>1],z[a+480188>>1],127),w[C+480188>>1]=E;break c}d=N()|0;break a}x[114409]=0;T(687,e+176|0,f|0,o|0);d=x[114409];x[114409]=0;if((d|0)!=1){break c}break d}d=N()|0;break a}x[114409]=0;x[e+164>>2]=0;T(681,e+176|0,f|0,e+164|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}d=x[e+164>>2];if(!d){break c}x[a+1074308>>2]=d;break c}if(x[a+480180>>2]==4){break c}x[114409]=0;T(686,e+176|0,f|0,e+164|0);d=x[114409];x[114409]=0;if((d|0)!=1){Pe(Wb(t),z[e+164>>1]);break c}d=N()|0;break a}g=Xb(e+164|0);x[114409]=0;d=S(228,e+176|0)|0;f=x[114409];x[114409]=0;z:{if((f|0)==1){break z}x[114409]=0;U(688,e+176|0,g|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break z}x[114409]=0;T(13,e+152|0,0,g|0);d=x[114409];x[114409]=0;if((d|0)==1){break z}d=e+152|0;Eb(u,d);xb(d);xb(g);break c}d=N()|0;xb(g);break a}if(f&1|f>>>0>126){break c}w[e+164>>1]=(f>>>1|0)- -64;x[114409]=0;w[e+152>>1]=127;d=O(457,e+164|0,e+152|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break h}h=z[d>>1];if(h>>>0<65){break c}g=64;while(1){x[114409]=0;P(452,e+164|0,e+176|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}d=ed(e+164|0);A:{if(y[e+164|0]==255){break A}f=y[d|0];d=(g<<5)+a|0;i=d+480284|0;w[i>>1]=128;w[d+480286>>1]=f;f=d+480280|0;x[f>>2]=0;x[f>>2]=(y[e+164|0]&128)<<3;d=y[e+164|0]&127;v[e+164|0]=d;if(d>>>0<65){w[i>>1]=d<<2;d=y[e+164|0]}if((d&255)!=100){break A}x[f>>2]=x[f>>2]|256}g=g+1|0;if((h|0)!=(g|0)){continue}break}break c}d=N()|0;break a}d=N()|0;break a}d=N()|0;xb(e+164|0);break a}d=N()|0;Pf(g);break a}B:{C:{D:while(1){x[114409]=0;d=O(231,e+176|0,1)|0;f=x[114409];x[114409]=0;if((f|0)==1){break C}if(!d|g>>>0>=110){break c}x[114409]=0;f=S(425,e+176|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break B}d=0;while(1){E:{if(!(!(f>>>d&1)|g>>>0>=110)){x[114409]=0;U(458,j|0,g|0,1)|0;h=x[114409];x[114409]=0;if((h|0)==1){break E}}g=g+1|0;d=d+1|0;if((d|0)!=8){continue}continue D}break}break}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}x[114409]=0;T(689,e+176|0,f|0,n|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}break c}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}x[114409]=0;T(681,e+176|0,f|0,g|0);d=x[114409];x[114409]=0;if((d|0)!=1){break c}}d=N()|0;break a}Ab(e+176|0);if(Qb(b,7)){continue}break}}Jo(a+480204|0,D(x[x[a+8>>2]+20>>2],1e4),D(x[x[a+8>>2]+24>>2],1e4));if(x[a+480224>>2]>=3){x[a+480224>>2]=0}if(x[a+1074372>>2]>=6){x[a+1074372>>2]=0}zc(a+480200|0,256);zc(a+480216|0,65536);zc(a+480220|0,65536)}hb=e+192|0;return}Ab(e+176|0);Q(d|0);p()}function Up(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;q=x[b+764>>2];j=y[b+824|0];a:{if(!j){if($b(a+1074312|0,11)){break a}}b:{c:{if(!h){break c}if(!be(j)){break c}d:{g=h+236|0;j=j-1|0;if(z[fd(g,j)>>1]){break d}if(!$b(a+1074312|0,43)){break d}if(Ri(h)){break d}x[b+656>>2]=h;return}if(y[fc(h+108|0,j)|0]>120){break a}j=z[fd(g,j)>>1];k=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break b}if(!z[a+480192>>1]){k=(D(c,104)+a|0)+484380|0;break b}if(j>>>0>250){break a}if(!$b(a+1074312|0,43)){break b}if(h){if(Ri(h)){break b}}v[b+825|0]=0;x[b+656>>2]=0;return}j=x[b+656>>2];g=x[b+104>>2];m=(g|0)!=0&(g|0)!=(k|0);g=!m;o=!h|x[a+480180>>2]!=16777216?o:x[h+44>>2]!=0;if(!(!d|!o|x[b+656>>2]!=(h|0)|g)){break a}p=d^1;e:{if(g|p){break e}i=a+1074312|0;if(!(!$b(i,32)|!(y[a+480208|0]&8))){k=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:k}f:{if(!(x[a+480180>>2]&1048580?!h|(h|0)!=(j|0):1)|x[a+480180>>2]==268435456){break f}if(x[a+480180>>2]==1){if(Zh(b)){break f}}if(!$b(i,79)){break e}if(!Zh(b)){break e}}n=1}g:{if(!x[b+16>>2]|(g|(!z[a+480192>>1]|(h|0)!=(j|0)))){break g}if(!$b(a+1074312|0,87)){break g}n=Ff(b+810|0)^1|n}j=(h|0)!=(j|0);h:{if(Zh(b)|!(x[a+480180>>2]&16777248)){break h}if(h){if(Ri(h)){break h}}j=1}i:{j:{if(!j|!d){break j}if(!$b(a+1074312|0,61)){break j}g=x[b+104>>2];i=x[b+656>>2];l=0;if(g|i){break i}}x[b+656>>2]=h;g=k;i=h;l=j}j=l;k:{l:{m:{if(!e){break m}n:{if(x[a+480180>>2]&3){if(g){if(He(g)){break n}}if(!Ej(b)){break m}}if(!g){break l}}if(w[g+34>>1]<0){break m}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(n&m)|!g){break k}if($b(a+1074312|0,85)){x[b+768>>2]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break k}if(!He(g)){break k}x[b+704>>2]=x[g+24>>2];break k}if(!(!i|!y[i+34|0])){h=x[b+656>>2];o:{if(h){l=x[h+4>>2]<<2;break o}l=x[b+688>>2]}x[b+688>>2]=l;h=0;break k}h=0;x[b+688>>2]=0}if(n){break a}v[b+825|0]=0;p:{if(!i){break p}if(r=(u=$b(a+1074312|0,29),B=1,C=g,C?u:B),s=0,t=!y[i+34|0]&(j^-1),t?r:s){break p}v[b+820|0]=y[i+16|0]}k=64;x[b+764>>2]=64;if(g){k=z[g+32>>1];x[b+764>>2]=k}if(i){x[b+764>>2]=D(x[i+4>>2],k)>>>6}q:{if(!(x[a+480180>>2]&1048580?e:1)){break q}if($b(a+1074312|0,48)){break q}BN(a,b,i,g)}r:{s:{t:{if(!f){break t}u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{f=a+1074312|0;if($b(f,19)){if(x[b+76>>2]){if(!(!c|p)){e=(y[a+480208|0]&8)>>>3|0;if(e){break C}break D}e=0;if(c){break D}break C}c=1;if(j|!x[b+696>>2]){break A}c=(y[b+89|0]&8)>>>3|0;break A}e=1;E:{if(!d|!(x[a+480180>>2]&17301536)|(!x[b+76>>2]|y[a+480208|0]&8)){break E}e=0;if(!(y[b+89|0]&16)){break E}e=!x[b+696>>2]}if(j|(!i|!(x[a+480180>>2]&17301536))){break B}if(!e){break x}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break z}break v}if(d){break C}if(!(y[b+89|0]&24)){e=0;break C}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break B}if(!e){break y}c=(y[b+89|0]&8)>>>3|0;break A}c=1;if(!e){break y}}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break u}if(!c){break v}}Wl(b);break u}if(!i){break w}}if(v[i+60|0]&1){break t}if($b(f,32)){Oi(b+724|0);break t}Wl(b);break t}c=0;if(!g){break s}break r}if(!(y[i+60|0]&8)){Oi(b+724|0)}if(!(y[i+80|0]&8)){Oi(b+736|0)}if(y[i+100|0]&8){break u}Oi(b+748|0)}if($b(f,21)){break t}v[b+838|0]=0;x[b+780>>2]=0}c=0;if(g){break r}if(!i){break s}c=1;if(Ri(i)){break r}}x[b+764>>2]=0;x[b+104>>2]=0;return}F:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){if(x[b+76>>2]?x[a+480180>>2]&16777250:0){break a}G:{H:{if(x[a+480180>>2]!=4){break H}if(!$b(a+1074312|0,40)|y[b+811|0]){break H}e=x[b+88>>2];break G}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break F}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;I:{J:{if(!$b(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break J}break I}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break I}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break F}v[b+724|0]=y[i+60|0];v[b+736|0]=y[i+80|0];v[b+748|0]=y[i+100|0];K:{if((y[i+100|0]&17)!=17){break K}if($b(e,36)|y[b+857|0]){break K}v[b+857|0]=127}if(pv(i)){r=b,s=AC(i),v[r+857|0]=s}if(!xC(i)){break F}r=b,s=yC(i),v[r+858|0]=s}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}L:{if(x[b+76>>2]|!d){break L}c=a+1074312|0;if(!$b(c,54)){if(!$b(c,39)){break L}}x[b+8>>2]=0;x[b+12>>2]=0}M:{if(y[b+810|0]!=255){break M}if(!$b(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break M}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+764>>2]=q;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break a}Nt(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!$b(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if($b(c,21)){v[b+838|0]=0;x[b+780>>2]=0}N:{O:{if(o){x[b+704>>2]=x[g+24>>2];v[b+872|0]=y[b+872|0]|16;d=0;break O}if(!(x[a+480180>>2]&5?m|p:1)){break N}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}x[b+768>>2]=d}if(Bq(a)){d=v[g+36|0]}else{d=0}x[b+772>>2]=d;if(!($b(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+876>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}P:{if(!(h&2)){h=x[b+76>>2];break P}h=x[b+76>>2];c=x[b+84>>2];if(h>>>0<=c>>>0){break P}x[b+76>>2]=c;h=c}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<h>>>0){break a}x[b>>2]=0;x[b+4>>2]=0}}function $G(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=hb-80|0;hb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){af(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;if(!(!nh(v[b+1|0])|y[b+2|0]!=36)){q=v[b+1|0]-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){m:{if(!(!nh(v[o+1|0])|y[o+2|0]!=36)){x[((v[o+1|0]<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=_G(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){o:{if(!(!nh(v[i+2|0])|y[i+3|0]!=36)){x[((v[i+2|0]<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=_G(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+58527|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}ZG(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=1772;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=1772;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+59056|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+1772|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=1772;break z}if(n&2048){q=1;z=1773;break z}q=n&1;z=q?1774:1772}k=kn(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:12945;m=l>>>0>=2147483647?2147483647:l;h=Zw(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;mf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=YG(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}mf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=YG(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}af(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}mf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=mb[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){ZG((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}mf(a,32,h,l,n);af(a,z,q);mf(a,48,h,l,n^65536);mf(a,48,i,m,0);af(a,k,m);mf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[114232]=o}p=-1}hb=j+80|0;return p}function Ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-208|0;hb=d;Nc(b);a:{b:{c:{d:{e:{f:{if(!Eu(b,d+196|0)){break f}if(!tR(d+196|0)){break f}h=ii(d+180|0);i=gd(d+168|0);Sb(d+104|0,0,64);x[114409]=0;f=O(913,b|0,d+96|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+100|0;g=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=(g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24))-4|0;g=g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);e=(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))-8|0;e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;k:{if(c){break k}e=d+96|0;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))!=1413764176){break k}g=1;break g}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[114409]=0;T(316,d+12|0,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));e=x[114409];x[114409]=0;l:{m:{n:{o:{p:{if((e|0)!=1){x[114409]=0;e=S(312,d+12|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break o}if(e){break p}Ab(d+12|0);break l}a=N()|0;break a}e=d+96|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}x[114409]=0;k=O(914,d+12|0,d+104|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}x[114409]=0;O(313,d+12|0,4)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}x[114409]=0;e=O(915,d+12|0,9470)|0;j=x[114409];x[114409]=0;if((j|0)==1){break o}if(!e){break m}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if((e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))>>>0<7){break m}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[114409]=0;Z(916,d+12|0,i|0,2,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))-6|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}break m}x[114409]=0;g=U(917,a|0,d+12|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break m}}a=N()|0;Ab(d+12|0);break a}sR(h,d+12|0)}Ab(d+12|0);x[114409]=0;e=O(913,b|0,d+96|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break j}if(e){continue}}break}if(Yc(i)){x[114409]=0;b=O(2,d+84|0,10398)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}Eb(i,b);xb(b)}if(!(g&k&1)){break h}b=d+146|0;b=y[b|0]|y[b+1|0]<<8;x[114409]=0;c=b&1;U(458,a+1074312|0,5,!c|0)|0;b=x[114409];x[114409]=0;q:{r:{s:{if((b|0)!=1){b=d+142|0;if(y[b|0]|y[b+1|0]<<8){w[d+12>>1]=64;b=y[b|0]|y[b+1|0]<<8;x[114409]=0;w[d+72>>1]=b<<8|b>>>8;b=O(457,d+12|0,d+72|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break s}x[a+480228>>2]=z[b>>1]}b=d+144|0;if(!(!c|!(y[b|0]|y[b+1|0]<<8))){b=y[b|0]|y[b+1|0]<<8;x[a+480204>>2]=D((b<<8|b>>>8)&65535,1e4)}if(y[d+104|0]){x[114409]=0;T(369,d+72|0,2,d+104|0);b=x[114409];x[114409]=0;if((b|0)==1){break r}x[114409]=0;P(370,d+12|0,d+72|0);b=x[114409];x[114409]=0;if((b|0)==1){break r}b=d+12|0;Eb(a+1304400|0,b);xb(b)}b=y[d+150|0]|y[d+151|0]<<8;w[d+70>>1]=b;w[d+10>>1]=b;if(!nq(d+10|0,1,12)){break h}b=y[d+148|0]|y[d+149|0]<<8;w[d+68>>1]=b;w[d+8>>1]=b;if(!nq(d+8|0,1,31)){break h}b=y[d+154|0]|y[d+155|0]<<8;w[d+66>>1]=b;w[d+6>>1]=b;if(!nq(d+6|0,0,23)){break h}b=y[d+156|0]|y[d+157|0]<<8;w[d+64>>1]=b;w[d+4>>1]=b;if(!nq(d+4|0,0,59)){break h}b=y[d+158|0]|y[d+159|0]<<8;w[d+62>>1]=b;w[d+2>>1]=b;if(nq(d+2|0,0,59)){break q}break h}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}b=Hq(d+12|0);c=d+152|0;c=y[c|0]|y[c+1|0]<<8;x[b+20>>2]=(c<<8|c>>>8)&65535;c=d+150|0;c=y[c|0]|y[c+1|0]<<8;x[b+16>>2]=((c<<8|c>>>8)&65535)-1;c=d+148|0;c=y[c|0]|y[c+1|0]<<8;x[b+12>>2]=(c<<8|c>>>8)&65535;c=d+154|0;c=y[c|0]|y[c+1|0]<<8;x[b+8>>2]=(c<<8|c>>>8)&65535;c=d+156|0;c=y[c|0]|y[c+1|0]<<8;x[b+4>>2]=(c<<8|c>>>8)&65535;c=d+158|0;c=y[c|0]|y[c+1|0]<<8;x[b>>2]=(c<<8|c>>>8)&65535;x[114409]=0;P(671,a+1304500|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break h}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}if(g&1){x[114409]=0;b=S(312,h|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break c}if(b){b=Xb(d+12|0);x[114409]=0;U(461,h|0,b|0,32)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}if(RA(b,9572)){x[114409]=0;T(13,d+72|0,2,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=d+72|0;Eb(a+1304412|0,c);xb(c)}x[114409]=0;c=S(918,h|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!c){x[114409]=0;c=S(305,h|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;aa(540,a+1304424|0,h|0,c|0,40,0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}}xb(b)}x[114409]=0;b=O(2,d+72|0,13300)|0;c=x[114409];x[114409]=0;if((c|0)==1){break e}x[114409]=0;T(732,d+12|0,b|0,i|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}c=d+12|0;Eb(a+1304460|0,c);xb(c);xb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[114409]=0;a=a+1074312|0;U(458,a|0,84,1)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;U(458,a|0,83,1)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;O(459,a|0,85)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}}xb(i);Ab(h)}hb=d+208|0;return g&1}a=N()|0;break a}a=N()|0;xb(b);break a}a=N()|0;break a}a=N()|0;xb(b)}xb(i);Ab(h);Q(a|0);p()}function cJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-432|0;hb=e;a:{if(Dj(b)){break a}f=y[yk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Lk(e+184|0,b,x[b+4>>2]-1|0);f=x[e+188>>2];x[b>>2]=x[e+184>>2];x[b+4>>2]=f}f=e+184|0;Gd(f);g=x[e+184>>2];Gd(e+404|0);h=xk(g,x[e+408>>2],b);Gd(f);f=x[b>>2];g=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)==x[e+188>>2]){x[e+424>>2]=f;x[e+428>>2]=g;a=uc(e+416|0,17381);f=x[e+428>>2];x[e+16>>2]=x[e+424>>2];x[e+20>>2]=f;f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;if(Mc(e+16|0,e+8|0)){d=ec(8);x[114409]=0;a=O(2266,e+404|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+184|0,13483,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break i}b=oc(d,e+184|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(e+184|0);xb(a);break c}b=N()|0;break d}if(!d){break k}f=ec(8);x[114409]=0;d=O(2266,e+380|0,b|0)|0;a=x[114409];x[114409]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[114409]=0;T(2242,e+392|0,13519,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break s}x[114409]=0;T(2261,e+404|0,e+392|0,13493);b=x[114409];x[114409]=0;a=1;if((b|0)==1){break r}x[114409]=0;c=O(2266,e+368|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break q}x[114409]=0;T(141,e+184|0,e+404|0,c|0);b=x[114409];x[114409]=0;a=1;if((b|0)==1){break p}a=oc(f,e+184|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(e+184|0);a=0;break o}b=N()|0;break l}b=N()|0;xb(d);break l}b=N()|0;break m}b=N()|0;a=1;break n}b=N()|0}xb(c)}xb(e+404|0)}xb(e+392|0);xb(d);if(!a){break c}}ic(f);break c}x[e+360>>2]=f;x[e+364>>2]=g;d=uc(e+352|0,17381);f=x[e+364>>2];x[e+176>>2]=x[e+360>>2];x[e+180>>2]=f;f=x[d+4>>2];x[e+168>>2]=x[d>>2];x[e+172>>2]=f;if(Mc(e+176|0,e+168|0)){d=ec(8);x[114409]=0;a=O(2266,e+404|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+184|0,13483,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}b=oc(d,e+184|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(e+184|0);xb(a);break c}b=N()|0;break e}d=x[b+4>>2];x[e+344>>2]=x[b>>2];x[e+348>>2]=d;d=uc(e+336|0,8168);f=x[e+348>>2];x[e+160>>2]=x[e+344>>2];x[e+164>>2]=f;f=x[d+4>>2];x[e+152>>2]=x[d>>2];x[e+156>>2]=f;if(Mc(e+160|0,e+152|0)){d=x[c+4>>2];b=x[c>>2];x[e+328>>2]=b;x[e+332>>2]=d;f=uc(e+320|0,2087);g=x[e+332>>2];x[e+64>>2]=x[e+328>>2];x[e+68>>2]=g;g=x[f+4>>2];x[e+56>>2]=x[f>>2];x[e+60>>2]=g;if(Mc(e- -64|0,e+56|0)){x[a+52>>2]=0;break k}x[e+312>>2]=b;x[e+316>>2]=d;f=uc(e+304|0,7165);g=x[e+316>>2];x[e+48>>2]=x[e+312>>2];x[e+52>>2]=g;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;if(Mc(e+48|0,e+40|0)){x[a+52>>2]=1;break k}x[e+296>>2]=b;x[e+300>>2]=d;b=uc(e+288|0,5177);d=x[e+300>>2];x[e+32>>2]=x[e+296>>2];x[e+36>>2]=d;d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Mc(e+32|0,e+24|0)){x[a+52>>2]=2;break k}d=ec(8);x[114409]=0;a=O(2266,e+404|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+184|0,10158,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}b=oc(d,e+184|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(e+184|0);xb(a);break c}b=N()|0;break f}d=x[b+4>>2];x[e+280>>2]=x[b>>2];x[e+284>>2]=d;b=uc(e+272|0,7402);d=x[e+284>>2];x[e+144>>2]=x[e+280>>2];x[e+148>>2]=d;d=x[b+4>>2];x[e+136>>2]=x[b>>2];x[e+140>>2]=d;if(!Mc(e+144|0,e+136|0)){break k}d=x[c+4>>2];c=x[c>>2];x[e+264>>2]=c;x[e+268>>2]=d;b=uc(e+256|0,11631);f=x[e+268>>2];x[e+128>>2]=x[e+264>>2];x[e+132>>2]=f;f=x[b+4>>2];x[e+120>>2]=x[b>>2];x[e+124>>2]=f;b=0;t:{if(Mc(e+128|0,e+120|0)){break t}x[e+248>>2]=c;x[e+252>>2]=d;b=uc(e+240|0,11636);f=x[e+252>>2];x[e+112>>2]=x[e+248>>2];x[e+116>>2]=f;f=x[b+4>>2];x[e+104>>2]=x[b>>2];x[e+108>>2]=f;b=1;if(Mc(e+112|0,e+104|0)){break t}x[e+232>>2]=c;x[e+236>>2]=d;b=uc(e+224|0,8427);f=x[e+236>>2];x[e+96>>2]=x[e+232>>2];x[e+100>>2]=f;f=x[b+4>>2];x[e+88>>2]=x[b>>2];x[e+92>>2]=f;b=2;if(Mc(e+96|0,e+88|0)){break t}x[e+216>>2]=c;x[e+220>>2]=d;b=uc(e+208|0,5241);c=x[e+220>>2];x[e+80>>2]=x[e+216>>2];x[e+84>>2]=c;c=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=c;b=3;if(Mc(e+80|0,e+72|0)){break t}a=ec(8);x[114409]=0;c=O(122,e+184|0,7438)|0;b=x[114409];x[114409]=0;if((b|0)==1){break j}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}x[a+56>>2]=b;b=a+24|0;if(!x[x[b>>2]+24668>>2]){break k}c=x[b>>2];d=c+24664|0;f=x[d+4>>2];x[e+200>>2]=x[d>>2];x[e+204>>2]=f;d=c+24656|0;f=x[d+4>>2];x[e+192>>2]=x[d>>2];x[e+196>>2]=f;d=x[c+24652>>2];x[e+184>>2]=x[c+24648>>2];x[e+188>>2]=d;i=e,j=KI(x[a+56>>2]),x[i+204>>2]=j;if(!Gx(e+184|0,x[b>>2]+24648|0)){break k}zy(x[b>>2],e+184|0)}hb=e+432|0;return}b=N()|0;ic(a);break c}b=N()|0;xb(a);break d}b=N()|0;xb(a);break e}b=N()|0;xb(a)}ic(d);break c}ic(d);break c}ic(d)}Q(b|0)}p()}function SH(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=E(0),k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=E(0),z=0,A=E(0),C=E(0),F=E(0),G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=0,O=0,P=0,Q=0;if((d|0)>0){while(1){v=0;if((c|0)>0){x=D(t,2304)+b|0;m=hb-128|0;while(1){p=x+(v<<2)|0;o=0;k=m;i=k;while(1){j=B[D(31-o|0,72)+p>>2];u=D(o,72)+p|0;h=B[u>>2];n=E(j+h);l=B[u+1152>>2];y=B[D(15-o|0,72)+p>>2];A=E(l+y);B[i>>2]=n+A;u=D(o,12)+45952|0;j=E(B[u+4>>2]*E(h-j));h=E(B[u>>2]*E(y-l));B[i+64>>2]=j+h;l=B[u+8>>2];B[i+32>>2]=l*E(n-A);B[i+96>>2]=l*E(j-h);i=i+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){n=B[k+28>>2];l=B[k>>2];j=E(n+l);y=B[k+16>>2];A=B[k+12>>2];h=E(y+A);C=E(j+h);F=B[k+24>>2];H=B[k+4>>2];I=E(F+H);J=B[k+20>>2];K=B[k+8>>2];L=E(J+K);M=E(I+L);B[k>>2]=C+M;B[k+16>>2]=E(C-M)*E(.7071067690849304);j=E(j-h);h=E(E(j+E(I-L))*E(.7071067690849304));B[k+24>>2]=E(j-h)*E(1.3065630197525024);B[k+8>>2]=E(h+j)*E(.5411961078643799);h=E(H-F);C=E(K-J);F=E(E(h+C)*E(.7071067690849304));j=E(l-n);n=E(F+j);h=E(j+h);l=E(E(E(A-y)+C)+E(h*E(-.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[k+28>>2]=E(n-h)*E(2.562915563583374);B[k+4>>2]=E(h+n)*E(.509795606136322);h=E(l+E(h*E(-.1989123672246933)));j=E(j-F);B[k+20>>2]=E(h+j)*E(.8999761939048767);B[k+12>>2]=E(j-h)*E(.601344883441925);k=k+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;j=B[m+32>>2];h=B[m+96>>2];l=B[m+64>>2];while(1){k=p;B[k>>2]=B[m+(o<<2)>>2];o=o+1|0;i=m+(o<<2)|0;n=B[i+96>>2];y=E(n+h);B[k+72>>2]=y+l;h=B[i+32>>2];B[k+144>>2]=h+j;l=B[i- -64>>2];B[k+216>>2]=y+l;p=k+288|0;j=h;h=n;if((o|0)!=7){continue}break}B[k+288>>2]=B[m+28>>2];j=B[m+124>>2];B[k+360>>2]=j+B[m+92>>2];h=B[m+60>>2];B[k+504>>2]=j;B[k+432>>2]=h;v=v+1|0;if((v|0)!=(c|0)){continue}break}}t=t+1|0;if((t|0)!=(d|0)){continue}break}}G=sc(f,a,3840);if((c|0)>0){O=d<<5;t=0;while(1){m=hb-32|0;hb=m;o=(t<<8)+G|0;v=(t<<2)+b|0;B[o+4080>>2]=B[v+1152>>2];f=d-1|0;u=v+D(f,2304)|0;B[o+4084>>2]=B[u+1152>>2];B[o+4088>>2]=B[v>>2];B[o+4092>>2]=B[u>>2];B[o+4336>>2]=B[v+1156>>2];B[o+4340>>2]=B[u+1156>>2];B[o+4344>>2]=B[v+4>>2];B[o+4348>>2]=B[u+4>>2];x=(D(t,O)<<1)+e|0;z=x+(f<<1)|0;vs(z,d,o+244|0);f=d<<6;vs(f+z|0,d,o+500|0);vs(x,d,o+240|0);vs(f+x|0,d,o+496|0);p=46048;N=o+3840|0;f=14;while(1){k=f;r=k<<4;i=r+N|0;g=D(31-k|0,72);B[i>>2]=B[g+v>>2];B[i+4>>2]=B[g+u>>2];g=g|4;B[i+8>>2]=B[g+v>>2];B[i+12>>2]=B[g+u>>2];g=D(k,72);q=g+76|0;B[i+256>>2]=B[q+v>>2];B[i+260>>2]=B[q+u>>2];g=g+72|0;B[i-248>>2]=B[g+v>>2];B[i-244>>2]=B[g+u>>2];q=k<<2;r=o+r|0;j=B[p+4>>2];h=B[p>>2];f=0;while(1){g=f<<2;n=B[g+i>>2];l=B[g+r>>2];B[g+(m+16|0)>>2]=E(n*h)-E(l*j);B[g+m>>2]=E(l*h)+E(n*j);f=f+1|0;if((f|0)!=4){continue}break}i=(q<<2)+N|0;r=i-3584|0;q=i-256|0;j=B[p+12>>2];h=B[p+8>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(n*j)-E(l*h))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-3328|0;q=i-512|0;j=B[p+20>>2];h=B[p+16>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(l*h)-E(n*j))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-3072|0;q=i-768|0;j=B[p+28>>2];h=B[p+24>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(n*j)-E(l*h))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-2816|0;q=i-1024|0;j=B[p+36>>2];h=B[p+32>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(l*h)-E(n*j))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-2560|0;q=i-1280|0;j=B[p+44>>2];h=B[p+40>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(n*j)-E(l*h))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-2304|0;q=i-1536|0;j=B[p+52>>2];h=B[p+48>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(l*h)-E(n*j))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=i-2048|0;r=i-1792|0;j=B[p+60>>2];h=B[p+56>>2];f=0;while(1){i=f<<2;q=i+m|0;n=B[g+i>>2];l=B[i+r>>2];B[q>>2]=E(E(n*h)+E(l*j))+B[q>>2];i=i+(m+16|0)|0;B[i>>2]=E(E(n*j)-E(l*h))+B[i>>2];f=f+1|0;if((f|0)!=4){continue}break}f=D(15-k|0,d)<<1;P=f+z|0,Q=zi(B[m+20>>2]),w[P>>1]=Q;i=D(k+17|0,d)<<1;P=i+z|0,Q=zi(B[m+4>>2]),w[P>>1]=Q;P=f+x|0,Q=zi(B[m+16>>2]),w[P>>1]=Q;P=i+x|0,Q=zi(B[m>>2]),w[P>>1]=Q;f=D(47-k|0,d)<<1;P=f+z|0,Q=zi(B[m+28>>2]),w[P>>1]=Q;i=D(k+49|0,d)<<1;P=i+z|0,Q=zi(B[m+12>>2]),w[P>>1]=Q;P=f+x|0,Q=zi(B[m+24>>2]),w[P>>1]=Q;P=i+x|0,Q=zi(B[m+8>>2]),w[P>>1]=Q;f=k-1|0;p=p- -64|0;if(k){continue}break}hb=m+32|0;t=t+2|0;if((t|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){t=0;while(1){B[(t<<2)+a>>2]=B[(b+t<<2)+G>>2];c=t>>>0<958;t=t+2|0;if(c){continue}break}break a}sc(a,(b<<2)+G|0,3840)}}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=hb-752|0;hb=d;Nc(b);f=hb-16|0;hb=f;e=f+8|0;h=d+144|0;eQ(e,h);g=Fb(e);e=nc(b,ac(f,e));if((g|0)==(e|0)){cc(b,Fb(f+8|0))}hb=f+16|0;f=(e|0)==(g|0);if(!f){fQ(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!hQ(d+144|0)){break n}if(!Qb(b,id(gQ(d+144|0),lb))){break n}if(!c){o=1;break n}Pd(a,262144);h=d+100|0;Du(h,2,d+144|0);f=d+20|0;Kc(f,h);Eb(a+1304400|0,f);xb(f);e=Vb(f,4522);Eb(a+1304436|0,e);xb(e);f=Vb(f,6106);Eb(a+1304448|0,f);xb(f);e=Vb(d+132|0,10899);x[114409]=0;P(192,h|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break c}v[d+8|0]=y[d+174|0];f=y[d+173|0];x[114409]=0;v[d+119|0]=f;P(1035,d+120|0,d+119|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}f=0;x[114409]=0;W(423,d+20|0,d+100|0,d+8|0,d+120|0);h=x[114409];x[114409]=0;if((h|0)==1){break f}h=d+20|0;Eb(a+1304460|0,h);xb(h);xb(d+120|0);g=d+100|0;Gb(g);xb(e);x[a+480208>>2]=12;x[a+1304496>>2]=4;w[a+480188>>1]=y[d+182|0]|y[d+183|0]<<8;w[d+20>>1]=y[d+178|0]|y[d+179|0]<<8;w[d+100>>1]=3999;B=a,C=z[Gf(h,g)>>1],w[B+480190>>1]=C;TA(Wb(a+484360|0),d+240|0,y[d+176|0]|y[d+177|0]<<8,255,254);if(z[a+480188>>1]){while(1){e=(f<<5)+a|0;Pg(e+480280|0);w[e+480284>>1]=(y[(d+f|0)+208|0]<<4|4)&244;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}Ad(d+100|0,b,D(y[d+178|0]|y[d+179|0]<<8,80));if(z[a+480190>>1]){h=c&2;g=d+68|0;f=0;while(1){x[114409]=0;O(1036,d+100|0,d+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}x[114409]=0;T(576,d+8|0,2,g|0);e=x[114409];x[114409]=0;o:{p:{q:{if((e|0)==1){break q}x[114409]=0;P(370,d+120|0,d+8|0);e=x[114409];x[114409]=0;if((e|0)==1){break q}x[114409]=0;f=f+1|0;O(348,((f<<5)+a|0)+946304|0,d+120|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break p}e=d+120|0;xb(e);x[114409]=0;i=e;e=(D(f,104)+a|0)+484380|0;T(1037,i|0,d+20|0,e|0);i=x[114409];x[114409]=0;r:{if((i|0)==1){break r}if(!h|!x[e>>2]){break o}i=y[d+38|0]|y[d+39|0]<<8|(y[d+40|0]<<16|y[d+41|0]<<24);x[114409]=0;i=O(229,b|0,i|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break r}if(!i){break o}x[114409]=0;U(376,d+120|0,e|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break o}}a=N()|0;break g}a=N()|0;break g}a=N()|0;xb(d+120|0);break g}if(z[a+480190>>1]>f>>>0){continue}break}}o=1;s:{if(!(c&1)){break s}c=y[d+180|0]|y[d+181|0]<<8;x[114409]=0;l=a+484344|0;P(377,l|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break l}if(!(y[d+180|0]|y[d+181|0]<<8)){break s}q=d+24|0;r=d+22|0;s=d+25|0;t=d+23|0;u=d+21|0;f=0;while(1){x[114409]=0;c=U(378,l|0,f&65535,64)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(f<<1)+d|0;e=c+496|0;if(!(y[e|0]|y[e+1|0]<<8)){break t}c=y[c+496|0]|y[c+497|0]<<8;x[114409]=0;c=O(229,b|0,c<<4)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}if(!c){break t}j=0;c=Zb(l,f);x[114409]=0;m=U(451,c|0,0,0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break h}while(1){x[114409]=0;c=O(231,b|0,1)|0;e=x[114409];x[114409]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}x[114409]=0;c=S(425,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}k=c<<24>>24;if(k){break v}j=j+1|0;m=D(z[a+480188>>1],6)+m|0;break u}a=N()|0;break g}a=N()|0;break g}w[q>>1]=0;x[d+20>>2]=0;c=k&31;e=D(c,6)+m|0;i=ei(d+20|0);h=c>>>0<z[a+480188>>1];n=h?e:i;x:{y:{z:{A:{B:{C:{g=k&255;D:{if(!(g&32)){break D}x[114409]=0;P(452,d+120|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break C}i=ed(d+120|0);c=y[d+120|0];v[n|0]=c;v[(h?e+1|0:u)|0]=y[i|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}v[n|0]=c}if(!(g&64)){break x}x[114409]=0;P(452,d+120|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break j}A=ed(d+120|0);g=h?e+3|0:t;c=y[d+120|0];v[g|0]=c;i=h?e+5|0:s;v[i|0]=y[A|0];if(c>>>0>15){break B}x[114409]=0;V(573,n|0);c=x[114409];x[114409]=0;if((c|0)!=1){break A}a=N()|0;break g}a=N()|0;break g}if(c>>>0>23){break y}c=y[c+23975|0];v[g|0]=c;break z}c=y[g|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}v[g|0]=20;c=y[i|0];x[114409]=0;v[d+8|0]=c>>>3;v[d+119|0]=1;c=O(426,d+8|0,d+119|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){v[i|0]=y[c|0]-1&15|128;break x}a=N()|0;break g}x[114409]=0;v[d+8|0]=64;c=O(431,i|0,d+8|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){v[i|0]=y[c|0]<<1;break x}a=N()|0;break g}v[g|0]=0}if((k|0)>=0){break u}v[(h?e+2|0:r)|0]=1;x[114409]=0;c=S(425,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break i}v[(h?e+4|0:q)|0]=c}if(j>>>0<64){continue}break}}f=f+1|0;if(f>>>0<(y[d+180|0]|y[d+181|0]<<8)>>>0){continue}break}}Ab(d+100|0)}hb=d+752|0;return o|0}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0}Ab(d+100|0);break a}a=N()|0;xb(d+120|0);break d}a=N()|0}Gb(d+100|0);break b}a=N()|0}xb(e)}Q(a|0);p()}function NV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-96|0;hb=e;Nc(b);a:{if(!yB(b,7618)){break a}if(!Xu(b,e+85|0)){break a}if(!AB(e+85|0)){break a}if(!Qb(b,id(zB(e+85|0),lb))){break a}if(!cc(b,y[e+94|0]|y[e+95|0]<<8)){break a}b:{if(!c){break b}Pd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[e+87|0]&31)+1;w[a+480190>>1]=y[e+88|0];Cj(a,1);d=e+40|0;h=Vb(d,4695);Eb(a+1304436|0,h);xb(h);d=Vb(d,3356);Eb(a+1304448|0,d);xb(d);d=Vb(e+60|0,10953);x[114409]=0;P(192,e+72|0,d|0);h=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((h|0)!=1){x[114409]=0;W(398,e+40|0,e+72|0,e+86|0,e+85|0);h=x[114409];x[114409]=0;if((h|0)==1){break o}h=e+40|0;Eb(a+1304460|0,h);xb(h);h=e+72|0;Gb(h);xb(d);x[a+1304496>>2]=4;g=y[e+88|0];d=hb-16|0;hb=d;x[h>>2]=0;x[h+4>>2]=0;x[d+12>>2]=0;Id(h+8|0,d+12|0,d+11|0);if(g){Uq(h,g);wC(h,g,0)}hb=d+16|0;if(z[a+480190>>1]){d=1;g=1;while(1){x[114409]=0;O(399,b|0,e+40|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break k}x[114409]=0;P(400,e+40|0,(D(d,104)+a|0)+484380|0);i=x[114409];x[114409]=0;if((i|0)==1){break k}i=y[e+56|0];f=e+28|0;se(f,h,d-1|0);le(f,(i&3)!=0);g=g+1|0;d=g&65535;if(d>>>0<=z[a+480190>>1]){continue}break}}x[114409]=0;U(401,b|0,a+1304400|0,-1)|0;g=x[114409];x[114409]=0;d=1;if((g|0)!=1){if(z[a+480190>>1]){while(1){x[114409]=0;U(402,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break m}d=d+1|0;if(z[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(z[a+480188>>1]){d=0;while(1){x[114409]=0;g=(d<<5)+a|0;V(403,g+480280|0);i=x[114409];x[114409]=0;if((i|0)==1){break e}x[114409]=0;U(404,b|0,g+480289|0,-1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}}g=y[e+89|0]|y[e+90|0]<<8;d=0;x[114409]=0;i=a+484344|0;P(377,i|0,g|0);g=x[114409];x[114409]=0;if((g|0)!=1){break l}}b=N()|0;break d}b=N()|0;break n}b=N()|0;Gb(e+72|0)}xb(d);break c}b=N()|0;break d}if(y[e+89|0]|y[e+90|0]<<8){while(1){x[114409]=0;g=U(405,b|0,e+40|0,-1)|0;f=x[114409];x[114409]=0;p:{q:{if((f|0)==1){break q}x[114409]=0;f=U(378,i|0,d&65535,64)|0;j=x[114409];x[114409]=0;if((j|0)==1){break q}if((f&g)!=1){break p}g=Zb(i,d);x[114409]=0;O(406,g|0,e+40|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break p}}b=N()|0;break d}d=d+1|0;if(d>>>0<(y[e+89|0]|y[e+90|0]<<8)>>>0){continue}break}}x[114409]=0;f=S(335,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}r:{if(!f){break r}x[114409]=0;d=O(231,b|0,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}if(!d){break r}g=br(e+40|0);x[114409]=0;U(407,b|0,g|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break h}d=Xb(e+28|0);x[114409]=0;P(112,d|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break i}k=e,l=bc(g),x[k+4>>2]=l;k=e,l=dc(g),x[k+24>>2]=l;if(Hb(e+4|0,e+24|0)){while(1){s:{f=v[x[e+4>>2]];if((f|0)<0){k=e,l=nf(d),x[k+16>>2]=l;j=x[rd(e+20|0,e+16|0)>>2];x[114409]=0;Z(408,d|0,j|0,f&127,32)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break s}break i}x[114409]=0;P(111,d|0,f|0);f=x[114409];x[114409]=0;if((f|0)!=1){break s}break i}f=e+4|0;gg(f);if(Hb(f,e+24|0)){continue}break}}x[114409]=0;W(409,e+4|0,4,5,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break i}f=e+4|0;Eb(d,f);xb(f);f=Rb(d);x[114409]=0;f=S(410,f|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break i}j=Cb(d);x[114409]=0;aa(411,a+1304424|0,f|0,j|0,76,0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break i}xb(d);de(g)}d=Wb(a+484360|0);g=y[e+91|0]|y[e+92|0]<<8;x[114409]=0;aa(412,d|0,b|0,g|0,65535,65535)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}t:{u:{v:{w:{if(!(y[e+89|0]|y[e+90|0]<<8)){break w}g=c&1;d=0;while(1){x[114409]=0;f=O(231,b|0,4)|0;j=x[114409];x[114409]=0;x:{if((j|0)!=1){if(f){break x}break w}b=N()|0;break d}x[114409]=0;f=S(413,b|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break u}x[114409]=0;T(316,e+40|0,b|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break t}y:{if(!g){break y}x[114409]=0;f=O(414,i|0,d&65535)|0;j=x[114409];x[114409]=0;if((j|0)==1){break v}if(!f){break y}f=Zb(i,d);x[114409]=0;T(415,f|0,0,e+40|0);f=x[114409];x[114409]=0;if((f|0)==1){break v}}Ab(e+40|0);d=d+1|0;if(d>>>0<(y[e+89|0]|y[e+90|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!z[a+480190>>1])){d=1;while(1){c=d&65535;g=D(c,104)+a|0;i=z[g+484414>>1];f=e+40|0;se(f,h,c-1|0);c=cd(e+28|0,i&1?16:8,1,0,Ib(f)?6:0);x[114409]=0;U(376,c|0,g+484380|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break j}d=d+1|0;if(z[a+480190>>1]>=(d&65535)>>>0){continue}break}}ge(h);break b}b=N()|0;Ab(e+40|0);break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;xb(d);break g}b=N()|0}de(g);break d}b=N()|0;break d}b=N()|0}ge(h)}Q(b|0);p()}d=1}hb=e+96|0;return d|0}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;i=hb-192|0;hb=i;Nc(b);a:{b:{c:{d:{e:{if(!SA(b,i+144|0)){break e}if(!HP(i+144|0)){break e}if(!c){g=1;break e}if(!Qb(b,id(GP(i+144|0),lb))){break e}Pd(a,128);g=i+132|0;Ng(g,2,i+159|0);d=i- -64|0;Kc(d,g);Eb(a+1304400|0,d);xb(d);h=Vb(d,4672);Eb(a+1304436|0,h);xb(h);h=Vb(d,2476);Eb(a+1304448|0,h);xb(h);h=Vb(g,13312);x[114409]=0;T(1077,d|0,h|0,x[(y[i+158|0]<<2)+76124>>2]);d=x[114409];x[114409]=0;if((d|0)==1){break b}d=i- -64|0;Eb(a+1304460|0,d);xb(d);xb(h);x[a+480208>>2]=12;x[a+1304496>>2]=4;Cz(a+1304424|0,b,y[i+191|0]<<5,32,0);t=a,u=te(b),w[t+480190>>1]=u;if(z[a+480190>>1]){g=1;h=1;while(1){f:{if(y[i+158|0]>=52){cB(b,i- -64|0);break f}d=hb-16|0;hb=d;x[d+12>>2]=64;x[d+4>>2]=66;e=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(b,e)){e=zf(b)}j=d+4|0;f=i- -64|0;Gu(j,f);qg(b,x[j>>2],e);Gu(j,f);Sb(x[j>>2]+e|0,0,66-e|0);cc(b,x[d+12>>2]);hb=d+16|0;d=y[i+126|0]|y[i+127|0]<<8;v[i+128|0]=d;v[i+129|0]=d>>>8;v[i+126|0]=171;v[i+127|0]=32}j=hb-32|0;hb=j;d=(D(g,104)+a|0)+484380|0;zd(d,0);f=j+8|0;l=i- -64|0;e=l;$k(f,2,e+32|0);k=j+20|0;Kc(k,f);x[114409]=0;O(350,d+43|0,k|0)|0;f=x[114409];x[114409]=0;g:{if((f|0)!=1){xb(j+20|0);f=e+56|0;k=e+52|0;h:{if((y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0<=(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))>>>0){break h}x[d>>2]=(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))-(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24));f=e+44|0;x[d+12>>2]=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);f=e+48|0;x[j+20>>2]=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);t=d,u=x[Mb(j+20|0,d)>>2],x[t+16>>2]=u;w[d+30>>1]=y[e+60|0];f=e+62|0;x[d+24>>2]=y[f|0]|y[f+1|0]<<8;f=e- -64|0;if(y[f|0]|y[f+1|0]<<8){Lt(d,+((y[f|0]|y[f+1|0]<<8)<<16>>16)*25431315104166665e-22)}e=e+61|0;if(y[e|0]&8){w[d+34>>1]=z[d+34>>1]|8}if(y[e|0]&16){w[d+34>>1]=z[d+34>>1]|16}if(!(y[e|0]&4)){break h}w[d+34>>1]=z[d+34>>1]|1;x[d+12>>2]=x[d+12>>2]>>>1;x[d+16>>2]=x[d+16>>2]>>>1}hb=j+32|0;break g}a=N()|0;xb(j+20|0);Q(a|0);p()}d=i+52|0;Ng(d,2,l);e=i+132|0;Kc(e,d);x[114409]=0;O(348,((g<<5)+a|0)+946304|0,e|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}xb(i+132|0);h=h+1|0;g=h&65535;if(g>>>0<=z[a+480190>>1]){continue}break}}Dq(Wb(a+484360|0),b,256,255,254);g=0;d=te(b);if(d>>>0>=127){break e}w[a+480188>>1]=d+1;d=te(b);r=d+1|0;if(z[a+480188>>1]){while(1){h=(g<<5)+a|0;Pg(h+480280|0);l=h+480284|0;i:{if(y[i+158|0]>=51){e=(te(b)<<4|8)&248;break i}e=g&1?192:64}w[l>>1]=e;g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break}}f=a+484344|0;ig(f,r);g=0;h=0;while(1){e=h&65535;if(!Zg(f,e,64)){break e}h=h+1|0;if(d>>>0>e>>>0){continue}break}if(z[a+480188>>1]){k=0;while(1){j=ei(i- -64|0);l=0;while(1){if(Qb(b,5)){h=0;g=Hf(Zb(f,l),0,k&65535);while(1){m=y[i+158|0];d=hb-16|0;hb=d;q=1;e=te(b);if((e|0)==252){q=te(b);e=te(b)}v[j|0]=(e-1&255)>>>0<60?e+36|0:0;e=d+12|0;qm(e,b);n=ed(e);o=wf(e);s=fi(e);v[j+1|0]=y[e|0];v[d+11|0]=y[n|0]&15;v[d+10|0]=y[n|0]>>>4;v[d+9|0]=y[o|0];v[d+8|0]=y[s|0];FP(d+11|0,d+9|0,m);FP(d+10|0,d+8|0,m);m=y[d+11|0];n=(m|0)!=10;e=y[d+10|0];j:{if(!(n|(e|0)!=10)){v[d+11|0]=0;t=d,u=ll((y[d+8|0]|y[d+9|0]<<8)>>>6|0),v[t+9|0]=u;break j}k:{l:{m:{if(!n){t=d,u=ll(y[d+9|0]<<2),v[t+9|0]=u;break m}if((e|0)==10){t=d,u=ll(y[d+8|0]<<2),v[t+8|0]=u;break j}if((e|0)!=(m|0)){break m}e=0;v[d+10|0]=0;break l}if((e|0)==13){break k}}if((m|0)==13|e){break j}}zh(d+11|0,d+10|0);zh(d+9|0,d+8|0)}e=d+10|0;m=d+8|0;n=d+11|0;o=d+9|0;jy(e,m,n,o);iy(d+6|0,n,o,e,m);v[j+2|0]=y[d+11|0];v[j+4|0]=y[d+9|0];v[j+3|0]=y[d+10|0];v[j+5|0]=y[d+8|0];hb=d+16|0;d=h+q|0;h=d>>>0>64?64-h|0:q;if(h){while(1){e=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);v[g|0]=e;v[g+1|0]=e>>>8;v[g+2|0]=e>>>16;v[g+3|0]=e>>>24;e=y[j+4|0]|y[j+5|0]<<8;v[g+4|0]=e;v[g+5|0]=e>>>8;g=D(z[a+480188>>1],6)+g|0;h=h-1|0;if(h){continue}break}h=d>>>0>=64?64:d;if(d>>>0<=63){continue}}break}l=l+1|0;if((r|0)!=(l|0)){continue}}break}k=k+1|0;if(z[a+480188>>1]>(k&65535)>>>0){continue}break}}g=z[a+480188>>1];d=bu(i+12|0);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=g;x[114409]=0;T(1079,d|0,g|0,0);g=x[114409];x[114409]=0;if((g|0)==1){a=N()|0;ge(d);Q(a|0);p()}x[114409]=0;T(1078,i+32|0,f|0,d|0);h=x[114409];x[114409]=0;g=1;if((h|0)==1){break d}ge(i+32|0);ge(d);if(!(c&2)|!z[a+480190>>1]){break e}h=1;while(1){c=D(h&65535,104)+a|0;Fg(cd(i- -64|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);h=h+1|0;if(z[a+480190>>1]>=(h&65535)>>>0){continue}break}}hb=i+192|0;return g|0}g=N()|0;ge(d);break a}g=N()|0;xb(i+132|0);break a}g=N()|0;xb(h)}Q(g|0);p()}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-192|0;hb=d;Nc(b);a:{if(!SA(b,d+144|0)){break a}if(!YP(d+144|0)){break a}if(!Qb(b,id(XP(d+144|0),lb))){break a}b:{if(!c){break b}Pd(a,256);h=d+16|0;mo(h,2,d+144|0);g=d+48|0;Kc(g,h);Eb(a+1304400|0,g);xb(g);e=Vb(g,11180);Eb(a+1304436|0,e);xb(e);e=Vb(g,6101);Eb(a+1304448|0,e);xb(e);g=Vb(d+132|0,10977);x[114409]=0;P(192,h|0,g|0);e=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){x[114409]=0;P(422,d+120|0,d+175|0);e=x[114409];x[114409]=0;if((e|0)==1){break i}x[114409]=0;W(423,d+48|0,d+16|0,d+174|0,d+120|0);e=x[114409];x[114409]=0;if((e|0)==1){break h}e=d+48|0;Eb(a+1304460|0,e);xb(e);xb(d+120|0);Gb(d+16|0);xb(g);x[a+1304496>>2]=4;Nb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;f=y[d+176|0];if(y[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-D(e,10)}h=(f&255?f:96)&255;e=CN(h);x[a+480196>>2]=h>>>4;x[a+480204>>2]=e;if(y[d+175|0]>10){break e}break d}f=N()|0;break f}f=N()|0;break g}f=N()|0;xb(d+120|0)}Gb(d+16|0)}xb(g);break c}v[d+48|0]=64;q=a,r=y[tc(d+178|0,d+48|0)|0]<<2,x[q+480200>>2]=r}f=0;while(1){e=(f<<5)+a|0;Pg(e+480280|0);w[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){du(b,d+16|0);if(y[d+28|0]!=46?y[d+28|0]:0){break k}j=hb-32|0;hb=j;i=(D(f,104)+a|0)+484380|0;zd(i,0);h=j+8|0;k=d+16|0;$k(h,2,k);e=j+20|0;Kc(e,h);x[114409]=0;O(350,i+43|0,e|0)|0;e=x[114409];x[114409]=0;l:{m:{if((e|0)!=1){h=j+20|0;xb(h);e=k+24|0;x[i+24>>2]=y[e|0]|y[e+1|0]<<8;v[j+20|0]=y[k+22|0];v[j+8|0]=64;q=i,r=y[tc(h,j+8|0)|0]<<2,w[q+30>>1]=r;e=k+16|0;x[i>>2]=y[e|0]|y[e+1|0]<<8;e=k+18|0;x[i+4>>2]=y[e|0]|y[e+1|0]<<8;e=k+20|0;g=y[e|0]|y[e+1|0]<<8;x[i+8>>2]=g;h=x[i>>2];if(h>>>0>1){break m}x[i>>2]=0;break l}a=N()|0;xb(j+20|0);Q(a|0);p()}e=x[i+4>>2];if((g|0)==65535|h>>>0<=e>>>0|e>>>0>=g>>>0){break l}w[i+34>>1]=2;q=i,r=x[Mb(i+8|0,i)>>2],x[q+8>>2]=r}hb=j+32|0;h=d+4|0;$k(h,2,k);e=d+120|0;Kc(e,h);x[114409]=0;O(348,((f<<5)+a|0)+946304|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break j}xb(d+120|0);w[((f<<1)+d|0)+46>>1]=y[d+30|0]|y[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;Dq(Wb(e),b,y[d+175|0]?128:64,65535,65535);e=Wb(e);q=d,r=bc(e),x[q+16>>2]=r;q=d,r=dc(e),x[q+120>>2]=r;if(Hb(d+16|0,d+120|0)){while(1){e=x[d+16>>2];h=z[e>>1];n:{if(!((h|0)!=255&(h|0)!=99)){w[e>>1]=65535;break n}if(h>>>0>63){break k}}e=d+16|0;ke(e);if(Hb(e,d+120|0)){continue}break}}k=c&1;if(k){ig(a+484344|0,y[d+177|0])}if(y[d+177|0]){o=a+484344|0;while(1){o:{p:{if(k){if(Zg(o,m&65535,64)){break p}}f=0;while(1){if((te(b)+2&255)>>>0<=252){cc(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break o}q=d,r=bc(Zb(o,m)),x[q+120>>2]=r;x[d+4>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;q:{r:{s:{t:{u:{v:{e=te(b);switch(e-251|0){case 1:break q;case 0:break t;case 2:break v;default:break u}}v[x[d+120>>2]]=254;break q}g=d+16|0;Sq(g,b);f=y[fc(g,0)|0];i=y[fc(g,1)|0];j=y[fc(g,2)|0];g=254;if((e|0)==254){break s}g=e;if(e>>>0>95){break r}}g=(D(g>>>4|0,12)+(g&15)|0)+37|0}e=g;v[x[d+120>>2]]=e}v[x[d+120>>2]+1|0]=(f&248)>>>3;if(y[x[d+120>>2]+1|0]>=32){v[x[d+120>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){v[x[d+120>>2]+2|0]=1;v[x[d+120>>2]+4|0]=e}v[x[d+120>>2]+3|0]=y[(i&15)+24e3|0];v[x[d+120>>2]+5|0]=j;w:{switch(y[x[d+120>>2]+3|0]-11|0){case 0:g=x[d+120>>2];e=y[g+5|0];if(y[x[d+120>>2]+5|0]&15){v[g+5|0]=e&15;break q}v[g+5|0]=e&240;break q;case 3:e=y[x[d+120>>2]+5|0];v[x[d+120>>2]+5|0]=D(e&240,10)|e&15;x:{if((l|0)!=65535){if(y[x[d+120>>2]+5|0]){break x}v[x[d+120>>2]+3|0]=12;v[x[d+120>>2]+5|0]=l}l=65535}zc(d+4|0,n);break q;case 1:l=y[x[d+120>>2]+5|0];x[d+4>>2]=63;v[x[d+120>>2]+3|0]=0;break q;case 5:if(y[d+175|0]<=20){e=y[x[d+120>>2]+5|0];v[x[d+120>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(y[x[d+120>>2]+5|0]){break q}v[x[d+120>>2]+3|0]=0;break q;case 7:break q;default:break w}}if(y[x[d+120>>2]+5|0]){break q}v[x[d+120>>2]+3|0]=0}Sj(d+120|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break o}Pl(Zb(o,m),lo(Oe(wo(d+16|0,12,l&255),x[d+4>>2])))}m=m+1|0;if(m>>>0<y[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}h=cd(d+16|0,8,1,0,0);while(1){c=D(f,104)+a|0;e=c+484380|0;y:{if(!x[e>>2]|!z[c+484410>>1]){break y}c=z[((f<<1)+d|0)+46>>1];if(c>>>0<4){break y}if(!Tc(b,c<<4)){break y}Fg(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=N()|0;xb(d+120|0)}Q(f|0);p()}f=1}hb=d+192|0;return f|0}function cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-96|0;hb=e;Nc(b);a:{b:{c:{d:{e:{if(!VQ(b,9899)){break e}g=Cq(e+84|0);h=Cq(e+72|0);l=bu(e+60|0);x[114409]=0;P(419,a|0,32768);d=x[114409];x[114409]=0;if((d|0)==1){break b}x[114409]=0;d=O(2,e+48|0,4374)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}Eb(a+1304436|0,d);xb(d);x[114409]=0;d=O(2,e+36|0,2480)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}Eb(a+1304448|0,d);xb(d);x[a+1304496>>2]=2;j=a+484360|0;i=e+32|0;while(1){x[114409]=0;d=O(231,b|0,8)|0;f=x[114409];x[114409]=0;f:{g:{h:{i:{if((f|0)!=1){j:{k:{l:{m:{n:{if(!d){break n}x[114409]=0;d=O(953,b|0,e+28|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break m}if(!d){break n}d=i;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114409]=0;T(316,e+12|0,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24));d=x[114409];x[114409]=0;if((d|0)==1){break l}x[114409]=0;d=S(312,e+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}if(d){break k}Ab(e+12|0)}if(z[a+480188>>1]){break j}d=0;break h}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{d=e+28|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);if((d|0)<=1396788559){if((d|0)<=1346522947){if((d|0)==1129140036){break t}if((d|0)!=1346458708){break p}d=Wb(j);x[114409]=0;f=S(228,e+12|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break g}x[114409]=0;aa(580,d|0,e+12|0,f|0,255,254)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}break f}if((d|0)==1346522948){break r}if((d|0)!=1347175758){break p}x[114409]=0;d=S(228,e+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}if(d>>>0<2){break f}x[114409]=0;m=S(464,e+12|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break f}break g}if((d|0)<=1397507405){if((d|0)==1396788560){break s}if((d|0)!=1396854596){break p}if(qd(h)>>>0>3998){break f}x[114409]=0;f=S(228,e+12|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}d=h;if(!f){break f}break q}if((d|0)==1397507406){break f}if((d|0)!=1397769541){break p}x[114409]=0;d=S(228,e+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}if(d>>>0<2){break f}x[114409]=0;d=S(464,e+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}o=a,q=Md(d,1,255),x[o+480196>>2]=q;break f}if(z[a+480188>>1]){break f}x[114409]=0;d=S(228,e+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}f=0;if(d>>>0<8){break f}while(1){x[114409]=0;k=S(425,e+12|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}x[114409]=0;n=S(425,e+12|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}d=z[a+480188>>1];if(k|n){x[114409]=0;V(403,((d<<5)+a|0)+480280|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}k=z[a+480188>>1];d=k+1|0;w[a+480188>>1]=d;w[((k<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}x[114409]=0;V(403,(((d&65535)<<5)+a|0)+480280|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}d=z[a+480188>>1];w[a+480188>>1]=d+1;w[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break f}d=1;break o}if(z[a+480190>>1]){break f}x[114409]=0;T(954,e+12|0,l|0,a|0);d=x[114409];x[114409]=0;if((d|0)!=1){break f}break g}d=g;if(qd(d)>>>0>=256){break f}}x[114409]=0;P(600,d|0,e+12|0);d=x[114409];x[114409]=0;if((d|0)!=1){break f}break g}d=e+28|0;if(!((y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))&-2139062144)){break f}d=0}Ab(e+12|0);break h}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=Wb(j);x[114409]=0;P(955,b|0,m&65535);b=x[114409];x[114409]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=qd(g);x[114409]=0;P(377,a+484344|0,b&65535);b=x[114409];x[114409]=0;if((b|0)==1){break b}if(!qd(g)){break u}b=0;while(1){d=wc(g,d);x[114409]=0;T(956,d|0,b&65535,a|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}b=b+1|0;d=b&65535;if(qd(g)>>>0>d>>>0){continue}break}}d=1;if(z[a+480190>>1]<2){break h}i=c&2;f=1;b=0;v:{while(1){if(!i|qd(h)>>>0<=b>>>0){break h}w:{c=(D(f,104)+a|0)+484380|0;if(x[c>>2]){d=wc(h,b);x[114409]=0;d=S(228,d|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break w}zc(c,d);d=e+12|0;se(d,l,f-1|0);d=cd(e+28|0,8,1,1,Ib(d)?10:0);j=wc(h,b);x[114409]=0;U(376,d|0,c|0,j|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<z[a+480190>>1]){continue}break h}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ge(l);hd(h);hd(g);break e}a=N()|0;Ab(e+12|0);break a}Ab(e+12|0);continue}}hb=e+96|0;return d|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}ge(l);hd(h);hd(g);Q(a|0);p()}function iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-3040|0;hb=g;Nc(b);f=hb-16|0;hb=f;i=f+8|0;j=g+1086|0;$U(i,j);h=Fb(i);i=nc(b,ac(f,i));if((h|0)==(i|0)){cc(b,Fb(f+8|0))}hb=f+16|0;f=(h|0)==(i|0);if(!f){aV(j)}a:{if(!f){break a}if(!fV(g+1086|0)){break a}if(!c){e=1;break a}if(!Qb(b,id(1024,0))){break a}eV(b,g+560|0);eV(b,g+48|0);while(1){f=d<<2;i=f+(g+560|0)|0;if((y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24))>>>0>16777215){break a}f=f+(g+48|0)|0;l=y[f+1|0]<<8;m=y[f+2|0]<<16|y[f+3|0]<<24;if((y[f|0]|l|m)>>>0<3|(m|(l|y[f|0]))>>>0>4096){break a}if(!dV(b,((y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24))+(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))|0)+2978|0)){break a}d=d+1|0;if((d|0)!=128){continue}break}Pd(a,2);Ni(a);d=g+16|0;e=Vb(d,9640);Eb(a+1304436|0,e);xb(e);e=Vb(d,10297);Eb(a+1304448|0,e);xb(e);d=Vb(d,11576);Eb(a+1304460|0,d);xb(d);x[a+1304496>>2]=4;d=y[g+1086|0];x[a+480204>>2]=143e4;x[a+480196>>2]=d;j=a+484360|0;Pe(Wb(j),y[g+1087|0]);x[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;e=0;while(1){w[((e<<5)+a|0)+480284>>1]=e&1?192:64;e=e+1|0;if((e|0)!=4){continue}break}b:{c:{d:{e:{while(1){e=d+1|0;f=D(e,104)+a|0;i=f+484380|0;zd(i,2);h=g+36|0;Bh(h,1,(D(d,13)+g|0)+1088|0);k=g+16|0;Kc(k,h);x[114409]=0;O(348,((e<<5)+a|0)+946304|0,k|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break e}xb(g+16|0);h=i;d=(g+1086|0)+(d<<4)|0;i=d+422|0;x[h>>2]=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);if((y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24))>>>0<=(y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24))>>>0){x[f+484384>>2]=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);d=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);w[f+484414>>1]=2;x[f+484388>>2]=d}x[f+484404>>2]=8287;d=e;if((d|0)!=32){continue}break}d=0;while(1){e=d+33|0;i=(D(e,104)+a|0)+484380|0;zd(i,2);f=g+36|0;Bh(f,1,(D(d,13)+g|0)+2016|0);h=g+16|0;Kc(h,f);x[114409]=0;O(348,((e<<5)+a|0)+946304|0,h|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}e=g+16|0;xb(e);x[g+24>>2]=0;x[g+16>>2]=0;x[g+20>>2]=0;f=(g+1086|0)+D(d,11)|0;h=y[f+1347|0];n=fc(e,0),o=h,v[n|0]=o;h=y[f+1352|0];n=fc(e,1),o=h,v[n|0]=o;h=y[f+1348|0];n=fc(e,2),o=h,v[n|0]=o;h=y[f+1353|0];n=fc(e,3),o=h,v[n|0]=o;h=y[f+1349|0];n=fc(e,4),o=h,v[n|0]=o;h=y[f+1354|0];n=fc(e,5),o=h,v[n|0]=o;h=y[f+1350|0];n=fc(e,6),o=h,v[n|0]=o;h=y[f+1355|0];n=fc(e,7),o=h,v[n|0]=o;h=y[f+1351|0];n=fc(e,8),o=h,v[n|0]=o;h=y[f+1356|0];n=fc(e,9),o=h,v[n|0]=o;f=y[f+1346|0];n=fc(e,10),o=f,v[n|0]=o;x[g+8>>2]=x[g+24>>2];e=x[g+20>>2];x[g>>2]=x[g+16>>2];x[g+4>>2]=e;fq(i,1,g);d=d+1|0;if((d|0)!=32){continue}break}Qq(Wb(j),g+2784|0,256,255,65535);h=a+484344|0;ig(h,128);m=c&1;f=0;f:{while(1){e=f<<2;d=e+(g+560|0)|0;Tc(b,(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+2978|0);d=e+(g+48|0)|0;Ad(g+16|0,b,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));g:{if(!m){break g}x[114409]=0;d=U(378,h|0,f&65535,64)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}if(!d){break g}d=0;i=Zb(h,f);while(1){x[114409]=0;e=O(231,g+16|0,1)|0;j=x[114409];x[114409]=0;h:{i:{if((j|0)!=1){if(!e){break g}x[114409]=0;e=S(425,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break c}if(e>>>0>12){break i}x[114409]=0;j=U(451,i|0,d|0,e|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break c}x[114409]=0;P(452,g+36|0,g+16|0);k=x[114409];x[114409]=0;if((k|0)==1){break c}k=ed(g+36|0);l=y[g+36|0];e=e>>>0>3;v[j|0]=((l&15)+(e?13:37)|0)+D(l>>>4&7,12);v[j+1|0]=((y[k|0]>>>4|0)+(e?33:1)|0)+(y[g+36|0]>>>3&16);bV(j,y[k|0],e);break h}break c}j=e-32|0;if((j&255)>>>0<=12){x[114409]=0;j=U(451,i|0,d|0,j&65535)|0;k=x[114409];x[114409]=0;if((k|0)==1){break c}x[114409]=0;k=S(425,g+16|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break c}bV(j,k,e>>>0>35);break h}if((e|0)!=64){if((e|0)!=96){break f}if(!d){break g}x[114409]=0;d=U(451,i|0,d-1|0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}v[d+3|0]=14;break g}x[114409]=0;e=S(425,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break c}d=d+e|0}if(d>>>0<64){continue}break}}Ab(g+16|0);f=f+1|0;if((f|0)!=128){continue}break}e=1;if(!(c&2)){break a}d=1;while(1){Fg(cd(g+16|0,8,1,0,1),(D(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=33){continue}break}break a}Ab(g+16|0);e=0;break a}e=N()|0;xb(g+16|0);break b}e=N()|0;xb(g+16|0);break b}e=N()|0;Ab(g+16|0)}Q(e|0);p()}hb=g+3040|0;return e|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb+-64|0;hb=f;a:{b:{if(Qb(c,8)){cc(c,4);while(1){if(AA(c)){break b}m=hb-288|0;hb=m;e=xO(m+6|0);g=hb-352|0;hb=g;h=sc(e,xO(g- -64|0),282);e=0;if(ej(c,9488)){rg(c,4);i=hf(g+48|0,c);x[114409]=0;j=O(1262,i|0,h|0)|0;k=x[114409];x[114409]=0;c:{d:{e:{f:{if((k|0)==1){break f}if(!j){break c}j=y[h+26|0];x[114409]=0;j=O(231,i|0,j|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break f}if(!j){break c}if(!y[h+26|0]){j=0;break e}j=0;while(1){g:{x[114409]=0;k=S(355,i|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break g}v[(e+h|0)+27|0]=k;j=j+k|0;e=e+1|0;if(e>>>0<y[h+26|0]){continue}break e}break}e=N()|0;break d}e=N()|0;break d}e=0;x[114409]=0;k=j&65535;j=O(231,i|0,k|0)|0;l=x[114409];x[114409]=0;h:{if((l|0)==1){break h}if(!j){break c}x[114409]=0;O(313,i|0,k|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}rg(i,yO(h));x[114409]=0;j=S(1263,g+44|0)|0;e=x[114409];x[114409]=0;i:{if((e|0)!=1){e=g- -64|0;wO(e);x[114409]=0;O(1264,i|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}x[114409]=0;w[g+86>>1]=0;w[g+88>>1]=0;U(1265,j|0,g- -64|0,g+91|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}e=y[h+26|0];x[114409]=0;O(313,i|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}e=y[h+26|0];x[114409]=0;l=h+27|0;U(1265,j|0,l|0,e+l|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}x[114409]=0;T(316,g+28|0,i|0,k|0);e=x[114409];x[114409]=0;j:{k:{l:{if((e|0)!=1){x[114409]=0;P(882,g+8|0,g+28|0);e=x[114409];x[114409]=0;if((e|0)==1){break l}x[114409]=0;P(1267,g|0,g+8|0);e=x[114409];x[114409]=0;if((e|0)==1){break k}x[114409]=0;O(1268,j|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}Jc(g+8|0);Ab(g+28|0);e=0;x[114409]=0;j=S(1269,j|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break i}if((j|0)!=(y[h+22|0]|y[h+23|0]<<8|(y[h+24|0]<<16|y[h+25|0]<<24))){break c}e=yO(h);x[114409]=0;O(313,c|0,e|0)|0;h=x[114409];x[114409]=0;e=1;if((h|0)!=1){break c}break h}e=N()|0;break d}e=N()|0;break j}e=N()|0;Jc(g+8|0)}Ab(g+28|0);break d}e=N()|0;break d}e=N()|0;break d}e=N()|0}Ab(i);Q(e|0);p()}Ab(i)}hb=g+352|0;hb=m+288|0;if(e){continue}break}}Nc(c);Fg(b,a,c);a=1;break a}v[d|0]=1;Nc(c);d=Kf(c);e=f+48|0;Ad(e,c,zf(c));w[a+34>>1]=z[a+34>>1]&65534|y[b|0]>15;b=y[b+1|0]!=1;c=z[a+34>>1]&-65|b<<6;w[a+34>>1]=c;x[a>>2]=d>>>(c&1)>>>b;x[114409]=0;x[f+44>>2]=0;x[f+40>>2]=0;P(882,f+20|0,e|0);b=x[114409];x[114409]=0;m:{n:{o:{p:{if((b|0)!=1){x[114409]=0;b=S(445,f+20|0)|0;c=x[114409];x[114409]=0;q:{if((c|0)!=1){c=x[f+20>>2];x[114409]=0;d=S(879,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}x[114409]=0;e=S(880,c|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}x[114409]=0;d=aa(881,d|0,e|0,f+44|0,f+40|0,0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}x[114409]=0;O(313,f+48|0,x[f+44>>2])|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}if(!d){break m}e=x[f+44>>2];x[114409]=0;S(438,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}g=c-e|0;e=b+e|0;c=x[f+40>>2];b=0;while(1){r:{if(c){if(!g|(c|0)!=1){break p}if(A[a>>2]>b>>>0){break r}break p}if(A[a>>2]<=b>>>0){break p}}if(!He(a)){break p}x[114409]=0;x[f+16>>2]=0;x[f+12>>2]=0;c=S(879,e|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break o}x[114409]=0;h=S(880,g|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break o}x[114409]=0;c=ga(883,d|0,c|0,h|0,f+16|0,f+8|0,f+12|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break o}x[114409]=0;x[f+44>>2]=c;O(313,f+48|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break o}c=x[a>>2];x[114409]=0;h=x[f+44>>2];c=S(884,c-b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break o}Fh(f+12|0,c);s:{if(x[f+12>>2]<=0){break s}if(x[f+16>>2]!=(Qe(a)|0)){break s}c=0;if(x[f+16>>2]<=0){break s}while(1){i=x[a+20>>2];n=z[a+34>>1];j=D(Qe(a),b);m=x[x[f+8>>2]+(c<<2)>>2];k=x[f+12>>2];l=x[f+16>>2];t:{if(n&1){x[114409]=0;ba(885,i+(j<<1)|0,m|0,l|0,k|0,c|0);i=x[114409];x[114409]=0;if((i|0)!=1){break t}break o}x[114409]=0;ba(886,i+j|0,m|0,l|0,k|0,c|0);i=x[114409];x[114409]=0;if((i|0)==1){break o}}c=c+1|0;if((c|0)<x[f+16>>2]){continue}break}}x[114409]=0;i=x[f+12>>2];c=S(887,d|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break o}g=g-h|0;e=e+h|0;x[f+40>>2]=c;b=b+i|0;continue}}break o}break o}c=N()|0;break n}x[114409]=0;V(888,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){break m}}c=N()|0;Jc(f+20|0)}Ab(f+48|0);Q(c|0);p()}Jc(f+20|0);Ab(f+48|0);a=(d|0)!=0}hb=f- -64|0;return a|0}function wd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=hb-96|0;hb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;A=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;lf(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;lf(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=sqa(v,e,c,0);e=lb;z=e;M=f;q=b;b=sqa(f,0,b,0);i=b+s|0;f=lb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=sqa(q,l,v,l);p=j+b|0;f=i;e=f+lb|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=sqa(v,l,d,0);P=lb;b=sqa(L,l,M,l);y=b+w|0;j=lb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=sqa(B,0,q,l);C=d+y|0;f=lb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=sqa(v,l,F,n);Q=lb;d=sqa(O,m,M,l);H=d+A|0;e=lb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=sqa(I,0,q,l);J=b+H|0;f=lb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=sqa(B,m,L,l);z=b+J|0;K=f;f=f+lb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;q=b+g|0;e=c+z|0;v=b>>>0>q>>>0?e+1|0:e;f=v;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=sqa(I,m,L,l);h=lb;e=sqa(F,m,M,l);g=e+d|0;f=lb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=sqa(B,m,O,m);d=e+g|0;f=lb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=sqa(I,m,F,m);h=h+g|0;f=lb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=sqa(B,m,F,m);l=lb;d=sqa(I,m,O,m);h=d+e|0;f=lb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;lf(k+48|0,p,r,b,c,f);lf(k+32|0,d,e,h,i,f);Fl(k+16|0,p,r,b,c,g);Fl(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;hb=k+96|0}function Xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-320|0;hb=d;Nc(b);a:{if(!Eu(b,d+308|0)){break a}if(!bU(d+308|0)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){cc(b,4)}if(!Mf(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}if(!c){f=1;break a}j=d+304|0;sV(b,d+108|0,y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24));k=d+144|0;if((y[k|0]|y[k+1|0]<<8)>>>0>128){break a}h=d+150|0;if((y[h|0]|y[h+1|0]<<8)>>>0>16){break a}e=d+148|0;if((y[e|0]|y[e+1|0]<<8)>>>0>256){break a}l=d+142|0;if((y[l|0]|y[l+1|0]<<8)>>>0>128){break a}Pd(a,8192);i=d+28|0;e=Vb(i,2868);Eb(a+1304436|0,e);xb(e);e=Vb(i,6122);Eb(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;e=d+92|0;Du(e,2,d+108|0);Kc(i,e);Eb(a+1304400|0,i);xb(i);w[d+28>>1]=y[h|0]|y[h+1|0]<<8;w[d+92>>1]=1;q=a,r=z[jj(i,e)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+28|0]=y[d+152|0];v[d+92|0]=64;e=y[tc(i,e)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=d+153|0;b:{if(y[e|0]==128){x[d+28>>2]=256/z[a+480188>>1];x[d+92>>2]=128;g=x[Mb(d+28|0,d+92|0)>>2];break b}g=y[e|0]&127}x[a+480228>>2]=g;while(1){h=(f<<5)+a|0;Pg(h+480280|0);e=(d+f|0)+156|0;if(y[e|0]<=128){w[h+480284>>1]=y[e|0]<<1}f=f+1|0;if((f|0)!=16){continue}break}e=a+484360|0;Uj(Wb(e),d+172|0,y[k|0]|y[k+1|0]<<8,255,254);if((y[l|0]|y[l+1|0]<<8)>>>0<(y[k|0]|y[k+1|0]<<8)>>>0){Pe(Wb(e),y[l|0]|y[l+1|0]<<8)}f=1;if(!Mf(b,d+300|0)){break a}i=c&2;n=a+484344|0;k=c&1;l=d- -64|0;while(1){Ad(d+92|0,b,y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24));c:{d:{e:{if(!(!k|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[114409]=0;h=o&65535;e=U(378,n|0,h|0,64)|0;c=x[114409];x[114409]=0;if((c|0)==1){break e}if(!e){break c}x[114409]=0;O(313,d+92|0,2)|0;c=x[114409];x[114409]=0;if((c|0)==1){break e}di(d+28|0);m=0;f:{while(1){x[114409]=0;e=O(231,d+92|0,1)|0;c=x[114409];x[114409]=0;g:{h:{if((c|0)!=1){if(!(e&m>>>0<64)){break f}x[114409]=0;e=S(425,d+92|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break h}g=e<<24>>24;if(g){break g}m=m+1|0;continue}b=N()|0;break d}b=N()|0;break d}f=d+28|0;i:{j:{k:{e=g&15;l:{if(e>>>0<z[a+480188>>1]){c=Zb(n,h);x[114409]=0;f=U(451,c|0,m|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break l}}m:{if((g|0)>=0){break m}x[114409]=0;e=S(425,d+92|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break k}if(!e){break m}v[f|0]=e>>>0<109?e+12|0:e}g=g&255;if(!(g&64)){break i}x[114409]=0;e=S(425,d+92|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break j}}b=N()|0;break d}b=N()|0;break d}v[f+1|0]=e}n:{o:{p:{q:{r:{s:{t:{u:{if(g&32){v[f+2|0]=1;x[114409]=0;e=S(425,d+92|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break u}x[114409]=0;v[d+16|0]=e;v[d+4|0]=64;e=O(431,d+16|0,d+4|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break t}v[f+4|0]=y[e|0]}if(!(g&16)){continue}x[114409]=0;P(452,d+16|0,d+92|0);c=x[114409];x[114409]=0;if((c|0)==1){break s}c=d+16|0;g=c;e=ed(c);c=y[c|0];switch(c-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}c=c&15;break o}v[g|0]=33;v[e|0]=145;c=y[g|0];break n}if(c>>>0<17){break n}c=(c&240)==32?9:-1}v[g|0]=c}v[f+3|0]=c;v[f+5|0]=y[e|0];x[114409]=0;V(573,f|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}b=N()|0;break d}o=o+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}if(!ho(a)){break c}e=z[a+480190>>1]+1|0;w[a+480190>>1]=e;x[114409]=0;O(574,d+92|0,d+28|0)|0;c=x[114409];x[114409]=0;v:{w:{x:{if((c|0)==1){break x}x[114409]=0;e=(D(e&65535,104)+a|0)+484380|0;P(575,d+28|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break x}x[114409]=0;T(576,d+4|0,2,l|0);c=x[114409];x[114409]=0;if((c|0)==1){break w}x[114409]=0;P(370,d+16|0,d+4|0);c=x[114409];x[114409]=0;if((c|0)==1){break w}c=z[a+480190>>1];x[114409]=0;O(348,((c<<5)+a|0)+946304|0,d+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break v}xb(d+16|0);if(!i){break c}x[114409]=0;P(577,d+16|0,d+28|0);c=x[114409];x[114409]=0;if((c|0)!=1){x[114409]=0;U(376,d+16|0,e|0,d+92|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break c}}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;xb(d+16|0);break d}b=N()|0}Ab(d+92|0);Q(b|0);p()}Ab(d+92|0);f=1;if(Mf(b,d+300|0)){continue}break}}hb=d+320|0;return f|0}function Afa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;g=hb-96|0;hb=g;Nc(c);a:{b:{if(!Qb(c,4)){break b}c:{while(1){d:{d=g+76|0;h=hb-16|0;hb=h;e:{if(Qb(c,3)){f=h+8|0;cv(f,d);Cd(c,f);break e}i=hb-16|0;hb=i;f=0;j=hb-16|0;hb=j;while(1){qf(d+f|0);f=f+1|0;if((f|0)!=3){continue}break}hb=j+16|0;hb=i+16|0}hb=h+16|0;f:{if(!dd(d,10611,3)){d=g+32|0;h=hb-16|0;hb=h;g:{if(Qb(c,7)){f=h+8|0;rB(f,d);Cd(c,f);break g}i=hb-16|0;hb=i;f=0;j=hb-16|0;hb=j;while(1){qf(d+f|0);f=f+1|0;if((f|0)!=7){continue}break}hb=j+16|0;hb=i+16|0}hb=h+16|0;h=3;d=0;while(1){f=v[(g+32|0)+h|0];if((f|0)<0){break c}d=f&255|d<<7;h=h+1|0;if((h|0)!=7){continue}break}cc(c,d);break f}h:{if(dd(g+76|0,9929,3)){break h}if(!CR(c,9398)){break h}cc(c,Kf(c)+16|0);break f}if(!dd(g+76|0,25740,3)){break f}if(!dd(g+76|0,25744,3)){break f}if(y[g+76|0]){break d}rg(c,2)}if(Qb(c,4)){continue}break b}break}if(rP(g+76|0)){break b}}h=0;break a}Nc(c);d=g+76|0;IA(d,c);j=x[d>>2];x[114409]=0;c=S(445,d|0)|0;d=x[114409];x[114409]=0;i:{j:{k:{l:{if((d|0)!=1){x[114409]=0;c=S(879,c|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break l}}c=N()|0;break k}f=hb-16|0;hb=f;d=g- -64|0;x[d>>2]=0;x[d+4>>2]=0;x[114409]=0;x[f+12>>2]=0;U(331,d+8|0,f+12|0,f+11|0)|0;h=x[114409];x[114409]=0;m:{if((h|0)!=1){hb=f+16|0;break m}R(0)|0;zb();p()}l=d;x[114409]=0;d=$(1308)|0;f=x[114409];x[114409]=0;n:{o:{p:{q:{r:{if((f|0)!=1){x[g+60>>2]=d;Sb(x[g+60>>2],0,6668);d=x[g+60>>2];x[114409]=0;V(1309,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[g+48>>2]=0;x[g+52>>2]=0;x[g+40>>2]=0;x[g+44>>2]=0;x[114409]=0;x[g+32>>2]=0;x[g+36>>2]=0;n=O(1310,g+20|0,2304)|0;d=x[114409];x[114409]=0;if((d|0)!=1){f=0;d=0;while(1){s:{h=x[g+60>>2];x[114409]=0;i=cg(432,j,m);k=x[114409];x[114409]=0;if((k|0)==1){break s}k=x[n>>2];x[114409]=0;o=aa(1311,h|0,c|0,i|0,k|0,g+32|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break s}if((o|0)<0){break q}h=x[g+32>>2];if((h|0)<0|!h){break q}i=x[g+44>>2];if((i|0)!=(f|0)?f:0){break q}h=x[g+40>>2];if((h|0)!=(d|0)?d:0){break q}if(h-3>>>0<4294967294|(i|0)<=0){break r}x[114409]=0;x[g>>2]=0;d=cg(432,j,m);f=x[114409];x[114409]=0;t:{u:{v:{if((f|0)==1){break v}x[114409]=0;x[g+16>>2]=d;d=U(1312,g+32|0,g|0,g+16|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break v}d=x[d>>2];x[114409]=0;x[g>>2]=0;f=cg(432,j,m);k=x[114409];x[114409]=0;if((k|0)==1){break u}x[114409]=0;x[g+16>>2]=f;f=U(1312,g+32|0,g|0,g+16|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break u}k=x[f>>2];q=k>>31;if(!o){break t}t=g,u=dc(l),x[t>>2]=u;f=rd(g+12|0,g);r=x[n>>2];s=x[n>>2];f=x[f>>2];x[114409]=0;Z(1313,l|0,f|0,r|0,(D(h,o)<<1)+s|0)|0;f=x[114409];x[114409]=0;if((f|0)!=1){break t}c=R(74984)|0;if((ib|0)!=(ca(74984)|0)){break p}Y(c|0)|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;d=h;f=i;if((c|0)!=1){break q}c=N()|0;break p}c=N()|0;break p}c=N()|0;break p}if((rc(l)>>>0)/(h>>>0)>>>0>268435456){break r}c=c+d|0;f=i;d=h;m=m-(q+(j>>>0<k>>>0)|0)|0;j=j-k|0;if(!!j&(m|0)>=0|(m|0)>0){continue}break q}break}c=N()|0;break p}c=N()|0;break o}c=N()|0;break o}c=N()|0;break n}d=h;f=i}h=0;if(!f|!d){break i}if(kd(l)){break i}if((rc(l)>>>0)/(d>>>0)>>>0>268435456){break i}x[114409]=0;O(1314,a|0,b|0)|0;c=x[114409];x[114409]=0;w:{x:{if((c|0)==1){break x}y:{z:{A:{if(!e){x[114409]=0;h=O(122,g|0,17381)|0;c=x[114409];x[114409]=0;if((c|0)==1){break A}x[114409]=0;O(348,((b<<5)+a|0)+946304|0,h|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break z}xb(h);x[114409]=0;c=D(b,104)+a|0;P(472,c+484380|0,0);h=x[114409];x[114409]=0;if((h|0)==1){break x}x[c+484404>>2]=f}f=D(b,104)+a|0;c=f+484380|0;t=c,u=(rc(l)>>>0)/(d>>>0)|0,x[t>>2]=u;h=f+484414|0;f=z[h>>1];w[h>>1]=(d|0)==2?f|65:f&65470|1;x[114409]=0;S(438,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break x}if(He(c)){d=bc(l);f=dc(l);b=x[(D(b,104)+a|0)+484400>>2];x[114409]=0;U(1315,d|0,f|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break x}}if(!e){break y}break j}c=N()|0;break p}c=N()|0;xb(h);break p}b=x[a+480180>>2];x[114409]=0;T(1316,c|0,32,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break w}x[114409]=0;T(1317,c|0,a|0,0);a=x[114409];x[114409]=0;if((a|0)!=1){break j}}c=N()|0;break p}c=N()|0}ar(n)}kg(g+60|0)}ar(l)}Jc(g+76|0);Q(c|0);p()}h=He(c)}ar(n);kg(g+60|0);ar(l);Jc(g+76|0)}hb=g+96|0;return h|0}function tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0),i=0,j=0,k=0;d=hb-288|0;hb=d;e=-1;a:{b:{c:{if(!xu(x[x[b>>2]-12>>2]+b|0)){b=vl(d+184|0,b);x[114409]=0;e=O(694,d+172|0,9753)|0;g=x[114409];x[114409]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((g|0)!=1){x[114409]=0;x[d+152>>2]=83886084;x[d+156>>2]=0;T(695,b|0,e|0,d+152|0);g=x[114409];x[114409]=0;if((g|0)==1){break F}Gb(e);x[114409]=0;v[d+171|0]=0;e=O(694,d+152|0,10280)|0;g=x[114409];x[114409]=0;if((g|0)==1){break E}x[114409]=0;U(696,b|0,d+171|0,e|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break D}Gb(e);x[114409]=0;g=y[d+171|0];e=O(694,d+140|0,11796)|0;f=x[114409];x[114409]=0;if((f|0)==1){break C}x[114409]=0;g=g?0:c;W(1720,b|0,a+40|0,e|0,g|0);c=x[114409];x[114409]=0;if((c|0)==1){break B}Gb(e);x[114409]=0;w[d+138>>1]=65535;c=O(694,d+124|0,11558)|0;e=x[114409];x[114409]=0;if((e|0)==1){break A}x[114409]=0;U(1237,b|0,d+138|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break z}Gb(c);x[114409]=0;w[d+122>>1]=0;c=O(694,d+108|0,11195)|0;e=x[114409];x[114409]=0;if((e|0)==1){break y}x[114409]=0;U(1237,b|0,d+122|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break x}Gb(c);w[a>>1]=z[d+122>>1];x[114409]=0;c=O(694,d+96|0,10696)|0;e=x[114409];x[114409]=0;if((e|0)==1){break w}x[114409]=0;W(1721,b|0,a+52|0,c|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break v}Gb(c);x[114409]=0;c=O(694,d+84|0,10582)|0;e=x[114409];x[114409]=0;if((e|0)==1){break u}x[114409]=0;U(1672,b|0,a+36|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break t}Gb(c);x[114409]=0;e=O(694,d+72|0,11560)|0;c=x[114409];x[114409]=0;if((c|0)==1){break s}x[114409]=0;c=a+4|0;Z(1722,b|0,c|0,e|0,1723)|0;g=x[114409];x[114409]=0;if((g|0)==1){break r}Gb(e);x[114409]=0;e=O(694,d+60|0,11197)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}x[114409]=0;g=a+28|0;U(1724,b|0,g|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break p}Gb(e);x[114409]=0;e=O(694,d+48|0,10797)|0;f=x[114409];x[114409]=0;if((f|0)==1){break o}x[114409]=0;U(1724,b|0,a+30|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break n}Gb(e);x[114409]=0;e=O(694,d+36|0,10606)|0;f=x[114409];x[114409]=0;if((f|0)==1){break m}x[114409]=0;U(1725,b|0,a+32|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break l}Gb(e);x[114409]=0;w[d+34>>1]=0;e=O(694,d+20|0,10549)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}x[114409]=0;U(1237,b|0,d+34|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break k}Gb(e);h=B[a+32>>2];x[114409]=0;h=E(db(1726,E(h)));e=x[114409];x[114409]=0;if((e|0)==1){break b}B[a+32>>2]=h;e=-1;j=d,k=bc(c),x[j+16>>2]=k;j=d,k=dc(c),x[j+12>>2]=k;if(Hb(d+16|0,d+12|0)){while(1){f=d+16|0;je(f);if(Hb(f,d+12|0)){continue}break}}if(x[b>>2]&1073741824|(z[g>>1]+300&65535)>>>0>600){break d}f=z[a>>1];if(f>>>0>3|(f|0)==2|w[a+30>>1]<0){break d}f=x[a+36>>2];x[114409]=0;f=S(884,f|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break j}x[114409]=0;x[d+16>>2]=f;x[d+12>>2]=0;f=U(1312,d+16|0,d+12|0,35976)|0;i=x[114409];x[114409]=0;if((i|0)==1){break i}x[a+36>>2]=x[f>>2];if(Lb(c)>>>0>32767){break d}switch(z[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;break a}if(w[d+34>>1]<=0){break d}w[d+10>>1]=z[a+30>>1];B[d+16>>2]=B[a+32>>2];c=z[a+28>>1];x[114409]=0;w[d+12>>1]=c;w[d+14>>1]=(c+z[d+34>>1]|0)-1;a=Z(1727,a|0,d+10|0,d+16|0,d+12|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){if(a){break e}break d}a=N()|0;break a}if(w[d+34>>1]<=0){break d}B[d+16>>2]=B[a+32>>2];f=z[a+28>>1];x[114409]=0;w[d+12>>1]=f;w[d+14>>1]=(f+z[d+34>>1]|0)-1;a=aa(1728,a|0,c|0,d+16|0,d+12|0,g|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){if(a){break e}break d}a=N()|0;break a}x[114409]=0;V(1729,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}}e=1}Ig(b)}hb=d+288|0;return e|0}a=N()|0;break a}a=N()|0}Ig(b);Q(a|0);p()}function mba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);d=hb-112|0;hb=d;h=-1;a:{b:{c:{d:{if(!Nf(x[x[b>>2]-12>>2]+b|0)){break d}Af(d+96|0,b);e=x[d+104>>2];f=x[d+108>>2];i=d+88|0;Cm(i);sk(b,i,8);if((y[d+88|0]|y[d+89|0]<<8|(y[d+90|0]<<16|y[d+91|0]<<24))!=1414681667|(y[d+92|0]|y[d+93|0]<<8|(y[d+94|0]<<16|y[d+95|0]<<24))!=776101705){a=_g(d+72|0,e,f);c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;tj(b,d);break d}w[d+70>>1]=0;Ef(b,d+70|0);if((z[d+70>>1]-4&65535)>>>0<65534){break d}e=d+62|0;Cm(e);sk(b,e,8);if((y[d+62|0]|y[d+63|0]<<8|(y[d+64|0]<<16|y[d+65|0]<<24))!=1933333571|(y[d+66|0]|y[d+67|0]<<8|(y[d+68|0]<<16|y[d+69|0]<<24))!=1111389030){break d}w[d+60>>1]=0;Ef(b,d+60|0);e=z[d+60>>1];if((e-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{k:{if(e>>>0<=3){e=Xb(d+96|0);x[114409]=0;f=U(734,b|0,e|0,65535)|0;i=x[114409];x[114409]=0;if((i|0)==1){break b}if(!f){break j}x[114409]=0;T(13,d+48|0,c|0,e|0);f=x[114409];x[114409]=0;if((f|0)!=1){break k}break b}e=Xb(d+96|0);x[114409]=0;f=U(736,b|0,e|0,255)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}if(!f){break i}x[114409]=0;T(13,d+48|0,c|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break c}}f=d+48|0;Eb(a+40|0,f);xb(f);xb(e);w[d+46>>1]=0;Ef(b,d+46|0);w[d+44>>1]=0;Ef(b,d+44|0);w[a>>1]=z[d+44>>1];w[d+42>>1]=0;l:{if(w[d+60>>1]<=3){x[d+96>>2]=0;Xi(b,d+96|0);e=x[d+96>>2];if(e>>>0>65535){break d}e=$A(e);w[d+42>>1]=e;break l}Ef(b,d+42|0);e=z[d+42>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Xb(d+96|0);x[114409]=0;w[d+24>>1]=0;O(1732,b|0,d+24|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break g}q:{if(w[d+60>>1]<=3){x[114409]=0;g=U(734,b|0,e|0,65535)|0;j=x[114409];x[114409]=0;if((j|0)==1){break g}if(g){break q}break e}x[114409]=0;g=U(736,b|0,e|0,255)|0;j=x[114409];x[114409]=0;if((j|0)==1){break g}if(!g){break e}}x[114409]=0;T(13,d+48|0,c|0,e|0);g=x[114409];x[114409]=0;if((g|0)==1){break p}x[114409]=0;g=O(1733,i|0,d+24|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break o}j=g;g=d+48|0;Eb(j,g);xb(g);xb(e);f=f+1|0;if(z[d+42>>1]>(f&65535)>>>0){continue}break}}c=d+48|0;Cm(c);sk(b,c,8);if((y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24))!=1933333571|(y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(w[d+70>>1]>2){break n}if(_K(b,c)){break m}break d}b=N()|0;break f}b=N()|0;xb(d+48|0);break f}if(!ZK(b,c)){break d}}c=a+4|0;k=d,l=bc(c),x[k+96>>2]=l;k=d,l=dc(c),x[k+24>>2]=l;if(Hb(d+96|0,d+24|0)){while(1){e=d+96|0;je(e);if(Hb(e,d+24|0)){continue}break}}e=a+16|0;r:{if(w[d+70>>1]<=2){if(_K(b,e)){break r}break d}if(!ZK(b,e)){break d}}e=a+16|0;k=d,l=bc(e),x[k+96>>2]=l;k=d,l=dc(e),x[k+24>>2]=l;if(Hb(d+96|0,d+24|0)){while(1){f=d+96|0;je(f);if(Hb(f,d+24|0)){continue}break}}k=a,l=Lb(e),x[k+36>>2]=l;w[d+40>>1]=0;Ef(b,d+40|0);e=z[d+40>>1];w[a+28>>1]=e;if((e-201&65535)>>>0<65135){break d}w[d+38>>1]=0;Ef(b,d+38|0);e=w[d+38>>1];w[a+30>>1]=e;if((e|0)<0){break d}x[d+32>>2]=0;Ap(b,d+32|0);k=a,m=$K(B[d+32>>2]),B[k+32>>2]=m;e=d+24|0;Cm(e);sk(b,e,8);if((y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24))!=1414681667|(y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24))!=776298313){break d}if(Lb(c)>>>0>32767){break d}b=z[a>>1];if(!(b?w[a+30>>1]>0&B[a+32>>2]>E(0):1)){break d}s:{switch(b-1|0){case 0:case 2:if(Lb(c)>>>0<w[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=x[a+36>>2];if(e){b=e-1|0;x[a+36>>2]=b}k=d,l=hu(b),x[k+96>>2]=l;x[d+20>>2]=0;k=a,l=x[gl(d+96|0,d+20|0,35976)>>2],x[k+36>>2]=l;Bp(a);h=1;if(z[a>>1]!=3){break d}if((dL(Lb(c))|0)<(w[a+30>>1]-w[a+28>>1]|0)){break d}e=Ck(d+96|0);h=0;if(w[a+30>>1]>0){while(1){b=Pb(c,h-w[a+28>>1]|0);x[114409]=0;P(1734,e|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<w[a+30>>1]){continue}break}}b=z[a+28>>1];w[d+20>>1]=b;c=Lb(c);x[114409]=0;w[d+22>>1]=(b+c|0)-1;w[d+18>>1]=0;aa(1728,a|0,e|0,a+32|0,d+20|0,d+18|0)|0;a=x[114409];x[114409]=0;h=1;if((a|0)!=1){lg(e);break d}break h}xb(e);break d}xb(e);break d}b=N()|0;lg(e);break a}b=N()|0}xb(e);break a}xb(e)}hb=d+112|0;return h|0}b=N()|0;xb(e);break a}b=N()|0;xb(e)}Q(b|0);p()}function gJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-400|0;hb=e;v[e+399|0]=c;a:{if(Dj(b)){break a}f=y[yk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Lk(e+160|0,b,x[b+4>>2]-1|0);f=x[e+164>>2];x[b>>2]=x[e+160>>2];x[b+4>>2]=f}f=e+160|0;Gd(f);g=x[e+160>>2];Gd(e+364|0);h=xk(g,x[e+368>>2],b);Gd(f);f=x[b>>2];g=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+164>>2]){x[e+384>>2]=f;x[e+388>>2]=g;a=uc(e+376|0,17381);c=x[e+388>>2];x[e+8>>2]=x[e+384>>2];x[e+12>>2]=c;c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Mc(e+8|0,e)){a=ec(8);x[114409]=0;P(2265,e+364|0,e+399|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+160|0,13483,e+364|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}a=oc(a,e+160|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(e+160|0);xb(e+364|0);break c}b=N()|0;break d}if(!d){break h}d=ec(8);x[114409]=0;a=O(2266,e+340|0,b|0)|0;b=x[114409];x[114409]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[114409]=0;T(2242,e+352|0,13519,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break p}x[114409]=0;T(2261,e+364|0,e+352|0,13493);b=x[114409];x[114409]=0;c=1;if((b|0)==1){break o}x[114409]=0;P(2265,e+328|0,e+399|0);b=x[114409];x[114409]=0;if((b|0)==1){break n}x[114409]=0;T(141,e+160|0,e+364|0,e+328|0);b=x[114409];x[114409]=0;if((b|0)==1){break m}b=oc(d,e+160|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(e+160|0);c=0;break l}b=N()|0;break i}b=N()|0;xb(a);break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}xb(e+328|0)}xb(e+364|0)}xb(e+352|0);xb(a);if(!c){break c}}ic(d);break c}x[e+320>>2]=f;x[e+324>>2]=g;d=uc(e+312|0,17381);f=x[e+324>>2];x[e+152>>2]=x[e+320>>2];x[e+156>>2]=f;f=x[d+4>>2];x[e+144>>2]=x[d>>2];x[e+148>>2]=f;if(Mc(e+152|0,e+144|0)){a=ec(8);x[114409]=0;P(2265,e+364|0,e+399|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+160|0,13483,e+364|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}a=oc(a,e+160|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(e+160|0);xb(e+364|0);break c}b=N()|0;break e}d=x[b+4>>2];x[e+304>>2]=x[b>>2];x[e+308>>2]=d;d=uc(e+296|0,3674);f=x[e+308>>2];x[e+136>>2]=x[e+304>>2];x[e+140>>2]=f;f=x[d+4>>2];x[e+128>>2]=x[d>>2];x[e+132>>2]=f;q:{if(!Mc(e+136|0,e+128|0)){d=x[b+4>>2];x[e+288>>2]=x[b>>2];x[e+292>>2]=d;d=uc(e+280|0,3656);f=x[e+292>>2];x[e+120>>2]=x[e+288>>2];x[e+124>>2]=f;f=x[d+4>>2];x[e+112>>2]=x[d>>2];x[e+116>>2]=f;if(!Mc(e+120|0,e+112|0)){break q}}v[a+60|0]=c;break h}d=x[b+4>>2];x[e+272>>2]=x[b>>2];x[e+276>>2]=d;d=uc(e+264|0,3240);f=x[e+276>>2];x[e+104>>2]=x[e+272>>2];x[e+108>>2]=f;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;r:{if(!Mc(e+104|0,e+96|0)){d=x[b+4>>2];x[e+256>>2]=x[b>>2];x[e+260>>2]=d;d=uc(e+248|0,3221);f=x[e+260>>2];x[e+88>>2]=x[e+256>>2];x[e+92>>2]=f;f=x[d+4>>2];x[e+80>>2]=x[d>>2];x[e+84>>2]=f;if(!Mc(e+88|0,e+80|0)){break r}}v[a+61|0]=c;break h}d=x[b+4>>2];x[e+240>>2]=x[b>>2];x[e+244>>2]=d;d=uc(e+232|0,3324);f=x[e+244>>2];x[e+72>>2]=x[e+240>>2];x[e+76>>2]=f;f=x[d+4>>2];x[e+64>>2]=x[d>>2];x[e+68>>2]=f;if(Mc(e+72|0,e- -64|0)){v[a+62|0]=c;break h}d=x[b+4>>2];x[e+224>>2]=x[b>>2];x[e+228>>2]=d;d=uc(e+216|0,2484);f=x[e+228>>2];x[e+56>>2]=x[e+224>>2];x[e+60>>2]=f;f=x[d+4>>2];x[e+48>>2]=x[d>>2];x[e+52>>2]=f;if(Mc(e+56|0,e+48|0)){v[a+63|0]=c;break h}d=x[b+4>>2];x[e+208>>2]=x[b>>2];x[e+212>>2]=d;d=uc(e+200|0,3723);f=x[e+212>>2];x[e+40>>2]=x[e+208>>2];x[e+44>>2]=f;f=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=f;if(Mc(e+40|0,e+32|0)){v[a+64|0]=c;break h}d=x[b+4>>2];x[e+192>>2]=x[b>>2];x[e+196>>2]=d;b=uc(e+184|0,9235);d=x[e+196>>2];x[e+24>>2]=x[e+192>>2];x[e+28>>2]=d;d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Mc(e+24|0,e+16|0)){break h}d=a+24|0;b=x[d>>2];f=b+24664|0;g=x[f+4>>2];x[e+176>>2]=x[f>>2];x[e+180>>2]=g;f=b+24656|0;g=x[f+4>>2];x[e+168>>2]=x[f>>2];x[e+172>>2]=g;f=x[b+24652>>2];x[e+160>>2]=x[b+24648>>2];x[e+164>>2]=f;if(c){a=KI(x[a+56>>2])}else{a=0}x[e+180>>2]=a;if(!Gx(e+160|0,x[d>>2]+24648|0)){break h}zy(x[d>>2],e+160|0)}hb=e+400|0;return}b=N()|0;xb(e+364|0);break d}b=N()|0;xb(e+364|0)}ic(a);break c}ic(a)}Q(b|0)}p()}function cF(){var a=0,b=0,c=0,d=0,e=0,f=0;if(y[461008]){return x[115251]}b=Fd(462648);x[b>>2]=65144;x[114409]=0;c=O(2663,b+8|0,30)|0;a=x[114409];x[114409]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[114409]=0;d=O(122,b+152|0,9986)|0;a=x[114409];x[114409]=0;if((a|0)==1){break e}Lb(c);jF(c);sg(c);e=Fd(462320),f=67732,x[e>>2]=f;x[114409]=0;P(2664,b|0,462320);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462328),f=67764,x[e>>2]=f;x[114409]=0;P(2665,b|0,462328);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;_E();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2667,b|0,462336);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462352),f=66680,x[e>>2]=f;x[114409]=0;P(2668,b|0,462352);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462360),f=66828,x[e>>2]=f;x[114409]=0;P(2669,b|0,462360);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;X(2670);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2671,b|0,462368);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462384),f=66976,x[e>>2]=f;x[114409]=0;P(2672,b|0,462384);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462392),f=67208,x[e>>2]=f;x[114409]=0;P(2673,b|0,462392);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462400),f=67092,x[e>>2]=f;x[114409]=0;P(2674,b|0,462400);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462408),f=67324,x[e>>2]=f;x[114409]=0;P(2675,b|0,462408);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;X(2676);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2677,b|0,462416);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;X(2678);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2679,b|0,462440);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462472),f=67796,x[e>>2]=f;x[114409]=0;P(2680,b|0,462472);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462480),f=68040,x[e>>2]=f;x[114409]=0;P(2681,b|0,462480);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462488),f=68252,x[e>>2]=f;x[114409]=0;P(2682,b|0,462488);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462496),f=68484,x[e>>2]=f;x[114409]=0;P(2683,b|0,462496);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;iF();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2685,b|0,462504);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462512),f=69616,x[e>>2]=f;x[114409]=0;P(2686,b|0,462512);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462520),f=69732,x[e>>2]=f;x[114409]=0;P(2687,b|0,462520);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462528),f=69848,x[e>>2]=f;x[114409]=0;P(2688,b|0,462528);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;hF();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2690,b|0,462536);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;gF();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2692,b|0,462544);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;fF();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2694,b|0,462552);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;eF();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2696,b|0,462560);a=x[114409];x[114409]=0;if((a|0)==1){break d}a=Fd(462568);x[a+8>>2]=71712;x[a>>2]=68684;x[a+8>>2]=68732;x[114409]=0;P(2697,b|0,462568);a=x[114409];x[114409]=0;if((a|0)==1){break d}a=Fd(462584);x[a+8>>2]=71748;x[a>>2]=68948;x[a+8>>2]=68996;x[114409]=0;P(2698,b|0,462584);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;X(2699);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2700,b|0,462600);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;X(2701);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2702,b|0,462616);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;dF();a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(2704,b|0,462632);a=x[114409];x[114409]=0;if((a|0)==1){break d}e=Fd(462640),f=70740,x[e>>2]=f;x[114409]=0;P(2705,b|0,462640);b=x[114409];x[114409]=0;if((b|0)==1){break d}break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;xb(d)}mF(c)}Q(b|0);p()}x[115250]=462648;v[461008]=1;x[115251]=461e3;return 461e3}function yN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=hb-16|0;hb=h;a:{if(!be(d&255)){break a}j=(D(b,896)+a|0)+1074984|0;b:{if(!(!(x[a+480180>>2]&17825824)|!z[a+480192>>1]|e)){break b}if(Ej(j)){break b}c=D(b,896)+a|0;d=c+1075060|0;if(!x[d>>2]){break a}c=x[c+1075072>>2];if(c&1024){break a}e=D(b,896)+a|0;g=e+1075004|0;e=e+1075008|0;if(!(x[g>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1304392|0;if(!yd(c)){break c}Pi(x[c>>2],b,0);break a}c=Wy(a,b);if((c|0)==65535){break a}k=D(c,896);c=a+1074984|0;a=k+c|0;Qp(a,j);v[a+851|0]=0;v[a+827|0]=0;w[a+808>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;au(a+810|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,896)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[e>>2]=0;break a}e=D(b,896)+a|0;l=x[e+1075088>>2];c=z[a+480192>>1]>=c>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}i=d-1|0;c=z[fd(g+236|0,i)>>1];m=h+8|0;f=a+1074312|0;Kb(m,f,104);e:{if(Ib(m)){Kb(h,f,34);if(Ib(h)){break e}}d=y[fc(g+108|0,i)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}c=h+8|0;Kb(c,f,43);if(!Ib(c)){break d}if(!Ri(g)){break a}}if(y[e+1075073|0]&4){break a}if(b>>>0<=255){i=a+1304392|0;m=a+1074312|0;p=b+1|0;c=b;while(1){f=(b|0)==(c|0);f:{if(!f&z[a+480188>>1]>c>>>0){break f}e=D(c,896)+a|0;if(!f&z[e+1075792>>1]!=(p|0)){break f}o=e+1075640|0;f=x[o>>2];if(!f){break f}n=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(y[f+17|0]-1|0){case 0:if(!d){break f}k=(f|0)==(g|0)&y[e+1075803|0]==(d|0);if(!g){break l}if(k){break i}break f;case 1:if(!l|x[e+1075088>>2]!=(l|0)){break f}if((f|0)==(g|0)){break g}f=h+8|0;Kb(f,m,104);if(!Ib(f)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}k=(f|0)==(g|0)}if(k){break g}break f}if(!g){break f}k=y[g+34|0];if(!k){break f}if((k|0)==y[f+34|0]){break h}break f}if((f|0)!=(g|0)){break f}}if(!y[g+34|0]){break g}}if(!y[e+1075803|0]|y[f+18|0]>2){break g}f=h+8|0;Kb(f,m,34);Vl(a,c&65535,jP(n,Ib(f))+255|0,0);v[e+1075806|0]=0}n:{o:{switch(y[x[o>>2]+18|0]){case 0:Fn(a,n);x[e+1075672>>2]=0;if(!(y[e+1075073|0]&2)){break n}if(!yd(i)){break n}Pi(x[i>>2],c&65535,1);break n;case 1:Fn(a,n);if(!(y[e+1075073|0]&2)){break n}if(!yd(i)){break n}Ok(x[i>>2],c&65535);break n;case 2:break o;default:break n}}n=e+1075072|0;f=x[n>>2];x[n>>2]=f|4096;if(!(f&512)){break n}if(!yd(i)){break n}f=h+8|0;Kb(f,m,105);if(Ib(f)){break n}Ok(x[i>>2],c&65535)}if(x[e+1075672>>2]){break f}x[e+1075680>>2]=0;e=e+1075072|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;c=0;p:{if(!Ej(j)){break p}c=0;if(!be(y[(D(b,896)+a|0)+1075803|0])){break p}d=Ul(a,b,2,1);c=0;if((d-1&255)>>>0>249){break p}e=x[(D(d,160)+a|0)+906140>>2];if(!e){e=0;c=0;break p}c=h+8|0;Kb(c,a+1074312|0,34);c=(r=e,s=jP(j,Ib(c)),t=b,q=x[x[e>>2]+96>>2],mb[q](r|0,s|0,t|0)|0)}if(!(Zh(j)|c)){break a}g=Wy(a,b);if((g|0)==65535){break a}f=D(g,896)+a|0;d=f+1075072|0;i=f+1074984|0;q:{if(!(y[f+1075073|0]&2)){break q}l=a+1304392|0;if(!yd(l)){break q}Pi(x[l>>2],g,1)}Qp(i,j);x[d>>2]=x[d>>2]&-917505;v[f+1075835|0]=0;l=z[a+480188>>1];v[f+1075811|0]=0;w[f+1075792>>1]=b>>>0<l>>>0?b+1|0:0;r:{if(!e|c^1){break r}c=y[(D(b,896)+a|0)+1075804|0];if(c>>>0>3|(c|0)==1){break r}Vl(a,b,255,0);v[(D(b,896)+a|0)+1075806|0]=0}s:{t:{switch(y[(D(b,896)+a|0)+1075804|0]){case 2:Fn(a,i);if(!(y[d+1|0]&2)){break s}c=a+1304392|0;if(!yd(c)){break s}Ok(x[c>>2],b);e=h+8|0;Kb(e,a+1074312|0,105);if(!Ib(e)){break s}mz(x[c>>2],b,g);break s;case 0:x[(D(g,896)+a|0)+1075680>>2]=0;c=x[d>>2];x[d>>2]=c|4096;if(!(c&512)){break s}c=a+1304392|0;if(!yd(c)){break s}Pi(x[c>>2],b,1);break s;case 3:c=x[d>>2];x[d>>2]=c|4096;if(!(c&512)){break s}c=a+1304392|0;if(!yd(c)){break s}e=h+8|0;Kb(e,a+1074312|0,105);e=Ib(e);c=x[c>>2];if(e){mz(c,b,g);break s}Ok(c,b);break s;case 1:break t;default:break s}}if(!(y[d+1|0]&2)){break s}c=a+1304392|0;if(!yd(c)){break s}mz(x[c>>2],b,g)}if(!x[(D(g,896)+a|0)+1075672>>2]){x[(D(g,896)+a|0)+1075680>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,896)+a|0;x[a+1075060>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075076|0;x[a>>2]=0;x[a+4>>2]=0}hb=h+16|0}function yM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;a:{b:{c:{if(!be(c)|(!d|x[b+480180>>2]!=16777216)|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[h+14>>1]=c-61;b=hb+-64|0;hb=b;e=w[d+28>>1];f=h+14|0;c=w[f>>1];g=d+4|0;Lb(g);d:{e:{if((c|0)>=(e|0)){if((c|0)<=(z[d+28>>1]+Lb(g)|0)-1<<16>>16){break e}}gd(a);break d}f:{c=w[d+30>>1];if(!c){c=d+52|0;m=b,n=Zx(c,f),x[m+44>>2]=n;m=b,n=Zi(c),x[m+32>>2]=n;if(!Yi(b+44|0,b+32|0)){break f}Zf(a,vh(b+44|0)+4|0);break d}e=w[f>>1];g:{if((e|0)>=0){c=(e|0)%(c|0)|0;break g}c=c+((e^-1)%(c|0)^-1)|0}w[b+62>>1]=c;c=gd(a);x[114409]=0;a=d+52|0;e=O(1714,a|0,b+62|0)|0;g=x[114409];x[114409]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}x[b+56>>2]=e;a=Zi(a);x[114409]=0;x[b+44>>2]=a;a=O(1715,b+56|0,b+44|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}if(a){x[114409]=0;a=S(1716,b+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break x}x[114409]=0;O(210,c|0,a+4|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break x}a=w[d+30>>1];d=w[f>>1];y:{if((d|0)>=0){a=(d|0)/(a|0)|0;break y}a=((d+1|0)/(a|0)|0)-1|0}x[114409]=0;x[b+32>>2]=a+5;P(207,b+44|0,b+32|0);a=x[114409];x[114409]=0;z:{if((a|0)!=1){x[114409]=0;O(164,c|0,b+44|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break z}xb(b+44|0);break d}a=N()|0;break h}a=N()|0;xb(b+44|0);break h}if(w[d+30>>1]>26){break u}x[114409]=0;e=U(820,b+32|0,1,y[b+62|0]+65<<24>>24)|0;a=x[114409];x[114409]=0;if((a|0)==1){break w}x[114409]=0;T(13,b+44|0,0,e|0);a=x[114409];x[114409]=0;if((a|0)==1){break v}a=b+44|0;Eb(c,a);xb(a);xb(e);x[114409]=0;O(208,c|0,10181)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break t}}a=N()|0;break h}a=N()|0;break h}a=N()|0;xb(e);break h}x[114409]=0;x[b+28>>2]=w[b+62>>1]%16;P(1717,b+32|0,b+28|0);a=x[114409];x[114409]=0;if((a|0)==1){break s}x[114409]=0;x[b+12>>2]=(w[b+62>>1]/16<<16>>16)%16;P(1717,b+16|0,b+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break r}x[114409]=0;T(3,b+44|0,b+32|0,b+16|0);a=x[114409];x[114409]=0;if((a|0)==1){break q}a=b+44|0;Eb(c,a);xb(a);xb(b+16|0);xb(b+32|0);if(w[b+62>>1]<256){break t}x[114409]=0;T(9,b|0,0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break o}x[114409]=0;P(1718,b+32|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break n}x[114409]=0;T(13,b+44|0,0,b+32|0);a=x[114409];x[114409]=0;if((a|0)==1){break m}a=b+44|0;Eb(c,a);xb(a);xb(b+32|0);xb(b)}a=w[d+30>>1];d=w[f>>1];if((d|0)<0){break k}a=(d|0)/(a|0)|0;break j}a=N()|0;break h}a=N()|0;break p}a=N()|0;xb(b+16|0)}xb(b+32|0);break h}a=N()|0;break h}a=N()|0;break l}a=N()|0;xb(b+32|0)}xb(b);break h}a=((d+1|0)/(a|0)|0)-1|0}x[114409]=0;x[b+16>>2]=a+5;P(207,b+44|0,b+16|0);a=x[114409];x[114409]=0;A:{if((a|0)!=1){x[114409]=0;O(164,c|0,b+44|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break A}xb(b+44|0);break d}a=N()|0;break h}a=N()|0;xb(b+44|0);break h}a=N()|0}xb(c);break a}j=hb-16|0;hb=j;d=hb-16|0;hb=d;g=d+4|0;e=hb-144|0;hb=e;c=qh(e+8|0);i=x[x[c>>2]-12>>2];x[114409]=0;k=$(125)|0;l=x[114409];x[114409]=0;B:{C:{if((l|0)==1){break C}x[114409]=0;T(126,e+4|0,c+i|0,k|0);i=x[114409];x[114409]=0;if((i|0)==1){break C}Ob(e+4|0);x[114409]=0;P(134,c|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break C}x[114409]=0;P(128,g|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break C}ae(c);hb=e+144|0;break B}a=N()|0;ae(c);break a}x[114409]=0;T(13,a|0,0,g|0);a=x[114409];x[114409]=0;D:{if((a|0)!=1){xb(d+4|0);hb=d+16|0;break D}a=N()|0;xb(d+4|0);break a}hb=j+16|0}hb=b- -64|0;break b}f=x[b>>2];b=hb-32|0;hb=b;E:{if(AM(c)){x[b+16>>2]=x[6452];d=x[6449];x[b>>2]=x[6448];x[b+4>>2]=d;d=x[6451];x[b+8>>2]=x[6450];x[b+12>>2]=d;Vb(a,(b+(c<<2)|0)-1004|0);break E}if(be(c)){d=gd(b);x[114409]=0;e=c-1|0;c=(e|0)/12|0;f=O(1529,d|0,f+(e-D(c,12)<<16>>16<<2)|0)|0;e=x[114409];x[114409]=0;F:{if((e|0)==1){break F}x[114409]=0;c=U(1530,f|0,1,c+48<<24>>24)|0;f=x[114409];x[114409]=0;if((f|0)==1){break F}x[114409]=0;O(4,a|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break F}xb(d);break E}a=N()|0;xb(d);break a}if(!c){Vb(a,12704);break E}Vb(a,10152)}hb=b+32|0}hb=h+16|0;return}Q(a|0);p()}function qoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-704|0;hb=l;a:{b:{c:{if(d>>>0<=511){d=0;j=hb-16|0;hb=j;a=hb-16|0;hb=a;i=j+8|0;g=l+30|0;jc(i,g,554);hb=a+16|0;k=Fb(i);a=nc(b,ac(j,i));if((k|0)==(a|0)){cc(b,Fb(j+8|0))}hb=j+16|0;b=(a|0)==(k|0);if(!b){a=hb-16|0;hb=a;Sb(g,0,554);hb=a+16|0}if(!b){break c}a=hb-32|0;hb=a;h=l+30|0;d:{if((y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))!=1229999433){break d}d=a+8|0;qv(d,3,h+32|0);b=a+20|0;Kc(b,d);x[114409]=0;O(348,c+492|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}d=a+20|0;xb(d);b=a+8|0;Bh(b,1,h+4|0);Kc(d,b);x[114409]=0;O(348,c+524|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}xb(a+20|0);b=y[h+24|0]|y[h+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[h+26|0];v[c+17|0]=y[h+27|0];k=c+108|0;d=c+236|0;while(1){b=h+(f<<1)|0;g=y[b- -64|0];b=y[b+65|0];m=fd(d,f),n=b,w[m>>1]=n;m=fc(k,f),n=(g>>>0<120?g:f)+1|0,v[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}v[c+60|0]=y[c+60|0]&254|v[h+17|0]&1;v[c+60|0]=y[c+60|0]&253|y[h+17|0]&2;v[c+60|0]=y[c+60|0]&251|y[h+17|0]&4;i=c+61|0;v[i|0]=y[h+18|0];g=c+62|0;v[g|0]=y[h+19|0];k=c+63|0;v[k|0]=y[h+20|0];d=c- -64|0;v[d|0]=y[h+21|0];e=c+48|0;Qg(e,25);f=0;while(1){e:{b=f<<1;j=y[(h+b|0)+504|0];m=Pb(e,f),n=j,w[m>>1]=n;if((j|0)==255){Qg(e,f);break e}b=y[(h+(b|1)|0)+504|0];m=Pb(e,f),n=b,v[m+2|0]=n;f=f+1|0;if((f|0)!=25){continue}}break}b=y[ah(i,g)|0];if(Lb(e)>>>0<=b>>>0){v[c+60|0]=y[c+60|0]&253}b=y[ah(k,d)|0];if(Lb(e)>>>0>b>>>0){break d}v[c+60|0]=y[c+60|0]&251}hb=a+32|0;d=554;break c}k=x[b+8>>2];i=hb-16|0;hb=i;x[i+12>>2]=674;x[i+4>>2]=674;g=x[Mb(i+12|0,i+4|0)>>2];if(!Qb(b,g)){g=zf(b)}d=i+4|0;e=l+30|0;_S(d,e);qg(b,x[d>>2],g);_S(d,e);Sb(x[d>>2]+g|0,0,674-g|0);cc(b,x[i+12>>2]);hb=i+16|0;i=x[a+480180>>2];a=hb-32|0;hb=a;f:{if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){g=a+8|0;qv(g,3,e+32|0);d=a+20|0;Kc(d,g);x[114409]=0;O(348,c+492|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}g=a+20|0;xb(g);d=a+8|0;Bh(d,1,e+4|0);Kc(g,d);x[114409]=0;O(348,c+524|0,g|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}g=a+20|0;xb(g);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;zc(c+4|0,64);d=y[e+25|0]&127;x[c+8>>2]=d>>>0>64?128:d<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[a+20|0]=y[e+26|0];v[a+8|0]=100;d=a+8|0;m=c,n=y[tc(g,d)|0],v[m+20|0]=n;v[a+20|0]=y[e+27|0];v[a+8|0]=64;m=c,n=y[tc(g,d)|0],v[m+19|0]=n;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];ov(c,y[e+58|0]&127,y[e+58|0]>>>7|0);nv(c,y[e+59|0]&127,y[e+59|0]>>>7|0);g:{h:{i:{d=y[e+28|0]|y[e+29|0]<<8;if(!((d|0)==514|(d|0)==529|(y[e+28|0]|y[e+29|0]<<8)==544)){if((y[e+28|0]|y[e+29|0]<<8)!=532){break i}}if(y[e+61|0]==255){break i}if(y[e+61|0]<=128){v[c+30|0]=y[e+61|0]}f=y[e+62|0]|y[e+63|0]<<8;if(f>>>0<129){break h}break g}if(v[e+61|0]>=0){v[c+30|0]=y[e+61|0]+1}f=v[e+62|0]>=0?y[e+62|0]+1|0:f;if(v[e+63|0]<0){break h}f=(y[e+63|0]<<7)+f|0}w[c+28>>1]=f}d=v[e+60|0];v[c+31|0]=d;if((d|0)<0){v[c+31|0]=0;v[c+34|0]=d^128}f=0;d=i&16777216?240:25;sv(e+304|0,c+48|0,0,d);sv(e+386|0,c+68|0,32,d);sv(e+468|0,c+88|0,32,d);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;i=c+108|0;g=c+236|0;while(1){d=e+(f<<1)|0;j=y[d- -64|0];d=y[d+65|0];m=fd(g,f),n=d,w[m>>1]=n;m=fc(i,f),n=(j>>>0<120?j:f)+1|0,v[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}f=554}hb=a+32|0;a=f;break f}if(a){d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){g=c+236|0;a=0;while(1){f=y[(a+e|0)+554|0];d=fd(g,a);w[d>>1]=z[d>>1]|f<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Tc(b,k+d|0);if(!ej(b,9783)){break c}a=l+12|0;Ad(a,b,Kf(b));x[114409]=0;k=S(228,a|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}x[114409]=0;b=O(628,l+12|0,9587)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}if(b){x[114409]=0;b=S(425,l+12|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}v[c+34|0]=b>>>0<=250?b:0}d=(d+k|0)+8|0;Ab(l+12|0)}hb=l+704|0;return d|0}a=N()|0;Ab(l+12|0);Q(a|0);p()}b=N()|0;xb(a+20|0);Q(b|0);p()}function yH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;h=hb-560|0;hb=h;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;k=g+D(t,-24)|0;n=x[(e<<2)+48416>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){C[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+x[(c<<2)+48432>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=k-24|0;g=0;i=(n|0)>0?n:0;m=(d|0)<=0;while(1){a:{if(m){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(h+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-k|0;r=48-k|0;z=k-25|0;g=n;b:{while(1){f=C[(g<<3)+h>>3];c=0;i=g;o=(g|0)<=0;if(!o){while(1){m=(h+480|0)+(c<<2)|0;l=f*5.960464477539063e-8;c:{if(F(l)<2147483648){j=~~l;break c}j=-2147483648}l=+(j|0);f=l*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[m>>2]=j;i=i-1|0;f=C[(i<<3)+h>>3]+l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=uk(f,q);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){m=~~f;break e}m=-2147483648}f=f-+(m|0);f:{g:{h:{u=(q|0)<=0;i:{if(!u){i=(g<<2)+h|0;j=x[i+476>>2];c=j>>r;s=i;i=j-(c<<r)|0;x[s+476>>2]=i;m=c+m|0;j=i>>y;break i}if(q){break h}j=x[((g<<2)+h|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;i=0;if(!o){while(1){s=(h+480|0)+(c<<2)|0;o=x[s>>2];v=16777215;j:{k:{if(i){break k}v=16777216;if(o){break k}i=0;break j}x[s>>2]=v-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(u){break l}c=8388607;m:{switch(z|0){case 1:c=4194303;break;case 0:break m;default:break l}}o=(g<<2)+h|0;x[o+476>>2]=x[o+476>>2]&c}m=m+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!i){break f}f=f-uk(1,q)}if(f==0){i=0;c=g;n:{if((g|0)<=(n|0)){break n}while(1){c=c-1|0;i=x[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){i=c;c=c+1|0;if(!x[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;C[(h+320|0)+(j<<3)>>3]=x[(t+g<<2)+48432>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(h+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=uk(f,24-k|0);o:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;l=f*5.960464477539063e-8;p:{if(F(l)<2147483648){c=~~l;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(h+480|0)+(g<<2)>>2]=c}f=uk(1,k);r:{if((g|0)<0){break r}d=g;while(1){a=d;C[(d<<3)+h>>3]=f*+x[(h+480|0)+(d<<2)>>2];d=d-1|0;f=f*5.960464477539063e-8;if(a){continue}break}if((g|0)<0){break r}i=g;while(1){f=0;c=0;a=g-i|0;d=(a|0)>(n|0)?n:a;if((d|0)>=0){while(1){f=C[(c<<3)+51200>>3]*C[(c+i<<3)+h>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}}C[(h+160|0)+(a<<3)>>3]=f;a=(i|0)>0;i=i-1|0;if(a){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<=0){break v}f=C[(h+160|0)+(g<<3)>>3];c=g;while(1){l=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;w=C[e>>3];f=w+f;C[d+(c<<3)>>3]=l+(w-f);C[e>>3]=f;d=c>>>0>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=C[(h+160|0)+(g<<3)>>3];c=g;while(1){l=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=l+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;if((g|0)<=1){break v}while(1){p=p+C[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[h+160>>3];if(j){break t}C[b>>3]=f;f=C[h+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(h+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=d-1|0;f=f+C[(h+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[h+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break s}C[b>>3]=-f;f=C[h+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}hb=h+560|0;return m&7}function AJ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=hb-48|0;hb=l;x[l+44>>2]=0;a:{if(!(d|g|h)){k=3;if(!i){break a}}k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}_b(j);x[k>>2]=0}x[114409]=0;X(86);j=x[114409];x[114409]=0;c:{d:{if((j|0)==1){m=Za(74984,82300,82312,82416,75152,75256,75204,75096,75084,75400,75368,75336,75324,74936,0)|0;e:{f:{n=ib;if((n|0)==(ca(74984)|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=277;if((k|0)==1){break f}break c}if((ca(82300)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=358;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(82312)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=359;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(82416)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=357;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75152)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=300;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75256)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=299;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75204)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=298;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75096)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=297;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75084)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=296;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75400)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=289;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75368)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=288;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75336)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=287;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}if((ca(75324)|0)==(n|0)){j=Y(m|0)|0;x[114409]=0;P(2231,k|0,j|0);k=x[114409];x[114409]=0;j=286;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}break e}o=ca(74936)|0;j=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[114409]=0;P(2231,k|0,m|0);k=x[114409];x[114409]=0;j=267;if((k|0)!=1){break c}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break e}break d}j=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break d}}R(0)|0;zb()}p()}Q(j|0);p()}_();m=!g;if(d){k=mb[d|0](j,e)|0}else{k=3}if(!(m|!(k&2))){x[g+16>>2]=j;m=g;g=x[l+44>>2];q=m,r=Ld(g?g:17381),x[q+20>>2]=r}if(h){x[h>>2]=j}if(!i){break a}g=x[l+44>>2];q=i,r=Ld(g?g:17381),x[q>>2]=r}g=x[l+44>>2];if(g){_b(g);x[l+44>>2]=0}g:{if(!(k&1)){break g}x[114409]=0;P(2114,l+32|0,a|0);g=x[114409];x[114409]=0;h:{i:{if((g|0)!=1){j:{if(f){x[114409]=0;P(2115,f|0,l+32|0);g=x[114409];x[114409]=0;if((g|0)!=1){break j}break i}g=Rb(l+32|0);if(b){x[114409]=0;P(b|0,g|0,c|0);g=x[114409];x[114409]=0;if((g|0)==1){break i}break j}Ns(g,l)}xb(l+32|0);break g}g=R(0)|0;break h}g=R(0)|0;xb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+4>>2]=252;x[l>>2]=5145;x[l+8>>2]=a?a:17381;a=x[14644];pH(a,13697,l);nn(a);_()}hb=l+48|0}function Y$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb-48|0;hb=h;x[h+44>>2]=b;x[e>>2]=0;Fc(h,d);x[114409]=0;i=S(2606,h|0)|0;j=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Ob(h);Q(a|0);p()}GF(a,f+24|0,h+44|0,c,e,i);break b}FF(a,f+16|0,h+44|0,c,e,i);break b}g=a;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=rj(g,b,c,d,e,f,Rb(a),Rb(a)+(Cb(a)<<2)|0),x[k+44>>2]=l;break b}a=pi(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[16247];x[h+24>>2]=x[16246];x[h+28>>2]=g;g=x[16245];x[h+16>>2]=x[16244];x[h+20>>2]=g;g=x[16243];x[h+8>>2]=x[16242];x[h+12>>2]=g;g=x[16241];x[h>>2]=x[16240];x[h+4>>2]=g;k=h,l=rj(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[16255];x[h+24>>2]=x[16254];x[h+28>>2]=g;g=x[16253];x[h+16>>2]=x[16252];x[h+20>>2]=g;g=x[16251];x[h+8>>2]=x[16250];x[h+12>>2]=g;g=x[16249];x[h>>2]=x[16248];x[h+4>>2]=g;k=h,l=rj(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=pi(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=pi(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=pi(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=pi(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=pi(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=hb-16|0;hb=b;x[b+12>>2]=c;while(1){H:{if(mh(a,b+12|0)){break H}if(!rk(i,1,Bl(a))){break H}gn(a);continue}break}if(mh(a,b+12|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+44|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(a)|0)==(0-Cb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=Rr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=sc(h,65024,44);k=g,l=rj(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[16272];g=x[16271];x[h+8>>2]=x[16270];x[h+12>>2]=g;g=x[16269];x[h>>2]=x[16268];x[h+4>>2]=g;k=h,l=rj(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=pi(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[16283];x[h+24>>2]=x[16282];x[h+28>>2]=g;g=x[16281];x[h+16>>2]=x[16280];x[h+20>>2]=g;g=x[16279];x[h+8>>2]=x[16278];x[h+12>>2]=g;g=x[16277];x[h>>2]=x[16276];x[h+4>>2]=g;k=h,l=rj(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=pi(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=rj(g,b,c,d,e,f,Rb(a),Rb(a)+(Cb(a)<<2)|0),x[k+44>>2]=l;break b}EF(f+20|0,h+44|0,c,e,i);break b}a=pi(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+12>>2]=c;b=6;c=h+44|0;L:{M:{if(mh(c,a+12|0)){break M}b=4;if((Xm(i,Bl(c))|0)!=37){break M}b=2;if(!mh(gn(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+44>>2]}hb=h+48|0;return a|0}function Jda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+4>>2]=0;x[a>>2]=25872;x[a+8>>2]=x[19559];b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;hq(a+24604|0);UM(a+24648|0,0);b=a+393352|0;x[b>>2]=8;x[b+4>>2]=0;x[b+4104>>2]=0;x[b+4108>>2]=0;w[b+4128>>1]=0;d=b+4120|0;x[d>>2]=0;x[d+4>>2]=0;d=b+4112|0;x[d>>2]=0;x[d+4>>2]=0;Sb(b+4132|0,0,40);nP(b+8|0,1024);Sb(b+4172|0,0,49824);Sb(b+53996|0,0,32832);x[a+480224>>2]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;k=Jk(a+480248|0);x[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{while(1){x[114409]=0;d=S(1473,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break m}c=d+32|0;if((b|0)!=(c|0)){continue}break}d=hb-16|0;hb=d;x[b>>2]=0;x[b+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(1487,b+8|0,d+12|0,d+11|0)|0;c=x[114409];x[114409]=0;n:{if((c|0)!=1){hb=d+16|0;break n}break a}x[b+12>>2]=a;d=b;x[114409]=0;l=O(1474,a+484360|0,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break l}g=a+900380|0;c=a+484380|0;while(1){x[114409]=0;b=O(1056,c|0,0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break k}c=b+104|0;if((g|0)!=(c|0)){continue}break}x[114409]=0;S(1475,a+901404|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break j}h=a+946300|0;i=a+906300|0;c=i;while(1){x[114409]=0;b=S(1476,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}c=b+160|0;if((h|0)!=(c|0)){continue}break}x[a+946300>>2]=0;c=a+1074304|0;j=a+946304|0;b=j;while(1){x[114409]=0;b=S(1215,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}b=b+32|0;if((c|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;gr(a+1074312|0);x[114409]=0;b=$(1477)|0;c=x[114409];x[114409]=0;if((c|0)==1){break g}x[114409]=0;b=S(1478,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break g}x[a+1074328>>2]=b;x[114409]=0;S(1479,a+1074332|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;S(1480,a+1074376|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;m=U(1414,a+1304360|0,a|0,255)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}c=hb-16|0;hb=c;x[114409]=0;b=U(1483,a+1304392|0,c+15|0,c+14|0)|0;e=x[114409];x[114409]=0;o:{if((e|0)!=1){hb=c+16|0;break o}break a}c=b;e=hb-16|0;hb=e;x[114409]=0;b=U(1484,a+1304396|0,e+15|0,e+14|0)|0;f=x[114409];x[114409]=0;p:{if((f|0)!=1){hb=e+16|0;break p}break a}e=b;n=Xb(a+1304400|0);o=gd(a+1304412|0);q=Xb(a+1304424|0);r=SM(a+1304436|0);f=hb-16|0;hb=f;b=a+1304500|0;x[b>>2]=0;x[b+4>>2]=0;x[114409]=0;x[f+12>>2]=0;U(1485,b+8|0,f+12|0,f+11|0)|0;s=x[114409];x[114409]=0;q:{if((s|0)!=1){hb=f+16|0;break q}break a}f=b;v[a+1304512|0]=0;b=a+1304520|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1304560>>2]=0;Lp(a+12|0);jq(a+8204|0);jq(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;RM(g);x[114409]=0;V(1481,j|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=S(1482,12)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;d=hb-16|0;hb=d;x[b>>2]=0;x[b+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(1488,b+8|0,d+12|0,d+11|0)|0;c=x[114409];x[114409]=0;r:{if((c|0)!=1){hb=d+16|0;break r}break a}x[a+4>>2]=b;return a|0}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;break d}b=N()|0;if((c|0)==(i|0)){break d}while(1){c=Kp(c-160|0);if((i|0)!=(c|0)){continue}break}break d}b=N()|0;break e}b=N()|0;break e}b=N()|0;QM(f);My(r);xb(q);xb(o);xb(n);Ly(e);Ky(c);pt(m)}while(1){h=Kp(h-160|0);if((i|0)!=(h|0)){continue}break}}sz(l)}LM(d)}Me(k);Q(b|0);p()}R(0)|0;zb();p()}function kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;f=hb-32|0;hb=f;a:{b:{c:{d:{e:{if(!c){break e}u=f,w=te(a),v[u+24|0]=w;e=f+24|0;f:{if(A[b+4>>2]<A[yb(b)>>2]){i=hb-16|0;hb=i;d=xh(i+4|0,b,1);h=yb(b);k=x[d+4>>2];x[114409]=0;T(904,h|0,k|0,e|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[d+4>>2]=x[d+4>>2]+1;Jb(d);hb=i+16|0;break f}break c}i=hb-32|0;hb=i;h=yb(b);d=ci(i+12|0,bi(b,xc(b)+1|0),xc(b),h);k=x[d+8>>2];x[114409]=0;T(904,h|0,k|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}x[d+8>>2]=x[d+8>>2]+1;x[114409]=0;P(342,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}Dh(d);hb=i+32|0}i=c-1|0;if(i){while(1){g:{h:{c=g<<1&254;i:{if(!c){if(!Ue(a,f+24|0)){break e}e=y[f+24|0]<<1|1;c=e&255;if(e>>>0>255){break i}break h}if((g&65535)>>>0<128){break h}}g=1;while(1){j:{k:{l:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!Ue(a,f+24|0)){break l}c=y[f+24|0]<<1|1;d=c&255;c=c>>>0>255}g=c|g<<1;c=d<<1&254;if(c){break k}if(!Ue(a,f+24|0)){break l}e=y[f+24|0]<<1|1;c=e&255;if(e>>>0>255){continue}break j}c=0;break j}if(d>>>0>127){continue}}break}m:{if((g|0)<=2){j=0;e=g-2|0;break m}if(!Ue(a,f+24|0)){break e}e=(y[f+24|0]|g<<8)-768|0;j=((e|0)>1279?2:1)+((e|0)>31999)|0;q=e^-1;e=0}d=c<<1&254;if(d){c=c>>>0>127}else{if(!Ue(a,f+24|0)){break e}c=y[f+24|0]<<1|1;d=c&255;c=c>>>0>255}g=d<<1&254;if(g){d=d>>>0>127}else{if(!Ue(a,f+24|0)){break e}d=y[f+24|0]<<1|1;g=d&255;d=d>>>0>255}c=d|(e<<2|(c?2:0));if(!c){d=1;while(1){n:{o:{p:{c=g<<1&254;if(c){e=(g&65535)>>>0>127}else{if(!Ue(a,f+24|0)){break p}e=y[f+24|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;g=c<<1&254;if(g){break o}if(!Ue(a,f+24|0)){break p}c=y[f+24|0]<<1|1;g=c&255;if(c>>>0>255){continue}break n}g=0;break n}if(c>>>0>127){continue}}break}c=d+2|0}e=c+j|0;d=0;if(e>>>0>i>>>0|(e|0)<=0|(q|0)>=0){break d}d=0;if((0-xc(b)|0)>(q|0)){break d}u=f,w=dc(b),x[u+24>>2]=w;c=rd(f+28|0,f+24|0);v[f+20|0]=0;m=f+20|0;l=hb-32|0;hb=l;x[l+28>>2]=x[c>>2];c=x[b>>2];u=l,w=bc(b),x[u+8>>2]=w;j=zm(l+28|0,l+8|0)+c|0;q:{r:{s:{if(!e){break s}c=x[yb(b)>>2];d=x[b+4>>2];if(e>>>0<=c-d>>>0){c=e;h=d-j|0;if(h>>>0<e>>>0){Fq(b,e-h|0,m);c=h;if(!c){break s}}r=hb-16|0;hb=r;k=d;t=x[b+4>>2];h=(t-(e+j|0)|0)+j|0;n=xh(r+4|0,b,d-h|0);t:{u:{if(d>>>0>h>>>0){o=x[n+4>>2];d=h;while(1){s=yb(b);x[114409]=0;T(904,s|0,o|0,d|0);s=x[114409];x[114409]=0;if((s|0)==1){break u}o=o+1|0;x[n+4>>2]=o;d=d+1|0;if(k>>>0>d>>>0){continue}break}}Jb(n);qq(j,h,t);hb=r+16|0;break t}a=N()|0;Jb(n);break a}$h(j,c,(j>>>0<=m>>>0?A[b+4>>2]>m>>>0?e:0:0)+m|0);break s}c=yb(b);c=ci(l+8|0,bi(b,xc(b)+e|0),j-x[b>>2]|0,c);x[114409]=0;T(714,c|0,e|0,m|0);d=x[114409];x[114409]=0;if((d|0)==1){break r}x[114409]=0;j=U(901,b|0,c|0,j|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break r}Dh(c)}Rg(j);hb=l+32|0;break q}a=N()|0;Dh(c);break a}u=f,w=dc(b),x[u+16>>2]=w;u=f,w=hA(f+16|0,e),x[u+20>>2]=w;u=f,w=Le(m,q),x[u+24>>2]=w;u=f,w=dc(b),x[u+16>>2]=w;u=f,w=hA(f+16|0,e),x[u+20>>2]=w;c=e;while(1){u=f,w=ex(f+24|0),x[u+16>>2]=w;d=y[x[f+16>>2]];u=f,w=ex(f+20|0),x[u+12>>2]=w;v[x[f+12>>2]]=d;d=c>>>0>1;c=c-1|0;if(d){continue}break}i=i-e|0;break g}if(!Ue(a,f+24|0)){break e}e=f+24|0;v:{if(x[b+4>>2]!=x[yb(b)>>2]){g=hb-16|0;hb=g;d=xh(g+4|0,b,1);h=yb(b);k=x[d+4>>2];x[114409]=0;T(565,h|0,k|0,e|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[d+4>>2]=x[d+4>>2]+1;Jb(d);hb=g+16|0;break v}break c}g=hb-32|0;hb=g;h=yb(b);d=ci(g+12|0,bi(b,xc(b)+1|0),xc(b),h);k=x[d+8>>2];x[114409]=0;T(565,h|0,k|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}x[d+8>>2]=x[d+8>>2]+1;x[114409]=0;P(342,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}Dh(d);hb=g+32|0}g=c;i=i-1|0}if(i){continue}break}}d=1;break d}d=0}hb=f+32|0;return d|0}a=N()|0;Jb(d);break a}a=N()|0;Dh(d)}Q(a|0);p()}function xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;g=hb-976|0;hb=g;Nc(b);d=hb-16|0;hb=d;e=d+8|0;f=g+878|0;LT(e,f);h=Fb(e);e=nc(b,ac(d,e));if((h|0)==(e|0)){cc(b,Fb(d+8|0))}hb=d+16|0;d=(e|0)==(h|0);if(!d){MT(f)}a:{if(!d){break a}if(!PT(g+878|0)){break a}if(!Qb(b,id(OT(g+878|0),lb))){break a}if(!c){k=1;break a}Pd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[g+953|0];x[a+480200>>2]=256;x[a+480204>>2]=8e5;d=g+104|0;e=Vb(d,4429);Eb(a+1304436|0,e);xb(e);e=Vb(d,5033);Eb(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;e=g+32|0;NT(e,2,g+882|0);Kc(d,e);Eb(a+1304400|0,d);xb(d);d=0;while(1){e=(d<<5)+a|0;f=e+480280|0;Pg(f);h=f;f=(g+878|0)+d|0;x[h>>2]=!y[f+50|0]<<10;w[e+480284>>1]=(y[f+76|0]<<4|8)&248;d=d+1|0;if((d|0)!=16){continue}break}if(y[g+974|0]|y[g+975|0]<<8){Cz(a+1304424|0,b,y[g+974|0]|y[g+975|0]<<8,132,0)}d=hb-16|0;hb=d;f=hb-16|0;hb=f;e=d+8|0;h=g+104|0;jc(e,h,771);hb=f+16|0;f=Fb(e);e=nc(b,ac(d,e));if((f|0)==(e|0)){cc(b,Fb(d+8|0))}hb=d+16|0;k=(e|0)==(f|0);if(!k){d=hb-16|0;hb=d;Sb(h,0,771);hb=d+16|0}if(!k){break a}d=a+484360|0;TA(Wb(d),g+104|0,y[g+361|0],255,254);Pe(Wb(d),y[g+362|0]);Tc(b,y[g+925|0]|y[g+926|0]<<8);m=a+484344|0;q=c&1;e=0;b:{c:{while(1){d=(e<<1)+g|0;if(y[d+363|0]|y[d+364|0]<<8){Ad(g+32|0,b,y[d+363|0]|y[d+364|0]<<8);d=y[d+363|0]|y[d+364|0]<<8;h=(d-2|0)/64|0;d:{if(!q){break d}x[114409]=0;f=U(378,m|0,e&65535,h|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break c}if(!f){break d}x[114409]=0;j=S(425,g+32|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}x[114409]=0;O(313,g+32|0,1)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}if(d>>>0>=66){r=h>>>0<=1?1:h;i=0;while(1){d=Zb(m,e);x[114409]=0;s=O(477,d|0,i|0)|0;d=x[114409];x[114409]=0;l=0;if((d|0)==1){break c}while(1){x[114409]=0;P(594,g+20|0,g+32|0);d=x[114409];x[114409]=0;e:{f:{g:{if((d|0)!=1){d=D(l,6)+s|0;f=g+20|0;t=ed(f);o=wf(f);n=fi(f);f=y[f|0];if((f-1&255)>>>0>71){break g}v[d|0]=f+36;v[d+1|0]=y[t|0]+1;break f}break c}if(!(y[d|0]|y[o|0])){break e}}v[d+2|0]=1;u=d,B=(Md(y[o|0],1,16)<<2)-4|0,v[u+4|0]=B}f=y[n|0]&15;v[d+5|0]=f;h:{i:{switch((y[n|0]>>>4|0)-3|0){case 0:v[d+5|0]=f<<2;break h;case 1:v[d+5|0]=(6/(f+1>>>0)|0)+1;break h;case 3:case 4:v[d+5|0]=f<<3;break h;case 7:v[d+4|0]=(f<<2)+4;v[d+2|0]=1;break h;case 8:v[d+5|0]=f|128;break h;case 9:break i;default:break h}}v[d+5|0]=(6/(f+1>>>0)|0)+1|13}v[d+3|0]=y[(y[n|0]>>>4|0)+23488|0];l=l+1|0;if((l|0)!=16){continue}break}i=i+1|0;if((r|0)!=(i|0)){continue}break}}d=Zb(m,e);x[114409]=0;f=U(478,g+88|0,14,0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break c}f=gi(Oe(f,j?j>>>0>=h-2>>>0?-1:j+1|0:-1));x[114409]=0;O(479,d|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}}Ab(g+32|0)}e=e+1|0;if((e|0)!=256){continue}break}if(!(c&2)){break a}TU(b,g+80|0);d=0;while(1){j:{k:{if(!(y[g+80+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;break k}if(!SA(b,g+32|0)){break a}d=d+1|0;w[a+480190>>1]=d;c=g+8|0;Ng(c,1,g+32|0);e=g+20|0;Kc(e,c);c=z[a+480190>>1];x[114409]=0;O(348,((c<<5)+a|0)+946304|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break j}f=g+20|0;xb(f);c=(D(d,104)+a|0)+484380|0;zd(c,0);e=g+32|0;x[c>>2]=y[e+32|0]|y[e+33|0]<<8|(y[e+34|0]<<16|y[e+35|0]<<24);x[c+4>>2]=y[e+38|0]|y[e+39|0]<<8|(y[e+40|0]<<16|y[e+41|0]<<24);h=y[e+42|0]|y[e+43|0]<<8|(y[e+44|0]<<16|y[e+45|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=h;w[c+30>>1]=y[e+37|0]<<4;if(v[e+46|0]&1){x[c>>2]=x[c>>2]>>>1;x[c+4>>2]=x[c+4>>2]>>>1;x[c+8>>2]=x[c+8>>2]>>>1}if(!(!(y[e+47|0]&8)|A[c+8>>2]<=A[c+4>>2])){w[c+34>>1]=z[c+34>>1]|2}cd(f,v[e+46|0]&1?16:8,1,0,0);Fg(f,c,b)}if((d|0)!=64){continue}break a}break}d=N()|0;xb(g+20|0);break b}d=N()|0;Ab(g+32|0)}Q(d|0);p()}hb=g+976|0;return k|0}function rN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;e=c&15;f=D(b,896)+a|0;d=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;x[a>>2]=x[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(x[a+480180>>2]==33554432){c=D(b,896)+a|0;d=c+1075684|0;if(!x[d>>2]){break a}c=x[c+1075088>>2];if(!c){break a}f=D(b,896)+a|0;g=f+1075688|0;e=z[D(e,24)+26112>>1];b=x[c+24>>2];i=sqa(b,b>>31,1712,0);c=(e>>>1|0)+i|0;b=lb;b=Ec(tqa(c,c>>>0<i>>>0?b+1|0:b,e,0),lb);x[g>>2]=b;k=d,l=jg(a,y[f+1075803|0],0,b),x[k>>2]=l;break a}if(x[a+480180>>2]!=64){b=D(b,896)+a|0;c=e<<28>>24;x[b+1075752>>2]=c;e=z[(e<<1)+26544>>1];x[b+1075688>>2]=e;d=b+1075684|0;if(!x[d>>2]){break a}k=d,l=jg(a,y[b+1075803|0],c,e),x[k>>2]=l;break a}a=D(b,896)+a|0;b=x[a+1075088>>2];if(!b){break a}x[a+1075688>>2]=x[b+24>>2]+D(e,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,896)+a|0)+1075826|0]=c&3;break a}d=h+8|0;Kb(d,a+1074312|0,21);if(Ib(d)){v[(D(b,896)+a|0)+1075826|0]=e>>>0<4?e:0;break a}v[(D(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,896)+a|0)+1075829|0]=c&3;break a}d=h+8|0;Kb(d,a+1074312|0,21);if(Ib(d)){v[(D(b,896)+a|0)+1075829|0]=e>>>0<4?e:0;break a}v[(D(b,896)+a|0)+1075829|0]=c&7;break a;case 4:d=h+8|0;Kb(d,a+1074312|0,21);if(Ib(d)){a=D(b,896)+a|0;v[a+1075825|0]=0;v[a+1075832|0]=e>>>0<4?e:0;break a}v[(D(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+e;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(e>>>0<=2){c=z[a+480188>>1];if(c>>>0>255){break a}d=a+1304392|0;i=b+1|0;j=e-1|0;while(1){e=D(c,896)+a|0;c:{if(z[e+1075792>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:Fn(a,e+1074984|0);if(!(y[e+1075073|0]&2)){break d}if(!yd(d)){break d}Ok(x[d>>2],c&65535);break d;case 1:g=e+1075072|0;f=x[g>>2];x[g>>2]=f|4096;if(!(f&512)){break d}if(!yd(d)){break d}Ok(x[d>>2],c&65535);break d;default:break e}}x[e+1075680>>2]=0;g=e+1075072|0;f=x[g>>2];x[g>>2]=f|4096;if(!(f&512)){break d}if(!yd(d)){break d}Pi(x[d>>2],c&65535,1)}f=x[e+1075640>>2];if(!f){break c}g=y[f+34|0];if(!g){break c}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break c}mb[x[x[g>>2]+88>>2]](g,f,y[e+1075803|0]+255|0,0,b)}c=c+1|0;if((c&65535)!=256){continue}break}break a}fP(d,e,a);break a;case 7:if(!(y[a+480209|0]&16)){break a}Xl(a,d,e,4);break a;case 8:b=x[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e|0){case 0:x[d+88>>2]=x[d+88>>2]&-257;break f;case 1:x[d+692>>2]=128;x[d+88>>2]=x[d+88>>2]|256;break f;case 8:x[d+88>>2]=x[d+88>>2]&-25165825|16777216;break f;case 9:x[d+88>>2]=x[d+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=b&-16385;break f;case 11:x[a+480208>>2]=b|16384;break f;case 12:x[a+480208>>2]=b&-8193;break f;case 13:x[a+480208>>2]=b|8192;break f;case 14:x[d+88>>2]=x[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!x[d+76>>2]|(x[d>>2]|x[d+4>>2])){break h}if(!(k=Ff(d+810|0),l=1,m=y[d+88|0]&2,m?k:l)){break h}a=x[d+76>>2]-1|0;x[d>>2]=-1;x[d+4>>2]=a}x[d+88>>2]=x[d+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,896)+a|0;v[c+1075840|0]=e;f=h+8|0;Kb(f,a+1074312|0,35);if(Ib(f)){break a}if(!Ff(c+1075794|0)){break a}b=x[(D(b,896)+a|0)+1075060>>2];a=e<<16;if(b>>>0<=a>>>0){break a}x[d+4>>2]=a;break a;case 11:i:{if(e){break i}e=1;if(x[a+480180>>2]&16777248){break i}e=0;if(x[a+480180>>2]==2){break a}}c=h+8|0;Kb(c,a+1074312|0,30);if(Ib(c)){c=1}else{c=x[a+480180>>2]==2}Uy(a,b,e,c);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,896)+a|0)+1075848|0]=e}hb=h+16|0}function c0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;x[h+12>>2]=b;x[e>>2]=0;Fc(h,d);x[114409]=0;i=S(21,h|0)|0;j=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Ob(h);Q(a|0);p()}JF(a,f+24|0,h+12|0,c,e,i);break b}IF(a,f+16|0,h+12|0,c,e,i);break b}g=a;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=sj(g,b,c,d,e,f,Rb(a),Rb(a)+Cb(a)|0),x[k+12>>2]=l;break b}a=qi(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=sj(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=sj(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=qi(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=qi(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=qi(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=qi(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=qi(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=hb-16|0;hb=b;x[b+12>>2]=c;while(1){H:{if(Cg(a,b+12|0)){break H}if(!Bg(i,1,tk(a))){break H}Dl(a);continue}break}if(Cg(a,b+12|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+12|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(a)|0)==(0-Cb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=Tr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[64936]|y[64937]<<8|(y[64938]<<16|y[64939]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[64933]|y[64934]<<8|(y[64935]<<16|y[64936]<<24);x[h>>2]=y[64929]|y[64930]<<8|(y[64931]<<16|y[64932]<<24);x[h+4>>2]=g;k=h,l=sj(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[64944];x[h>>2]=y[64940]|y[64941]<<8|(y[64942]<<16|y[64943]<<24);k=h,l=sj(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=qi(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=sj(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=qi(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=sj(g,b,c,d,e,f,Rb(a),Rb(a)+Cb(a)|0),x[k+12>>2]=l;break b}HF(f+20|0,h+12|0,c,e,i);break b}a=qi(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+12>>2]=c;b=6;c=h+12|0;L:{M:{if(Cg(c,a+12|0)){break M}b=4;if((Ym(i,tk(c))|0)!=37){break M}b=2;if(!Cg(Dl(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+12>>2]}hb=h+16|0;return a|0}function dJ(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=hb-240|0;hb=e;C[e+232>>3]=c;a:{if(Dj(b)){break a}f=y[yk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Lk(e+200|0,b,x[b+4>>2]-1|0);f=x[e+204>>2];x[b>>2]=x[e+200>>2];x[b+4>>2]=f}f=e+200|0;Gd(f);g=x[e+200>>2];Gd(e+188|0);h=xk(g,x[e+192>>2],b);Gd(f);f=x[b>>2];g=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)==x[e+204>>2]){x[e+224>>2]=f;x[e+228>>2]=g;a=uc(e+216|0,17381);f=x[e+228>>2];x[e+16>>2]=x[e+224>>2];x[e+20>>2]=f;f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;if(Mc(e+16|0,e+8|0)){a=ec(8);x[114409]=0;P(2268,e+188|0,e+232|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+200|0,13483,e+188|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}a=oc(a,e+200|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(e+200|0);xb(e+188|0);break c}b=N()|0;break d}if(!d){break i}f=ec(8);x[114409]=0;d=O(2266,e+164|0,b|0)|0;a=x[114409];x[114409]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[114409]=0;T(2242,e+176|0,13519,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break q}x[114409]=0;T(2261,e+188|0,e+176|0,13493);b=x[114409];x[114409]=0;a=1;if((b|0)==1){break p}x[114409]=0;P(2268,e+152|0,e+232|0);a=x[114409];x[114409]=0;if((a|0)==1){break o}x[114409]=0;T(141,e+200|0,e+188|0,e+152|0);b=x[114409];x[114409]=0;a=1;if((b|0)==1){break n}a=oc(f,e+200|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(e+200|0);a=0;break m}b=N()|0;break j}b=N()|0;xb(d);break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}xb(e+152|0)}xb(e+188|0)}xb(e+176|0);xb(d);if(!a){break c}}ic(f);break c}x[e+144>>2]=f;x[e+148>>2]=g;d=uc(e+136|0,17381);f=x[e+148>>2];x[e+80>>2]=x[e+144>>2];x[e+84>>2]=f;f=x[d+4>>2];x[e+72>>2]=x[d>>2];x[e+76>>2]=f;if(Mc(e+80|0,e+72|0)){a=ec(8);x[114409]=0;P(2268,e+188|0,e+232|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,e+200|0,13483,e+188|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}a=oc(a,e+200|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(e+200|0);xb(e+188|0);break c}b=N()|0;break e}d=x[b+4>>2];x[e+128>>2]=x[b>>2];x[e+132>>2]=d;d=uc(e+120|0,3991);f=x[e+132>>2];x[e+64>>2]=x[e+128>>2];x[e+68>>2]=f;f=x[d+4>>2];x[e+56>>2]=x[d>>2];x[e+60>>2]=f;if(Mc(e- -64|0,e+56|0)){if(!y[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ec(8);x[114409]=0;d=O(122,e+200|0,4086)|0;b=x[114409];x[114409]=0;if((b|0)==1){break h}a=oc(a,d);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(d);break c}b=mg(65536/c);a=a+24|0;x[x[a>>2]+480244>>2]=b;Hp(x[a>>2]);break i}d=x[b+4>>2];x[e+112>>2]=x[b>>2];x[e+116>>2]=d;d=uc(e+104|0,4043);f=x[e+116>>2];x[e+48>>2]=x[e+112>>2];x[e+52>>2]=f;f=x[d+4>>2];x[e+40>>2]=x[d>>2];x[e+44>>2]=f;if(Mc(e+48|0,e+40|0)){if(!y[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ec(8);x[114409]=0;d=O(122,e+200|0,4107)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,d);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(d);break c}b=N()|0;ic(a);break c}b=mg(c*65536);a=a+24|0;x[x[a>>2]+480240>>2]=b;Hp(x[a>>2]);break i}d=x[b+4>>2];x[e+96>>2]=x[b>>2];x[e+100>>2]=d;b=uc(e+88|0,4061);d=x[e+100>>2];x[e+32>>2]=x[e+96>>2];x[e+36>>2]=d;d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(!Mc(e+32|0,e+24|0)){break i}b=Mn(c*65536);x[x[a+24>>2]+480236>>2]=b}hb=e+240|0;return}b=N()|0;ic(a);break c}b=N()|0;xb(e+188|0);break d}b=N()|0;xb(e+188|0)}ic(a);break c}ic(a)}Q(b|0)}p()}function oW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-560|0;hb=f;Nc(b);d=hb-16|0;hb=d;e=d+8|0;j=f+63|0;eC(e,j);h=Fb(e);e=nc(b,ac(d,e));if((h|0)==(e|0)){cc(b,Fb(d+8|0))}hb=d+16|0;d=(e|0)==(h|0);if(!d){fC(j)}a:{if(!d){break a}if(!jC(f+63|0)){break a}b:{if(!c){break b}if(!Qb(b,id(iC(f+63|0),lb))){break a}Pd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;d=f+36|0;g=Vb(d,10194);Eb(a+1304436|0,g);xb(g);d=Vb(d,10227);Eb(a+1304448|0,d);xb(d);Rc(a+1304460|0,(y[f+63|0]|y[f+64|0]<<8)==26217?10194:10222);x[a+1304496>>2]=4;d=y[f+173|0];w[a+480190>>1]=d;c:{d:{e:{f:{if(d){g=1;j=1;while(1){e=hb-16|0;hb=e;i=hb-16|0;hb=i;h=e+8|0;d=f+36|0;jc(h,d,25);hb=i+16|0;i=Fb(h);h=nc(b,ac(e,h));if((i|0)==(h|0)){cc(b,Fb(e+8|0))}hb=e+16|0;if((h|0)!=(i|0)){e=hb-16|0;hb=e;v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0;hb=e+16|0}if((y[f+49|0]|y[f+50|0]<<8|(y[f+51|0]<<16|y[f+52|0]<<24))>>>0>67108863){break d}e=(D(g,104)+a|0)+484380|0;zd(e,0);x[e+24>>2]=8363;h=f+36|0;d=h;x[e>>2]=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[e+4>>2]=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[e+8>>2]=d;g:{if(!(x[e+4>>2]|d>>>0<=A[e>>2])){x[e+8>>2]=0;break g}if(d){w[e+34>>1]=2;Nn(e)}}d=f+12|0;Bh(d,2,h);e=f+24|0;Kc(e,d);x[114409]=0;O(348,((g<<5)+a|0)+946304|0,e|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}xb(f+24|0);j=j+1|0;g=j&65535;if(g>>>0<=z[a+480190>>1]){continue}break}}g=f+24|0;e=f+65|0;hC(g,3,e,36);d=f+36|0;Kc(d,g);Eb(a+1304400|0,d);xb(d);g=0;qP(a+1304424|0,Db(e),108,36,0);d=a+484360|0;Uj(Wb(d),f+176|0,128,255,254);if(z[vc(Wb(d),y[f+175|0])>>1]<y[f+174|0]){break e}break c}a=N()|0;xb(f+24|0);Q(a|0);p()}Pe(Wb(d),y[f+175|0]);break c}g=0;break a}while(1){d=(g<<5)+a|0;Pg(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;if((g|0)!=8){continue}break}h=a+484344|0;ig(h,y[f+174|0]);if(y[f+174|0]){m=c&1;e=0;while(1){h:{i:{if(m){if(Zg(h,e&65535,64)){break i}}cc(b,1536);break h}x[f+24>>2]=-1;x[f+28>>2]=-1;l=0;while(1){g=tm(Zb(h,e),l);j=0;while(1){i=f+36|0;Sq(i,b);d=ed(i);n=wf(i);k=y[d|0];d=y[i|0];if(d>>>0<=253){v[g|0]=(d>>>2|0)+37;v[g+1|0]=(d<<4&48|k>>>4)+1;v[(f+24|0)+j|0]=255;d=y[i|0]}if((d|0)!=255){v[g+2|0]=1;v[g+4|0]=(((k&15)<<6|8)>>>0)/15}i=(f+24|0)+j|0;j:{k:{d=y[n|0];l:{if((d|0)!=255){v[i|0]=d;if(d&15|(d|0)==48){break l}break k}d=y[i|0];if((d|0)==255){break j}}k=d&15;v[g+5|0]=k;m:{if(d<<24>>24<0){break m}d=d>>>4|0;v[g+3|0]=y[d+23288|0];n:{switch(d-3|0){case 0:v[g+5|0]=k|32;break k;case 1:v[g+5|0]=D(k,17);break j;case 2:break k;case 3:break n;default:break j}}o:{switch(k|0){case 0:v[g+5|0]=79;break j;case 1:break o;default:break m}}v[g+5|0]=244;break j}v[g+3|0]=0;break j}v[i|0]=255}g=g+6|0;j=j+1|0;if((j|0)!=8){continue}break}l=l+1|0;if((l|0)!=64){continue}break}d=(f+63|0)+e|0;if(y[d+369|0]<63){Pl(Zb(h,e),gi(Oe(wo(f+36|0,14,0),y[d+369|0])))}Pl(Zb(h,e),gi(wo(f+36|0,16,y[d+241|0])))}e=e+1|0;if(e>>>0<y[f+174|0]){continue}break}}g=1;if(!(c&2)){break a}c=cd(f+36|0,8,1,0,1);if(!z[a+480190>>1]){break b}while(1){Fg(c,(D(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}}g=1}hb=f+560|0;return g|0}function q4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-352|0;hb=d;a:{if(Dj(b)){break a}e=y[yk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Lk(d+320|0,b,x[b+4>>2]-1|0);e=x[d+324>>2];x[b>>2]=x[d+320>>2];x[b+4>>2]=e}f=d+320|0;Gd(f);e=x[d+320>>2];Gd(d+308|0);e=xk(e,x[d+312>>2],b);Gd(f);b:{c:{d:{e:{f:{g:{if((e|0)==x[d+324>>2]){a=x[b+4>>2];x[d+344>>2]=x[b>>2];x[d+348>>2]=a;a=uc(d+336|0,17381);e=x[d+348>>2];x[d+8>>2]=x[d+344>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;if(Mc(d+8|0,d)){a=ec(8);x[114409]=0;c=O(122,d+320|0,6463)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}e=0;if(!c){break g}c=ec(8);x[114409]=0;a=O(2266,d+308|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,d+320|0,13519,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}b=oc(c,d+320|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(d+320|0);xb(a);break c}b=N()|0;break d}if(x[e+4>>2]){a=ec(8);x[114409]=0;c=O(122,d+320|0,7464)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];x[d+296>>2]=x[b>>2];x[d+300>>2]=c;c=uc(d+288|0,17381);e=x[d+300>>2];x[d+152>>2]=x[d+296>>2];x[d+156>>2]=e;e=x[c+4>>2];x[d+144>>2]=x[c>>2];x[d+148>>2]=e;if(Mc(d+152|0,d+144|0)){a=ec(8);x[114409]=0;c=O(122,d+320|0,6463)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];x[d+280>>2]=x[b>>2];x[d+284>>2]=c;c=uc(d+272|0,3674);e=x[d+284>>2];x[d+136>>2]=x[d+280>>2];x[d+140>>2]=e;e=x[c+4>>2];x[d+128>>2]=x[c>>2];x[d+132>>2]=e;h:{if(!Mc(d+136|0,d+128|0)){c=x[b+4>>2];x[d+264>>2]=x[b>>2];x[d+268>>2]=c;c=uc(d+256|0,3656);e=x[d+268>>2];x[d+120>>2]=x[d+264>>2];x[d+124>>2]=e;e=x[c+4>>2];x[d+112>>2]=x[c>>2];x[d+116>>2]=e;if(!Mc(d+120|0,d+112|0)){break h}}e=y[a+60|0]!=0;break g}c=x[b+4>>2];x[d+248>>2]=x[b>>2];x[d+252>>2]=c;c=uc(d+240|0,3240);e=x[d+252>>2];x[d+104>>2]=x[d+248>>2];x[d+108>>2]=e;e=x[c+4>>2];x[d+96>>2]=x[c>>2];x[d+100>>2]=e;i:{if(!Mc(d+104|0,d+96|0)){c=x[b+4>>2];x[d+232>>2]=x[b>>2];x[d+236>>2]=c;c=uc(d+224|0,3221);e=x[d+236>>2];x[d+88>>2]=x[d+232>>2];x[d+92>>2]=e;e=x[c+4>>2];x[d+80>>2]=x[c>>2];x[d+84>>2]=e;if(!Mc(d+88|0,d+80|0)){break i}}e=y[a+61|0]!=0;break g}c=x[b+4>>2];x[d+216>>2]=x[b>>2];x[d+220>>2]=c;c=uc(d+208|0,3324);e=x[d+220>>2];x[d+72>>2]=x[d+216>>2];x[d+76>>2]=e;e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;if(Mc(d+72|0,d- -64|0)){e=y[a+62|0]!=0;break g}c=x[b+4>>2];x[d+200>>2]=x[b>>2];x[d+204>>2]=c;c=uc(d+192|0,2484);e=x[d+204>>2];x[d+56>>2]=x[d+200>>2];x[d+60>>2]=e;e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;if(Mc(d+56|0,d+48|0)){e=y[a+63|0]!=0;break g}c=x[b+4>>2];x[d+184>>2]=x[b>>2];x[d+188>>2]=c;c=uc(d+176|0,3723);e=x[d+188>>2];x[d+40>>2]=x[d+184>>2];x[d+44>>2]=e;e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Mc(d+40|0,d+32|0)){e=y[a+64|0]!=0;break g}c=x[b+4>>2];x[d+168>>2]=x[b>>2];x[d+172>>2]=c;b=uc(d+160|0,9235);c=x[d+172>>2];x[d+24>>2]=x[d+168>>2];x[d+28>>2]=c;c=x[b+4>>2];x[d+16>>2]=x[b>>2];x[d+20>>2]=c;e=0;if(!Mc(d+24|0,d+16|0)){break g}e=x[x[a+24>>2]+24668>>2]!=0}hb=d+352|0;return e|0}b=N()|0;ic(a);break c}b=N()|0;xb(a)}ic(c)}Q(b|0)}p()}
function Rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-352|0;hb=f;d=f+104|0;g=hb-48|0;hb=g;e=g+28|0;IA(e,b);x[114409]=0;P(715,g+12|0,e|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)==1){break b}x[114409]=0;P(716,g+20|0,g+12|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=g+20|0;e=x[b>>2];b=x[b+4>>2];x[114409]=0;U(717,d|0,e|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}Jc(g+28|0);hb=g+48|0;break a}a=N()|0;Jc(g+28|0);Q(a|0);p()}x[114409]=0;g=U(683,f+212|0,d|0,8)|0;b=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((b|0)!=1){xb(f+104|0);if(c>>>0<2189){break i}x[114409]=0;b=O(693,f+104|0,g|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break e}x[114409]=0;c=O(694,f+92|0,6105)|0;d=x[114409];x[114409]=0;if((d|0)==1){break B}x[114409]=0;x[f+72>>2]=19469602;x[f+76>>2]=0;T(695,b|0,c|0,f+72|0);d=x[114409];x[114409]=0;if((d|0)==1){break A}Gb(c);x[114409]=0;v[f+91|0]=0;c=O(694,f+72|0,6987)|0;d=x[114409];x[114409]=0;if((d|0)==1){break k}d=0;x[114409]=0;U(696,b|0,f+91|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break z}Gb(c);if(!y[f+91|0]){x[114409]=0;d=S(697,a|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break y}}e=x[a+4>>2];x[114409]=0;c=O(694,f+60|0,11796)|0;h=x[114409];x[114409]=0;if((h|0)==1){break x}x[114409]=0;W(698,b|0,e|0,c|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break w}Gb(c);x[114409]=0;c=O(694,f+48|0,11558)|0;e=x[114409];x[114409]=0;if((e|0)==1){break v}x[114409]=0;W(699,b|0,a|0,c|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break u}Gb(c);x[114409]=0;c=O(694,f+36|0,11195)|0;d=x[114409];x[114409]=0;if((d|0)==1){break t}x[114409]=0;d=a+484360|0;Z(700,b|0,d|0,c|0,701)|0;e=x[114409];x[114409]=0;if((e|0)==1){break s}Gb(c);x[114409]=0;c=O(694,f+24|0,23702)|0;e=x[114409];x[114409]=0;if((e|0)==1){break r}x[114409]=0;Z(702,b|0,a+484344|0,c|0,703)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}Gb(c);x[114409]=0;e=S(697,a|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break p}x[114409]=0;c=O(694,f+12|0,23708)|0;h=x[114409];x[114409]=0;if((h|0)==1){break o}x[114409]=0;W(704,b|0,d|0,c|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break n}Gb(c);if(x[b>>2]&1073741824){x[114409]=0;c=O(2,f|0,12159)|0;d=x[114409];x[114409]=0;if((d|0)==1){break m}x[114409]=0;T(655,a|0,1,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break l}xb(c)}Ig(b);break h}a=N()|0;xb(f+104|0);break c}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;xb(c);break j}a=N()|0}Ig(b);break d}b=gd(f+104|0);d=x[a+4>>2];x[114409]=0;e=S(697,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break g}x[114409]=0;d=Z(705,d|0,g|0,b|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}C:{if((d|0)!=1){x[114409]=0;c=O(2,f+92|0,12465)|0;d=x[114409];x[114409]=0;D:{if((d|0)!=1){x[114409]=0;T(655,a|0,1,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break D}xb(c);break C}a=N()|0;break f}a=N()|0;xb(c);break f}x[114409]=0;d=S(697,a|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;W(706,g|0,a|0,d|0,c>>>0<2188|0);a=x[114409];x[114409]=0;if((a|0)==1){break g}}xb(b)}Pf(g);hb=f+352|0;return}a=N()|0}xb(b);break d}a=N()|0}Pf(g)}Q(a|0);p()}function nT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-144|0;hb=e;h=hb-16|0;hb=h;f=h+15|0;i=hb-16|0;hb=i;x[114409]=0;j=e+132|0;S(738,j+4|0)|0;g=x[114409];x[114409]=0;a:{b:{if((g|0)==1){break b}x[114409]=0;x[i+12>>2]=0;U(739,j+8|0,i+12|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}m=j,n=mc(j),x[m>>2]=n;hb=i+16|0;break a}R(0)|0;zb();p()}hb=h+16|0;c:{d:{e:{if(d){x[114409]=0;T(722,a|0,j|0,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){break e}break d}x[114409]=0;T(723,a|0,j|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}}i=Gw(e+120|0);if(z[b+480192>>1]){d=1;k=1;while(1){x[114409]=0;w[e+118>>1]=0;O(724,a|0,e+118|0)|0;c=x[114409];x[114409]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((c|0)!=1){x[114409]=0;c=O(725,j|0,e+118|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break i}x[e+112>>2]=c;h=((d<<2)+b|0)+900380|0;if(!x[h>>2]){break f}c=Zi(j);x[114409]=0;x[e+48>>2]=c;c=O(726,e+112|0,e+48|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break D}if(!c){break j}x[114409]=0;c=S(727,e+112|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break C}x[114409]=0;c=O(4,e+100|0,c+4|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break C}x[114409]=0;d=O(2,e+88|0,12720)|0;f=x[114409];x[114409]=0;if((f|0)==1){break l}f=zq(c,d);xb(d);if(f){break u}d=x[b+4>>2];x[114409]=0;d=O(728,d|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break A}x[x[h>>2]+44>>2]=d;if(!x[x[h>>2]+44>>2]){break B}break g}b=N()|0;break h}b=N()|0;break h}b=N()|0;break h}x[114409]=0;d=O(2,e+76|0,9266)|0;f=x[114409];x[114409]=0;if((f|0)==1){break z}E:{F:{if(zq(c,d)){xb(d);break F}x[114409]=0;f=O(2,e- -64|0,9477)|0;g=x[114409];x[114409]=0;if((g|0)==1){break y}g=zq(c,f);xb(f);xb(d);if(!g){break E}}x[114409]=0;d=S(729,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break x}x[e+48>>2]=d;d=x[b+4>>2];f=x[yq(e+60|0,e+48|0)>>2];x[114409]=0;d=O(730,d|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break w}Xf(e+48|0);if(d){break g}}f=bc(i);g=dc(i);d=hb-16|0;hb=d;x[d+8>>2]=g;x[d+12>>2]=f;G:{if(!Hb(d+12|0,d+8|0)){break G}while(1){if(zq(x[d+12>>2],c)){break G}f=d+12|0;dk(f);if(Hb(f,d+8|0)){continue}break}}hb=d+16|0;x[e+48>>2]=x[d+12>>2];m=e,n=dc(i),x[m+36>>2]=n;if(!Zs(e+48|0,e+36|0)){break u}x[114409]=0;P(731,i|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){break v}}b=N()|0;break k}b=N()|0;break k}b=N()|0;xb(d);break k}b=N()|0;break k}b=N()|0;Xf(e+48|0);break k}x[114409]=0;d=O(2,e+12|0,13224)|0;f=x[114409];x[114409]=0;if((f|0)==1){break t}x[114409]=0;T(732,e+24|0,d|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break s}x[114409]=0;f=O(2,e|0,12208)|0;g=x[114409];x[114409]=0;if((g|0)==1){break r}x[114409]=0;T(3,e+36|0,e+24|0,f|0);g=x[114409];x[114409]=0;if((g|0)==1){break q}g=Gt(e+48|0,e+36|0);x[114409]=0;P(634,b|0,g|0);l=x[114409];x[114409]=0;if((l|0)==1){break p}xb(g);xb(e+36|0);xb(f);xb(e+24|0);xb(d)}x[x[h>>2]+44>>2]=0;break g}b=N()|0;break k}b=N()|0;break m}b=N()|0;break n}b=N()|0;break o}b=N()|0;xb(g);xb(e+36|0)}xb(f)}xb(e+24|0)}xb(d);break k}b=N()|0}xb(c);break h}if(!x[h>>2]){break f}x[x[h>>2]+44>>2]=0;break f}b=N()|0}Al(i);break c}xb(c)}k=k+1|0;d=k&65535;if(d>>>0<=z[b+480192>>1]){continue}break}}Al(i);hT(j);hb=e+144|0;return}b=N()|0}hT(j);Q(b|0);p()}function NI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=hb-48|0;hb=g;a:{b:{if(Fs(c)){h=b+24|0;if(pg(x[h>>2]+484344|0,c&65535)){break b}}c=a;a=Xb(g+36|0);b=Xb(g+24|0);Uh(c,a,b);xb(b);xb(a);break a}b=Zb(x[h>>2]+484344|0,c);if(!(x[b+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Xb(g+36|0);b=Xb(g+24|0);Uh(c,a,b);xb(b);xb(a);break a}if(!(z[x[h>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Xb(g+36|0);b=Xb(g+24|0);Uh(c,a,b);xb(b);xb(a);break a}if(f>>>0>=6){c=a;a=Xb(g+36|0);b=Xb(g+24|0);Uh(c,a,b);xb(b);xb(a);break a}b=Hf(b,d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{if(!Ff(b)){if(!ct(b)){break k}}c=g+24|0;yM(c,x[h>>2],y[b|0],y[b+1|0]);x[114409]=0;T(9,g+36|0,0,c|0);c=x[114409];x[114409]=0;d=1;if((c|0)!=1){break j}c=N()|0;break g}d=0;x[114409]=0;O(122,g+36|0,12704)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}}x[114409]=0;c=S(546,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}if(c){b=5954}else{b=ct(b)?6259:12704}x[114409]=0;b=O(122,g+12|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break h}c=a;a=g+36|0;Uh(c,a,b);xb(b);xb(a);if(!d){break a}xb(g+24|0);break a}c=N()|0;break d}c=N()|0;xb(g+36|0);if(!d){break d}}xb(g+24|0);break d;case 1:c=b+1|0;l:{if(y[b+1|0]){iu(g+36|0,c);break l}Vb(g+36|0,12709)}b=y[c|0];x[114409]=0;b=O(122,g+24|0,(b?6741:12709)|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break e}c=a;a=g+36|0;Uh(c,a,b);xb(b);xb(a);break a;case 2:m:{if(Hn(b)){Vb(g+36|0,13666);break m}if(y[b+2|0]){Qj(g+36|0,1,BL(x[x[h>>2]+8>>2],y[b+2|0]));break m}Vb(g+36|0,13666)}x[114409]=0;c=S(1422,b|0)|0;d=x[114409];x[114409]=0;n:{if((d|0)==1){break n}b=c?13666:y[b+2|0]?1991:13666;x[114409]=0;b=O(122,g+24|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break n}c=a;a=g+36|0;Uh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+36|0);break d;case 4:o:{if(Hn(b)){i=g,j=Zy(b)&255,x[i+12>>2]=j;jA(g+36|0,g+12|0);break o}if(y[b+2|0]){iu(g+36|0,b+4|0);break o}Vb(g+36|0,12709)}x[114409]=0;c=S(1422,b|0)|0;d=x[114409];x[114409]=0;p:{if((d|0)==1){break p}b=c?1975:y[b+2|0]?1975:12709;x[114409]=0;b=O(122,g+24|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break p}c=a;a=g+36|0;Uh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+36|0);break d;case 3:q:{if(Hn(b)){i=g,j=(rt(b)&3840)!=0,v[i+12|0]=j;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=1;d=hb-16|0;hb=d;x[d+12>>2]=y[g+12|0];Bx(g+36|0,d+12|0,c+8|0);hb=d+16|0;hb=c+32|0;break q}if(y[b+3|0]){Qj(g+36|0,1,AL(x[x[h>>2]+8>>2],y[b+3|0]));break q}Vb(g+36|0,12710)}x[114409]=0;c=S(1422,b|0)|0;d=x[114409];x[114409]=0;r:{if((d|0)==1){break r}b=c?8131:y[b+3|0]?8131:12710;x[114409]=0;b=O(122,g+24|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break r}c=a;a=g+36|0;Uh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+36|0);break d;case 5:break f;default:break c}}s:{if(Hn(b)){i=g,j=rt(b)&255,x[i+12>>2]=j;jA(g+36|0,g+12|0);break s}if(y[b+3|0]){iu(g+36|0,b+5|0);break s}Vb(g+36|0,12709)}x[114409]=0;c=S(1422,b|0)|0;d=x[114409];x[114409]=0;t:{if((d|0)==1){break t}b=c?7028:y[b+3|0]?7028:12709;x[114409]=0;b=O(122,g+24|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break t}c=a;a=g+36|0;Uh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+36|0);break d}c=N()|0;xb(g+36|0)}Q(c|0);p()}c=a;a=Xb(g+36|0);b=Xb(g+24|0);Uh(c,a,b);xb(b);xb(a)}hb=g+48|0}function Cpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-720|0;hb=e;Nc(b);f=hb-16|0;hb=f;g=f+8|0;i=e+110|0;EU(g,i);h=Fb(g);g=nc(b,ac(f,g));if((h|0)==(g|0)){cc(b,Fb(f+8|0))}hb=f+16|0;f=(g|0)==(h|0);if(!f){FU(i)}a:{if(!f){break a}if(!HU(e+110|0)){break a}b:{if(!c){break b}Pd(a,67108864);Ni(a);d=y[e+135|0];w[a+480190>>1]=31;w[a+480188>>1]=d;x[a+480228>>2]=256/(d>>>0);d=Vb(e,4384);Eb(a+1304436|0,d);xb(d);d=Vb(e,6744);Eb(a+1304448|0,d);xb(d);f=Vb(e+96|0,10880);x[114409]=0;P(192,e+72|0,f|0);d=x[114409];x[114409]=0;c:{d:{if((d|0)!=1){x[e+92>>2]=y[e+134|0]>>>4;d=y[e+134|0];x[114409]=0;x[e+88>>2]=d&15;W(527,e|0,e+72|0,e+92|0,e+88|0);d=x[114409];x[114409]=0;if((d|0)!=1){Eb(a+1304460|0,e);xb(e);Gb(e+72|0);xb(f);x[a+1304496>>2]=2;Uj(Wb(a+484360|0),e+158|0,y[e+157|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;i=D(d,104)+a|0;j=i+484380|0;zd(j,1);g=(e+110|0)+(f<<2)|0;h=y[g+176|0]|y[g+177|0]<<8|(y[g+178|0]<<16|y[g+179|0]<<24);x[j>>2]=h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24);h=y[g+300|0]|y[g+301|0]<<8|(y[g+302|0]<<16|y[g+303|0]<<24);k=h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24);x[i+484384>>2]=k;h=y[g+424|0]|y[g+425|0]<<8|(y[g+426|0]<<16|y[g+427|0]<<24);x[i+484388>>2]=k+(h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24));if(y[g+424|0]|y[g+425|0]<<8|(y[g+426|0]<<16|y[g+427|0]<<24)){g=i+484414|0;w[g>>1]=z[g>>1]|2}Nn(j);f=(e+110|0)+f|0;v[e|0]=y[f+548|0];v[e+72|0]=64;o=i+484410|0,q=y[tc(e,e+72|0)|0]<<2,w[o>>1]=q;v[i+484417|0]=y[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}oB(b,a+1304400|0,32);d=1;while(1){GU(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){ig(a+484344|0,y[e+156|0]+1|0)}j=a+484344|0;d=0;e:{while(1){g=d;i=ii(e+72|0);f:{if(y[e+136|0]){x[114409]=0;d=S(464,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}x[114409]=0;T(316,e|0,b|0,d|0);break f}d=z[a+480188>>1];x[114409]=0;T(316,e|0,b|0,d<<8)}d=x[114409];x[114409]=0;if((d|0)==1){break e}Zd(i,e);Ab(e);g:{if(!k){break g}x[114409]=0;d=U(378,j|0,g&65535,64)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}if(!d){break g}if(!y[e+136|0]){d=0;if(!z[a+480188>>1]){break g}while(1){f=0;while(1){h=Zb(j,g);x[114409]=0;h=U(451,h|0,f|0,d&65535)|0;l=x[114409];x[114409]=0;if((l|0)==1){break e}x[114409]=0;P(528,i|0,h|0);h=x[114409];x[114409]=0;if((h|0)==1){break e}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if(z[a+480188>>1]>(d&65535)>>>0){continue}break}break g}h=0;x[114409]=0;O(529,i|0,e|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}while(1){d=Zb(j,g);x[114409]=0;l=O(477,d|0,h|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}if(z[a+480188>>1]){m=e+h|0;d=128;f=0;while(1){h:{if(!(y[m|0]&d)){break h}x[114409]=0;P(528,i|0,l+D(f,6)|0);n=x[114409];x[114409]=0;if((n|0)!=1){break h}break e}d=d>>>1|0;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break}}Ab(i);d=g+1|0;if(g>>>0<y[e+156|0]){continue}break}d=1;if(!(c&2)){break a}c=cd(e,8,1,1,0);while(1){Fg(c,(D(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=N()|0;Ab(i);break c}d=N()|0;Gb(e+72|0);break d}d=N()|0}xb(f)}Q(d|0);p()}d=1}hb=e+720|0;return d|0}function Xda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-32|0;hb=f;a:{b:{c:{l=a+24|0;d:{if(yd(l)){break d}k=a+4|0;m=Cb(k);c=hb-48|0;hb=c;j=c+40|0;a=j;x[a>>2]=-1;x[a+4>>2]=-1;if(!(v[84092]&1)){while(1){d=h&255;b=0;e=0;while(1){b=d&1|b<<1;d=(d&254)>>>1|0;e=e+1|0;if((e|0)!=8){continue}break}b=(b&255)<<24;e=0;d=0;while(1){a=b<<1|e>>>31;e=e<<1;b=(b|0)<0;e=b?e^-1798752855:e;b=b?a^-1382821323:a;d=d+1|0;if((d|0)!=8){continue}break}g=0;i=0;d=0;while(1){i=i<<1|g>>>31;g=e&1|g<<1;a=b;b=b>>>1|0;e=(a&1)<<31|e>>>1;d=d+1|0;if((d|0)!=64){continue}break}a=(h<<3)+84096|0;x[a>>2]=g;x[a+4>>2]=i;h=h+1|0;if((h|0)!=256){continue}break}v[84092]=1}x[114409]=0;a=dE(2439);b=x[114409];x[114409]=0;d=lb;if((b|0)==1){R(0)|0;zb();p()}x[c+8>>2]=a;x[c+12>>2]=d;a=x[c+12>>2];x[c+16>>2]=x[c+8>>2];x[c+20>>2]=a;b=hb-16|0;hb=b;a=hb-16|0;hb=a;e=c+16|0;d=e;n=a,o=sqa(x[d>>2],x[d+4>>2],1e3,0),x[n>>2]=o;x[a+4>>2]=lb;d=Li(a+8|0,a);g=x[d>>2];d=x[d+4>>2];hb=a+16|0;hb=b+16|0;x[c+24>>2]=g;x[c+28>>2]=d;a=c+24|0;b=x[a>>2];d=b&16711680;g=d>>>8|0;h=b&-16777216;i=h>>>24|0;h=h<<8|d<<24;d=x[a+4>>2];d=h|(((d&255)<<24|b>>>8)&-16777216|((d&16777215)<<8|b>>>24)&16711680|(d>>>8&65280|d>>>24));v[c+32|0]=d;v[c+33|0]=d>>>8;v[c+34|0]=d>>>16;v[c+35|0]=d>>>24;b=b<<24|(b&65280)<<8|(g|i);v[c+36|0]=b;v[c+37|0]=b>>>8;v[c+38|0]=b>>>16;v[c+39|0]=b>>>24;b=x[c+36>>2];x[c+24>>2]=x[c+32>>2];x[c+28>>2]=b;IM(j,a,yb(a));x[114409]=0;b=dE(2440);d=x[114409];x[114409]=0;g=lb;if((d|0)==1){R(0)|0;zb();p()}x[c+8>>2]=b;x[c+12>>2]=g;b=x[c+12>>2];x[c+16>>2]=x[c+8>>2];x[c+20>>2]=b;d=hb-16|0;hb=d;b=hb-16|0;hb=b;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;e=Li(b+8|0,b);g=x[e>>2];e=x[e+4>>2];hb=b+16|0;hb=d+16|0;x[c+24>>2]=g;x[c+28>>2]=e;b=x[a>>2];e=b<<24|(b&65280)<<8;d=b&16711680;g=d>>>8|0;h=b&-16777216;i=h>>>24|0;h=h<<8|d<<24;d=x[a+4>>2];b=h|(((d&255)<<24|b>>>8)&-16777216|((d&16777215)<<8|b>>>24)&16711680|(d>>>8&65280|d>>>24));v[c+32|0]=b;v[c+33|0]=b>>>8;v[c+34|0]=b>>>16;v[c+35|0]=b>>>24;b=e|(g|i);v[c+36|0]=b;v[c+37|0]=b>>>8;v[c+38|0]=b>>>16;v[c+39|0]=b>>>24;b=x[c+36>>2];x[c+24>>2]=x[c+32>>2];x[c+28>>2]=b;IM(j,a,yb(a));a=x[j>>2];d=x[j+4>>2];hb=c+48|0;if(m){b=Jk(f+20|0);x[114409]=0;x[f+8>>2]=d;P(91,b|0,f+8|0);c=x[114409];x[114409]=0;e:{f:{g:{if((c|0)!=1){x[114409]=0;x[f+8>>2]=a;P(91,b|0,f+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break g}if(Cb(k)){a=0;while(1){c=y[pc(k,a)|0];x[114409]=0;x[f+8>>2]=c;P(91,b|0,f+8|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}a=a+1|0;if(Cb(k)>>>0>a>>>0){continue}break}}a=bc(b);c=dc(b);x[114409]=0;c=U(92,f+8|0,a|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;a=S(93,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}x[f+4>>2]=a;a=f+4|0;ht(l,a);kg(a);Me(c);Me(b);break d}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Me(c);break a}lb=a;x[f+8>>2]=d;x[f+12>>2]=lb;b=Jk(f+20|0);x[114409]=0;T(100,b|0,f+8|0,f+16|0);a=x[114409];x[114409]=0;if((a|0)==1){a=N()|0;Me(b);Q(a|0);p()}x[114409]=0;a=S(93,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break c}x[f+4>>2]=a;a=f+4|0;ht(l,a);kg(a);Me(b)}hb=f+32|0;return}a=N()|0;break a}a=N()|0}Me(b);Q(a|0);p()}function PJ(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=0,t=0,u=E(0);j=hb-16|0;hb=j;s=a,t=Si(E(B[a+4256>>2]*E(3))),x[s+4264>>2]=t;s=a,u=E(cf(x[a+16>>2])>>>((x[a+4264>>2]^-1)>>>1&1)>>>0),B[s+4268>>2]=u;B[a+4272>>2]=E(B[a+4244>>2]*E(100))*E(.0061803399585187435);s=j,u=pe(E(10),E(E(OJ(a)+E(E(B[a+4228>>2]*E(11e3))+E(-1e4)))*E(.0005000000237487257))),B[s+12>>2]=u;x[j+8>>2]=1065353216;s=a,u=E(B[Ml(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[s+4280>>2]=u;d=pe(E(10),E(E(E(B[a+4212>>2]*E(1e4))+E(-1e4))*E(.0010000000474974513)));if(d!=E(1)){c=np(E(E(NJ(a)*E(6.2831854820251465))/B[a+4268>>2]));h=E(d+d);e=E(d*d);d=E(d*E(8));c=bz(E(E(E(E(c*h)+E(-2))+E(M(E(E(E(e*E(-4))+d)+E(E(E(E(e*E(4))*c)-d)*c)))))/E(h+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=hb-16|0;hb=i;d=B[a+4268>>2];c=E(B[a+4232>>2]*E(.30000001192092896));B[i+12>>2]=B[a+4240>>2]*E(.10000000149011612);x[i+8>>2]=1000593162;h=B[Qx(i+12|0,i+8|0)>>2];e=E(d*E(E(c+E(.007000000216066837))+h));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(E(E(B[(b<<2)+36352>>2]*h)+c)*d);b:{if(E(F(e))<E(2147483648)){g=~~e;break b}g=-2147483648}x[k>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}B[i+12>>2]=E(E(B[a+4248>>2]*E(100))*E(.009091000072658062))+E(.09091000258922577);x[i+8>>2]=1065353216;c=E(B[Ml(i+12|0,i+8|0)>>2]*d);h=E(c*E(.07500000298023224));c=E(c*E(.06700000166893005));b=0;while(1){g=(b<<2)+a|0;p=g+4316|0;n=b+n|0;e=pe(E(.9300000071525574),E(n|0));f=E(h*e);c:{if(E(F(f))<E(2147483648)){k=~~f;break c}k=-2147483648}x[p>>2]=k;k=g+4292|0;e=E(c*e);d:{if(E(F(e))<E(2147483648)){g=~~e;break d}g=-2147483648}x[k>>2]=g;b=b+1|0;if((b|0)!=6){continue}break}g=a+4348|0;c=E(d*E(.0035299998708069324));e:{if(E(F(c))<E(2147483648)){b=~~c;break e}b=-2147483648}x[g>>2]=b;g=a+4344|0;c=E(d*E(.0032500000670552254));f:{if(E(F(c))<E(2147483648)){b=~~c;break f}b=-2147483648}x[g>>2]=b;g=a+4340|0;d=E(d*E(.009999999776482582));g:{if(E(F(d))<E(2147483648)){b=~~d;break g}b=-2147483648}x[g>>2]=b;b=0;while(1){QJ((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}hb=i+16|0;b=hb-16|0;hb=b;c=Xg(a,5);e=Xg(a,11);d=E(c*Xg(a,4));h=E(E(d*E(.03999999910593033))+E(c*E(.02250000089406967)));c=E(e*Xg(a,10));e=E(E(c*E(.03999999910593033))+E(e*E(.02250000089406967)));if(v[a+4264|0]&1){f=Xg(a,3);l=Xg(a,9);f=E(f*d);d=E(Xg(a,2)*f);h=E(E(E(f*E(.12250000238418579))+h)+E(d*E(.1444000005722046)));f=E(l*c);c=E(Xg(a,8)*f);e=E(E(E(f*E(.12250000238418579))+e)+E(c*E(.1444000005722046)))}Xg(a,12);f=B[a+4496>>2];l=Xg(a,1);m=Xg(a,7);q=Xg(a,0);r=Xg(a,6);s=b,u=pe(E(10),E(E(OJ(a)+E(E(B[a+4236>>2]*E(12e3))+E(-1e4)))*E(.0005000000237487257))),B[s+12>>2]=u;x[b+8>>2]=1065353216;o=B[Ml(b+12|0,b+8|0)>>2];f=E(f*f);c=E(m*E(f*c));m=E(r*c);d=E(l*E(f*d));f=E(q*d);l=E(E(E(m+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(l/E(E(E(f+c)*E(.1444000005722046))+h))));B[a+4288>>2]=o*E(M(E(l/E(E(E(m+d)*E(.1444000005722046))+e))));hb=b+16|0;v[a+5046|0]=0;hb=j+16|0}function Sy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;h=hb-16|0;hb=h;j=D(b,896)+a|0;m=j+1075782|0;i=z[m>>1];e=h+8|0;k=a+1074312|0;Kb(e,k,23);g=c&15;a:{b:{c:{d:{e:{f:{if(Ib(e)){if(!(x[a+1074392>>2]|!y[(D(b,896)+a|0)+1075794|0])){w[m>>1]=g;break f}e=z[m>>1];if(e){f=e-1|0;w[m>>1]=f;e=0;if(f&65535){break c}}w[m>>1]=g;e=1;break c}e=h+8|0;Kb(e,k,52);f=c&256;if(!(!f|!Ib(e))){g:{if(!(y[a+480209|0]&16)){break g}e=D(b,896)+a|0;if(y[e+1075795|0]){i=CT(e+1075794|0)?1:i}if(y[e+1075796|0]!=1){break g}if(y[(D(b,896)+a|0)+1075798|0]){break b}}e=0;if(i<<16>>16<(g|0)){break c}if(y[a+480209|0]&16){if(Ff((D(b,896)+a|0)+1075794|0)){break c}}i=0;e=1;break c}if(x[a+480180>>2]&16777250){e=!(i&65535?(i<<16>>16)%((g>>>0<=1?1:g)|0)|0:1);i=i+1|0;break c}if(x[a+480180>>2]!=1){break d}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Ff((D(b,896)+a|0)+1075794|0)){break a}}if(g){break e}}e=0;break c}e=!((e>>>0)%(g>>>0)|0);break c}if(x[a+480180>>2]==16){e=x[a+1074392>>2]==(g|0)&(g|0)!=0;break c}h:{i:{j:{k:{l:{if(f){e=D(b,896)+a|0;if(y[e+1075796|0]==1){g=(y[e+1075799|0]>15)+g|0}g=g>>>0<=1?1:g;break l}if(y[a+480209|0]&16){break i}g=g>>>0<=1?1:g;if(x[a+1074416>>2]){break k}}e=0;break j}e=!(A[a+1074392>>2]%(g>>>0)|0)}i=i+1|0;break h}e=0;i=x[a+480180>>2]&1048580?0:i}if(!(!(y[(D(b,896)+a|0)+1075794|0]|!f?x[a+1074392>>2]:1)|i<<16>>16<(g|0))){e=1}g=h+8|0;Kb(g,k,52);if(!Ib(g)|c){break c}e=!x[a+1074392>>2]}g=j+1074984|0;j=(D(b,896)+a|0)+1075060|0;m:{if(x[j>>2]){break m}f=h+8|0;Kb(f,k,38);if(!Ib(f)){break m}if(!Ej(g)){break a}}f=h+8|0;Kb(f,k,106);if(u=0,B=Ib(f),C=x[(D(b,896)+a|0)+1075680>>2],C?u:B){break a}if(e){e=D(b,896)+a|0;p=e+1075672|0;x[h+4>>2]=x[p>>2];f=c>>>4&15;if(f){l=h+8|0;Kb(l,k,52);n:{if(u=Ib(l),B=0,C=y[(D(b,896)+a|0)+1075796|0]==1,C?u:B){break n}l=v[f+26960|0];if(l){x[h+4>>2]=(D(l,x[h+4>>2])|0)/16;break n}x[h+4>>2]=x[h+4>>2]+(v[f+26976|0]<<2)}ce(h+4|0,0,256);f=(D(b,896)+a|0)+1075072|0;x[f>>2]=x[f>>2]|2097152}q=e+1075684|0;l=x[q>>2];f=y[e+1075808|0];o:{if(!x[j>>2]|(f-1&255)>>>0>119){break o}if(!(!(y[(D(b,896)+a|0)+1075073|0]&2)|x[a+480180>>2]!=2)){e=h+8|0;Kb(e,k,108);if(!Ib(e)){break o}}yN(a,b,0,f,1)}e=0;p:{if(!(x[a+480180>>2]&1048580)){break p}e=(c|0)<256;if((c|0)>255){break p}j=y[(D(b,896)+a|0)+1075795|0];if(!j){break p}e=1;Up(a,g,j,0,0,1)}j=D(b,896)+a|0;n=j+1075644|0;s=x[n>>2];x[n>>2]=0;o=j+1075072|0;t=x[o>>2];r=h+8|0;Kb(r,k,23);qt(a,g,f,Ib(r),e,0,b);if(!y[j+1075795|0]){x[n>>2]=s}if(!(!(t&4096)|x[a+480180>>2]!=4)){x[o>>2]=x[o>>2]|4096}e=j+1075794|0;x[p>>2]=x[h+4>>2];if(z[a+480192>>1]){v[e|0]=f;aM(a,b)}if(!(!(x[a+480180>>2]&16777248)|(y[e|0]|!l))){x[q>>2]=l}e=x[a+480180>>2];f=h+8|0;Kb(f,k,23);if(Ib(f)){x[g>>2]=0;x[g+4>>2]=0}e=e&16777250;q:{if(d-1>>>0>9){break q}f=x[(D(b,896)+a|0)+1075088>>2];if(!f){break q}r:{if((d|0)==1){b=x[(D(b,896)+a|0)+1075648>>2];break r}j=(D(b,896)+a|0)+1075648|0;b=x[(f+(d<<2)|0)+60>>2];x[j>>2]=b}Tp(a,g,b)}i=e?i:0}a=h+8|0;Kb(a,k,52);b=Ib(a);Kb(a,k,23);if(Ib(a)){break a}i=(b&c>>>8)+i|0}w[m>>1]=i}hb=h+16|0}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-224|0;hb=f;Af(f+208|0,b);e=hb-32|0;hb=e;x[e+28>>2]=0;Xi(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(Vj(9875)|0)){break c}x[e+24>>2]=0;Xi(b,e+24|0);h=-1;g=x[e+24>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Xb(e+12|0);x[114409]=0;i=U(734,b|0,g|0,256)|0;j=x[114409];x[114409]=0;if((j|0)==1){break b}if(!i){break e}x[114409]=0;T(13,e|0,d|0,g|0);i=x[114409];x[114409]=0;if((i|0)!=1){break f}break b}g=Xb(e+12|0);x[114409]=0;i=U(736,b|0,g|0,255)|0;j=x[114409];x[114409]=0;if((j|0)==1){break b}if(!i){break d}x[114409]=0;T(13,e|0,d|0,g|0);i=x[114409];x[114409]=0;if((i|0)==1){break b}}Eb(c,e);xb(e);xb(g);g=0;w[e>>1]=0;Ef(b,e);x[e+12>>2]=0;Xi(b,e+12|0);i=x[e+12>>2];if(i>>>0>50){break c}if(i){while(1){if(!TK(a,b,d)){break c}g=g+1|0;if(g>>>0<A[e+12>>2]){continue}break}}x[e+12>>2]=0;Xi(b,e+12|0);h=x[e+12>>2]==(Vj(9913)|0)?1:-1;break c}xb(g);break c}xb(g)}hb=e+32|0;break a}a=N()|0;xb(g);Q(a|0);p()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!h){bo(x[x[b>>2]-12>>2]+b|0,0);h=x[f+220>>2];x[f+16>>2]=x[f+216>>2];x[f+20>>2]=h;h=x[f+212>>2];x[f+8>>2]=x[f+208>>2];x[f+12>>2]=h;tj(b,f+8|0);b=vl(f+104|0,b);x[114409]=0;h=O(694,f+92|0,9982)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}x[114409]=0;x[f+72>>2]=3;x[f+76>>2]=0;T(695,b|0,h|0,f+72|0);e=x[114409];x[114409]=0;if((e|0)==1){break i}Gb(h);x[114409]=0;v[f+91|0]=0;h=O(694,f+72|0,10280)|0;e=x[114409];x[114409]=0;if((e|0)==1){break j}x[114409]=0;U(696,b|0,f+91|0,h|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}Gb(h);x[114409]=0;h=y[f+91|0];e=S(1741,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break l}x[114409]=0;g=S(1742,b|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break m}x[f+68>>2]=g;x[f+64>>2]=e;if(Hb(f- -64|0,f+68|0)){h=h?0:d;while(1){x[114409]=0;w[f+62>>1]=65535;d=O(694,f+48|0,11796)|0;e=x[114409];x[114409]=0;if((e|0)==1){break p}x[114409]=0;e=U(1743,b|0,f- -64|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break o}Gb(d);s:{if(!e){x[114409]=0;W(1744,b|0,f- -64|0,c|0,h|0);d=x[114409];x[114409]=0;if((d|0)==1){break n}break s}x[114409]=0;d=O(694,f+36|0,11558)|0;e=x[114409];x[114409]=0;t:{u:{if((e|0)!=1){x[114409]=0;e=U(1743,b|0,f- -64|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break u}Gb(d);if(e){break t}x[114409]=0;U(1745,b|0,f- -64|0,f+62|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break s}break n}a=N()|0;break g}a=N()|0;Gb(d);break g}x[114409]=0;d=O(694,f+24|0,11195)|0;e=x[114409];x[114409]=0;if((e|0)==1){break r}x[114409]=0;e=U(1743,b|0,f- -64|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break q}Gb(d);if(e){break s}x[114409]=0;W(1746,b|0,f- -64|0,a|0,h|0);d=x[114409];x[114409]=0;if((d|0)==1){break n}}d=f- -64|0;sf(d);if(Hb(d,f+68|0)){continue}break}}a=x[b>>2];Ig(b);h=a&1073741824?-1:1}hb=f+224|0;return h|0}a=N()|0;break g}a=N()|0;Gb(d);break g}a=N()|0;break g}a=N()|0;Gb(d);break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;Gb(h);break g}a=N()|0;break g}a=N()|0;Gb(h);break g}a=N()|0}Ig(b);Q(a|0);p()}function eg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-112|0;hb=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;lf(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;lf(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}lf(j- -64|0,d,e,b,c,128-f|0);Fl(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;lf(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}lf(j+16|0,d,e,h,i,p+127|0);Fl(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;hb=j+112|0}function _b(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[114289]){break a}a=a+b|0;c:{d:{if(x[114290]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+12>>2];c=x[d+8>>2];if((b|0)==(c|0)){i=457140,j=x[114285]&wqa(-2,e),x[i>>2]=j;break b}x[c+12>>2]=b;x[b+8>>2]=c;break b}g=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[114287]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!g){break b}c=x[d+28>>2];e=(c<<2)+457444|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=457144,j=x[114286]&wqa(-2,c),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=g;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[114291]==(f|0)){x[114291]=d;a=x[114288]+a|0;x[114288]=a;x[d+4>>2]=a|1;if(x[114290]!=(d|0)){break a}x[114287]=0;x[114290]=0;return}if(x[114290]==(f|0)){x[114290]=d;a=x[114287]+a|0;x[114287]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+12>>2];c=x[f+8>>2];if((b|0)==(c|0)){i=457140,j=x[114285]&wqa(-2,e),x[i>>2]=j;break g}x[c+12>>2]=b;x[b+8>>2]=c;break g}g=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!g){break g}c=x[f+28>>2];e=(c<<2)+457444|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=457144,j=x[114286]&wqa(-2,c),x[i>>2]=j;break g}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=g;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[114290]!=(d|0)){break f}x[114287]=a;return}if(a>>>0<=255){b=(a&-8)+457180|0;c=x[114285];a=1<<(a>>>3);k:{if(!(c&a)){x[114285]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+457444|0;l:{m:{e=x[114286];h=1<<c;n:{if(!(e&h)){x[114286]=e|h;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=c>>>29|0;c=c<<1;h=e+(b&4)|0;b=x[h+16>>2];if(b){continue}break}x[h+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[114293]-1|0;x[114293]=a?a:-1}}function PW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;x[e+28>>2]=b;if((d|0)<=0){a=0}else{x[e+8>>2]=d;x[e+16>>2]=214748364;s=e,t=D(x[Mb(e+28|0,e+16|0)>>2],20),x[s+20>>2]=t;ew(c,x[Mb(e+8|0,e+20|0)>>2]);x[e+8>>2]=a;x[e+12>>2]=x[e+28>>2];a=0;while(1){a:{b=e+8|0;f=Sg(b,a);j=Sg(b,a+4|0);n=Sg(b,a+5|0);s=e,t=Sg(b,a+6|0)<<8|Sg(b,a+7|0),x[s+24>>2]=t;b=n|j<<8;q=a+8|0;b:{c:{d:{e:{switch(f|0){case 0:f:{if(b>>>0<=d>>>0){j=0;n=0;if(b){break f}break b}b=ec(8);x[114409]=0;a=S(328,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break d}break c}while(1){s=e,t=Sg(e+8|0,j+q|0),v[s+20|0]=t;_o(c,e+20|0);j=j+1|0;if((b|0)!=(j|0)){continue}break};j=b;n=b;break b;case 1:break e;default:break a}}Fh(e+24|0,d);j=x[e+24>>2];g=Sg(e+8|0,a+10|0);v[e+20|0]=g;_o(c,e+20|0);f=x[e+24>>2];x[e+24>>2]=f-1;n=b+3&65532;if((f|0)<2){break b}h=a+11|0;l=0;m=0;k=0;b=0;while(1){a=$f(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((k|0)<=7){if(a){f=b;break h}b=b+1|0;l=8;break k}f=b+1|0;l:{if(!a){if(!$f(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!$f(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!$f(h,a,1,e+8|0)){break n}f=$f(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;o:{p:{q:{f=((l<<3)+f|0)-17|0;r:{if((f|0)<0){a=ec(8);x[114409]=0;b=S(328,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break q}break r}if(f>>>0<56){break o}a=ec(8);x[114409]=0;b=S(328,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break p}}b=N()|0;ic(a);Q(b|0);p()}da(b|0,76196,238);p()}da(b|0,76196,238);p()}l=y[f+23232|0];if((l|0)!=8){break j}break l}a=4;b=f;if((l|0)!=8){break j}}l=8;a=1;if((m|0)>19){break j}}a=0;break i}m=m+8|0}i=x[e+24>>2];s:{if((i|0)<=0){break s}while(1){f=e+8|0;o=(b|0)/8|0;i=o+h|0;r=Sg(f,i);i=(Sg(f,i+1|0)<<8|r<<16|Sg(f,i+2|0))<<(b-(o<<3)|0)+8^-2147483648;f=32-l|0;g=g-((i>>>f)-(-2147483648>>>f)|0)|0;v[e+20|0]=g;_o(c,e+20|0);f=x[e+24>>2];i=f-1|0;x[e+24>>2]=i;b=b+l|0;if(!a){break s}a=a-1|0;if((f|0)>1){continue}break}}k=(k|0)==31?31:k+1|0;break g}t:{u:{v:{a=f+1|0;if(!$f(h,a,1,e+8|0)){g=2;break v}a=f+2|0;if(!$f(h,a,1,e+8|0)){g=4;break v}a=f+3|0;if(!$f(h,a,1,e+8|0)){g=6;break v}a=f+5|0;if(!$f(h,f+4|0,1,e+8|0)){b=f+8|0;a=$f(h,a,3,e+8|0)+8|0;break t}b=f+10|0;g=16;a=$f(h,a,5,e+8|0);break u}b=a+2|0;a=$f(h,a+1|0,1,e+8|0)}a=a+g|0}w:{if($f(h,b,1,e+8|0)){f=-256;g=12;break w}b=b+1|0;g=$f(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;i=$f(h,b,g,e+8|0);if(a>>>0>=3){k=k-((a|0)!=3)|0;k=((k|0)<=1?1:k)-1|0}f=xc(c)+((i^-1)+f|0)|0;if(f>>>0<xc(c)>>>0){if(x[e+24>>2]<=0){break b}b=b+g|0;while(1){g=y[Cc(c,f)|0];v[e+20|0]=g;_o(c,e+20|0);o=x[e+24>>2];i=o-1|0;x[e+24>>2]=i;if(a>>>0<2){break g}f=f+1|0;a=a-1|0;if((o|0)>1){continue}break}break g}b=ec(8);x[114409]=0;a=S(328,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break c}da(a|0,76196,238);p()}m=m-(m>>3)|0;if((i|0)>0){continue}break}break b}da(a|0,76196,238);p()}a=N()|0;ic(b);Q(a|0);p()}a=n+q|0;d=d-j|0;if((d|0)>0){continue}}break}a=kd(c)^1}hb=e+32|0;return a|0}function VL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;a:{b:{if(b){f=a+327720|0;b=hb-352|0;hb=b;sO(b+340|0,8);x[114409]=0;ma(1270,b+328|0,9);h=x[114409];x[114409]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((h|0)!=1){x[114409]=0;h=O(1271,b+312|0,14)|0;e=x[114409];x[114409]=0;if((e|0)==1){break n}x[114409]=0;P(1272,b+340|0,h|0);e=x[114409];x[114409]=0;if((e|0)==1){break m}x[114409]=0;P(1272,b+328|0,h|0);e=x[114409];x[114409]=0;if((e|0)==1){break m}rO(b+240|0,4900);rO(b+168|0,32e3);oO(b+96|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[114409]=0;e=O(1273,b+72|0,b+340|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break l}Dt(b+84|0,b+240|0,e);Tf(e);x[114409]=0;e=O(1273,b+48|0,b+328|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break k}Dt(b+60|0,b+168|0,e);Tf(e);x[114409]=0;e=O(1273,b+24|0,b+84|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break j}Dt(b+36|0,b+96|0,e);Tf(e);x[114409]=0;g=O(1273,b|0,b+60|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}e=b+12|0;Dt(e,b+96|0,g);Tf(g);g=b+84|0;aq(g);i=b+36|0;aq(i);j=b+60|0;aq(j);aq(e);k=b+328|0;aq(k);$p(g,Jn(f,0));$p(i,Jn(f,1));$p(j,Jn(f,2));$p(e,Jn(f,3));$p(k,Jn(f,4));Tf(e);Tf(i);Tf(j);Tf(g);_p(h);Tf(k);Tf(b+340|0);hb=b+352|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break h}a=N()|0;Tf(b+36|0)}Tf(b+60|0)}Tf(b+84|0)}_p(h)}Tf(b+328|0)}Tf(b+340|0);Q(a|0);p()}ry(a+131112|0,9.6377,.97);ry(a+196648|0,8.5,.5);ry(a+262184|0,2.7625,.425);b=a+368680|0;qy(b,a);break b}b=a+368680|0;if(qy(b,a)){break a}}g=a+24|0;n=C[a+8>>3];i=y[a+16|0];h=hb+-64|0;hb=h;while(1){q=+(l-4096|0)*.0001220703125;m=0;f=0;while(1){d=1;e=h+(f<<3)|0;c=+(f|0)-q;o=c+-3.5;if(F(o)<1e-8){c=n}else{o:{p:{switch(i|0){case 0:d=.5-De(c*.8975979010256552)*.5;break o;case 1:d=De(c*.8975979010256552)*-.46+.54;break o;case 2:c=c*.8975979010256552;d=De(c+c);d=De(c)*-.5+.42+d*.08;break o;case 3:c=c*.8975979010256552;d=De(c+c);d=De(c)*-.49364+.44959+d*.05677;break o;case 4:c=c*.8975979010256552;d=De(c+c);d=De(c)*-.49755+.42323+d*.07922;break o;case 5:c=c*.8975979010256552;d=De(c+c);d=De(c)*-.48829+.35875+d*.14128+De(c*3)*-.01168;break o;case 6:c=c*.8975979010256552;d=De(c+c);d=De(c)*-.49703+.40217+d*.09392+De(c*3)*-.00183;break o;case 7:break p;default:break o}}c=c*.8975979010256552;d=De(c+c);d=De(c)*-.49804+.40243+d*.09831+De(c*3)*-.00122}c=o*3.141592653589793;c=vi(c*n)/c}c=c*d;C[e>>3]=c;m=c+m;f=f+1|0;if((f|0)!=8){continue}break}c=1/m;j=l<<3;f=0;while(1){k=g+(f+j<<1)|0;d=J(C[h+(f<<3)>>3]*32768*c+.5);d=I(d>32768?32768:d,-32768);q:{if(F(d)<2147483648){e=~~d;break q}e=-2147483648}w[k>>1]=e;f=f+1|0;if((f|0)!=8){continue}break}l=l+1|0;if((l|0)!=8193){continue}break}hb=h- -64|0;f=x[a+20>>2];x[b+16>>2]=x[a+16>>2];x[b+20>>2]=f;f=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=f;f=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=f}}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;r=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Wf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Ze(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;yf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}i=x[a+44>>2];x[e+28>>2]=i;h=x[a+48>>2];x[e+32>>2]=h;j=x[a+52>>2];x[e+36>>2]=j;k=x[a+56>>2];x[e+40>>2]=k;l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];n=b;f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=b;b=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=b;b:{c:{if(!d){b=l>>12;g=m>>12;break c}while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=(((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+r|0;x[e+72>>2]=b;x[e+76>>2]=0;d:{b=x[e+64>>2];if((b|0)<=0){break d}while(1){e:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=w[(g<<1|2)+f>>1];g=w[f+((g&2147483646)<<1)>>1];x[114409]=0;P(1113,x[e+56>>2],(g+i|0)/8<<16>>16);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+56>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=w[(i<<1|2)+f>>1];f=w[f+((i&2147483646)<<1)>>1];x[114409]=0;P(1113,b|0,(f+h|0)/8<<16>>16);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+56>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;b=O(1115,b|0,x[e+60>>2])|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;o=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;q=x[i+4>>2];j=Yb(q,-16777216,16776704);k=x[a+64>>2];n=Yb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=q;q=x[a+72>>2];o=o<<8;h=sqa(h,h>>31,o,o>>31);s=lb;k=sqa(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=sqa(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(o&q);f=g&1;g=0;b=1;if(f){continue}break}b=x[a+32>>2];m=x[a+28>>2]+m|0;g=m>>12;x[c>>2]=x[c>>2]+D(g,x[e>>2]);l=b+l|0;b=l>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}k=x[e+40>>2];j=x[e+36>>2];h=x[e+32>>2];i=x[e+28>>2];f=x[e+16>>2];n=x[e+20>>2]}x[a>>2]=f;x[a+4>>2]=n;x[a+40>>2]=l;x[a+20>>2]=g;x[a+36>>2]=m;x[a+56>>2]=k;x[a+52>>2]=j;x[a+48>>2]=h;x[a+44>>2]=i;x[a+24>>2]=b;hb=e+80|0;return}b=N()|0;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function mM(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=0,k=E(0),l=0,m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){Gp(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;BM(a)}lM(a+24648|0);q=x[a+24620>>2];g=hb-144|0;hb=g;d=!b;e=a+393352|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}j=D(c,44)+81024|0;if(!((j|0)==x[e+4112>>2]&d)){x[e+4112>>2]=j;c=g+12|0;d=x[j+24>>2];x[c>>2]=d;f=x[j+16>>2];x[c+4>>2]=f;x[c+8>>2]=x[j+4>>2];l=(d|0)>(f|0)?d:f;if((l|0)<=-601){i=f;f=l+600|0;x[c+4>>2]=i-f;x[c>>2]=d-f}m=E(q>>>0);h=E(B[j+36>>2]*E(79.30999755859375));a:{if(E(F(h))<E(2147483648)){d=~~h;break a}d=-2147483648}x[c+16>>2]=d- -8192;h=E(E(B[j+32>>2]*E(117.9612045288086))+E(4915.05029296875));b:{if(E(F(h))<E(2147483648)){d=~~h;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;l=0;h=B[j+8>>2];k=B[j+20>>2];k=E((k>E(.10000000149011612)?E(.10000000149011612):k)*m);c:{if(E(F(k))<E(2147483648)){d=~~k;break c}d=-2147483648}f=(d|0)<=96?96:d;i=f-7500|0;n=f>>>0>=i>>>0?i:0;k=E(B[j+28>>2]*m);d:{if(E(F(k))<E(2147483648)){i=~~k;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;r=i>>>0>=3800?3800:i;x[c+24>>2]=r;n=(d|0)<128?d-128|0:0;h=E(h*m);e:{if(E(F(h))<E(2147483648)){o=~~h;break e}o=-2147483648}d=i-3800|0;i=(o+n|0)+(d>>>0<=i>>>0?d:0)|0;x[c+32>>2]=i;n=f>>>0>=7500?7500:f;while(1){f=D(l,12);d=f+c|0;f=f+36480|0;w[d+42>>1]=z[f+10>>1];w[d+36>>1]=z[f+4>>1];o=z[f+6>>1]|z[f+8>>1]<<16;w[d+38>>1]=o;w[d+40>>1]=o>>>16;x[d+44>>2]=((D(x[f>>2],r)+50|0)/100|0)+n;l=l+1|0;if((l|0)!=8){continue}break}h=E(i|0);k=E(pe(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/h))*E(32768));f:{if(E(F(k))<E(2147483648)){d=~~k;break f}d=-2147483648}x[c+12>>2]=d;h=E(B[j+12>>2]*h);s=c,t=pe(E(.0010000000474974513),h>E(4720)?E(E(4720)/h):E(1)),B[s+28>>2]=t;x[e+4124>>2]=x[g+44>>2];c=CJ(DJ(x[g+20>>2]),m);w[e+4190>>1]=c;w[e+4188>>1]=c;c=z[g+28>>1]<<1;w[e+4198>>1]=c;w[e+4196>>1]=c;while(1){c=(p<<4)+e|0;d=(g+12|0)+D(p,12)|0;j=x[d+44>>2];x[c+4204>>2]=j;x[c+4208>>2]=j;w[c+4212>>1]=z[d+36>>1];w[c+4214>>1]=z[d+42>>1];w[c+4216>>1]=z[d+40>>1];w[c+4218>>1]=z[d+38>>1];p=p+1|0;if((p|0)!=8){continue}break}x[e+53996>>2]=x[g+36>>2];d=e+4184|0;c=x[g+16>>2];if((c|0)>-9e3){c=BJ(c)}else{c=0}x[d>>2]=c;d=e+54052|0;c=x[g+12>>2];if((c|0)>=-8999){c=BJ(c)}else{c=0}x[d>>2]=c;c=x[g+32>>2];d=e+54036|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+54010>>1]=c;w[e+54008>>1]=c;w[e+54006>>1]=c;w[e+54004>>1]=c;x[g+8>>2]=x[g+24>>2];ce(g+8|0,0,32752);c=z[g+8>>1];w[e+54018>>1]=c;w[e+54014>>1]=0;w[e+54016>>1]=0;w[e+54012>>1]=c;h=B[g+40>>2];s=g,u=CJ(E(h*h),m),x[s+4>>2]=u;ce(g+4|0,256,32512);c=z[g+4>>1];w[e+54026>>1]=c;w[e+54022>>1]=0;w[e+54024>>1]=0;w[e+54020>>1]=c}if(b){x[e+4120>>2]=0;FJ(e)}b=D(q,5);if(b>>>0>A[e+4124>>2]){x[e+4124>>2]=b}hb=g+144|0;b=a+1304392|0;if(yd(b)){DO(x[b>>2],x[a+24620>>2])}}function I5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=hb-144|0;hb=d;x[d+140>>2]=c;a:{b:{c:{d:{if(!(b<.8)){x[114409]=0;c=$(2283)|0;e=x[114409];x[114409]=0;e:{f:{g:{if((e|0)!=1){x[d+72>>2]=c;c=x[d+140>>2];x[114409]=0;c=S(2284,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}x[d+60>>2]=c;sn(x[d+72>>2],x[d+60>>2]);c=x[d+72>>2];a=hf(d+124|0,a);x[114409]=0;e=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=e;e=x[a+4>>2];x[d+40>>2]=x[a>>2];x[d+44>>2]=e;a=U(2269,c|0,d+40|0,15)|0;c=x[114409];x[114409]=0;if((c|0)==1){break g}if(a){a=x[d+72>>2];x[114409]=0;S(1490,a|0)|0;a=x[114409];x[114409]=0;f=1;if((a|0)==1){break g}}od(d+60|0);Ai(d+72|0);break c}c=R(0)|0;break d}c=R(0)|0;od(d+60|0);break e}c=R(0)|0}Ai(d+72|0);break d}if(!(b<.6)){x[114409]=0;c=$(2283)|0;e=x[114409];x[114409]=0;h:{i:{j:{if((e|0)!=1){x[d+72>>2]=c;c=x[d+140>>2];x[114409]=0;c=S(2284,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break i}x[d+60>>2]=c;sn(x[d+72>>2],x[d+60>>2]);c=x[d+72>>2];a=hf(d+108|0,a);x[114409]=0;e=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=e;e=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=e;a=U(2269,c|0,d+24|0,2)|0;c=x[114409];x[114409]=0;if((c|0)==1){break j}if(a){a=x[d+72>>2];x[114409]=0;S(1490,a|0)|0;a=x[114409];x[114409]=0;f=.8;if((a|0)==1){break j}}od(d+60|0);Ai(d+72|0);break c}c=R(0)|0;break d}c=R(0)|0;od(d+60|0);break h}c=R(0)|0}Ai(d+72|0);break d}f=.2;if(!(b<.2)){x[114409]=0;c=$(2283)|0;e=x[114409];x[114409]=0;k:{l:{m:{if((e|0)!=1){x[d+72>>2]=c;c=x[d+140>>2];x[114409]=0;c=S(2284,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}x[d+60>>2]=c;sn(x[d+72>>2],x[d+60>>2]);c=x[d+72>>2];a=hf(d+92|0,a);x[114409]=0;e=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=e;e=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=e;a=U(2269,c|0,d+8|0,0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break m}f=0;if(a){a=x[d+72>>2];x[114409]=0;S(1490,a|0)|0;a=x[114409];x[114409]=0;f=.6;if((a|0)==1){break m}}od(d+60|0);Ai(d+72|0);break c}c=R(0)|0;break d}c=R(0)|0;od(d+60|0);break k}c=R(0)|0}Ai(d+72|0);break d}if(b<.1){break c}x[114409]=0;T(878,d+72|0,a|0,2048);c=x[114409];x[114409]=0;n:{o:{p:{if((c|0)!=1){x[114409]=0;c=S(445,d+72|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break o}e=x[d+72>>2];x[114409]=0;a=S(228,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break o}x[114409]=0;a=fE(2285,3,0,c,e,a,0);c=x[114409];x[114409]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=C[(a<<3)+37640>>3];Jc(d+72|0);break c}c=R(0)|0;break d}a=ec(8);x[114409]=0;e=O(122,d+60|0,17381)|0;c=x[114409];x[114409]=0;if((c|0)!=1){a=oc(a,e);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}c=R(0)|0;xb(e);break n}c=R(0)|0;ic(a);break n}c=R(0)|0}Jc(d+72|0)}Y(c|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;f=0;if((a|0)==1){break a}}od(d+140|0);hb=d+144|0;return+f}p()}a=N()|0;od(d+140|0);Q(a|0);p()}function ks(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[114290]){if(c>>>0<=255){d=x[a+8>>2];e=x[a+12>>2];if((d|0)!=(e|0)){break e}i=457140,j=x[114285]&wqa(-2,c>>>3|0),x[i>>2]=j;break b}g=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[114287]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=e;x[e+8>>2]=d;break b}c=0}if(!g){break b}d=x[a+28>>2];e=(d<<2)+457444|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=457144,j=x[114286]&wqa(-2,d),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=g;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[114291]==(f|0)){x[114291]=a;b=x[114288]+b|0;x[114288]=b;x[a+4>>2]=b|1;if(x[114290]!=(a|0)){break a}x[114287]=0;x[114290]=0;return}if(x[114290]==(f|0)){x[114290]=a;b=x[114287]+b|0;x[114287]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+12>>2];d=x[f+8>>2];if((c|0)==(d|0)){i=457140,j=x[114285]&wqa(-2,e),x[i>>2]=j;break h}x[d+12>>2]=c;x[c+8>>2]=d;break h}g=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!g){break h}d=x[f+28>>2];e=(d<<2)+457444|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=457144,j=x[114286]&wqa(-2,d),x[i>>2]=j;break h}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=g;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[114290]!=(a|0)){break g}x[114287]=b;return}if(b>>>0<=255){c=(b&-8)+457180|0;d=x[114285];b=1<<(b>>>3);l:{if(!(d&b)){x[114285]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+457444|0;m:{e=x[114286];h=1<<d;n:{if(!(e&h)){x[114286]=e|h;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;h=e+(c&4)|0;c=x[h+16>>2];if(c){continue}break}x[h+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function qD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-144|0;hb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(x[18872]>=(c|0)){wv(a+108|0,c);x[114409]=0;c=O(2,a+96|0,13619)|0;d=x[114409];x[114409]=0;if((d|0)==1){break E}x[114409]=0;T(3,a+120|0,a+108|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break D}x[114409]=0;d=O(4,a+72|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break C}x[114409]=0;e=O(2,a+60|0,15361)|0;f=x[114409];x[114409]=0;if((f|0)==1){break B}x[114409]=0;T(5,a+84|0,d|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break A}x[114409]=0;T(3,a+132|0,a+120|0,a+84|0);f=x[114409];x[114409]=0;if((f|0)==1){break z}xb(a+84|0);xb(e);xb(d);xb(a+120|0);xb(c);xb(a+108|0);c=x[b>>2]?x[b>>2]:17381;x[114409]=0;T(6,a+120|0,1,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break t}c=x[b+4>>2]?x[b+4>>2]:17381;x[114409]=0;T(6,a+108|0,1,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break s}b=x[b+8>>2];x[114409]=0;x[a+48>>2]=b;P(7,a+84|0,a+48|0);b=x[114409];x[114409]=0;if((b|0)==1){break r}x[114409]=0;b=O(8,460232,13498)|0;c=x[114409];x[114409]=0;if((c|0)==1){break q}x[114409]=0;T(9,a+48|0,0,a+120|0);c=x[114409];x[114409]=0;if((c|0)==1){break p}x[114409]=0;b=O(10,b|0,a+48|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break o}x[114409]=0;b=O(8,b|0,13222)|0;c=x[114409];x[114409]=0;if((c|0)==1){break o}x[114409]=0;T(9,a+36|0,0,a+84|0);c=x[114409];x[114409]=0;if((c|0)==1){break n}x[114409]=0;b=O(10,b|0,a+36|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break m}x[114409]=0;b=O(8,b|0,13219)|0;c=x[114409];x[114409]=0;if((c|0)==1){break m}x[114409]=0;b=O(8,b|0,13619)|0;c=x[114409];x[114409]=0;if((c|0)==1){break m}x[114409]=0;T(9,a+24|0,0,a+132|0);c=x[114409];x[114409]=0;if((c|0)==1){break l}x[114409]=0;b=O(10,b|0,a+24|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break k}x[114409]=0;b=O(8,b|0,9292)|0;c=x[114409];x[114409]=0;if((c|0)==1){break k}x[114409]=0;T(9,a+12|0,0,a+108|0);c=x[114409];x[114409]=0;if((c|0)==1){break j}x[114409]=0;b=O(10,b|0,a+12|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}x[114409]=0;b=O(8,b|0,9290)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}x[114409]=0;O(11,b|0,12)|0;b=x[114409];x[114409]=0;if((b|0)==1){break i}xb(a+12|0);xb(a+24|0);xb(a+36|0);xb(a+48|0);xb(a+84|0);xb(a+108|0);xb(a+120|0);xb(a+132|0)}hb=a+144|0;return}b=N()|0;break u}b=N()|0;break v}b=N()|0;break w}b=N()|0;break x}b=N()|0;break y}b=N()|0;xb(a+84|0)}xb(e)}xb(d)}xb(a+120|0)}xb(c)}xb(a+108|0);break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;break e}b=N()|0;break e}b=N()|0;break f}b=N()|0;break f}b=N()|0;break g}b=N()|0;break g}b=N()|0;break h}b=N()|0;break h}b=N()|0;xb(a+12|0)}xb(a+24|0)}xb(a+36|0)}xb(a+48|0)}xb(a+84|0)}xb(a+108|0)}xb(a+120|0)}xb(a+132|0)}Q(b|0);p()}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;r=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Wf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Ze(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;yf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}i=x[a+44>>2];x[e+28>>2]=i;h=x[a+48>>2];x[e+32>>2]=h;j=x[a+52>>2];x[e+36>>2]=j;k=x[a+56>>2];x[e+40>>2]=k;l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];n=b;f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=b;b=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=b;b:{c:{if(!d){b=l>>12;g=m>>12;break c}while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=((x[e+20>>2]&2147483647)<<1|b>>>31)&-2;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+r|0;x[e+72>>2]=b;x[e+76>>2]=0;d:{b=x[e+64>>2];if((b|0)<=0){break d}while(1){e:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=v[(g|1)+f|0];g=v[f+(g&-2)|0];x[114409]=0;P(1113,x[e+56>>2],g+i<<5);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+56>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=v[(i|1)+f|0];f=v[f+(i&-2)|0];x[114409]=0;P(1113,b|0,f+h<<5);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+56>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;b=O(1115,b|0,x[e+60>>2])|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;o=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;q=x[i+4>>2];j=Yb(q,-16777216,16776704);k=x[a+64>>2];n=Yb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=q;q=x[a+72>>2];o=o<<8;h=sqa(h,h>>31,o,o>>31);s=lb;k=sqa(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=sqa(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(o&q);f=g&1;g=0;b=1;if(f){continue}break}b=x[a+32>>2];m=x[a+28>>2]+m|0;g=m>>12;x[c>>2]=x[c>>2]+D(g,x[e>>2]);l=b+l|0;b=l>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}k=x[e+40>>2];j=x[e+36>>2];h=x[e+32>>2];i=x[e+28>>2];f=x[e+16>>2];n=x[e+20>>2]}x[a>>2]=f;x[a+4>>2]=n;x[a+40>>2]=l;x[a+20>>2]=g;x[a+36>>2]=m;x[a+56>>2]=k;x[a+52>>2]=j;x[a+48>>2]=h;x[a+44>>2]=i;x[a+24>>2]=b;hb=e+80|0;return}b=N()|0;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function Yba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb-32|0;hb=c;if(Ah(b)){g=Fk(b);j=x[b+12>>2];e=hb-16|0;hb=e;f=c+20|0;x[f>>2]=0;x[f+4>>2]=0;x[e+4>>2]=0;Zc(f+8|0);Yd(e+4|0,x[Bb(e,f)>>2]);a:{if(!g){break a}x[114409]=0;P(690,f|0,g|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(1669,f|0,g|0);d=x[114409];x[114409]=0;if((d|0)!=1){break a}}a=N()|0;co(e+4|0);Q(a|0);p()}d=e+4|0;Xd(d);co(d);hb=e+16|0;b:{if(!j){break b}while(1){e=x[x[a>>2]-12>>2];x[114409]=0;e=S(1675,a+e|0)|0;d=x[114409];x[114409]=0;c:{if((d|0)!=1){d:{if(!e){break b}x[114409]=0;v[c+19|0]=0;O(1676,a|0,c+19|0)|0;e=x[114409];x[114409]=0;e:{if((e|0)!=1){e=v[c+19|0];if(e){break e}i=i+1|0;break c}break d}v[c+18|0]=0;f:{if((e|0)>=0){break f}x[114409]=0;O(1676,a|0,c+18|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break f}break d}v[c+17|0]=0;di(c+11|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{e=e&127;e=(e?e-1|0:0)&65535;k=e>>>0>=g>>>0;B:{C:{if(!k){x[114409]=0;h=U(451,b|0,i|0,e|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(v[c+18|0]&1){break C}break z}h=c+11|0;d=y[c+18|0];if(!(d&1)){break B}}x[114409]=0;O(1676,a|0,c+17|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break A}d=y[c+18|0]}if(d&2){break y}break x}d=y[c+17|0];l=Sc(f,e),m=d,v[l|0]=m}l=h,m=y[Sc(f,e)|0],v[l|0]=m;if(!(y[c+18|0]&2)){break v}}x[114409]=0;O(1676,a|0,c+17|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break w}d=y[c+18|0]}if(d&4){break u}break t}d=y[c+17|0];l=Sc(f,e),m=d,v[l+1|0]=m}l=h,m=y[Sc(f,e)+1|0],v[l+1|0]=m;if(!(y[c+18|0]&4)){break r}}x[114409]=0;O(1676,a|0,c+17|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break s}d=y[c+18|0]}if(d&8){break q}break p}d=y[c+17|0];l=Sc(f,e),m=d,v[l+2|0]=m}l=h,m=y[Sc(f,e)+2|0],v[l+2|0]=m;if(!(y[c+18|0]&8)){break n}}x[114409]=0;O(1676,a|0,c+17|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break o}d=y[c+18|0]}if(d&16){break m}break l}d=y[c+17|0];l=Sc(f,e),m=d,v[l+4|0]=m}l=h,m=y[Sc(f,e)+4|0],v[l+4|0]=m;if(!(y[c+18|0]&16)){break j}}x[114409]=0;O(1676,a|0,c+17|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break k}d=y[c+18|0]}if(d&32){break i}break g}d=y[c+17|0];l=Sc(f,e),m=d,v[l+3|0]=m}l=h,m=y[Sc(f,e)+3|0],v[l+3|0]=m;if(!(y[c+18|0]&32)){break h}}x[114409]=0;O(1676,a|0,c+17|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(k){break g}d=y[c+17|0];l=Sc(f,e),m=d,v[l+5|0]=m}l=h,m=y[Sc(f,e)+5|0],v[l+5|0]=m}if(!(y[c+18|0]&64)){break c}x[114409]=0;O(1676,a|0,c+10|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){e=y[c+10|0];x[114409]=0;U(1677,a|0,e|0,-1)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break c}}}}a=N()|0;hm(f);Q(a|0);p()}if(i>>>0<j>>>0){continue}break}}hm(f)}hb=c+32|0}function P5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-144|0;hb=d;h=bJ(d+128|0);x[h>>2]=82568;f=hb-16|0;hb=f;e=h+4|0;x[e>>2]=0;x[e+4>>2]=0;x[114409]=0;x[f+12>>2]=0;U(2277,e+8|0,f+12|0,f+11|0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){hb=f+16|0;break a}R(0)|0;zb();p()}f=a+24|0;sn(x[f>>2],h);e=y[a+62|0];g=y[a+61|0];j=y[a+60|0];k=x[f>>2];b=hf(d+112|0,b);x[114409]=0;i=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=i;i=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=i;b=j?13:15;b=g?b&14:b;b=U(2269,k|0,d|0,(e?b&3:b)|0)|0;e=x[114409];x[114409]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((e|0)==1){break s}if(!b){b=ec(8);x[114409]=0;c=O(122,d+100|0,7854)|0;a=x[114409];x[114409]=0;if((a|0)!=1){a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}a=N()|0;xb(c);break c}a=N()|0;ic(b);break c}if(!y[a+63|0]){x[114409]=0;P(2270,a|0,a+36|0);b=x[114409];x[114409]=0;if((b|0)==1){break s}}v[a+28|0]=1;sn(x[f>>2],x[a+4>>2]);x[114409]=0;P(2271,d+100|0,h|0);b=x[114409];x[114409]=0;if((b|0)==1){break r}b=d+100|0;l=d,m=bc(b),x[l+96>>2]=m;l=d,m=dc(b),x[l+92>>2]=m;if(Hb(d+96|0,d+92|0)){f=a+68|0;while(1){b=x[d+96>>2];e=x[b>>2];x[114409]=0;g=e;e=b+4|0;T(2272,a|0,g|0,e|0);g=x[114409];x[114409]=0;if((g|0)==1){break f}b=x[b>>2];x[114409]=0;P(2273,d+44|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;T(9,d+56|0,0,d+44|0);b=x[114409];x[114409]=0;if((b|0)==1){break i}x[114409]=0;b=O(122,d+32|0,13619)|0;g=x[114409];x[114409]=0;if((g|0)==1){break k}x[114409]=0;T(141,d+68|0,d+56|0,b|0);g=x[114409];x[114409]=0;if((g|0)==1){break m}x[114409]=0;T(822,d+80|0,d+68|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break o}x[114409]=0;P(1631,f|0,d+80|0);e=x[114409];x[114409]=0;if((e|0)==1){break p}xb(d+80|0);xb(d+68|0);xb(b);xb(d+56|0);xb(d+44|0);b=d+96|0;sf(b);if(Hb(b,d+92|0)){continue}break}}l=d,m=Xn(c),x[l+80>>2]=m;l=d,m=Zi(c),x[l+68>>2]=m;t:{while(1){x[114409]=0;b=O(2274,d+80|0,d+68|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break e}if(!b){break q}x[114409]=0;c=S(2275,d+80|0)|0;b=x[114409];x[114409]=0;u:{if((b|0)==1){break u}x[114409]=0;b=O(121,d+20|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break u}x[114409]=0;W(2204,a|0,b|0,c+12|0,0);c=x[114409];x[114409]=0;if((c|0)==1){break t}xb(b);x[114409]=0;S(2276,d+80|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}break e}break}a=N()|0;break d}a=N()|0;xb(b);break d}a=N()|0;break c}a=N()|0;break c}Ex(d+100|0);Ks(h);hb=d+144|0;return}a=N()|0;xb(d+80|0);break n}a=N()|0}xb(d+68|0);break l}a=N()|0}xb(b);break j}a=N()|0}xb(d+56|0);break h}a=N()|0}xb(d+44|0);break d}a=N()|0;break d}a=N()|0;break d}a=N()|0}Ex(d+100|0)}Ks(h);Q(a|0)}p()}function fJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-208|0;hb=f;x[f+200>>2]=c;x[f+204>>2]=d;a:{if(Dj(b)){break a}g=y[yk(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Lk(f+168|0,b,x[b+4>>2]-1|0);g=x[f+172>>2];x[b>>2]=x[f+168>>2];x[b+4>>2]=g}g=f+168|0;Gd(g);h=x[f+168>>2];Gd(f+156|0);i=xk(h,x[f+160>>2],b);Gd(g);g=x[b>>2];h=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+172>>2]){x[f+192>>2]=g;x[f+196>>2]=h;a=uc(f+184|0,17381);c=x[f+196>>2];x[f+16>>2]=x[f+192>>2];x[f+20>>2]=c;c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Mc(f+16|0,f+8|0)){a=ec(8);x[114409]=0;P(2267,f+156|0,f+200|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,f+168|0,13483,f+156|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}a=oc(a,f+168|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(f+168|0);xb(f+156|0);break c}b=N()|0;break d}if(!e){break h}d=ec(8);x[114409]=0;c=O(2266,f+132|0,b|0)|0;a=x[114409];x[114409]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[114409]=0;T(2242,f+144|0,13519,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break p}x[114409]=0;T(2261,f+156|0,f+144|0,13493);b=x[114409];x[114409]=0;a=1;if((b|0)==1){break o}x[114409]=0;P(2267,f+120|0,f+200|0);a=x[114409];x[114409]=0;if((a|0)==1){break n}x[114409]=0;T(141,f+168|0,f+156|0,f+120|0);b=x[114409];x[114409]=0;a=1;if((b|0)==1){break m}a=oc(d,f+168|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(f+168|0);a=0;break l}b=N()|0;break i}b=N()|0;xb(c);break i}b=N()|0;break j}b=N()|0;a=1;break k}b=N()|0}xb(f+120|0)}xb(f+156|0)}xb(f+144|0);xb(c);if(!a){break c}}ic(d);break c}x[f+112>>2]=g;x[f+116>>2]=h;e=uc(f+104|0,17381);g=x[f+116>>2];x[f+64>>2]=x[f+112>>2];x[f+68>>2]=g;g=x[e+4>>2];x[f+56>>2]=x[e>>2];x[f+60>>2]=g;if(Mc(f- -64|0,f+56|0)){a=ec(8);x[114409]=0;P(2267,f+156|0,f+200|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,f+168|0,13483,f+156|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}a=oc(a,f+168|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(f+168|0);xb(f+156|0);break c}b=N()|0;break e}e=x[b+4>>2];x[f+96>>2]=x[b>>2];x[f+100>>2]=e;e=uc(f+88|0,6914);g=x[f+100>>2];x[f+48>>2]=x[f+96>>2];x[f+52>>2]=g;g=x[e+4>>2];x[f+40>>2]=x[e>>2];x[f+44>>2]=g;if(Mc(f+48|0,f+40|0)){UI(a,Ec(c,d));break h}e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;b=uc(f+72|0,4819);e=x[f+84>>2];x[f+32>>2]=x[f+80>>2];x[f+36>>2]=e;e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(!Mc(f+32|0,f+24|0)){break h}b=Ec(c,d);x[x[a+32>>2]+40>>2]=b>>>0>3?1:b}hb=f+208|0;return}b=N()|0;xb(f+156|0);break d}b=N()|0;xb(f+156|0)}ic(a);break c}ic(a)}Q(b|0)}p()}function Uv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-96|0;hb=e;a:{if(Bd(a,11)|x[a+4>>2]){b=x[a+28>>2];d=x[a+12>>2];g=x[a+64>>2];c=g+x[a+8>>2]|0;d=_g(e+80|0,c,c>>>0<g>>>0?d+1|0:d);c=x[d+12>>2];x[e+32>>2]=x[d+8>>2];x[e+36>>2]=c;c=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=c;tj(b,e+24|0);d=x[a+28>>2];if(xu(x[x[d>>2]-12>>2]+d|0)){Ug(a,1073741826);break a}c=x[a+92>>2];d=a+44|0;b=qd(d);b:{if(c>>>0>b>>>0){f=hb-32|0;hb=f;c:{b=c-b|0;d:{if(b>>>0<=x[yb(d)>>2]-x[d+4>>2]>>4>>>0){g=hb-16|0;hb=g;e:{c=Qm(g+4|0,d,b);b=x[c+4>>2];i=x[c+8>>2];if((b|0)!=(i|0)){while(1){h=yb(d);x[114409]=0;P(189,h|0,b|0);h=x[114409];x[114409]=0;if((h|0)==1){break e}b=b+16|0;x[c+4>>2]=b;if((b|0)!=(i|0)){continue}break}}Jb(c);hb=g+16|0;break d}a=N()|0;Jb(c);Q(a|0);p()}c=yb(d);c=wr(f+12|0,xr(d,qd(d)+b|0),qd(d),c);x[114409]=0;P(185,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;P(186,d|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}YD(c)}hb=f+32|0;break b}a=N()|0;YD(c);Q(a|0);p()}if(b>>>0>c>>>0){c=x[d>>2]+(c<<4)|0;qd(d);XD(d,c);WD(d)}}f=a+32|0;ew(f,x[a+92>>2]<<2);if(x[a+92>>2]){c=0;while(1){b=x[a+28>>2];if(xu(x[x[b>>2]-12>>2]+b|0)){Ug(a,1073741828);break a}b=z[a+16>>1];w[e+78>>1]=b;if((b|0)==65535){Vv(x[a+28>>2],e+78|0)}j=e,k=xc(f),x[j+72>>2]=k;f:{if(!z[e+78>>1]){b=0;break f}b=z[e+78>>1];g=x[e+72>>2];if(b>>>0>-1-g>>>0){break f}Tv(f,b+g|0);sk(x[a+28>>2],Cc(f,x[e+72>>2]),z[e+78>>1]);b=z[e+78>>1]}j=wc(d,c),k=b,w[j+12>>1]=k;b=x[e+72>>2];j=wc(d,c),k=b,x[j>>2]=k;if(Bd(a,6)){$j(x[a+28>>2],e+56|0);if(A[e+60>>2]>2147483647){Ug(a,1073741829);break a}b=x[e+56>>2];j=wc(d,c),k=b,x[j+4>>2]=k}b=x[a+4>>2];g:{if(b){j=wc(d,c),k=b,x[j+8>>2]=k;break g}if(!Bd(a,7)){break g}$j(x[a+28>>2],e+56|0);if(A[e+60>>2]>2147483647){Ug(a,1073741829);break a}b=x[e+56>>2];j=wc(d,c),k=b,x[j+8>>2]=k}h:{if(x[wc(d,c)+8>>2]==-1){break h}if(Bd(a,6)){break h}if(c){b=c-1|0;b=x[wc(d,b)+4>>2]+x[wc(d,b)+8>>2]|0}else{b=0}j=wc(d,c),k=b,x[j+4>>2]=k}if(Bd(a,8)){w[e+56>>1]=0;Vv(x[a+28>>2],e+56|0);b=Bd(a,9);Cl(x[a+28>>2],z[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<A[a+92>>2]){continue}break}}Af(e+56|0,x[a+28>>2]);d=x[e+68>>2];x[a+72>>2]=x[e+64>>2];x[a+76>>2]=d}ak(a,4,1);b=x[a+72>>2];f=x[a+76>>2];c=x[a+12>>2];d=x[a+88>>2];g=x[a+8>>2]+d|0;c=d>>>0>g>>>0?c+1|0:c;h=b;b=(d|0)==x[a+64>>2];d=b?h:g;x[a+80>>2]=d;c=b?f:c;x[a+84>>2]=c;b=x[a+28>>2];d=_g(e+40|0,d,c);c=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=c;c=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=c;tj(b,e+8|0);if(Bd(a,6)){break a}if(!(Bd(a,7)|x[a+4>>2])|!x[a+92>>2]){break a}d=x[a+80>>2]-x[a+8>>2]|0;b=a+44|0;c=0;while(1){f=wc(b,c);x[f+4>>2]=d+x[f+4>>2];c=c+1|0;if(c>>>0<A[a+92>>2]){continue}break}}hb=e+96|0}function $ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;o=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Wf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Ze(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;yf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}b=x[a+44>>2];x[e+28>>2]=b;g=x[a+48>>2];x[e+32>>2]=g;i=x[a+52>>2];x[e+36>>2]=i;h=x[a+56>>2];x[e+40>>2]=h;q=x[a+24>>2];r=x[a+20>>2];j=x[a+4>>2];f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=j;k=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=k;b:{if(d){while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=(((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+o|0;x[e+72>>2]=b;x[e+76>>2]=0;c:{b=x[e+64>>2];if((b|0)<=0){break c}while(1){d:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=w[(g<<1|2)+f>>1];g=w[f+((g&2147483646)<<1)>>1];x[114409]=0;P(1113,x[e+56>>2],(g+i|0)/8<<16>>16);g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;P(1114,x[e+56>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break d}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break c}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=w[(i<<1|2)+f>>1];f=w[f+((i&2147483646)<<1)>>1];x[114409]=0;P(1113,b|0,(f+h|0)/8<<16>>16);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+56>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;b=O(1115,b|0,x[e+60>>2])|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;l=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;m=x[i+4>>2];j=Yb(m,-16777216,16776704);k=x[a+64>>2];n=Yb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=m;m=x[a+72>>2];l=l<<8;h=sqa(h,h>>31,l,l>>31);s=lb;k=sqa(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=sqa(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(l&m);f=g&1;g=0;b=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],r);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],q);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}h=x[e+40>>2];i=x[e+36>>2];g=x[e+32>>2];f=x[e+16>>2];j=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+56>>2]=h;x[a+52>>2]=i;x[a+48>>2]=g;x[a+44>>2]=b;hb=e+80|0;return}b=N()|0;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function KJ(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);PN(a+4208|0,B[a+4272>>2]);b=E(E(B[a+4208>>2]*E(15920))+E(80));d=cf(x[a+16>>2]);s=pe(E(10),E(E(E(B[a+4216>>2]*E(30))+E(-15))*E(.02500000037252903)));c=E(E(b*E(6.2831854820251465))/E(d>>>0));b=dH(c);v=np(c);w=b;f=E(E(E(c*E(.02888113260269165))*E(E(B[a+4212>>2]*E(35))+E(1)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(f),j(2))&2147483647;a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Xw(b)&2047;j:{k:{if(Xw(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Xw(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=lH(0);break j}if(!(b<E(-103.97207641601562))){break k}c=kH(0);break j}g=C[7281]*+b;t=C[7280];u=g+t;g=g-(u-t);g=(C[7282]*g+C[7283])*(g*g)+(C[7284]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+57952|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;o=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Wf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Ze(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;yf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}b=x[a+44>>2];x[e+28>>2]=b;g=x[a+48>>2];x[e+32>>2]=g;i=x[a+52>>2];x[e+36>>2]=i;h=x[a+56>>2];x[e+40>>2]=h;q=x[a+24>>2];r=x[a+20>>2];j=x[a+4>>2];f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=j;k=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=k;b:{if(d){while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=((x[e+20>>2]&2147483647)<<1|b>>>31)&-2;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+o|0;x[e+72>>2]=b;x[e+76>>2]=0;c:{b=x[e+64>>2];if((b|0)<=0){break c}while(1){d:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=v[(g|1)+f|0];g=v[f+(g&-2)|0];x[114409]=0;P(1113,x[e+56>>2],g+i<<5);g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;P(1114,x[e+56>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break d}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break c}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=v[(i|1)+f|0];f=v[f+(i&-2)|0];x[114409]=0;P(1113,b|0,f+h<<5);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+56>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;b=O(1115,b|0,x[e+60>>2])|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;l=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;m=x[i+4>>2];j=Yb(m,-16777216,16776704);k=x[a+64>>2];n=Yb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=m;m=x[a+72>>2];l=l<<8;h=sqa(h,h>>31,l,l>>31);s=lb;k=sqa(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=sqa(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(l&m);f=g&1;g=0;b=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],r);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],q);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}h=x[e+40>>2];i=x[e+36>>2];g=x[e+32>>2];f=x[e+16>>2];j=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+56>>2]=h;x[a+52>>2]=i;x[a+48>>2]=g;x[a+44>>2]=b;hb=e+80|0;return}b=N()|0;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function uma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=y[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}v[a+3|0]=5;v[f+15|0]=y[a+5|0]>>>3;v[f+14|0]=15;b=y[tc(f+15|0,f+14|0)|0];v[f+13|0]=y[a+5|0]<<1&30;v[f+12|0]=15;h=a,i=y[tc(f+13|0,f+12|0)|0]|b<<4,v[h+5|0]=i;break a}v[a+3|0]=0;break a}if((y[a+5|0]-1&255)>>>0<=19){v[a+3|0]=16;break a}v[a+3|0]=0;break a}v[a+3|0]=13;b=y[a+5|0];A:{if(!e){if(b>>>0>152){break A}v[a+5|0]=D((b&240)>>>4|0,10)+(b&15);break a}v[a+5|0]=(b&127)+1>>>1;break a}v[a+3|0]=0;break a}v[a+3|0]=11;break a}v[a+3|0]=0;break a}e=y[a+5|0];if(!e){v[a+3|0]=14;break a}if(e>>>0<=240){v[a+3|0]=17;if(e>>>0<=2){v[a+5|0]=112;break a}h=a,i=lu(+(lS(e,b,c,d)>>>0)*1e-4),v[h+5|0]=i;break a}v[a+3|0]=0;break a}v[a+3|0]=31;v[a+5|0]=y[a+5|0]|128;break a}v[a+3|0]=19;v[f+11|0]=15;h=a,i=y[tc(a+5|0,f+11|0)|0]|16,v[h+5|0]=i;break a}v[a+3|0]=19;v[f+10|0]=15;h=a,i=y[tc(a+5|0,f+10|0)|0]|32,v[h+5|0]=i;break a}v[a+3|0]=5;v[f+9|0]=(y[a+5|0]>>>4|0)+1;v[f+8|0]=15;b=tc(f+9|0,f+8|0);v[a+5|0]=y[a+5|0]&15|y[b|0]<<4;break a}v[a+3|0]=19;v[a+5|0]=y[a+5|0]&15|80;break a}v[a+3|0]=19;v[f+7|0]=15;h=a,i=y[tc(a+5|0,f+7|0)|0]|96,v[h+5|0]=i;break a}v[a+3|0]=19;v[f+6|0]=15;h=a,i=y[tc(a+5|0,f+6|0)|0]|192,v[h+5|0]=i;break a}v[a+3|0]=10;break a}v[a+3|0]=19;v[f+5|0]=15;h=a,i=y[tc(a+5|0,f+5|0)|0]|160,v[h+5|0]=i;break a}v[a+3|0]=19;v[f+4|0]=15;h=a,i=y[tc(a+5|0,f+4|0)|0]|176,v[h+5|0]=i;break a}b=y[a+5|0]-1<<24>>24;if((b|0)>=0){v[a+5|0]=b;v[a+3|0]=31;break a}v[a+3|0]=0;break a}v[a+3|0]=14;break a}v[a+3|0]=19;v[f+3|0]=15;h=a,i=y[tc(a+5|0,f+3|0)|0]|224,v[h+5|0]=i;break a}b=y[a+5|0];if(b>>>0>=16){v[a+3|0]=19;v[a+5|0]=b>>>4|208;break a}if(b){v[a+3|0]=19;v[a+5|0]=b|144;break a}v[a+3|0]=0;break a}if(!(y[a+5|0]|y[a+4|0])){if(!Ff(a)){break a}v[a+5|0]=159;v[a+3|0]=20;break a}v[a+3|0]=0;break a}b=y[a+4|0];if(b){v[a+3|0]=41;h=a,i=ll(id(((y[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),v[h+5|0]=i;break a}v[a+3|0]=0;break a}b=y[a+5|0];if((b+16&255)>>>0<=32){v[a+3|0]=9;h=a,i=_k(((b^128)<<3)-896|0),v[h+5|0]=i;break a}v[a+3|0]=0;break a}if(g>>>0<=15){Mj(a);break a}v[a+3|0]=0}hb=f+16|0}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0;f=hb-32|0;hb=f;r=a+4|0;p=x[r>>2];n=a+20|0;t=x[Vc(n,b)+16>>2];a:{if(t+1>>>0<2){break a}g=(D(b,896)+p|0)+608|0;if(!Zh(g)){if(!y[Vc(n,b)+20|0]){break a}}h=D(b,896)+p|0;if(!x[h+712>>2]){break a}k=x[h+696>>2]&2;e=x[(k?h+692|0:h+684|0)>>2];m=x[h+692>>2];i=x[h+688>>2];u=$b(x[a>>2]+1074312|0,31);w=h+1356|0;l=y[w|0];A=h+616|0;j=Ze(A,c);x[f+24>>2]=j;o=lb;x[f+28>>2]=o;if(y[h+696|0]&128){x[f+24>>2]=0-j;x[f+28>>2]=0-(((j|0)!=0)+o|0)}j=0;o=e;e=j;j=k;B=j?e:0;e=i;q=j?e:0;k=m-e|0;C=k<<1;e=D(b,896)+p|0;F=e+1308|0;m=e+1480|0;G=(l&17)!=1;b:{while(1){c:{if(d>>>0>s>>>0){e=(y[w|0]&17)==1;break c}v[m|0]=y[m|0]&254;i=Hf(Zb(x[a>>2]+484344|0,z[x[r>>2]+60>>1]),x[x[r>>2]+48>>2],b);j=y[i+3|0];if(y[i+2|0]==11){e=f+16|0;Yy(e,x[a>>2],i,0);l=mc(e);Dn(x[a>>2],g,x[e>>2]);e=1;if(y[l|0]){break c}}e=1;d:{switch(j-4|0){case 0:Dn(x[a>>2],g,y[i+5|0]);break c;case 2:break d;default:break c}}Dn(x[a>>2],g,0)}x[f+12>>2]=x[F>>2];if(u){et(x[a>>2],g)}if(!G){gM(x[a>>2],g,f+12|0);e=1}if(!u){et(x[a>>2],g)}x[f+8>>2]=0;jM(g,f+8|0);e:{f:{if(y[h+697|0]&2){break f}g:{if(!e){if(!y[Vc(n,b)+20|0]){break g}}if(y[m|0]&24){hP(g,E(1),0,x[a>>2]);e=y[m|0];v[m|0]=(e&16?-17:-9)&e}e=A;I=e,J=yy(x[a>>2],g,x[f+12>>2],0),x[I>>2]=J;x[e+4>>2]=lb;I=Vc(n,b),J=0,v[I+20|0]=J;e=Ze(e,c);x[f+24>>2]=e;i=lb;x[f+28>>2]=i;if(!(y[h+696|0]&128)){break g}x[f+24>>2]=0-e;x[f+28>>2]=0-(((e|0)!=0)+i|0)}Tb(g,f+24|0);i=x[g>>2];e=x[g+4>>2];if(i>>>0<H>>>0&(e|0)<=(o|0)|(e|0)<(o|0)){if((e|0)>=(q|0)&i>>>0>=B>>>0|(e|0)>(q|0)){break f}j=x[f+28>>2];if((j|0)>0|(j|0)>=0){break f}}j=x[h+696>>2];if(!(j&2)){break e}if(j&4){if(i>>>0<B>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){e=x[h+688>>2]<<1;x[f+16>>2]=0;x[f+20>>2]=e;I=g,J=ug(f+16|0,g),x[I>>2]=J;x[g+4>>2]=lb;x[h+696>>2]=x[h+696>>2]^128;e=x[f+24>>2];i=0-e|0;e=0-(x[f+28>>2]+((e|0)!=0)|0)|0;x[f+24>>2]=i;x[f+28>>2]=e;e=x[g+4>>2]}e=(e-x[h+688>>2]>>>0)%(C-$b(x[a>>2]+1074312|0,33)>>>0)|0;i=e>>>0<k>>>0;h:{if(!i){x[g+4>>2]=x[h+692>>2]+(k-e|0);e=x[h+696>>2];if(!(i^(e&128)>>>7)){break h}break f}x[g+4>>2]=e+x[h+688>>2];e=x[h+696>>2];if(i^(e&128)>>>7){break f}}x[h+696>>2]=e^128;e=x[f+24>>2];i=0-e|0;e=0-(x[f+28>>2]+((e|0)!=0)|0)|0;x[f+24>>2]=i;x[f+28>>2]=e;break f}l=x[h+692>>2];if(l+k>>>0<=e>>>0){e=l+((e-l>>>0)%(k>>>0)|0)|0}while(1){j=e;e=e-k|0;if(j>>>0>=l>>>0){continue}break}x[g>>2]=i;x[g+4>>2]=j}s=s+1|0;if((t|0)!=(s|0)){continue}break b}break}kP(g);x[(D(b,896)+p|0)+1316>>2]=0}I=Vc(n,b),J=0,x[I+16>>2]=J}hb=f+32|0}function R5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-128|0;hb=e;a:{if(Yc(b)){break a}f=y[iJ(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+116|0;Vr(f,b,0,Cb(b)-1|0);Eb(b,f);xb(f)}g=e+116|0;Gd(g);f=x[e+116>>2];Gd(e+104|0);f=hJ(f,x[e+108>>2],b);Gd(g);b:{c:{d:{e:{f:{if((f|0)==x[e+120>>2]){if(Rd(b,17381)){a=ec(8);x[114409]=0;T(2260,e+116|0,13483,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}a=oc(a,e+116|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break c}b=N()|0;xb(e+116|0);break d}if(!d){break f}a=ec(8);x[114409]=0;T(2260,e+92|0,13519,b|0);b=x[114409];x[114409]=0;g:{h:{i:{j:{if((b|0)!=1){x[114409]=0;T(2261,e+104|0,e+92|0,13493);b=x[114409];x[114409]=0;if((b|0)==1){break j}x[114409]=0;T(822,e+116|0,e+104|0,c|0);b=x[114409];x[114409]=0;c=1;if((b|0)==1){break i}b=oc(a,e+116|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break c}b=N()|0;xb(e+116|0);c=0;break h}b=N()|0;break g}b=N()|0;xb(e+92|0);break g}b=N()|0}xb(e+104|0);xb(e+92|0);if(!c){break d}}ic(a);break d}k:{switch(x[f+4>>2]){case 0:Ei(e+84|0,b);b=(tH(c)|0)!=0;c=x[e+88>>2];x[e+8>>2]=x[e+84>>2];x[e+12>>2]=c;gJ(a,e+8|0,b,d);break f;case 1:Ei(e+76|0,b);b=hb-160|0;hb=b;c=mn(b+20|0,c,8);f=x[x[c>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;l:{if((h|0)==1){break b}x[114409]=0;T(126,b+16|0,c+f|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}Ob(b+16|0);x[114409]=0;f=O(157,c|0,b+8|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}g=x[x[f>>2]-12>>2];x[114409]=0;f=S(153,f+g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}g=x[b+8>>2];h=x[b+12>>2];Pf(c);hb=b+160|0;b=f?0:g;c=f?0:h;break l}f=x[e+80>>2];x[e+16>>2]=x[e+76>>2];x[e+20>>2]=f;fJ(a,e+16|0,b,c,d);break f;case 2:Ei(e+68|0,b);b=hb-160|0;hb=b;c=mn(b+20|0,c,8);f=x[x[c>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;m:{if((h|0)==1){break b}x[114409]=0;T(126,b+16|0,c+f|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}Ob(b+16|0);x[114409]=0;f=O(158,c|0,b+8|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}g=x[x[f>>2]-12>>2];x[114409]=0;f=S(153,f+g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}i=C[b+8>>3];Pf(c);hb=b+160|0;i=f?0:i;break m}b=x[e+72>>2];x[e+24>>2]=x[e+68>>2];x[e+28>>2]=b;dJ(a,e+24|0,i,d);break f;case 3:break k;default:break f}}Ei(e+60|0,b);Ei(e+52|0,c);b=x[e+64>>2];x[e+40>>2]=x[e+60>>2];x[e+44>>2]=b;b=x[e+56>>2];x[e+32>>2]=x[e+52>>2];x[e+36>>2]=b;cJ(a,e+40|0,e+32|0,d)}hb=e+128|0;return}b=N()|0;ic(a)}Q(b|0)}p()}a=N()|0;Pf(c);Q(a|0);p()}function xH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=hb-48|0;hb=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=yH(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}hb=h+48|0;return d}function m4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;a:{if(Dj(b)){break a}e=y[yk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Lk(d+160|0,b,x[b+4>>2]-1|0);e=x[d+164>>2];x[b>>2]=x[d+160>>2];x[b+4>>2]=e}g=d+160|0;Gd(g);e=x[d+160>>2];Gd(d+148|0);e=xk(e,x[d+152>>2],b);Gd(g);b:{c:{d:{e:{f:{g:{if((e|0)==x[d+164>>2]){a=x[b+4>>2];x[d+184>>2]=x[b>>2];x[d+188>>2]=a;a=uc(d+176|0,17381);e=x[d+188>>2];x[d+8>>2]=x[d+184>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;if(Mc(d+8|0,d)){a=ec(8);x[114409]=0;c=O(122,d+160|0,6463)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}f=0;if(!c){break g}c=ec(8);x[114409]=0;a=O(2266,d+148|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,d+160|0,13519,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}b=oc(c,d+160|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(d+160|0);xb(a);break c}b=N()|0;break d}if(x[e+4>>2]!=2){a=ec(8);x[114409]=0;c=O(122,d+160|0,7464)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];x[d+136>>2]=x[b>>2];x[d+140>>2]=c;c=uc(d+128|0,17381);e=x[d+140>>2];x[d+72>>2]=x[d+136>>2];x[d+76>>2]=e;e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;if(Mc(d+72|0,d- -64|0)){a=ec(8);x[114409]=0;c=O(122,d+160|0,6463)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];x[d+120>>2]=x[b>>2];x[d+124>>2]=c;c=uc(d+112|0,3991);e=x[d+124>>2];x[d+56>>2]=x[d+120>>2];x[d+60>>2]=e;e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;if(Mc(d+56|0,d+48|0)){f=1;if(!y[a+28|0]){break g}f=65536/+A[x[a+24>>2]+480244>>2];break g}c=x[b+4>>2];x[d+104>>2]=x[b>>2];x[d+108>>2]=c;c=uc(d+96|0,4043);e=x[d+108>>2];x[d+40>>2]=x[d+104>>2];x[d+44>>2]=e;e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Mc(d+40|0,d+32|0)){f=1;if(!y[a+28|0]){break g}f=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break g}c=x[b+4>>2];x[d+88>>2]=x[b>>2];x[d+92>>2]=c;b=uc(d+80|0,4061);c=x[d+92>>2];x[d+24>>2]=x[d+88>>2];x[d+28>>2]=c;c=x[b+4>>2];x[d+16>>2]=x[b>>2];x[d+20>>2]=c;f=0;if(!Mc(d+24|0,d+16|0)){break g}f=+A[x[a+24>>2]+480236>>2]*152587890625e-16}hb=d+192|0;return+f}b=N()|0;ic(a);break c}b=N()|0;xb(a)}ic(c)}Q(b|0)}p()}function Cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-560|0;hb=f;a:{if(!Tc(b,1464)){break a}if(!eo(b,f+556|0)){break a}Pd(a,1);d=a+1074312|0;Kg(d,83);Nb(d,84,1);Nb(d,85,1);b:{if(Wd(f+556|0,23938)){d=f+32|0;e=Vb(d,4649);Eb(a+1304436|0,e);xb(e);e=Vb(d,10337);Eb(a+1304448|0,e);xb(e);d=Vb(d,10402);Eb(a+1304460|0,d);break b}if(!Wd(f+556|0,11604)){break a}d=f+32|0;e=Vb(d,4807);Eb(a+1304436|0,e);xb(e);e=Vb(d,8096);Eb(a+1304448|0,e);xb(e);d=Vb(d,11254);Eb(a+1304460|0,d)}xb(d);x[a+1304496>>2]=2;d=0;Tc(b,0);LA(b,a+1304400|0,20);w[a+480190>>1]=31;e=1;while(1){d=dA(b,f+32|0,(D(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+554|0;av(i,b);m=ed(i);if(y[i|0]>128){break a}d=f+32|0;e=hb-16|0;hb=e;c:{if(Qb(b,512)){g=e+8|0;qB(g,d);Cd(b,g);break c}kR(d)}hb=e+16|0;e=0;d=y[m|0];while(1){n=d>>>0>=y[(f+32|0)+e|0];if(!n){break a}e=e+1|0;if((e|0)!=512){continue}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Cj(a,0);o=a+484360|0;Og(Wb(o),y[i|0]);w[f+30>>1]=0;j=a+484344|0;ig(j,y[i|0]);if(y[i|0]){while(1){s=vc(Wb(o),h),t=h,w[s>>1]=t;if(Zg(j,h&65535,64)){p=h<<2;g=0;while(1){Tc(b,(y[f+32+(g+p)|0]<<8)+1468|0);e=Hf(Zb(j,h),0,g&65535);d=0;while(1){gu(b,e);d:{e:{l=y[e+3|0];f:{if((l|0)!=14){if(!l){if(y[e+5|0]){break e}break f}if((l-5&255)>>>0<5){break f}break e}if(y[e+5|0]<=15){break e}}v[e+3|0]=0;break d}Mj(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}g=g+1|0;if((g|0)!=4){continue}break}s=f,t=bc(Zb(j,h)),x[s+24>>2]=t;g=0;while(1){d=0;while(1){e=d;d=y[x[f+24>>2]+3|0];g:{if((d|0)!=16&(d|0)!=17){break g}v[x[f+24>>2]+3|0]=16;k=0;if(y[x[f+24>>2]+5|0]<16){break g}d=y[x[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=y[x[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=x[f+24>>2];v[d+5|0]=y[d+5|0]>>>4}Sj(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}v[f+30|0]=q;v[f+31|0]=r;d=k&255;if(d){Pl(Zb(j,h),Oe(wo(f+8|0,16,y[(d+f|0)+29|0]),g));d=k+1|0;k=(d&255)==3?1:d}else{k=0}g=g+1|0;if((g|0)!=64){continue}break}}h=h+1|0;if(h>>>0<y[i|0]){continue}break}}if(!(c&2)){break a}Tc(b,(y[m|0]<<8)+1468|0);e=1;while(1){c=(D(e,104)+a|0)+484380|0;if(x[c>>2]){Fg(cd(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}hb=f+560|0;return n|0}function iW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-368|0;hb=f;Nc(b);d=hb-16|0;hb=d;e=d+8|0;h=f+330|0;QB(e,h);i=Fb(e);e=nc(b,ac(d,e));if((i|0)==(e|0)){cc(b,Fb(d+8|0))}hb=d+16|0;d=(e|0)==(i|0);if(!d){RB(h)}a:{b:{if(!d){break b}if(!bC(f+330|0)){break b}if(!Qb(b,id(aC(f+330|0),lb))){break b}c:{if(!c){break c}Pd(a,2097152);Ni(a);g=1;Cj(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[f+362|0];x[a+480204>>2]=D(y[f+363|0],1e4);w[a+480190>>1]=y[f+364|0];if(y[f+367|0]<y[f+366|0]){Pe(Wb(a+484360|0),y[f+367|0])}d=f- -64|0;e=Vb(d,2848);Eb(a+1304436|0,e);xb(e);e=Vb(d,7023);Eb(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;bv(b,d);Qq(Wb(a+484360|0),d,y[f+366|0],65535,65535);if(z[a+480190>>1]){while(1){i=f+24|0;$B(b,i);j=hb-16|0;hb=j;k=g&65535;h=(D(k,104)+a|0)+484380|0;zd(h,0);v[h+37|0]=y[i+22|0]<<4;v[j+15|0]=y[i+23|0];v[j+14|0]=64;m=h,n=y[tc(j+15|0,j+14|0)|0]<<2,w[m+30>>1]=n;v[h+36|0]=y[i+24|0];e=i+25|0;x[h>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);d=i+33|0;d:{if((y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0<3){break d}l=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=i+29|0;if(l>>>0<(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))+(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0){break d}w[h+34>>1]=z[h+34>>1]|2;x[h+4>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[h+8>>2]=(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))+(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))}hb=j+16|0;rm(f,2,i);d=f+12|0;Kc(d,f);x[114409]=0;O(348,((k<<5)+a|0)+946304|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}xb(f+12|0);g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}}cc(b,D(64-y[f+364|0]|0,37));e=a+484344|0;ig(e,y[f+365|0]);if(y[f+365|0]){h=c&1;g=0;while(1){e:{f:{if(h){if(Zg(e,g&65535,64)){break f}}cc(b,2048);break e}d=Zb(e,g);m=f,n=bc(d),x[m+24>>2]=n;m=f,n=dc(d),x[m+12>>2]=n;if(!Hb(f+24|0,f+12|0)){break e}while(1){d=x[f+24>>2];qm(f,b);i=ed(f);j=wf(f);k=fi(f);l=y[f|0];if((l-1&255)>>>0<=106){v[d|0]=l+13}v[d+1|0]=y[i|0];v[d+3|0]=y[j|0];v[d+5|0]=y[k|0];Mj(d);d=f+24|0;Sj(d);if(Hb(d,f+12|0)){continue}break}}g=g+1|0;if(g>>>0<y[f+365|0]){continue}break}}if(!(c&2)){break c}g=1;c=cd(f+24|0,8,1,0,0);if(!z[a+480190>>1]){break c}while(1){Fg(c,(D(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}}g=1}hb=f+368|0;return g|0}a=N()|0;xb(f+12|0);Q(a|0);p()}function k0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;k=hb-16|0;hb=k;m=Lw(g);o=qw(g);zg(k+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[114409]=0;g=O(2631,m|0,g<<24>>24)|0;i=x[114409];x[114409]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[114409]=0;g=O(2631,m|0,48)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[114409]=0;g=O(2631,m|0,g|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114409]=0;j=$(2603)|0;l=x[114409];x[114409]=0;e:{if((l|0)==1){break e}x[114409]=0;h=zw(h,j);j=x[114409];x[114409]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114409]=0;$(2603)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}x[114409]=0;h=nh(h);j=x[114409];x[114409]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Yc(k+4|0)){h=x[f>>2];x[114409]=0;Z(2619,m|0,i|0,g|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break f}l=0;x[114409]=0;kk(i,g);h=x[114409];x[114409]=0;if((h|0)==1){break a}x[114409]=0;r=S(2616,o|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=x[f>>2];x[114409]=0;ip((i-a<<2)+d|0,h);i=x[114409];x[114409]=0;if((i|0)!=1){break f}break a}g:{if(v[pc(k+4|0,j)|0]<=0){break g}if(v[pc(k+4|0,j)|0]!=(l|0)){break g}l=x[f>>2];x[f>>2]=l+4;x[l>>2]=r;j=(Cb(k+4|0)-1>>>0>j>>>0)+j|0;l=0}q=v[h|0];x[114409]=0;q=O(2631,m|0,q|0)|0;n=x[114409];x[114409]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[114409]=0;i=S(2620,o|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}j=x[f>>2];h=j+4|0;x[f>>2]=h;x[j>>2]=i;g=g+1|0;break h}x[114409]=0;i=O(2631,m|0,i<<24>>24)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[114409]=0;Z(2619,m|0,g|0,c|0,h|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;xb(k+4|0);hb=k+16|0;return}a=N()|0;xb(k+4|0);Q(a|0);p()}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;x[114409]=0;f=S(918,a|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){a:{b:{if(f){break b}x[114409]=0;f=S(425,a|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}j=Md(f+1|0,1,1024);x[114409]=0;k=d+484344|0;f=U(378,k|0,b|0,j|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}if(!f){break b}d=z[d+480188>>1];if(!d|!j){break b}l=d-1|0;h=0;while(1){x[114409]=0;d=O(231,a|0,1)|0;f=x[114409];x[114409]=0;c:{d:{if((f|0)!=1){if(!d){break b}x[114409]=0;f=S(425,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}if(f){break d}h=h+1|0;break c}break a}d=Zb(k,b);x[114409]=0;w[i+14>>1]=f&31;w[i+12>>1]=l;e=O(457,i+14|0,i+12|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}e=z[e>>1];x[114409]=0;d=U(451,d|0,h|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}if(f>>>0<32){break c}e:{if(f<<24>>24>=0){break e}x[114409]=0;e=S(425,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}v[d+5|0]=e;x[114409]=0;e=S(425,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}f:{if(e>>>0>=26){break f}e=y[e+35824|0];v[d+3|0]=e;g:{switch(e-1|0){case 0:if(!y[d+5|0]){break f}break e;case 12:if(y[d+2|0]){break e}v[d+2|0]=1;e=Md(y[d+5|0],0,64);v[d+5|0]=0;v[d+3|0]=0;v[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=y[d+5|0]&240;if(!e){break e}v[d+5|0]=e;break e;case 8:e=y[d+5|0];if(e>>>0<=128){x[114409]=0;e=S(910,e<<1)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}v[d+5|0]=e;break e}if((e|0)!=164){break e}v[d+5|0]=145;v[d+3|0]=20;break e;case 13:e=y[d+5|0];v[d+5|0]=D(e>>>4|0,10)+(e&15);break e;case 18:x[114409]=0;V(624,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){break e}break a;case 16:if(y[d+5|0]>31){break e}v[d+3|0]=16;break e;case 27:break g;default:break e}}g=y[d+5|0];e=g&240;h:{if((e|0)==16){e=2}else{if((e|0)!=32){break h}e=3}v[d+3|0]=e}v[d+5|0]=g&15|224;break e}v[d+3|0]=0}i:{if(!(f&64)){break i}x[114409]=0;P(452,i+10|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}e=i+10|0;g=ed(e);v[d+1|0]=y[e|0];e=y[g|0];v[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break i}}v[d|0]=g}if(!(f&32)){break c}v[d+2|0]=1;x[114409]=0;f=S(425,a|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}v[d+4|0]=f;if(!c){break c}v[d+4|0]=(f<<6>>>0)/127}if(h>>>0<j>>>0){continue}break}}Ab(a);hb=i+16|0;return}}b=N()|0;Ab(a);Q(b|0);p()}function u0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;k=hb-16|0;hb=k;m=Wu(g);o=tw(g);zg(k+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[114409]=0;g=O(22,m|0,g<<24>>24)|0;i=x[114409];x[114409]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[114409]=0;g=O(22,m|0,48)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[114409]=0;g=O(22,m|0,g|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114409]=0;j=$(2603)|0;l=x[114409];x[114409]=0;e:{if((l|0)==1){break e}x[114409]=0;h=zw(h,j);j=x[114409];x[114409]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114409]=0;$(2603)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}x[114409]=0;h=nh(h);j=x[114409];x[114409]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Yc(k+4|0)){h=x[f>>2];x[114409]=0;Z(2599,m|0,i|0,g|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break f}l=0;x[114409]=0;kk(i,g);h=x[114409];x[114409]=0;if((h|0)==1){break a}x[114409]=0;r=S(2590,o|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=x[f>>2];x[114409]=0;kk((i-a|0)+d|0,h);i=x[114409];x[114409]=0;if((i|0)!=1){break f}break a}g:{if(v[pc(k+4|0,j)|0]<=0){break g}if(v[pc(k+4|0,j)|0]!=(l|0)){break g}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;j=(Cb(k+4|0)-1>>>0>j>>>0)+j|0;l=0}q=v[h|0];x[114409]=0;q=O(22,m|0,q|0)|0;n=x[114409];x[114409]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break h}x[114409]=0;i=S(2600,o|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[114409]=0;Z(2599,m|0,g|0,c|0,i|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;xb(k+4|0);hb=k+16|0;return}x[114409]=0;i=O(22,m|0,i<<24>>24)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=N()|0;xb(k+4|0);Q(a|0);p()}function nY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-336|0;hb=d;e=hb-16|0;hb=e;x[a>>2]=0;f=a+32|0;ew(f,32);v[e+15|0]=0;_o(f,e+15|0);hb=e+16|0;e=x[a+28>>2];a:{if(!Nf(x[x[e>>2]-12>>2]+e|0)){Ug(a,1073741825);break a}e=d- -64|0;Af(e,x[a+28>>2]);f=x[e+12>>2];x[a+8>>2]=x[e+8>>2];x[a+12>>2]=f;f=Bb(e,3);h=x[a+28>>2];g=d+24|0;e=0;if(x[f>>2]){while(1){Jh(h,e+g|0);e=e+1|0;if(e>>>0<A[f>>2]){continue}break}}if(dd(g,22720,3)){Ug(a,1073741827);break a}v[d+335|0]=0;Jh(x[a+28>>2],d+335|0);e=d- -64|0;bE(e);g=b;h=d+24|0;f=y[d+335|0];if(f){sk(x[a+28>>2],d- -64|0,f);b=y[d+335|0]}else{b=0}b=Sm(h,e,b);e=Wv(g,b);Gb(b);if(!e){Ug(a,1073741830)}if(y[a+3|0]&64){break a}Jh(x[a+28>>2],d+63|0);e=y[d+63|0];b=e&3;w[a+16>>1]=(b|0)==3?4:b;if(ni(e,6)){ak(a,9,1)}x[d+56>>2]=0;aE(x[a+28>>2],d+56|0);b=x[d+56>>2];v[d+55|0]=0;if(b>>>0>=2){Jh(x[a+28>>2],d+63|0);f=y[d+63|0];if(!f){Jh(x[a+28>>2],d+55|0);f=y[d+63|0]}Cl(x[a+28>>2],b+(f?-1:-2)|0,-1)}x[d+40>>2]=0;x[d+44>>2]=0;b:{if(!ni(e,4)){break b}$j(x[a+28>>2],d+40|0);b=x[d+44>>2];f=x[d+40>>2];x[a+56>>2]=f;x[a+60>>2]=b;g=x[c+4>>2];if((g|0)==(b|0)&A[c>>2]>=f>>>0|b>>>0<g>>>0){break b}Ug(a,536871424)}if(ni(e,5)){Jh(x[a+28>>2],d+63|0);Cl(x[a+28>>2],y[d+63|0],-1)}c:{if(!ni(y[d+55|0],0)){break c}Jh(x[a+28>>2],d+63|0);b=y[d+63|0];b=b&1?-1:b>>>1|0;w[a+16>>1]=b;if(b){break c}Ug(a,536871168)}x[a+4>>2]=0;b=1;if(ni(y[d+55|0],1)){aE(x[a+28>>2],a+4|0)}ak(a,6,ni(e,2));ak(a,7,ni(e,3));ak(a,5,z[a+16>>1]!=0);ak(a,8,ni(e,7));d:{if(Bd(a,5)){break d}if(Bd(a,6)){break d}if(Bd(a,7)){break d}b=Bd(a,8)}ak(a,11,b);Bd(a,11);b=y[d+55|0];if(ni(b,2)){w[d+24>>1]=0;Vv(x[a+28>>2],d+24|0);Cl(x[a+28>>2],z[d+24>>1]<<Bd(a,9),-1);b=y[d+55|0]}if(ni(b,3)){Cl(x[a+28>>2],5,-1)}$j(x[a+28>>2],d+40|0);c=x[d+44>>2];b=x[d+40>>2];if(!c&b>>>0>=16001|c){Ug(a,1073741831);break a}x[a+92>>2]=b;if(!b){Ug(a,536871040)}e:{if(!Bd(a,11)){break e}$j(x[a+28>>2],d+40|0);b=x[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}Ug(a,1073741829);break a}b=d+8|0;Af(b,x[a+28>>2]);hE(d+24|0,b,x[a+8>>2],x[a+12>>2]);b=x[d+32>>2];c=x[d+36>>2];if(!(((c|0)>0|(c|0)>=0)&!c)){Ug(a,1073741832);break a}x[a+88>>2]=b;i=a,j=x[(Bd(a,11)?d+40|0:a+88|0)>>2],x[i+64>>2]=j;if(!Bd(a,11)){b=x[a+12>>2];c=x[a+88>>2];e=c+x[a+8>>2]|0;b=e>>>0<c>>>0?b+1|0:b;x[a+72>>2]=e;x[a+76>>2]=b}ak(a,10,1)}hb=d+336|0}function UQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-80|0;hb=e;f=x[b>>2];g=x[b+4>>2];a:{if(x[b+4>>2]==x[d+4>>2]){x[e+72>>2]=f;x[e+76>>2]=g;b=x[c+4>>2];x[e+64>>2]=x[c>>2];x[e+68>>2]=b;f=Dd(e+56|0,d);b=x[e+76>>2];x[e+8>>2]=x[e+72>>2];x[e+12>>2]=b;b=x[e+68>>2];x[e>>2]=x[e+64>>2];x[e+4>>2]=b;b=hb-16|0;hb=b;d=Sk(e,e+8|0);x[b+12>>2]=d;b:{if((d|0)<=0){break b}c=x[e+12>>2];c:{if(!c){c=x[e+8>>2];break c}g=32-c|0;x[b+8>>2]=g;c=x[fe(b+8|0,b+12|0)>>2];x[b+12>>2]=x[b+12>>2]-c;d=x[f>>2];g=-1<<x[e+12>>2]&-1>>>g-c;h=x[e+8>>2];x[d>>2]=x[d>>2]&(g^-1)|g&x[h>>2];c=c+x[f+4>>2]|0;x[f+4>>2]=c&31;x[f>>2]=d+(c>>>3&536870908);c=h+4|0;x[e+8>>2]=c;d=x[b+12>>2]}h=c;c=(d|0)/32|0;SQ(h,c,x[f>>2]);d=x[b+12>>2]-(c<<5)|0;x[b+12>>2]=d;g=c<<2;c=g+x[f>>2]|0;x[f>>2]=c;if((d|0)<=0){break b}g=g+x[e+8>>2]|0;x[e+8>>2]=g;h=c;j=x[c>>2];c=-1>>>32-d|0;x[h>>2]=j&(c^-1)|c&x[g>>2];x[f+4>>2]=x[b+12>>2]}Dd(a,f);hb=b+16|0;break a}x[e+48>>2]=f;x[e+52>>2]=g;b=x[c+4>>2];x[e+40>>2]=x[c>>2];x[e+44>>2]=b;g=Dd(e+32|0,d);b=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=b;b=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=b;f=hb-16|0;hb=f;d=Sk(e+16|0,e+24|0);x[f+12>>2]=d;d:{if((d|0)<=0){break d}b=x[e+28>>2];e:{if(!b){c=x[g+4>>2];b=x[e+24>>2];break e}c=32-b|0;x[f+8>>2]=c;d=f+8|0;b=x[fe(d,f+12|0)>>2];x[f+12>>2]=x[f+12>>2]-b;h=x[g+4>>2];k=x[x[e+24>>2]>>2];j=x[e+28>>2];x[f+8>>2]=b;h=32-h|0;x[f+4>>2]=h;l=Mb(d,f+4|0);i=x[g>>2];k=k&(-1<<j&-1>>>c-b);c=x[g+4>>2];d=x[e+28>>2];j=h;h=x[l>>2];x[i>>2]=(c>>>0>d>>>0?k<<c-d:k>>>d-c|0)|x[i>>2]&(-1<<c&-1>>>j-h^-1);j=c+h|0;c=j&31;x[g+4>>2]=c;i=i+(j>>>3&536870908)|0;x[g>>2]=i;b=b-h|0;if((b|0)>0){x[i>>2]=x[i>>2]&(-1>>>32-b^-1)|k>>>d+h;x[g+4>>2]=b;c=b}d=x[f+12>>2];b=x[e+24>>2]+4|0}i=32-c|0;if((d|0)>=32){j=-1<<c;l=j^-1;h=x[g>>2];k=x[h>>2];while(1){d=x[b>>2];x[h>>2]=k&l|d<<c;k=j&x[h+4>>2]|d>>>i;x[h+4>>2]=k;m=x[f+12>>2];d=m-32|0;x[f+12>>2]=d;b=b+4|0;h=h+4|0;if((m|0)>63){continue}break}x[g>>2]=h}x[e+24>>2]=b;if((d|0)<=0){break d}k=x[b>>2];x[f+8>>2]=i;b=fe(f+12|0,f+8|0);c=x[g>>2];h=x[g+4>>2];b=x[b>>2];j=x[c>>2]&(-1<<h&-1>>>i-b^-1);i=k&-1>>>32-d;x[c>>2]=j|i<<h;d=b+h|0;x[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;x[g>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|i>>>b;x[g+4>>2]=x[f+12>>2]}Dd(a,g);hb=f+16|0}hb=e+80|0}function Zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;n=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;s=e,t=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[s+28>>2]=t;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}j=a+8|0;s=e,t=Wf(j,b),x[s+16>>2]=t;x[e+20>>2]=lb;s=e,t=Ze(j,d),x[s+40>>2]=t;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];f=x[a+4>>2];j=x[a>>2];x[e+8>>2]=j;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;b:{c:{if(!d){g=k>>12;i=l>>12;break c}while(1){j=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+n|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=w[f+(x[e+44>>2]<<1)>>1];x[114409]=0;P(1113,x[e+24>>2],(g|0)/4<<16>>16);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=w[f+(x[e+44>>2]<<1)>>1];x[114409]=0;P(1113,b|0,(f|0)/4<<16>>16);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;i=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+60>>2];f=Yb(j,-16777216,16776704);g=x[a+64>>2];h=Yb(h,-16777216,16776704);o=x[a+72>>2];q=x[a+32>>2];r=x[c>>2];m=i<<8;i=m;b=sqa(b,b>>31,i,i>>31);i=lb;g=sqa(g,g>>31,f,f>>31);f=g+b|0;b=lb+i|0;b=f>>>0<g>>>0?b+1|0:b;i=f;f=x[a+68>>2];f=sqa(f,f>>31,h,h>>31);h=i+f|0;b=lb+b|0;b=f>>>0>h>>>0?b+1|0:b;l=x[a+28>>2]+l|0;i=l>>12;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(i,h)+r;k=k+q|0;g=k>>12;x[c+4>>2]=x[c+4>>2]+D(h,g);b=b-(m&o)|0;c=c+8|0;Tb(e+8|0,e);h=j;d=d-1|0;if(d){continue}break}j=x[e+8>>2];f=x[e+12>>2]}x[a>>2]=j;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=b;x[a+24>>2]=g;hb=e+48|0;return}b=N()|0;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=j;x[a+24>>2]=k>>12;Q(b|0);p()}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=hb-48|0;hb=k;f=x[a+4>>2];h=Dd(k+40|0,b);e=Dd(k+32|0,c);d=hb-16|0;hb=d;h=TQ(Dd(d+8|0,h),Dd(d,e));hb=d+16|0;d=h+x[a+4>>2]|0;x[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){x[x[a>>2]+((d>>>0>=33?d-1>>>5|0:0)<<2)>>2]=0}b=Dd(k+24|0,b);e=Dd(k+16|0,c);c=k+8|0;zo(c,a,f);h=hb-48|0;hb=h;a:{if(x[b+4>>2]==x[c+4>>2]){d=Dd(h+40|0,b);b=Dd(h+32|0,e);f=Dd(h+24|0,c);a=hb-16|0;hb=a;c=Sk(b,d);x[a+12>>2]=c;b:{if((c|0)<=0){break b}b=x[d+4>>2];c:{if(!b){b=x[d>>2];break c}e=32-b|0;x[a+8>>2]=e;b=x[fe(a+8|0,a+12|0)>>2];x[a+12>>2]=x[a+12>>2]-b;c=x[f>>2];e=-1<<x[d+4>>2]&-1>>>e-b;x[c>>2]=x[c>>2]&(e^-1)|e&x[x[d>>2]>>2];b=b+x[f+4>>2]|0;x[f+4>>2]=b&31;x[f>>2]=c+(b>>>3&536870908);b=x[d>>2]+4|0;x[d>>2]=b;c=x[a+12>>2]}e=b;b=(c|0)/32|0;SQ(e,b,x[f>>2]);c=x[a+12>>2]-(b<<5)|0;x[a+12>>2]=c;b=b<<2;x[f>>2]=b+x[f>>2];if((c|0)<=0){break b}b=b+x[d>>2]|0;x[d>>2]=b;d=x[f>>2];c=-1>>>32-c|0;x[d>>2]=x[d>>2]&(c^-1)|c&x[b>>2];x[f+4>>2]=x[a+12>>2]}Dd(k,f);hb=a+16|0;break a}d=Dd(h+16|0,b);a=Dd(h+8|0,e);f=Dd(h,c);b=hb-16|0;hb=b;a=Sk(a,d);x[b+12>>2]=a;d:{if((a|0)<=0){break d}c=x[d+4>>2];e:{if(!c){c=x[f+4>>2];break e}c=32-c|0;x[b+8>>2]=c;e=b+8|0;a=x[fe(e,b+12|0)>>2];x[b+12>>2]=x[b+12>>2]-a;g=x[f+4>>2];i=x[x[d>>2]>>2];j=x[d+4>>2];x[b+8>>2]=a;l=32-g|0;x[b+4>>2]=l;m=Mb(e,b+4|0);g=x[f>>2];i=i&(-1<<j&-1>>>c-a);c=x[f+4>>2];e=x[d+4>>2];j=c>>>0>e>>>0?i<<c-e:i>>>e-c|0;e=x[m>>2];x[g>>2]=j|x[g>>2]&(-1<<c&-1>>>l-e^-1);j=c+e|0;c=j&31;x[f+4>>2]=c;g=g+(j>>>3&536870908)|0;x[f>>2]=g;a=a-e|0;if((a|0)>0){x[g>>2]=x[g>>2]&(-1>>>32-a^-1)|i>>>e+x[d+4>>2];x[f+4>>2]=a;c=a}x[d>>2]=x[d>>2]+4;a=x[b+12>>2]}e=32-c|0;if((a|0)>=32){i=-1<<c;j=i^-1;g=x[d>>2];while(1){a=x[f>>2];g=x[g>>2];x[a>>2]=j&x[a>>2]|g<<c;x[f>>2]=a+4;x[a+4>>2]=i&x[a+4>>2]|g>>>e;l=x[b+12>>2];a=l-32|0;x[b+12>>2]=a;g=x[d>>2]+4|0;x[d>>2]=g;if((l|0)>63){continue}break}}if((a|0)<=0){break d}i=x[x[d>>2]>>2];x[b+8>>2]=e;c=fe(b+12|0,b+8|0);d=x[f>>2];g=x[f+4>>2];c=x[c>>2];j=x[d>>2]&(-1<<g&-1>>>e-c^-1);e=i&-1>>>32-a;x[d>>2]=j|e<<g;a=c+g|0;x[f+4>>2]=a&31;a=d+(a>>>3&536870908)|0;x[f>>2]=a;d=x[b+12>>2]-c|0;x[b+12>>2]=d;if((d|0)<=0){break d}x[a>>2]=x[a>>2]&(-1>>>32-d^-1)|e>>>c;x[f+4>>2]=x[b+12>>2]}Dd(k,f);hb=b+16|0}hb=h+48|0;hb=k+48|0}function _ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;n=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;s=e,t=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[s+28>>2]=t;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}j=a+8|0;s=e,t=Wf(j,b),x[s+16>>2]=t;x[e+20>>2]=lb;s=e,t=Ze(j,d),x[s+40>>2]=t;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];g=x[a+4>>2];j=x[a>>2];x[e+8>>2]=j;x[e+12>>2]=g;f=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=f;b:{c:{if(!d){f=k>>12;i=l>>12;break c}while(1){j=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2];if(!f){x[e+16>>2]=0;x[e+20>>2]=0}g=g+n|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=v[g+x[e+44>>2]|0];x[114409]=0;P(1113,x[e+24>>2],f<<6);f=x[114409];x[114409]=0;if((f|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);f=x[114409];x[114409]=0;if((f|0)==1){break e}f=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(f){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];f=x[b+4>>2];if(f){g=v[g+x[e+44>>2]|0];x[114409]=0;P(1113,b|0,g<<6);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],f|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];g=x[b>>2];x[b>>2]=g;x[b+4>>2]=0}x[114409]=0;i=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+60>>2];g=Yb(j,-16777216,16776704);f=x[a+64>>2];h=Yb(h,-16777216,16776704);o=x[a+72>>2];q=x[a+32>>2];r=x[c>>2];m=i<<8;i=m;b=sqa(b,b>>31,i,i>>31);i=lb;f=sqa(f,f>>31,g,g>>31);g=f+b|0;b=lb+i|0;b=g>>>0<f>>>0?b+1|0:b;i=g;g=x[a+68>>2];g=sqa(g,g>>31,h,h>>31);h=i+g|0;b=lb+b|0;b=g>>>0>h>>>0?b+1|0:b;l=x[a+28>>2]+l|0;i=l>>12;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(i,h)+r;k=k+q|0;f=k>>12;x[c+4>>2]=x[c+4>>2]+D(h,f);b=b-(m&o)|0;c=c+8|0;Tb(e+8|0,e);h=j;d=d-1|0;if(d){continue}break}j=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=j;x[a+4>>2]=g;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=b;x[a+24>>2]=f;hb=e+48|0;return}b=N()|0;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=j;x[a+24>>2]=k>>12;Q(b|0);p()}function o6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Xb(a);x[114409]=0;X(86);c=x[114409];x[114409]=0;a:{b:{if((c|0)==1){c=Ya(82416,74984,74936,0)|0;c:{d:{e:{d=ib;if((d|0)==(ca(82416)|0)){c=Y(c|0)|0;x[114409]=0;O(2119,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;O(2119,a|0,13619)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;O(2119,a|0,13595)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}b=mb[x[x[c>>2]+8>>2]](c)|0;x[114409]=0;O(2119,a|0,(b?b:17381)|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if((ca(74984)|0)==(d|0)){c=Y(c|0)|0;x[114409]=0;O(2119,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;O(2119,a|0,13619)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;O(2119,a|0,13570)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}b=mb[x[x[c>>2]+8>>2]](c)|0;x[114409]=0;O(2119,a|0,(b?b:17381)|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;break a}e=ca(74936)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[114409]=0;O(2119,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;O(2119,a|0,13619)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;O(2119,a|0,13586)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}b=mb[x[x[c>>2]+8>>2]](c)|0;x[114409]=0;O(2119,a|0,(b?b:17381)|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;break a}x[114409]=0;O(2119,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;O(2119,a|0,13619)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;O(2119,a|0,9549)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){break a}break c}b=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){break a}break c}b=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)==1){break c}break a}b=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){break a}}R(0)|0;zb()}p()}return}xb(a);Q(b|0);p()}function o4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-160|0;hb=d;a:{if(Dj(b)){break a}e=y[yk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Lk(d+128|0,b,x[b+4>>2]-1|0);e=x[d+132>>2];x[b>>2]=x[d+128>>2];x[b+4>>2]=e}f=d+128|0;Gd(f);e=x[d+128>>2];Gd(d+116|0);e=xk(e,x[d+120>>2],b);Gd(f);b:{c:{d:{e:{f:{g:{if((e|0)==x[d+132>>2]){a=x[b+4>>2];x[d+152>>2]=x[b>>2];x[d+156>>2]=a;a=uc(d+144|0,17381);e=x[d+156>>2];x[d+8>>2]=x[d+152>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;if(Mc(d+8|0,d)){a=ec(8);x[114409]=0;c=O(122,d+128|0,6463)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}e=0;f=0;if(!c){break g}c=ec(8);x[114409]=0;a=O(2266,d+116|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;T(2242,d+128|0,13519,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}b=oc(c,d+128|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=N()|0;xb(d+128|0);xb(a);break c}b=N()|0;break d}if(x[e+4>>2]!=1){a=ec(8);x[114409]=0;c=O(122,d+128|0,7464)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];x[d+104>>2]=x[b>>2];x[d+108>>2]=c;c=uc(d+96|0,17381);e=x[d+108>>2];x[d+56>>2]=x[d+104>>2];x[d+60>>2]=e;e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;if(Mc(d+56|0,d+48|0)){a=ec(8);x[114409]=0;c=O(122,d+128|0,6463)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];x[d+88>>2]=x[b>>2];x[d+92>>2]=c;c=uc(d+80|0,6914);e=x[d+92>>2];x[d+40>>2]=x[d+88>>2];x[d+44>>2]=e;e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Mc(d+40|0,d+32|0)){e=x[a+8>>2];f=e>>31;break g}c=x[b+4>>2];x[d+72>>2]=x[b>>2];x[d+76>>2]=c;b=uc(d- -64|0,4819);c=x[d+76>>2];x[d+24>>2]=x[d+72>>2];x[d+28>>2]=c;c=x[b+4>>2];x[d+16>>2]=x[b>>2];x[d+20>>2]=c;e=0;f=0;if(!Mc(d+24|0,d+16|0)){break g}e=x[x[a+32>>2]+40>>2];f=e>>31}hb=d+160|0;lb=f;return e|0}b=N()|0;ic(a);break c}b=N()|0;xb(a)}ic(c)}Q(b|0)}p()}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-1136|0;hb=e;Nc(b);d=hb-16|0;hb=d;f=d+8|0;h=e+1112|0;DL(f,h);j=Fb(f);f=nc(b,ac(d,f));if((j|0)==(f|0)){cc(b,Fb(d+8|0))}hb=d+16|0;d=(f|0)==(j|0);if(!d){EL(h)}a:{if(!d){break a}if(!JL(e+1112|0)){break a}d=e+1120|0;if((y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))!=(oj(b)|0)){break a}h=e+1128|0;if((y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))!=(zf(b)|0)){break a}if(!c){g=1;break a}d=e+1056|0;Sb(d,0,56);i=-2;b:{if(!d){break b}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;f=x[d+32>>2];if(!f){x[d+32>>2]=2429;f=2429}if(!x[d+36>>2]){x[d+36>>2]=2430}f=mb[f|0](x[d+40>>2],1,43784)|0;i=-4;if(!f){break b}x[d+28>>2]=f;x[f+43780>>2]=1;x[f+10992>>2]=0;x[f+10996>>2]=0;x[f>>2]=0;x[f+11008>>2]=15;x[f+11e3>>2]=1;x[f+11004>>2]=0;i=0}if(i){break a}d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[e+1052>>2]=d;g=e+1132|0;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);k=(g|0)!=0;h=wT(e+1040|0,g);c:{d:{e:{f:{if(!g){j=1;break f}j=1;if(!d){break f}while(1){x[114409]=0;x[e+12>>2]=1024;d=O(306,e+12|0,e+1052|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}f=x[d>>2];x[114409]=0;U(234,b|0,e+16|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;l=U(1655,l|0,e+16|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}x[e+1072>>2]=g;x[e+1060>>2]=f;x[e+1056>>2]=e+16;d=x[h>>2];x[114409]=0;x[e+1068>>2]=d+m;n=O(1656,e+1056|0,0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}i=x[e+1052>>2];x[e+1052>>2]=i-f;j=(n|0)!=1;d=x[e+1072>>2];k=(d|0)!=0;if(!d|(f|0)==(i|0)){break f}m=(g+m|0)-d|0;g=d;if((n|0)!=1){continue}break}}x[114409]=0;S(1657,e+1056|0)|0;b=x[114409];x[114409]=0;g:{h:{if((b|0)!=1){g=0;b=e+1124|0;if(!((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=(l|0)|k|j)){x[114409]=0;P(856,e+4|0,h|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}x[114409]=0;b=U(857,e+16|0,e+4|0,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break h}x[114409]=0;g=U(1595,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break g}Ab(b)}de(h);break a}a=N()|0;break c}a=N()|0;break c}a=N()|0;Ab(b);break c}a=N()|0;break c}a=N()|0}de(h);Q(a|0);p()}hb=e+1136|0;return g|0}function k4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;a:{if(Dj(c)){break a}f=y[yk(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Lk(e+128|0,c,x[c+4>>2]-1|0);f=x[e+132>>2];x[c>>2]=x[e+128>>2];x[c+4>>2]=f}f=e+128|0;Gd(f);g=x[e+128>>2];Gd(e+116|0);h=xk(g,x[e+120>>2],c);Gd(f);f=x[c>>2];g=x[c+4>>2];b:{c:{d:{e:{f:{g:{if((h|0)==x[e+132>>2]){x[e+152>>2]=f;x[e+156>>2]=g;b=uc(e+144|0,17381);f=x[e+156>>2];x[e+8>>2]=x[e+152>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;if(Mc(e+8|0,e)){a=ec(8);x[114409]=0;b=O(122,e+128|0,6463)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}c=N()|0;xb(b);break c}if(d){b=ec(8);x[114409]=0;a=O(2266,e+116|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){x[114409]=0;T(2242,e+128|0,13519,a|0);c=x[114409];x[114409]=0;if((c|0)==1){break e}b=oc(b,e+128|0);x[114409]=0;T(2132,b|0,82416,2140);b=x[114409];x[114409]=0;if((b|0)!=1){break b}c=N()|0;xb(e+128|0);xb(a);break c}c=N()|0;break d}Xb(a);break g}x[e+104>>2]=f;x[e+108>>2]=g;d=uc(e+96|0,17381);f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;f=x[d+4>>2];x[e+48>>2]=x[d>>2];x[e+52>>2]=f;if(Mc(e+56|0,e+48|0)){a=ec(8);x[114409]=0;b=O(122,e+128|0,6463)|0;c=x[114409];x[114409]=0;if((c|0)!=1){a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}c=N()|0;xb(b);break c}c=N()|0;ic(a);break c}d=x[c+4>>2];x[e+88>>2]=x[c>>2];x[e+92>>2]=d;d=uc(e+80|0,8168);f=x[e+92>>2];x[e+40>>2]=x[e+88>>2];x[e+44>>2]=f;f=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=f;if(Mc(e+40|0,e+32|0)){h:{switch(x[b+52>>2]){case 0:Vb(a,2087);break g;case 1:Vb(a,7165);break g;case 2:Vb(a,5177);break g;default:break h}}Xb(a);break g}d=x[c+4>>2];x[e+72>>2]=x[c>>2];x[e+76>>2]=d;c=uc(e- -64|0,7402);d=x[e+76>>2];x[e+24>>2]=x[e+72>>2];x[e+28>>2]=d;d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Mc(e+24|0,e+16|0)){i:{switch(x[b+56>>2]){case 0:Vb(a,11631);break g;case 1:Vb(a,11636);break g;case 2:Vb(a,8427);break g;case 3:Vb(a,5241);break g;default:break i}}Xb(a);break g}Xb(a)}hb=e+160|0;return}c=N()|0;ic(a);break c}c=N()|0;xb(a)}ic(b)}Q(c|0)}p()}function Mx(a){a=a|0;var b=0,c=0,d=E(0),e=0;Sb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[114409]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}ba(2040,e|0,67,5,c|0,b|0);b=x[114409];x[114409]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[114409]=0;ba(2040,a+4528|0,62,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[114409]=0;ba(2040,a+4552|0,53,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[114409]=0;ba(2040,a+4576|0,43,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[114409]=0;ba(2040,a+4600|0,32,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[114409]=0;ba(2040,a+4624|0,22,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[114409]=0;ba(2040,a+4648|0,75,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[114409]=0;ba(2040,a+4672|0,69,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[114409]=0;ba(2040,a+4696|0,60,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[114409]=0;ba(2040,a+4720|0,48,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[114409]=0;ba(2040,a+4744|0,36,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[114409]=0;ba(2040,a+4768|0,25,5,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;ba(2040,a+4792|0,0,0,0,0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[114409]=0;ba(2040,a+4816|0,3,0,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[114409]=0;ba(2040,a+4840|0,3,0,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;ba(2040,a+4864|0,407,1,c|0,0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;ba(2040,a+4888|0,400,1,c|0,0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;ba(2040,a+4912|0,10,0,c|0,-1);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;ba(2040,a+4936|0,10,0,c|0,-1);c=x[114409];x[114409]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=R(74984)|0;if((ib|0)==(ca(74984)|0)){Y(c|0)|0;v[a+5045|0]=0;_();return}Q(c|0);p()}function CV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,B=0,C=0,E=0;e=hb-32|0;hb=e;j=ei(e+26|0);if(x[a+12>>2]){o=j+3|0;p=j+5|0;q=j+4|0;r=j+2|0;s=j+1|0;t=e+25|0;u=e+23|0;while(1){z=tm(a,l);while(1){a:{if(!Qb(c,1)){break a}d=te(c);if((d|0)==255){break a}m=d<<24>>24;d=m&31;f=D(d,6)+z|0;h=Fk(a)>>>0>d>>>0;i=h?f:j;b:{if(!(m&64)){g=te(c);k=g<<24>>24;d=255;g=g&127;c:{d:{if((g|0)==1){break d}d=g-1|0;if(b?d>>>0<=120:0){break d}if((g-109&255)>>>0<159|b){break c}d=g+13|0}v[i|0]=d}C=h?f+1|0:s,E=te(c),v[C|0]=E;if((k|0)>=0){break b}}g=h?f+3|0:o;d=h?f+5|0:p;n=h?f+4|0:q;k=h?f+2|0:r;while(1){w[e+24>>1]=y[i+4|0]|y[i+5|0]<<8;x[e+20>>2]=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);f=te(c);h=f&63;B=f<<24>>24;e:{if(f&64){v[k|0]=1;v[n|0]=h;break e}f=te(c);v[d|0]=f;f:{g:{if(h>>>0<=15){v[g|0]=h;Mj(i);h:{i:{j:{f=y[g|0];switch(f-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[g|0]=9;v[d|0]=D(y[d|0]&15,17);break f}v[g|0]=0;v[k|0]=1;x[e+16>>2]=y[d|0]+1>>>1;x[e+12>>2]=64;C=n,E=x[fe(e+16|0,e+12|0)>>2],v[C|0]=E;break f}if((f|0)!=19){break f}if(y[d|0]==128){break g}zL(i);break f}if(h>>>0>44){break f}h=h-16|0;v[g|0]=y[h+23360|0];k:{switch(h|0){case 0:if(f>>>0>1){break g}v[d|0]=f|158;break f;case 1:case 2:v[e+16|0]=15;C=d,E=y[tc(e+16|0,d)|0]|224,v[C|0]=E;break f;case 5:case 6:x[e+16>>2]=16;x[e+12>>2]=f+1;C=d,E=x[fe(e+16|0,e+12|0)>>2]/2|240,v[C|0]=E;break f;case 14:l:{m:{n:{o:{p:{h=f>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[g|0]=2;v[d|0]=f|240;break f}v[g|0]=3;v[d|0]=f|240;break f}v[g|0]=11;v[d|0]=(f<<3&120)+8|15;break f}v[g|0]=11;v[d|0]=(f&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[e+16>>2]=f+1>>>1;x[e+12>>2]=64;C=d,E=x[fe(e+16|0,e+12|0)>>2],v[C|0]=E;break f}v[g|0]=0}jy(g,d,u,t);if(Bn(y[e+23|0])>>>0<=Bn(y[g|0])>>>0){break e}q:{if(y[k|0]){break q}if(!ky(g,d,1)){break q}v[k|0]=y[g|0];v[n|0]=y[d|0]}v[g|0]=y[e+23|0];v[d|0]=y[e+25|0]}if((B|0)<0){continue}break}}if((m|0)>=0){continue}}break}l=l+1|0;if(l>>>0<A[a+12>>2]){continue}break}}hb=e+32|0}function Qna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0);c=hb-80|0;hb=c;d=hb-16|0;hb=d;e=d+8|0;f=b+16|0;NS(e,f);g=Fb(e);e=nc(a,ac(d,e));if((g|0)==(e|0)){cc(a,Fb(d+8|0))}hb=d+16|0;if((e|0)!=(g|0)){d=hb-16|0;hb=d;Sb(f,0,128);hb=d+16|0}lT(b+48|0);v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;d=c- -64|0;Ad(d,a,Kf(a));x[114409]=0;d=S(305,d|0)|0;e=x[114409];x[114409]=0;a:{b:{if((e|0)==1){break b}x[114409]=0;e=b+4|0;P(488,e|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}x[114409]=0;P(709,c+56|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}x[114409]=0;O(710,c- -64|0,c+56|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}x[114409]=0;d=S(413,a|0)|0;e=x[114409];x[114409]=0;c:{if((e|0)==1){break c}x[114409]=0;T(316,c+40|0,a|0,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}x[114409]=0;a=S(312,c+40|0)|0;d=x[114409];x[114409]=0;d:{if((d|0)!=1){e:{f:{if(!a){break f}while(1){g:{x[114409]=0;a=O(231,c+40|0,5)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}if(!a){break f}x[114409]=0;O(711,c+40|0,c+36|0)|0;a=x[114409];x[114409]=0;h:{if((a|0)!=1){a=4;d=y[c+36|0]|y[c+37|0]<<8|(y[c+38|0]<<16|y[c+39|0]<<24);if((d|0)==1414682436|(d|0)==1196380752){break h}x[114409]=0;a=S(413,c+40|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[114409]=0;T(316,c+20|0,c+40|0,a|0);a=x[114409];x[114409]=0;i:{j:{k:{if((a|0)!=1){if((y[c+36|0]|y[c+37|0]<<8|(y[c+38|0]<<16|y[c+39|0]<<24))!=1414682436){break k}x[114409]=0;h=E(wa(712,c+20|0));a=x[114409];x[114409]=0;if((a|0)==1){break g}x[114409]=0;B[c+16>>2]=h;x[c+12>>2]=0;x[c+8>>2]=1065353216;a=U(713,c+16|0,c+12|0,c+8|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}d=x[a>>2];B[b+144>>2]=B[a>>2];if((d&2147483647)-8388608>>>0<2130706432){break j}x[b+144>>2]=0;break j}a=N()|0;break d}if((y[c+36|0]|y[c+37|0]<<8|(y[c+38|0]<<16|y[c+39|0]<<24))!=1196380752){break j}x[114409]=0;a=S(413,c+20|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break i}x[b+148>>2]=a}Ab(c+20|0);continue}}break}a=N()|0;Ab(c+20|0);break d}Ab(c+40|0);Ab(c- -64|0);hb=c+80|0;return}a=N()|0;break d}a=N()|0}Ab(c+40|0);break a}a=N()|0;break a}a=N()|0}Ab(c- -64|0);Q(a|0);p()}function hM(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-240|0;hb=f;a:{if(!y[84088]){if(!y[83964]){d=hb-16|0;hb=d;h=Xb(83940);c=hb-16|0;hb=c;x[114409]=0;b=U(88,83952,c+15|0,c+14|0)|0;a=x[114409];x[114409]=0;b:{c:{d:{if((a|0)!=1){hb=c+16|0;break d}break c}v[83956]=0;a=hb-16|0;hb=a;x[114409]=0;c=U(89,83960,a+15|0,a+14|0)|0;e=x[114409];x[114409]=0;e:{if((e|0)!=1){hb=a+16|0;break e}break c}x[114409]=0;a=$(85)|0;e=x[114409];x[114409]=0;f:{g:{h:{if((e|0)!=1){x[d+12>>2]=a;a=d+12|0;nt(b,oe(a));_y(a);v[83956]=0;a=0;break h}a=ya(74984,74936)|0;e=ib;if((ca(74984)|0)==(e|0)){Y(a|0)|0;x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)==1){a=N()|0;x[114409]=0;X(20);f=x[114409];x[114409]=0;if((f|0)!=1){break g}R(0)|0;zb()}p()}if((ca(74936)|0)!=(e|0)){break g}Y(a|0)|0;v[83956]=0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){a=N()|0;break g}a=y[83956]}if(a&255){break f}x[114409]=0;V(87,83936);a=x[114409];x[114409]=0;if((a|0)!=1){break f}a=N()|0}kg(c);_y(b);xb(h);Q(a|0);p()}hb=d+16|0;break b}R(0)|0;zb();p()}v[83964]=1}c=hb+-64|0;hb=c;h=c+4|0;d=c+16|0;while(1){j=d+(i<<2)|0;a=0;b=0;e=hb-16|0;hb=e;Bb(e+12|0,83936);i:{j:{k:{l:{m:{if(yd(83952)){while(1){n:{g=x[20988];x[114409]=0;g=S(104,g|0)|0;k=x[114409];x[114409]=0;if((k|0)==1){break n}a=a|g;b=b+32|0;if(b>>>0<32){continue}break m}break}b=R(74936)|0;if((ib|0)!=(ca(74936)|0)){break j}Y(b|0)|0;v[83956]=0;x[114409]=0;V(87,83936);b=x[114409];x[114409]=0;if((b|0)==1){break l}x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break m}b=N()|0;break j}v[83956]=0}if(!y[83956]){b=x[20990];x[114409]=0;b=S(105,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break k}a=a^b}hb=e+16|0;break i}b=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){break j}R(0)|0;zb();p()}b=N()|0}Q(b|0);p()}x[j>>2]=a;i=i+1|0;if((i|0)!=12){continue}break}b=Jk(h);x[114409]=0;T(110,b|0,d|0,d+48|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}x[114409]=0;a=f+120|0;U(108,a|0,b|0,0)|0;d=x[114409];x[114409]=0;o:{if((d|0)!=1){Me(b);hb=c- -64|0;break o}break a}sc(83968,sc(f,a,120),116);v[84088]=1}hb=f+240|0;return 83968}c=N()|0;Me(b);Q(c|0);p()}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;x[h+28>>2]=d;k=_j(a,c);Af(h,x[a+28>>2]);d=x[h+12>>2];x[h+16>>2]=x[h+8>>2];x[h+20>>2]=d;a:{if(!k){if(Bd(a,5)){break a}}f=x[h+28>>2];d=hb-208|0;hb=d;i=vl(d+104|0,x[a+28>>2]);x[114409]=0;g=O(694,d+92|0,24352)|0;e=x[114409];x[114409]=0;b:{c:{d:{e:{if((e|0)!=1){x[114409]=0;x[d+72>>2]=19469602;x[d+76>>2]=0;T(695,i|0,g|0,d+72|0);e=x[114409];x[114409]=0;if((e|0)==1){break e}Gb(g);if(!(x[i>>2]&1073741824)){break d}break b}a=N()|0;break c}a=N()|0;Gb(g);break c}x[114409]=0;v[d+91|0]=0;g=O(694,d+72|0,1991)|0;e=x[114409];x[114409]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){x[114409]=0;U(696,i|0,d+91|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break q}Gb(g);g=Xb(d+60|0);x[114409]=0;e=O(694,d+48|0,6080)|0;j=x[114409];x[114409]=0;if((j|0)==1){break p}x[114409]=0;U(1236,i|0,g|0,e|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break o}Gb(e);x[114409]=0;T(13,d+36|0,(y[d+91|0]?0:f)|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break n}x[114409]=0;P(466,b|0,d+36|0);e=x[114409];x[114409]=0;if((e|0)==1){break m}e=d+36|0;xb(e);x[114409]=0;w[d+34>>1]=0;e=O(694,e|0,6727)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}x[114409]=0;U(1237,i|0,d+34|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break l}Gb(e);dg(d+34|0,z[x[19555]+12>>1]);x[114409]=0;e=O(694,d+20|0,9264)|0;f=x[114409];x[114409]=0;if((f|0)==1){break k}f=x[Bb(d+16|0,z[d+34>>1])>>2];x[114409]=0;Z(1238,i|0,b|0,e|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break j}Gb(e);x[114409]=0;w[d+14>>1]=65535;e=O(694,d|0,5085)|0;f=x[114409];x[114409]=0;if((f|0)==1){break i}x[114409]=0;f=U(1237,i|0,d+14|0,e|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break h}j=z[d+34>>1];l=z[d+14>>1];Gb(e);if(!((f|0)==1|j>>>0<=l>>>0)){Pe(b,z[d+14>>1])}xb(g);break b}a=N()|0;break c}a=N()|0;Gb(g);break c}a=N()|0;break f}a=N()|0;Gb(e);break f}a=N()|0;break f}a=N()|0;xb(d+36|0);break f}a=N()|0;Gb(e);break f}a=N()|0;break f}a=N()|0;Gb(e);break f}a=N()|0;break f}a=N()|0;Gb(e);break f}a=N()|0}xb(g)}Ig(i);Q(a|0);p()}Ig(i);hb=d+208|0}qj(a,k,c,h+16|0);hb=h+32|0}function N6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-80|0;hb=j;a:{b:{c:{k=lp(1,32);d:{e:{if(!k){a=bk(ec(4));x[114409]=0;T(2132,a|0,74984,26);a=x[114409];x[114409]=0;if((a|0)!=1){break a}i=R(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;x[k>>2]=c?c:2121;d=zt(j+68|0);f:{g:{h:{i:{if(!i){break i}c=x[i>>2];if(!c){break i}while(1){j:{e=x[i+4>>2];if(e){x[114409]=0;c=O(122,j+56|0,c|0)|0;f=x[114409];x[114409]=0;k:{if((f|0)!=1){x[114409]=0;f=O(2133,d|0,c|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break k}x[114409]=0;O(463,f|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}break j}i=R(0)|0;break h}i=R(0)|0;xb(c);break h}x[114409]=0;c=O(122,j+44|0,c|0)|0;e=x[114409];x[114409]=0;l:{if((e|0)!=1){x[114409]=0;O(2134,d|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}break j}i=R(0)|0;break h}i=R(0)|0;xb(c);break h}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}c=x[a+8>>2];e=x[a+4>>2];f=x[a>>2];x[114409]=0;a=S(1482,96)|0;i=x[114409];x[114409]=0;m:{n:{if((i|0)!=1){x[114409]=0;x[j+40>>2]=c;x[j+36>>2]=e;x[j+32>>2]=f;x[j+28>>2]=b;b=O(2135,k|0,k+4|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break n}x[j+20>>2]=b;b=x[xp(j+24|0,j+20|0)>>2];x[114409]=0;c=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=c;c=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=c;b=Z(2209,a|0,j|0,b|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break g}i=R(0)|0;od(j+20|0);break m}i=R(0)|0;break h}i=R(0)|0}_b(a)}Mk(d);Y(i|0)|0;x[114409]=0;W(2113,7220,k|0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){a=x[k+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){_b(a);x[k+20>>2]=0}_b(k);k=0;break d}i=R(0)|0;break e}x[k+28>>2]=b;od(j+20|0);a=x[k+28>>2];x[k+24>>2]=a?a+8|0:0;Mk(d);break d}i=R(0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[114409]=0;W(2113,7220,0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=j+80|0;return k|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}R(0)|0;zb()}p()}function fM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;a:{b:{c:{f=D(b,896)+a|0;if(y[f+1075074|0]&2){e=x[a+480180>>2];d:{e:{f:{if(x[a+480208>>2]&4096){if(!(e&16777248)){break f}if(x[a+480180>>2]==64){break e}if(x[a+480208>>2]&4){break d}break c}if((e|0)!=64){break c}break e}if(x[a+480180>>2]!=64){break d}}a=D(b,896)+a|0;b=a+1075823|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075828|0],167)}v[b|0]=d+1;break a}break b}if(!(y[f+1075654|0]&2)){break a}a=Qy(a,b);if(!a){break a}mb[x[x[a>>2]+84>>2]](a,0,0,b);break a}e=h+8|0;Kb(e,a+1074312|0,21);k=1;if(!Ib(e)){break b}e=D(b,896)+a|0;g=e+1075823|0;v[g|0]=y[g|0]+(y[e+1075827|0]<<2)}g=D(b,896)+a|0;i=g+1075826|0;j=g+1075823|0;e=xy(a,y[i|0],y[j|0]);g:{if(Lj(f+1074984|0)){B[d>>2]=E(E(D(y[g+1075828|0],e)|0)*E(6510417279059766e-21))+B[d>>2];c=g+1075856|0;d=y[c|0];v[c|0]=d&231|16;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break g}v[c|0]=d|24;break g}if((x[a+480208>>2]&2101248)==2101248|(y[a+480209|0]&16?x[a+480180>>2]&67633152:0)){break a}e=x[a+480180>>2]&5?(y[i|0]&3)==1?0-e|0:e:e;d=h+8|0;f=a+1074312|0;Kb(d,f,21);d=Ib(d);g=x[a+480208>>2];h:{if(d){d=g&4;e=d?e:0-e|0;d=d?5:6;break h}d=5;i:{if(g&131072){break i}d=8;if(x[a+480180>>2]==1024){break i}d=7;if(x[a+480180>>2]&524304|(y[a+480208|0]&4?0:x[a+480180>>2]&16777248)){break i}d=6}g=h+8|0;Kb(g,f,80);if(!Ib(g)){break h}d=y[(D(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(D(y[(D(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;g=0-d|0;j:{if(!(y[a+480208|0]&16)|x[a+480180>>2]==4){break j}e=x[c>>2];f=e>>31;k:{if((d|0)<0){d=Py(a,g>>>2|0);d=Ec(tqa(sqa(d,d>>31,e,f),lb,65536,0),lb);e=x[c>>2];d=d-e|0;f=g&3;if(!f){break j}f=hN(a,f);break k}i=d&3;d=Oy(a,d>>>2|0);d=Ec(tqa(sqa(d,d>>31,e,f),lb,65536,0),lb);e=x[c>>2];d=d-e|0;if(!i){break j}f=gN(a,i)}d=(Ec(tqa(sqa(f,f>>31,e,e>>31),lb,65536,0),lb)+d|0)-x[c>>2]|0}x[c>>2]=x[c>>2]+d;c=Qy(a,b);if(!c){break g}f=g<<16>>16;d=x[(D(b,896)+a|0)+1075640>>2];if(d){d=y[d+33|0]}else{d=2}mb[x[x[c>>2]+84>>2]](c,f,d<<24>>24,b)}if(!k){break a}c=h+8|0;Kb(c,a+1074312|0,21);if(Ib(c)){break a}v[j|0]=y[j|0]+y[(D(b,896)+a|0)+1075827|0]}hb=h+16|0}function bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;r=e,s=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[r+28>>2]=s;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}i=a+8|0;r=e,s=Wf(i,b),x[r+16>>2]=s;x[e+20>>2]=lb;r=e,s=Ze(i,d),x[r+40>>2]=s;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];b=x[a+44>>2];i=x[a+4>>2];g=i;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=g;i=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=i;b:{c:{if(!d){i=h;break c}while(1){i=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=w[f+(x[e+44>>2]<<1)>>1];x[114409]=0;P(1113,x[e+24>>2],(g|0)/4<<16>>16);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=w[f+(x[e+44>>2]<<1)>>1];x[114409]=0;P(1113,b|0,(f|0)/4<<16>>16);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;j=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+60>>2];f=Yb(i,-16777216,16776704);g=x[a+64>>2];h=Yb(h,-16777216,16776704);n=x[a+72>>2];o=x[c>>2];j=j<<8;b=sqa(b,b>>31,j,j>>31);q=lb;g=sqa(g,g>>31,f,f>>31);f=g+b|0;b=lb+q|0;b=f>>>0<g>>>0?b+1|0:b;g=f;f=x[a+68>>2];f=sqa(f,f>>31,h,h>>31);h=g+f|0;b=lb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(h,m)+o;x[c+4>>2]=x[c+4>>2]+D(h,l);b=b-(j&n)|0;c=c+8|0;Tb(e+8|0,e);h=i;d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0;return}b=N()|0;x[a+48>>2]=h;x[a+44>>2]=i;Q(b|0);p()}function Pl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;a:{b:{if(kd(a)|A[a+12>>2]<=A[b+4>>2]){break b}f=z[b+8>>1]>=Fk(a)>>>0;i=z[b+8>>1];if(f&(i|0)!=65535){break b}f=i;if((f&65535)==65535){i=Fk(a)-1|0;f=0}c=Hf(a,x[b+4>>2],f&65535);c:{h=y[b+12|0];d:{if(h&2){break d}k=i&65535;if(k>>>0<(f&65535)>>>0){break d}l=h&4;j=y[b+10|0];e=f;d=c;while(1){e:{if(!l){if((j|0)!=y[d+3|0]){break e}break c}if((j|0)==y[d+2|0]){break c}}d=d+6|0;e=e+1|0;if(k>>>0>=(e&65535)>>>0){continue}break}}j=i&65535;if(j>>>0>=(f&65535)>>>0){k=h&4;e=f;d=c;while(1){f:{if(!k){if(y[d+3|0]){break f}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break c}if(y[d+2|0]){break f}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break c}d=d+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(h&1)){break g}h=x[An(a)+480180>>2]&2;e=y[b+12|0];h:{if(e&4){break h}d=i&65535;if(d>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(y[c+3|0]-9|0){case 4:if(!CL(x[An(a)+8>>2],1)){break i}d=1;v[c+2|0]=1;v[c+4|0]=y[c+5|0];v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break a;case 0:break j;default:break i}}k:{if(h){e=y[c+5|0];if(e>>>0>128){break i}v[c+2|0]=2;v[c+3|0]=y[b+10|0];a=1;break k}v[c+2|0]=2;v[c+3|0]=y[b+10|0];e=y[c+5|0];a=2}v[c+4|0]=a+e>>>a;v[c+5|0]=y[b+11|0];break c}c=c+6|0;f=f+1|0;if(d>>>0>=(f&65535)>>>0){continue}break}e=y[b+12|0]}l:{if(e&4){d=y[b+11|0];c=13;m:{switch(y[b+10|0]-1|0){case 1:d=ll(d<<(h?1:2));e=y[b+12|0];c=9;break;case 0:break m;default:break l}}v[b+11|0]=d;v[b+10|0]=c;e=e&254;v[b+12|0]=e;break l}c=y[b+11|0];v[g+14|0]=c;f=y[b+10|0];n:{o:{if(!(!h|(f|0)!=9)){if(c>>>0>128){break n}d=2;f=(c&254)>>>1|0;break o}v[g+15|0]=f;if(!ky(g+15|0,g+14|0,1)){break n}d=y[g+15|0];if(!d){break n}e=y[b+12|0];f=y[g+14|0]}v[b+11|0]=f;v[b+10|0]=d;v[b+12|0]=e&254}e=y[b+12|0]}d=1;if(e&1){break g}v[b+12|0]=e^4;if(Pl(a,b)){break a}}c=x[b>>2];p:{if((c|0)==1){if(A[a+12>>2]>x[b+4>>2]+1>>>0){x[b+4>>2]=x[b+4>>2]+1;break p}c=x[b>>2]}if((c|0)!=2){break b}d=0;c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=Pl(a,b);break a}d=1;break a}d=0}hb=g+16|0;return d|0}function gG(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-128|0;hb=j;a:{b:{c:{if(!zl(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}wd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];hG(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if((zl(b,c,k,p,f,g,h,m)|0)<=0){if(zl(b,c,k,p,f,g,n,m)){h=b;i=c;break a}wd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{wd(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){wd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){wd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}wd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){wd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;hb=j+128|0}function tJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-80|0;hb=j;a:{b:{c:{d:{e:{f:{k=lp(1,28);if(!k){a=bk(ec(4));x[114409]=0;T(2132,a|0,74984,26);a=x[114409];x[114409]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;x[k>>2]=c?c:2121;d=zt(j+68|0);g:{h:{i:{j:{if(!i){break j}c=x[i>>2];if(!c){break j}while(1){k:{e=x[i+4>>2];if(e){x[114409]=0;c=O(122,j+56|0,c|0)|0;f=x[114409];x[114409]=0;l:{if((f|0)!=1){x[114409]=0;f=O(2133,d|0,c|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break l}x[114409]=0;O(463,f|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}break k}i=R(0)|0;break i}i=R(0)|0;xb(c);break i}x[114409]=0;c=O(122,j+44|0,c|0)|0;e=x[114409];x[114409]=0;m:{if((e|0)!=1){x[114409]=0;O(2134,d|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}break k}i=R(0)|0;break i}i=R(0)|0;xb(c);break i}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}c=x[a+8>>2];e=x[a+4>>2];f=x[a>>2];x[114409]=0;a=S(1482,80)|0;i=x[114409];x[114409]=0;n:{o:{if((i|0)!=1){x[114409]=0;x[j+40>>2]=c;x[j+36>>2]=e;x[j+32>>2]=f;x[j+28>>2]=b;b=O(2135,k|0,k+4|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break o}x[j+20>>2]=b;b=x[xp(j+24|0,j+20|0)>>2];x[114409]=0;c=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=c;c=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=c;b=Z(2136,a|0,j|0,b|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break h}i=R(0)|0;od(j+20|0);break n}i=R(0)|0;break i}i=R(0)|0}_b(a)}Mk(d);Y(i|0)|0;x[114409]=0;W(2113,10774,k|0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break g}x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){_b(Js(a))}c=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){_b(a);x[k+20>>2]=0}_b(k);break d}x[k+24>>2]=b;od(j+20|0);Mk(d);c=k;break d}i=R(0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break e}break b}i=R(0)|0}Y(i|0)|0;c=0;x[114409]=0;W(2113,10774,0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=j+80|0;return c|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}R(0)|0;zb()}p()}function Bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;q=x[a+12>>2];g=q;a:{b:{c:{f=x[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}v=x[a+16>>2];j=x[a+44>>2];x[e+32>>2]=j;p=x[a+48>>2];x[e+36>>2]=p;h=x[a+52>>2];x[e+40>>2]=h;n=x[a+56>>2];x[e+44>>2]=n;r=x[a+40>>2];s=x[a+36>>2];b=x[a+4>>2];l=b;i=x[a>>2];x[e+16>>2]=i;x[e+20>>2]=b;x[e+8>>2]=f;x[e+12>>2]=g;e:{if(!d){b=r>>12;k=s>>12;break e}while(1){p=1;b=x[e+16>>2];m=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(b>>>16&65520)+q|0;t=w[b+14>>1];u=w[b+12>>1];o=w[b+10>>1];g=w[b+8>>1];n=w[b+6>>1];l=w[b+4>>1];f=w[b+2>>1];i=w[b>>1];j=0;h=1;k=0;while(1){b=k<<1;x[(k<<2)+e>>2]=(((((((D(w[m+(b|-8)>>1],f)+D(w[m+(b|-12)>>1],i)|0)+D(w[m+(b|-4)>>1],l)|0)+D(w[b+m>>1],n)|0)+D(w[m+(b|4)>>1],g)|0)+D(w[m+(b|8)>>1],o)|0)+D(u,w[m+(b|12)>>1])|0)+D(t,w[m+(b|16)>>1])|0)/32768;b=h&1;h=0;k=1;if(b){continue}break}while(1){b=(j<<2)+e|0;l=x[b>>2];k=x[a+60>>2];j=(e+28|0)+(j<<3)|0;f=x[j+4>>2];h=Yb(f,-16777216,16776704);o=x[a+64>>2];t=Yb(x[j+8>>2],-16777216,16776704);i=x[a+68>>2];g=i>>31;x[j+8>>2]=f;n=x[a+72>>2];u=l<<8;f=u;f=sqa(k,k>>31,f,f>>31);l=lb;k=f;f=sqa(o,o>>31,h,h>>31);o=k+f|0;h=lb+l|0;h=f>>>0>o>>>0?h+1|0:h;f=sqa(i,g,t,t>>31);l=f+o|0;i=lb+h|0;i=f>>>0>l>>>0?i+1|0:i;g=b;f=l+8388608|0;b=((f>>>0<8388608?i+1|0:i)&16777215)<<8|f>>>24;x[g>>2]=(b|0)/256;x[j+4>>2]=b-(n&u);j=1;b=p&1;p=0;if(b){continue}break}b=x[a+32>>2];s=x[a+28>>2]+s|0;k=s>>12;x[c>>2]=x[c>>2]+D(k,x[e>>2]);r=b+r|0;b=r>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}n=x[e+44>>2];h=x[e+40>>2];p=x[e+36>>2];j=x[e+32>>2];i=x[e+16>>2];l=x[e+20>>2]}x[a>>2]=i;x[a+4>>2]=l;x[a+40>>2]=r;x[a+20>>2]=k;x[a+36>>2]=s;x[a+56>>2]=n;x[a+52>>2]=h;x[a+48>>2]=p;x[a+44>>2]=j;x[a+24>>2]=b;hb=e+48|0}function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;r=e,s=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[r+28>>2]=s;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}i=a+8|0;r=e,s=Wf(i,b),x[r+16>>2]=s;x[e+20>>2]=lb;r=e,s=Ze(i,d),x[r+40>>2]=s;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];b=x[a+44>>2];i=x[a+4>>2];f=i;g=x[a>>2];x[e+8>>2]=g;x[e+12>>2]=f;i=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=i;b:{c:{if(!d){i=h;break c}while(1){i=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2];if(!f){x[e+16>>2]=0;x[e+20>>2]=0}g=g+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=v[g+x[e+44>>2]|0];x[114409]=0;P(1113,x[e+24>>2],f<<6);f=x[114409];x[114409]=0;if((f|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);f=x[114409];x[114409]=0;if((f|0)==1){break e}f=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(f){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];f=x[b+4>>2];if(f){g=v[g+x[e+44>>2]|0];x[114409]=0;P(1113,b|0,g<<6);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],f|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];g=x[b>>2];x[b>>2]=g;x[b+4>>2]=0}x[114409]=0;j=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+60>>2];g=Yb(i,-16777216,16776704);f=x[a+64>>2];h=Yb(h,-16777216,16776704);n=x[a+72>>2];o=x[c>>2];j=j<<8;b=sqa(b,b>>31,j,j>>31);q=lb;f=sqa(f,f>>31,g,g>>31);g=f+b|0;b=lb+q|0;b=g>>>0<f>>>0?b+1|0:b;f=g;g=x[a+68>>2];g=sqa(g,g>>31,h,h>>31);h=f+g|0;b=lb+b|0;b=g>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(h,m)+o;x[c+4>>2]=x[c+4>>2]+D(h,l);b=b-(j&n)|0;c=c+8|0;Tb(e+8|0,e);h=i;d=d-1|0;if(d){continue}break}g=x[e+8>>2];f=x[e+12>>2]}x[a>>2]=g;x[a+4>>2]=f;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0;return}b=N()|0;x[a+48>>2]=h;x[a+44>>2]=i;Q(b|0);p()}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb+-64|0;hb=d;w[d+62>>1]=c;dg(d+62|0,32);f=pm(a);x[114409]=0;P(813,f|0,z[d+62>>1]);a=x[114409];x[114409]=0;a:{if((a|0)!=1){b:{c:{if(!z[d+62>>1]){break c}while(1){a=z[b+480190>>1]+1|0;w[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}w[d+24>>1]=1;f:{if(!z[b+480190>>1]){break f}while(1){g:{if(He(mq(b,z[d+24>>1]))){break g}j=d,k=$z(bc(f),dc(f),d+24|0),x[j+48>>2]=k;j=d,k=dc(f),x[j+40>>2]=k;if(!Zs(d+48|0,d+40|0)){break g}w[d+60>>1]=z[d+24>>1];a=1;if(!z[b+480192>>1]){break f}while(1){c=x[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=St(c);if((c|0)==(e|0)){break h}while(1){if(z[c>>1]==z[d+60>>1]){w[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(z[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=z[d+24>>1]+1|0;w[d+24>>1]=a;if(z[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(z[d+60>>1]<4e3){break e}a=bu(d+48|0);x[114409]=0;c=O(1101,b|0,a|0)|0;e=x[114409];x[114409]=0;i:{j:{if((e|0)==1){break j}k:{if(c){x[114409]=0;O(1102,b|0,a|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break j}e=1;if(!z[b+480192>>1]){break k}while(1){c=x[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=St(c);if((c|0)==(g|0)){break l}while(1){m:{if(A[a+4>>2]<=z[c>>1]){break m}h=d+40|0;se(h,a,z[c>>1]);if(Ib(h)){break m}w[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(z[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}ge(a);break c}c=d+24|0;cm(c,a);x[114409]=0;T(1103,d+32|0,c|0,1);c=x[114409];x[114409]=0;if((c|0)!=1){c=d+16|0;lq(c,a);x[114409]=0;v[d+15|0]=0;W(1104,d+40|0,d+32|0,c|0,d+15|0);c=x[114409];x[114409]=0;if((c|0)!=1){break i}}}c=N()|0;ge(a);break a}c=d+4|0;cm(c,a);j=d,k=Sk(d+40|0,c),w[j+60>>1]=k;ge(a);if(z[d+60>>1]>=4e3){break d}}x[114409]=0;P(435,f|0,d+60|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}if(z[b+480190>>1]>=z[d+60>>1]){break d}w[b+480190>>1]=z[d+60>>1]}i=i+1|0;if(z[d+62>>1]>(i&65535)>>>0){continue}break}}hb=d- -64|0;return}c=N()|0;break a}c=N()|0}vf(f);Q(c|0);p()}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;f=hb-48|0;hb=f;q=x[a+12>>2];g=q;a:{b:{c:{e=x[a+8>>2];d:{if((g|0)<=1&e>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&e>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&e>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&e>>>0>2147483648|g>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}y=x[a+16>>2];i=x[a+44>>2];x[f+32>>2]=i;p=x[a+48>>2];x[f+36>>2]=p;j=x[a+52>>2];x[f+40>>2]=j;n=x[a+56>>2];x[f+44>>2]=n;r=x[a+40>>2];s=x[a+36>>2];b=x[a+4>>2];k=b;h=x[a>>2];x[f+16>>2]=h;x[f+20>>2]=b;x[f+8>>2]=e;x[f+12>>2]=g;e:{if(!d){b=r>>12;e=s>>12;break e}while(1){b=x[f+16>>2];m=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(b>>>16&65520)+q|0;l=w[b+14>>1];t=w[b+12>>1];u=w[b+10>>1];o=w[b+8>>1];g=w[b+6>>1];n=w[b+4>>1];k=w[b+2>>1];e=w[b>>1];i=0;p=1;j=1;b=0;while(1){x[(b<<2)+f>>2]=(((((((D(v[m+(b|-4)|0],k)+D(v[m+(b|-6)|0],e)|0)+D(v[m+(b|-2)|0],n)|0)+D(v[b+m|0],g)|0)+D(v[m+(b|2)|0],o)|0)+D(v[m+(b|4)|0],u)|0)+D(t,v[m+(b|6)|0])|0)+D(l,v[m+(b|8)|0])<<8)/32768;h=j&1;j=0;b=1;if(h){continue}break}while(1){b=(i<<2)+f|0;k=x[b>>2];j=x[a+60>>2];i=(f+28|0)+(i<<3)|0;e=x[i+4>>2];l=Yb(e,-16777216,16776704);o=x[a+64>>2];t=Yb(x[i+8>>2],-16777216,16776704);h=x[a+68>>2];g=h>>31;x[i+8>>2]=e;n=x[a+72>>2];u=k<<8;e=u;e=sqa(j,j>>31,e,e>>31);k=lb;j=e;e=sqa(o,o>>31,l,l>>31);o=j+e|0;l=lb+k|0;l=e>>>0>o>>>0?l+1|0:l;e=sqa(h,g,t,t>>31);k=e+o|0;h=lb+l|0;h=e>>>0>k>>>0?h+1|0:h;g=b;e=k+8388608|0;b=((e>>>0<8388608?h+1|0:h)&16777215)<<8|e>>>24;x[g>>2]=(b|0)/256;x[i+4>>2]=b-(n&u);i=1;b=p&1;p=0;if(b){continue}break}b=x[a+32>>2];s=x[a+28>>2]+s|0;e=s>>12;x[c>>2]=x[c>>2]+D(e,x[f>>2]);r=b+r|0;b=r>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+4>>2]);c=c+8|0;Tb(f+16|0,f+8|0);d=d-1|0;if(d){continue}break}n=x[f+44>>2];j=x[f+40>>2];p=x[f+36>>2];i=x[f+32>>2];h=x[f+16>>2];k=x[f+20>>2]}x[a>>2]=h;x[a+4>>2]=k;x[a+40>>2]=r;x[a+20>>2]=e;x[a+36>>2]=s;x[a+56>>2]=n;x[a+52>>2]=j;x[a+48>>2]=p;x[a+44>>2]=i;x[a+24>>2]=b;hb=f+48|0}function Dn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;x[b+88>>2]=x[b+88>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if($b(a+1074312|0,15)){break b}}if(x[a+480180>>2]!=268435456){break a}}c=c?c:y[b+831|0];v[b+832|0]=c;v[b+831|0]=c}if(c){x[b+776>>2]=c}c:{d:{if(Lj(b)){c=x[b+776>>2];if(!c){break d}e=x[a+1074392>>2];d=x[b+708>>2];if(!(!((c|0)<0&(d|0)>0)&((c|0)<=0|(d|0)>=0))){c=0-c|0;x[b+776>>2]=c}f=x[b+880>>2];g=(+(e>>>0)+1)*+(c|0)/+A[a+1074416>>2];e:{if(F(g)<2147483648){a=~~g;break e}a=-2147483648}x[b+880>>2]=a;if(y[b+90|0]&16){a=D(x[x[x[b+656>>2]+44>>2]+36>>2]+1|0,a);x[b+880>>2]=a}a=a-(e?f:0)|0;c=a>>31;e=d>>31;if((e^d)-e>>>0<=(a^c)-c>>>0){if(!d){break d}x[b+708>>2]=0;x[b+876>>2]=d+x[b+876>>2];break c}x[b+708>>2]=d-a;x[b+876>>2]=a+x[b+876>>2];break c}e=1;f:{if(!(v[b+872|0]&1)|x[a+480180>>2]&524352){break f}if(x[a+1074416>>2]==1){if($b(a+1074312|0,6)){break f}}e=0;if(x[a+480180>>2]!=8){break f}e=(y[a+480208|0]&2)>>>1|0}f=x[b+776>>2];h=x[a+480180>>2];i=y[b+872|0];j=x[a+480180>>2];c=x[b+700>>2];g:{if(!c){d=x[b+708>>2];c=0;break g}d=x[b+708>>2];if(!d){break g}k=e;e=(h|0)==268435456&(f|0)>239;if(!((e?i:k)&1)){break g}e=e?f-240|0:f;e=(j|0)==64?D(e,10):e;h:{i:{j:{k:{l:{if((c|0)<(d|0)){if(y[a+480208|0]&16){if(x[a+480180>>2]!=4){break l}c=x[b+700>>2]}d=e<<2;break i}if((c|0)<=(d|0)){break g}if(y[a+480208|0]&16){if(x[a+480180>>2]!=4){break k}c=x[b+700>>2]}d=0-(e<<2)|0;break j}c=x[((e>>>0>=255?255:e)<<2)+30400>>2];d=c;e=c>>31;c=x[b+700>>2];d=sqa(d,e,c,c>>31);c=lb;d=d+32768|0;c=d>>>0<32768?c+1|0:c;d=Ec(tqa(d,c,65536,0),lb);c=x[b+700>>2];d=d-c|0;d=(d|0)<=1?1:d;break i}c=x[((e>>>0>=255?255:e)<<2)+31424>>2];d=c;e=c>>31;c=x[b+700>>2];d=sqa(d,e,c,c>>31);c=lb;d=d+32768|0;c=d>>>0<32768?c+1|0:c;d=Ec(tqa(d,c,65536,0),lb);c=x[b+700>>2];d=d-c|0;d=(d|0)>=-1?-1:d}c=c+d|0;d=x[b+708>>2];c=(c|0)>(d|0)?c:d;break h}c=c+d|0;d=x[b+708>>2];c=(c|0)<(d|0)?c:d}x[b+700>>2]=c}if((c|0)!=(d|0)){break d}if(!$b(a+1074312|0,25)&x[a+480180>>2]!=1){break d}x[b+708>>2]=0}return}v[b+872|0]=y[b+872|0]|16}function E$(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=hb-1056|0;hb=j;x[j+16>>2]=f;x[j+20>>2]=g;x[j+24>>2]=h;x[j+28>>2]=i;a=j+944|0;x[j+940>>2]=a;k=yw(a,100,7031,j+16|0);x[j+48>>2]=2580;a=j+48|0;n=Sd(j+520|0,0,a);x[j+48>>2]=2580;l=Sd(j+512|0,0,a);m=j+528|0;a:{b:{c:{d:{if(k>>>0>=100){x[114409]=0;a=$(2603)|0;k=x[114409];x[114409]=0;if((k|0)==1){break d}x[j>>2]=f;x[j+4>>2]=g;x[114409]=0;x[j+8>>2]=h;x[j+12>>2]=i;k=Z(2623,j+940|0,a|0,7031,j|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){Ce(n,x[j+940>>2]);Ce(l,xd(k<<2));if(!Ij(l)){break e}}x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)==1){break d}break a}m=x[l>>2]}x[114409]=0;Fc(j+508|0,d);a=x[114409];x[114409]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){x[114409]=0;q=S(2606,j+508|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break k}x[114409]=0;a=x[j+940>>2];Z(2619,q|0,a|0,a+k|0,m|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break k}o=(k|0)>0?y[x[j+940>>2]]==45:o;h=Xb(j+484|0);f=Dg(j+472|0);g=Dg(j+460|0);x[114409]=0;ja(2660,c|0,o|0,j+508|0,j+504|0,j+500|0,j+496|0,h|0,f|0,g|0,j+456|0);a=x[114409];x[114409]=0;if((a|0)==1){break j}x[j+36>>2]=2580;i=Sd(j+40|0,0,j+36|0);c=j+48|0;a=x[j+456>>2];l:{if((a|0)<(k|0)){a=(((Cb(g)+(k-a<<1)|0)+Cb(f)|0)+x[j+456>>2]|0)+1|0;break l}a=((Cb(g)+Cb(f)|0)+x[j+456>>2]|0)+2|0}if(a>>>0<101){break i}Ce(i,xd(a<<2));c=x[i>>2];if(c){break i}x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break a}break h}k=N()|0;break b}k=N()|0;break f}k=N()|0;break g}a=x[d+4>>2];x[114409]=0;oa(2661,c|0,j+36|0,j+32|0,a|0,m|0,(k<<2)+m|0,q|0,o|0,j+504|0,x[j+500>>2],x[j+496>>2],h|0,f|0,g|0,x[j+456>>2]);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;a=ga(2635,b|0,c|0,x[j+36>>2],x[j+32>>2],d|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break c}}}k=N()|0;Lc(i)}Pc(g);Pc(f);xb(h)}Ob(j+508|0);break b}k=N()|0;break b}Lc(i);Pc(g);Pc(f);xb(h);Ob(j+508|0);Lc(l);Lc(n);hb=j+1056|0;return a|0}Lc(l);Lc(n);Q(k|0);p()}p()}function ww(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[114276]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Bf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+61408>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+61408>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=y[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[114232]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[114232]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c|0}function wI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;h=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;b=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=b;x[e+20>>2]=a;x[e+24>>2]=e+44;b=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=b;a:{b:{switch(x[h+40>>2]){case 0:c=hb-80|0;hb=c;b=x[e>>2];d=x[b+4>>2];g=x[b+24>>2];x[c+40>>2]=x[b+20>>2];x[c+44>>2]=g;g=x[b+16>>2];x[c+32>>2]=x[b+12>>2];x[c+36>>2]=g;Th(c- -64|0,c+32|0,d);b=Oc(c+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];f=x[x[e+8>>2]>>2];d=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=d;d=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=d;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;if(g){k=c+16|0;while(1){d=0;if(f){while(1){j=C[ph(c,d,i)>>3];fc(h,d);j=Td(Gg(j)*32768);c:{if(F(j)<2147483648){b=~~j;break c}b=-2147483648}b=Wc(b);o=rn(k,d,i),p=b,w[o>>1]=p;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}hb=c+80|0;break a;case 2:xx(e,yb(h));break a;case 3:h=fh(h);d=0;b=hb-80|0;hb=b;c=x[e>>2];i=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Th(b- -64|0,b+32|0,i);c=Oc(b+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);i=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];f=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=f;f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(i){k=b+16|0;l=h+16|0;while(1){c=0;if(g){while(1){j=C[ph(b,c,d)>>3];f=ef(h,c);m=f;f=Kj(Td(j*134217728))+(x[f>>2]>>1)|0;n=f;f=As(l)+f&-4096;x[m>>2]=n-f;j=Td(Gg(+(f|0)*7.450580596923828e-9)*32768);d:{if(F(j)<2147483648){f=~~j;break d}f=-2147483648}f=Wc(f);o=rn(k,c,d),p=f,w[o>>1]=p;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:xx(e,yb(h));break a;default:break b}}xx(e,yb(h))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function Mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=hb-208|0;hb=c;j=1;h=x[a+12>>2];i=1<<h;m=2;g=h;if(g>>>0>=2){f=i;while(1){l=f>>>2|0;if(f>>>0>=4){v=l>>>0<=1?1:l;w=D(j,3);y=j<<1;g=0;while(1){e=c+192|0;QL(e,wc(a,g<<1));f=c+176|0;QL(f,wc(a,g));Yh(c+160|0,f,e);f=g<<m;r=j+f|0;if(f>>>0<r>>>0){while(1){d=wc(b,f);e=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=e;e=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=e;s=f+j|0;d=wc(b,s);e=x[d+12>>2];x[c+136>>2]=x[d+8>>2];x[c+140>>2]=e;e=x[d+4>>2];x[c+128>>2]=x[d>>2];x[c+132>>2]=e;t=f+y|0;d=wc(b,t);e=x[d+12>>2];x[c+120>>2]=x[d+8>>2];x[c+124>>2]=e;e=x[d+4>>2];x[c+112>>2]=x[d>>2];x[c+116>>2]=e;u=f+w|0;d=wc(b,u);e=x[d+12>>2];x[c+104>>2]=x[d+8>>2];x[c+108>>2]=e;e=x[d+4>>2];x[c+96>>2]=x[d>>2];x[c+100>>2]=e;n=c+80|0;d=c+144|0;e=c+128|0;Gk(n,d,e);o=c- -64|0;Mi(o,d,e);p=c+48|0;d=c+112|0;e=c+96|0;Gk(p,d,e);k=c+16|0;Mi(k,d,e);q=c+32|0;Yh(q,35024,k);Gk(k,n,p);d=wc(b,f);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;Gk(c,o,q);Yh(k,c+192|0,c);d=wc(b,s);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;Mi(c,n,p);Yh(k,c+176|0,c);d=wc(b,t);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;Mi(c,o,q);Yh(k,c+160|0,c);d=wc(b,u);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;f=f+1|0;if((r|0)!=(f|0)){continue}break}}g=g+1|0;if((v|0)!=(g|0)){continue}break}g=x[a+12>>2]}j=j<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){g=i>>>1|0;l=g>>>0<=1?1:g;f=0;while(1){i=f+g|0;h=wc(b,i);a=x[h+12>>2];x[c+200>>2]=x[h+8>>2];x[c+204>>2]=a;a=x[h+4>>2];x[c+192>>2]=x[h>>2];x[c+196>>2]=a;h=c+192|0;Mi(c+176|0,wc(b,f),h);i=wc(b,i);a=x[c+188>>2];x[i+8>>2]=x[c+184>>2];x[i+12>>2]=a;a=x[c+180>>2];x[i>>2]=x[c+176>>2];x[i+4>>2]=a;ny(wc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}hb=c+208|0}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-48|0;hb=e;l=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;m=e,n=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[m+28>>2]=n;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;m=e,n=Wf(f,b),x[m+16>>2]=n;x[e+20>>2]=lb;m=e,n=Ze(f,d),x[m+40>>2]=n;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=i>>12;h=j>>12;break c}while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=(((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+l|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{h=x[e+40>>2];g=(x[e+44>>2]&2147483647)<<1|h>>>31;h=w[(g<<1|2)+f>>1];g=w[f+((g&2147483646)<<1)>>1];x[114409]=0;P(1113,x[e+24>>2],(g+h|0)/8<<16>>16);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){k=x[e+40>>2];h=(x[e+44>>2]&2147483647)<<1|k>>>31;k=w[(h<<1|2)+f>>1];f=w[f+((h&2147483646)<<1)>>1];x[114409]=0;P(1113,b|0,(f+k|0)/8<<16>>16);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;f=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(f,h);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;Q(b|0);p()}function XO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a:{if(!He(a)){break a}Nn(a);if(c){n=hb-16|0;hb=n;if(He(a)){r=b+1304360|0;d=b+1074984|0;c=z[a+34>>1];f=c&4;s=c&2;l=c&16;t=c&8;g=x[a+8>>2];o=x[a+4>>2];h=x[a+16>>2];p=x[a+12>>2];while(1){b:{if(x[d+104>>2]!=(a|0)){break b}e=x[d+76>>2];if(!e){break b}c:{d:{e:{f:{m=x[a>>2];if(!t|(h>>>0<=p>>>0|h>>>0>m>>>0)){break f}i=x[d+88>>2];if(i&2048){break f}x[d+84>>2]=h;x[d+80>>2]=p;e=h;c=l;break e}if(!s|(g>>>0<=o>>>0|g>>>0>m>>>0)){break d}x[d+84>>2]=g;x[d+80>>2]=o;i=x[d+88>>2];e=g;c=f}x[d+76>>2]=e;k=i|2;q=d+88|0;i=(c|0)!=0;c=1;break c}q=d+88|0;k=x[d+88>>2]&-3;i=0;c=0}j=c;k=k&-5|(i?c?4:0:0);x[d+88>>2]=k;if(A[d+4>>2]>e>>>0){k=k&-129;x[d+88>>2]=k;c=x[d+80>>2];x[d>>2]=0;x[d+4>>2]=c}if(!i){x[q>>2]=k&-129}if(j){break b}x[d+76>>2]=m}d=d+896|0;if((r|0)!=(d|0)){continue}break}}hb=n+16|0}if((cr(a)|0)==2){d=0;h=hb-48|0;hb=h;e=Qe(a);l=e<<6;g=x[a+20>>2];f=g+(D(e,x[a>>2])<<1)|0;while(1){if(e){j=D(d,e);i=D(e,d^-1);c=0;while(1){w[f+(c+j<<1)>>1]=z[f+(c-e<<1)>>1];w[g+(c+i<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<5)|0;c=z[a+34>>1];if(c&2){f=x[a+4>>2];j=x[a+8>>2]-f|0;VO(h+28|0,d,g+(D(e,f)<<1)|0,j,e,(c&4)>>>2|0,$b(b+1074312|0,33));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];f=f-a|0;VO(h+8|0,d+(l<<1)|0,g+(D(a,e)<<1)|0,f,e,(c&16)>>>4|0,$b(b+1074312|0,33))}hb=h+48|0;return}if((cr(a)|0)!=1){break a}d=0;h=hb-48|0;hb=h;e=Qe(a);l=e<<6;g=x[a+20>>2];f=g+D(e,x[a>>2])|0;while(1){if(e){j=D(d,e);i=D(e,d^-1);c=0;while(1){v[f+(c+j|0)|0]=y[f+(c-e|0)|0];v[g+(c+i|0)|0]=y[c+g|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<4)|0;c=z[a+34>>1];if(c&2){f=x[a+4>>2];j=x[a+8>>2]-f|0;UO(h+28|0,d,g+D(e,f)|0,j,e,(c&4)>>>2|0,$b(b+1074312|0,33));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];f=f-a|0;UO(h+8|0,d+l|0,g+D(a,e)|0,f,e,(c&16)>>>4|0,$b(b+1074312|0,33))}hb=h+48|0}}function I$(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=hb-448|0;hb=j;x[j+16>>2]=f;x[j+20>>2]=g;x[j+24>>2]=h;x[j+28>>2]=i;a=j+336|0;x[j+332>>2]=a;k=yw(a,100,7031,j+16|0);x[j+48>>2]=2580;a=j+48|0;n=Sd(j+216|0,0,a);x[j+48>>2]=2580;l=Sd(j+208|0,0,a);m=j+224|0;a:{b:{c:{d:{if(k>>>0>=100){x[114409]=0;a=$(2603)|0;k=x[114409];x[114409]=0;if((k|0)==1){break d}x[j>>2]=f;x[j+4>>2]=g;x[114409]=0;x[j+8>>2]=h;x[j+12>>2]=i;k=Z(2623,j+332|0,a|0,7031,j|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){Ce(n,x[j+332>>2]);Ce(l,xd(k));if(!Ij(l)){break e}}x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)==1){break d}break a}m=x[l>>2]}x[114409]=0;Fc(j+204|0,d);a=x[114409];x[114409]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){x[114409]=0;q=S(21,j+204|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break k}x[114409]=0;a=x[j+332>>2];Z(2599,q|0,a|0,a+k|0,m|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break k}o=(k|0)>0?y[x[j+332>>2]]==45:o;h=Xb(j+184|0);f=Xb(j+172|0);g=Xb(j+160|0);x[114409]=0;ja(2658,c|0,o|0,j+204|0,j+200|0,j+199|0,j+198|0,h|0,f|0,g|0,j+156|0);a=x[114409];x[114409]=0;if((a|0)==1){break j}x[j+36>>2]=2580;i=Sd(j+40|0,0,j+36|0);c=j+48|0;a=x[j+156>>2];l:{if((a|0)<(k|0)){a=(((Cb(g)+(k-a<<1)|0)+Cb(f)|0)+x[j+156>>2]|0)+1|0;break l}a=((Cb(g)+Cb(f)|0)+x[j+156>>2]|0)+2|0}if(a>>>0<101){break i}Ce(i,xd(a));c=x[i>>2];if(c){break i}x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break a}break h}k=N()|0;break b}k=N()|0;break f}k=N()|0;break g}a=x[d+4>>2];x[114409]=0;oa(2659,c|0,j+36|0,j+32|0,a|0,m|0,k+m|0,q|0,o|0,j+200|0,v[j+199|0],v[j+198|0],h|0,f|0,g|0,x[j+156>>2]);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;a=ga(17,b|0,c|0,x[j+36>>2],x[j+32>>2],d|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break c}}}k=N()|0;Lc(i)}xb(g);xb(f);xb(h)}Ob(j+204|0);break b}k=N()|0;break b}Lc(i);xb(g);xb(f);xb(h);Ob(j+204|0);Lc(l);Lc(n);hb=j+448|0;return a|0}Lc(l);Lc(n);Q(k|0);p()}p()}function M6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=hb-48|0;hb=k;a:{b:{c:{j=lp(1,32);d:{e:{if(!j){a=bk(ec(4));x[114409]=0;T(2132,a|0,74984,26);a=x[114409];x[114409]=0;if((a|0)!=1){break a}i=R(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;x[j>>2]=c?c:2121;d=zt(k+36|0);f:{g:{h:{i:{if(!i){break i}c=x[i>>2];if(!c){break i}while(1){j:{e=x[i+4>>2];if(e){x[114409]=0;c=O(122,k+24|0,c|0)|0;f=x[114409];x[114409]=0;k:{if((f|0)!=1){x[114409]=0;f=O(2133,d|0,c|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break k}x[114409]=0;O(463,f|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break k}break j}i=R(0)|0;break h}i=R(0)|0;xb(c);break h}x[114409]=0;c=O(122,k+12|0,c|0)|0;e=x[114409];x[114409]=0;l:{if((e|0)!=1){x[114409]=0;O(2134,d|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}break j}i=R(0)|0;break h}i=R(0)|0;xb(c);break h}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}x[114409]=0;c=S(1482,96)|0;e=x[114409];x[114409]=0;m:{n:{if((e|0)!=1){x[114409]=0;e=O(2135,j|0,j+4|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break n}x[k+4>>2]=e;e=x[xp(k+8|0,k+4|0)>>2];x[114409]=0;a=aa(2210,c|0,a|0,b|0,e|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break g}i=R(0)|0;od(k+4|0);break m}i=R(0)|0;break h}i=R(0)|0}_b(c)}Mk(d);Y(i|0)|0;x[114409]=0;W(2113,1480,j|0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){a=x[j+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){_b(a);x[j+20>>2]=0}_b(j);j=0;break d}i=R(0)|0;break e}x[j+28>>2]=a;od(k+4|0);a=x[j+28>>2];x[j+24>>2]=a?a+8|0:0;Mk(d);break d}i=R(0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[114409]=0;W(2113,1480,0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=k+48|0;return j|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}R(0)|0;zb()}p()}function Gi(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=0;if(!(mb[x[x[a>>2]+132>>2]](a)|0)){g=y[x[a+20>>2]+25|0]}j=B[x[a+20>>2]+144>>2];k=E(1);if(!(mb[x[x[a>>2]+132>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((mb[x[x[a>>2]+148>>2]](a)|0)<=0){break a}if(!nK(x[a+20>>2])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(n*k);j=E(n*j);l=a+44|0;m=Qd(l,0);l=Qd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;p=h;k=E(B[g+m>>2]+B[h>>2]);h=c+g|0;B[p>>2]=E(k-E(B[g+l>>2]+E(k+B[h>>2])))+E(B[d+g>>2]*j);B[h>>2]=E(B[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(E(B[g+m>>2]*j)-B[d+g>>2])+B[h>>2];h=c+g|0;B[h>>2]=E(E(B[g+l>>2]*j)-B[e+g>>2])+B[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(B[h>>2]+B[d+g>>2])-E(B[g+m>>2]*k);h=c+g|0;B[h>>2]=E(B[h>>2]+B[e+g>>2])-E(B[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(B[h>>2]+B[g+m>>2])-E(B[d+g>>2]*j);h=c+g|0;B[h>>2]=E(B[h>>2]+B[g+l>>2])-E(B[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(E(B[g+m>>2]*k)+E(B[d+g>>2]*j))+B[h>>2];h=c+g|0;B[h>>2]=E(E(B[g+l>>2]*k)+E(B[e+g>>2]*j))+B[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=nK(x[a+20>>2]);if(!f){break b}j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;while(1){g=i<<2;h=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[h>>2]=E(B[h>>2]+E(n*j))+E(o*k);g=c+g|0;B[g>>2]=E(E(o*j)+E(n*k))+B[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break d}if(mb[x[x[a>>2]+132>>2]](a)|!f){break d}d=0;while(1){a=d<<2;e=a+b|0;B[e>>2]=B[e>>2]+B[a+m>>2];e=a+c|0;B[e>>2]=B[e>>2]+B[a+l>>2];d=d+1|0;if((f|0)!=(d|0)){continue}break}}}function ls(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return xd(b)}if(b>>>0>=4294967232){x[114232]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[114405]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){c=d-f|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|f|2;d=e+f|0;x[d+4>>2]=c|3;x[g+4>>2]=x[g+4>>2]|1;ks(d,c);break b}if(x[114291]==(g|0)){d=d+x[114288]|0;if(d>>>0<=f>>>0){break a}x[e+4>>2]=i&1|f|2;c=e+f|0;d=d-f|0;x[c+4>>2]=d|1;x[114288]=d;x[114291]=c;break b}if(x[114290]==(g|0)){d=d+x[114287]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[114290]=h;x[114287]=c;break b}h=x[g+4>>2];if(h&2){break a}j=d+(h&-8)|0;if(j>>>0<f>>>0){break a}l=j-f|0;d:{if(h>>>0<=255){c=x[g+12>>2];d=x[g+8>>2];if((c|0)==(d|0)){n=457140,o=x[114285]&wqa(-2,h>>>3|0),x[n>>2]=o;break d}x[d+12>>2]=c;x[c+8>>2]=d;break d}k=x[g+24>>2];d=x[g+12>>2];e:{if((g|0)!=(d|0)){c=x[g+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=g+20|0;h=x[c>>2];if(!h){h=x[g+16>>2];if(!h){break f}c=g+16|0}while(1){m=c;d=h;c=d+20|0;h=x[c>>2];if(h){continue}c=d+16|0;h=x[d+16>>2];if(h){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[g+28>>2];h=(c<<2)+457444|0;g:{if(x[h>>2]==(g|0)){x[h>>2]=d;if(d){break g}n=457144,o=x[114286]&wqa(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(g|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[g+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[g+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|f|2;c=e+f|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;ks(c,l)}c=e}if(c){return c+8|0}c=xd(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;sc(c,a,b>>>0>e>>>0?e:b);_b(a);return c}function w5(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=E(0),n=0;d=hb-16|0;hb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=B[a+48>>2];a=x[a+48>>2];e:{f:{g:{if((a|0)<=8388607){f=E(E(-1)/E(c*c));if(!(a&2147483647)){break e}f=E(E(c-c)/E(0));if((a|0)<0){break e}a=(q(E(c*E(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;m=E((a>>>23|0)+b|0);c=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));g=E(c*E(c*E(.5)));h=E(c/E(c+E(2)));i=E(h*h);k=E(i*i);f=c;c=(l(2,(q(E(c-g)),j(2))&-4096),r());g=E(E(h*E(g+E(E(i*E(E(k*E(.2849878668785095))+E(.6666666269302368)))+E(k*E(E(k*E(.24279078841209412))+E(.40000972151756287))))))+E(E(f-c)-g));c=E(E(m*E(.3010292053222656))+E(E(c*E(.434326171875))+E(E(g*E(.434326171875))+E(E(m*E(7.903415166765626e-7))+E(E(g+c)*E(-3168997136526741e-20))))))}f=c}c=E(f*E(2e3));if(!(E(F(c))<E(2147483648))){break c}a=~~c;break b;case 1:a=(D(x[x[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=hb-16|0;hb=b;h:{i:{j:{k:{a=y[x[a+24>>2]+24648|0];if(a>>>0>=6){a=ec(8);x[114409]=0;b=O(122,b+4|0,1613)|0;d=x[114409];x[114409]=0;if((d|0)==1){break k}a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break i}d=N()|0;xb(b);break j}hb=b+16|0;a=x[(a<<24>>24<<2)+37664>>2];break h}d=N()|0;ic(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;b=hb-80|0;hb=b;a=x[a+24>>2]+24604|0;x[b+40>>2]=x[a+32>>2];x[b>>2]=x[a+36>>2];e=b+40|0;n=x[Yf(e,b)>>2];l:{if(x[a+32>>2]==x[hq(e)+32>>2]){e=-1;if(x[a+36>>2]==x[hq(b)+36>>2]){break l}}e=0;if((n|0)<=0){break l}e=(n+500>>>0)/1e3|0}x[d+4>>2]=e;hb=b+80|0;a=x[d+4>>2];break b;default:break d}}a=ec(8);x[114409]=0;d=O(122,d+4|0,6366)|0;b=x[114409];x[114409]=0;m:{if((b|0)!=1){a=oc(a,d);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(d);break m}b=N()|0;ic(a)}Q(b|0);p()}a=-2147483648}hb=d+16|0;return a|0}p()}function xI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;h=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;b=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=b;x[e+20>>2]=a;x[e+24>>2]=e+44;b=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=b;a:{b:{switch(x[h+40>>2]){case 0:c=hb-80|0;hb=c;b=x[e>>2];d=x[b+4>>2];g=x[b+24>>2];x[c+40>>2]=x[b+20>>2];x[c+44>>2]=g;g=x[b+16>>2];x[c+32>>2]=x[b+12>>2];x[c+36>>2]=g;Th(c- -64|0,c+32|0,d);b=Oc(c+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];f=x[x[e+8>>2]>>2];d=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=d;d=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=d;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;if(g){b=c+16|0;while(1){d=0;if(f){while(1){j=x[Vf(c,d,i)>>2];fc(h,d);j=j-2147481600>>>12|0;j=j>>>0<=491520?491520:j;n=rn(b,d,i),o=(j|0)>=557055?557055:j,w[n>>1]=o;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}hb=c+80|0;break a;case 2:yx(e,yb(h));break a;case 3:h=fh(h);d=0;b=hb-80|0;hb=b;c=x[e>>2];i=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Th(b- -64|0,b+32|0,i);c=Oc(b+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);i=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];f=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=f;f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(i){j=b+16|0;l=h+16|0;while(1){c=0;if(g){while(1){f=x[Vf(b,c,d)>>2];k=ef(h,c);f=f+(x[k>>2]>>1)|0;m=f;f=As(l)+f&-4096;x[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0<=491520?491520:f;n=rn(j,c,d),o=(f|0)>=557055?557055:f,w[n>>1]=o;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:yx(e,yb(h));break a;default:break b}}yx(e,yb(h))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function Fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;p=x[a+12>>2];i=p;a:{b:{c:{f=x[a+8>>2];d:{if((i|0)<=1&f>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&f>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&f>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&f>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];b=x[a+44>>2];x[e+32>>2]=b;h=x[a+48>>2];x[e+36>>2]=h;j=x[a+52>>2];x[e+40>>2]=j;o=x[a+56>>2];x[e+44>>2]=o;u=x[a+24>>2];v=x[a+20>>2];k=x[a+4>>2];g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=k;x[e+8>>2]=f;x[e+12>>2]=i;if(d){while(1){o=1;b=x[e+16>>2];m=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+p|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];n=w[b+8>>1];s=w[b+6>>1];i=w[b+4>>1];k=w[b+2>>1];f=w[b>>1];j=0;b=1;h=0;while(1){g=h<<1;x[(h<<2)+e>>2]=(((((((D(w[m+(g|-8)>>1],k)+D(w[m+(g|-12)>>1],f)|0)+D(w[m+(g|-4)>>1],i)|0)+D(w[g+m>>1],s)|0)+D(w[m+(g|4)>>1],n)|0)+D(w[m+(g|8)>>1],r)|0)+D(w[m+(g|12)>>1],q)|0)+D(l,w[m+(g|16)>>1])|0)/32768;g=b;b=0;h=1;if(g){continue}break}while(1){b=(j<<2)+e|0;k=x[b>>2];h=x[a+60>>2];j=(e+28|0)+(j<<3)|0;f=x[j+4>>2];l=Yb(f,-16777216,16776704);n=x[a+64>>2];q=Yb(x[j+8>>2],-16777216,16776704);g=x[a+68>>2];s=g>>31;x[j+8>>2]=f;i=x[a+72>>2];r=k<<8;f=r;f=sqa(h,h>>31,f,f>>31);k=lb;h=f;f=sqa(n,n>>31,l,l>>31);n=h+f|0;l=lb+k|0;l=f>>>0>n>>>0?l+1|0:l;f=sqa(g,s,q,q>>31);k=f+n|0;g=lb+l|0;g=f>>>0>k>>>0?g+1|0:g;h=b;f=k+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[h>>2]=(b|0)/256;x[j+4>>2]=b-(i&r);j=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],v);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],u);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+44>>2];j=x[e+40>>2];h=x[e+36>>2];g=x[e+16>>2];k=x[e+20>>2];b=x[e+32>>2]}x[a>>2]=g;x[a+4>>2]=k;x[a+56>>2]=o;x[a+52>>2]=j;x[a+48>>2]=h;x[a+44>>2]=b;hb=e+48|0}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=E(0),r=E(0),s=0,t=0,u=0,v=0,w=E(0),y=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0);k=a+44|0;if(Eh(k)){z=Qd(k,0);A=Qd(k,1);C=ld(k,0);D=ld(k,1);m=x[a+4300>>2];p=x[a+4296>>2];if(d){j=a+4304|0;i=p+1|0;s=i+x[a+4272>>2]&4095;n=j+(s<<4)|0;t=i+x[a+4276>>2]&4095;f=((t<<4)+j|0)+4|0;u=i+x[a+4280>>2]&4095;F=((u<<4)+j|0)+8|0;v=i+x[a+4284>>2]&4095;G=((v<<4)+j|0)+12|0;g=x[a+4288>>2]+m|0;o=x[a+4292>>2]+m|0;I=a+69840|0;J=a+78032|0;H=d;while(1){t=t-1&4095;i=((t<<4)+j|0)+4|0;e=B[i>>2];K=g&1023;g=(K<<3)+I|0;h=B[g>>2];N=B[G>>2];O=B[F>>2];P=B[f>>2];Q=B[n>>2];w=B[A>>2];R=B[z>>2];L=m<<3;f=L+I|0;y=B[a+4232>>2];s=s-1&4095;n=(s<<4)+j|0;q=B[n>>2];r=E(E(B[g+4>>2]*y)-E(q*E(.6180340051651001)));B[f>>2]=E(r*E(.6180340051651001))+q;l=e;e=E(E(y*h)+E(e*E(.6180340051651001)));B[f+4>>2]=l-E(e*E(.6180340051651001));B[n>>2]=e;B[i>>2]=r;M=o&1023;f=(M<<3)+J|0;y=B[f+4>>2];u=u-1&4095;o=(u<<4)+j|0;F=o+8|0;h=B[F>>2];q=B[a+4236>>2];l=E(q*B[f>>2]);v=v-1&4095;f=(v<<4)+j|0;G=f+12|0;r=B[G>>2];e=E(l+E(r*E(.6180340051651001)));g=J+L|0;B[g+4>>2]=r-E(e*E(.6180340051651001));l=h;h=E(E(y*q)-E(h*E(.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[o+8>>2]=e;B[f+12>>2]=h;l=E(B[n>>2]+e);e=E(R+E(1.0000000031710769e-30));B[C>>2]=l+E(B[a+4224>>2]*e);h=E(w+E(1.0000000031710769e-30));B[D>>2]=E(E(B[a+4224>>2]*h)+B[i>>2])+B[f+12>>2];g=(p<<4)+j|0;w=B[a+4228>>2];e=E(w*e);B[g>>2]=E(E(B[a+4240>>2]*B[n>>2])+e)+E(Q*B[a+4244>>2]);h=E(w*h);B[g+4>>2]=E(E(B[a+4248>>2]*B[i>>2])+h)+E(P*B[a+4252>>2]);B[g+8>>2]=E(E(B[a+4256>>2]*B[o+8>>2])-h)+E(O*B[a+4260>>2]);B[g+12>>2]=E(E(B[a+4264>>2]*B[f+12>>2])+e)+E(N*B[a+4268>>2]);D=D+4|0;C=C+4|0;A=A+4|0;z=z+4|0;o=M-1|0;g=K-1|0;m=m-1&1023;p=p-1&4095;f=i;H=H-1|0;if(H){continue}break}}x[a+4300>>2]=m;x[a+4296>>2]=p;Gi(a,b,c,ld(k,0),ld(k,1),d)}}function eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-48|0;hb=e;l=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;m=e,n=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[m+28>>2]=n;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;m=e,n=Wf(f,b),x[m+16>>2]=n;x[e+20>>2]=lb;m=e,n=Ze(f,d),x[m+40>>2]=n;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=i>>12;h=j>>12;break c}while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+l|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{h=x[e+40>>2];g=(x[e+44>>2]&2147483647)<<1|h>>>31;h=v[(g|1)+f|0];g=v[f+(g&-2)|0];x[114409]=0;P(1113,x[e+24>>2],g+h<<5);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){k=x[e+40>>2];h=(x[e+44>>2]&2147483647)<<1|k>>>31;k=v[(h|1)+f|0];f=v[f+(h&-2)|0];x[114409]=0;P(1113,b|0,f+k<<5);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;f=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(f,h);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;Q(b|0);p()}function rI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;c=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;b=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=b;x[e+20>>2]=a;x[e+24>>2]=e+44;b=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=b;a:{b:{switch(x[c+40>>2]){case 0:b=hb-80|0;hb=b;d=x[e>>2];g=x[d+4>>2];x[b+48>>2]=x[d+20>>2];h=x[d+16>>2];x[b+40>>2]=x[d+12>>2];x[b+44>>2]=h;qn(b+68|0,b+40|0,g);d=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[d+8>>2];f=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=f;if(g){k=b+24|0;l=b+8|0;while(1){d=0;if(h){while(1){i=C[ph(l,d,j)>>3];fc(c,d);i=Td(Gg(i)*32768);c:{if(F(i)<2147483648){f=~~i;break c}f=-2147483648}f=Wc(f);p=pn(k,d,j),q=f,w[p>>1]=q;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}hb=b+80|0;break a;case 2:ux(e,yb(c));break a;case 3:j=fh(c);d=0;b=hb-80|0;hb=b;c=x[e>>2];g=x[c+4>>2];x[b+48>>2]=x[c+20>>2];h=x[c+16>>2];x[b+40>>2]=x[c+12>>2];x[b+44>>2]=h;qn(b+68|0,b+40|0,g);c=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[c+8>>2];f=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=f;if(g){k=b+24|0;l=b+8|0;m=j+16|0;while(1){c=0;if(h){while(1){i=C[ph(l,c,d)>>3];f=ef(j,c);n=f;f=Kj(Td(i*134217728))+(x[f>>2]>>1)|0;o=f;f=As(m)+f&-4096;x[n>>2]=o-f;i=Td(Gg(+(f|0)*7.450580596923828e-9)*32768);d:{if(F(i)<2147483648){f=~~i;break d}f=-2147483648}f=Wc(f);p=pn(k,c,d),q=f,w[p>>1]=q;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:ux(e,yb(c));break a;default:break b}}ux(e,yb(c))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function Gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;e=hb-48|0;hb=e;p=x[a+12>>2];g=p;a:{b:{c:{f=x[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];b=x[a+44>>2];x[e+32>>2]=b;i=x[a+48>>2];x[e+36>>2]=i;j=x[a+52>>2];x[e+40>>2]=j;o=x[a+56>>2];x[e+44>>2]=o;u=x[a+24>>2];y=x[a+20>>2];m=x[a+4>>2];h=x[a>>2];x[e+16>>2]=h;x[e+20>>2]=m;x[e+8>>2]=f;x[e+12>>2]=g;if(d){while(1){b=x[e+16>>2];k=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(b>>>16&65520)+p|0;q=w[b+14>>1];l=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];n=w[b+6>>1];g=w[b+4>>1];m=w[b+2>>1];f=w[b>>1];j=0;o=1;i=1;b=0;while(1){x[(b<<2)+e>>2]=(((((((D(v[k+(b|-4)|0],m)+D(v[k+(b|-6)|0],f)|0)+D(v[k+(b|-2)|0],g)|0)+D(v[b+k|0],n)|0)+D(v[k+(b|2)|0],s)|0)+D(v[k+(b|4)|0],r)|0)+D(v[k+(b|6)|0],l)|0)+D(q,v[k+(b|8)|0])<<8)/32768;h=i;i=0;b=1;if(h){continue}break}while(1){b=(j<<2)+e|0;i=x[b>>2];q=x[a+60>>2];j=(e+28|0)+(j<<3)|0;f=x[j+4>>2];l=Yb(f,-16777216,16776704);n=x[a+64>>2];r=Yb(x[j+8>>2],-16777216,16776704);h=x[a+68>>2];g=h>>31;x[j+8>>2]=f;m=x[a+72>>2];s=i<<8;f=s;f=sqa(q,q>>31,f,f>>31);i=lb;k=f;f=sqa(n,n>>31,l,l>>31);n=k+f|0;l=lb+i|0;l=f>>>0>n>>>0?l+1|0:l;f=sqa(h,g,r,r>>31);i=f+n|0;h=lb+l|0;h=f>>>0>i>>>0?h+1|0:h;g=b;f=i+8388608|0;b=((f>>>0<8388608?h+1|0:h)&16777215)<<8|f>>>24;x[g>>2]=(b|0)/256;x[j+4>>2]=b-(m&s);j=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],y);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],u);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+44>>2];j=x[e+40>>2];i=x[e+36>>2];h=x[e+16>>2];m=x[e+20>>2];b=x[e+32>>2]}x[a>>2]=h;x[a+4>>2]=m;x[a+56>>2]=o;x[a+52>>2]=j;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0}function sJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=hb-48|0;hb=k;a:{b:{c:{d:{e:{f:{j=lp(1,28);if(!j){a=bk(ec(4));x[114409]=0;T(2132,a|0,74984,26);a=x[114409];x[114409]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;x[j>>2]=c?c:2121;d=zt(k+36|0);g:{h:{i:{j:{if(!i){break j}c=x[i>>2];if(!c){break j}while(1){k:{e=x[i+4>>2];if(e){x[114409]=0;c=O(122,k+24|0,c|0)|0;f=x[114409];x[114409]=0;l:{if((f|0)!=1){x[114409]=0;f=O(2133,d|0,c|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break l}x[114409]=0;O(463,f|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}break k}i=R(0)|0;break i}i=R(0)|0;xb(c);break i}x[114409]=0;c=O(122,k+12|0,c|0)|0;e=x[114409];x[114409]=0;m:{if((e|0)!=1){x[114409]=0;O(2134,d|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break m}break k}i=R(0)|0;break i}i=R(0)|0;xb(c);break i}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}x[114409]=0;c=S(1482,80)|0;e=x[114409];x[114409]=0;n:{o:{if((e|0)!=1){x[114409]=0;e=O(2135,j|0,j+4|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break o}x[k+4>>2]=e;e=x[xp(k+8|0,k+4|0)>>2];x[114409]=0;a=aa(2137,c|0,a|0,b|0,e|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break h}i=R(0)|0;od(k+4|0);break n}i=R(0)|0;break i}i=R(0)|0}_b(c)}Mk(d);Y(i|0)|0;x[114409]=0;W(2113,10730,j|0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break g}x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){_b(Js(a))}c=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){_b(a);x[j+20>>2]=0}_b(j);break d}x[j+24>>2]=a;od(k+4|0);Mk(d);c=j;break d}i=R(0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){break e}break b}i=R(0)|0}Y(i|0)|0;c=0;x[114409]=0;W(2113,10730,0,g|0,h|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=k+48|0;return c|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}R(0)|0;zb()}p()}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;h=Bb(g+12|0,b);ou(h);if(x[a>>2]==(b|0)){x[a>>2]=x[h>>2]}d=yb(a);x[d>>2]=x[d>>2]-1;a=x[mc(a)>>2];a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}c=x[b+4>>2];c:{if(!c){if(!Hg(d)){while(1){d=x[d+8>>2];if(!Hg(d)){continue}break}}d=x[d+8>>2];break c}d=ZR(c)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;i=1;break a}x[e+8>>2]=x[d+8>>2];i=0}d:{e:{if(Hg(d)){x[x[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=x[d+8>>2]+4|0;break e}x[x[d+8>>2]+4>>2]=e;c=x[d+8>>2]}c=x[c>>2]}j=!y[d+12|0];if((b|0)!=(d|0)){x[d+8>>2]=x[b+8>>2];f:{if(Hg(b)){f=x[d+8>>2];break f}f=x[d+8>>2]+4|0}x[f>>2]=d;f=x[b>>2];x[d>>2]=f;_n(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){_n(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(j|!a)){g:{if(i){while(1){d=Hg(c);b=y[c+12|0];h:{i:{if(!d){if(!b){v[c+12|0]=1;v[x[c+8>>2]+12|0]=0;xq(x[c+8>>2]);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}d=x[c>>2];j:{k:{l:{if(!(y[d+12|0]?0:d)){b=x[c+4>>2];if(y[b+12|0]?0:b){break l}v[c+12|0]=0;m:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break m}a=b}v[a+12|0]=1;break g}if(!Hg(b)){break i}b=x[b+8>>2]+4|0;break h}b=x[c+4>>2];if(!b){break k}}if(!y[b+12|0]){break j}}v[d+12|0]=1;v[c+12|0]=0;wq(c);c=x[c+8>>2]}v[c+12|0]=y[x[c+8>>2]+12|0];v[x[c+8>>2]+12|0]=1;v[x[c+4>>2]+12|0]=1;xq(x[c+8>>2]);break g}if(!b){v[c+12|0]=1;v[x[c+8>>2]+12|0]=0;wq(x[c+8>>2]);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];n:{if(y[d+12|0]?0:d){break n}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;break g}if(Hg(b)){b=x[b+8>>2]+4|0;break h}b=x[b+8>>2];break h}if(d){if(!y[d+12|0]){break n}b=x[c+4>>2]}v[b+12|0]=1;v[c+12|0]=0;xq(c);c=x[c+8>>2]}v[c+12|0]=y[x[c+8>>2]+12|0];v[x[c+8>>2]+12|0]=1;v[x[c>>2]+12|0]=1;wq(x[c+8>>2]);break g}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}hb=g+16|0;return x[h>>2]}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[tc(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d}v[a+5|0]=d;v[a+3|0]=c;Mj(a);g=y[b+6|0]==15;break d}v[a+3|0]=2;h=a,i=_k(c<<4|(d&240)>>>4),v[h+5|0]=i;break d}v[a+3|0]=3;h=a,i=_k(c<<4|(d&240)>>>4),v[h+5|0]=i;break d}v[a+3|0]=4;h=a,i=_k(c<<4|(d&240)>>>4),v[h+5|0]=i;break d}v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d}if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d}v[a+3|0]=13;v[a+5|0]=c>>>1;break d}if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d}v[a+5|0]=d;v[a+3|0]=c;Iz(a,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];t:{if(!b){break t}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break t}if(y[a+2|0]){break t}v[a+2|0]=2;v[a+4|0]=b>>>2}hb=f+16|0;return g|0}function Nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=hb-208|0;hb=c;g=1;d=x[a+12>>2];j=1<<d;if(d&1){l=j>>>1|0;e=l>>>0<=1?1:l;d=0;while(1){i=d+l|0;g=wc(b,i);m=x[g+12>>2];x[c+200>>2]=x[g+8>>2];x[c+204>>2]=m;m=x[g+4>>2];x[c+192>>2]=x[g>>2];x[c+196>>2]=m;m=c+192|0;Mi(c+176|0,wc(b,d),m);g=wc(b,i);i=x[c+188>>2];x[g+8>>2]=x[c+184>>2];x[g+12>>2]=i;i=x[c+180>>2];x[g>>2]=x[c+176>>2];x[g+4>>2]=i;ny(wc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=x[a+12>>2];g=2;j=j>>>3|0}else{j=j>>>2|0}i=d&-2;if(i){while(1){if(g){t=D(j,3);u=j<<1;l=0;while(1){d=wc(a,l<<1);e=x[d+12>>2];x[c+200>>2]=x[d+8>>2];x[c+204>>2]=e;e=x[d+4>>2];x[c+192>>2]=x[d>>2];x[c+196>>2]=e;d=wc(a,l);e=x[d+12>>2];x[c+184>>2]=x[d+8>>2];x[c+188>>2]=e;e=x[d+4>>2];x[c+176>>2]=x[d>>2];x[c+180>>2]=e;Yh(c+160|0,c+176|0,c+192|0);d=l<<i;m=j+d|0;if(d>>>0<m>>>0){while(1){e=wc(b,d);h=x[e+12>>2];x[c+152>>2]=x[e+8>>2];x[c+156>>2]=h;h=x[e+4>>2];x[c+144>>2]=x[e>>2];x[c+148>>2]=h;h=c+128|0;q=d+j|0;Yh(h,c+192|0,wc(b,q));e=c+112|0;r=d+u|0;Yh(e,c+176|0,wc(b,r));f=c+96|0;s=d+t|0;Yh(f,c+160|0,wc(b,s));k=c+80|0;n=c+144|0;Gk(k,n,e);o=c- -64|0;Mi(o,n,e);n=c+48|0;Gk(n,h,f);e=c+16|0;_l(e,-C[4378],-C[4379]);Mi(c,h,f);h=c+32|0;Yh(h,e,c);Gk(e,k,n);f=wc(b,d);p=x[c+28>>2];x[f+8>>2]=x[c+24>>2];x[f+12>>2]=p;p=x[c+20>>2];x[f>>2]=x[c+16>>2];x[f+4>>2]=p;Mi(e,k,n);f=wc(b,q);k=x[c+28>>2];x[f+8>>2]=x[c+24>>2];x[f+12>>2]=k;k=x[c+20>>2];x[f>>2]=x[c+16>>2];x[f+4>>2]=k;Gk(e,o,h);f=wc(b,r);k=x[c+28>>2];x[f+8>>2]=x[c+24>>2];x[f+12>>2]=k;k=x[c+20>>2];x[f>>2]=x[c+16>>2];x[f+4>>2]=k;Mi(e,o,h);e=wc(b,s);h=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=h;h=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(g|0)){continue}break}}j=j>>>2|0;g=g<<2;i=i-2|0;if(i){continue}break}}hb=c+208|0}function sI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;c=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;b=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=b;x[e+20>>2]=a;x[e+24>>2]=e+44;b=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=b;a:{b:{switch(x[c+40>>2]){case 0:b=hb-80|0;hb=b;d=x[e>>2];g=x[d+4>>2];x[b+48>>2]=x[d+20>>2];h=x[d+16>>2];x[b+40>>2]=x[d+12>>2];x[b+44>>2]=h;qn(b+68|0,b+40|0,g);d=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[d+8>>2];f=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=f;if(g){f=b+24|0;k=b+8|0;while(1){d=0;if(h){while(1){i=x[Vf(k,d,j)>>2];fc(c,d);i=i-2147481600>>>12|0;i=i>>>0<=491520?491520:i;o=pn(f,d,j),p=(i|0)>=557055?557055:i,w[o>>1]=p;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}hb=b+80|0;break a;case 2:vx(e,yb(c));break a;case 3:j=fh(c);d=0;b=hb-80|0;hb=b;c=x[e>>2];g=x[c+4>>2];x[b+48>>2]=x[c+20>>2];h=x[c+16>>2];x[b+40>>2]=x[c+12>>2];x[b+44>>2]=h;qn(b+68|0,b+40|0,g);c=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[c+8>>2];f=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=f;if(g){k=b+24|0;i=b+8|0;m=j+16|0;while(1){c=0;if(h){while(1){f=x[Vf(i,c,d)>>2];l=ef(j,c);f=f+(x[l>>2]>>1)|0;n=f;f=As(m)+f&-4096;x[l>>2]=n-f;f=f-2147481600>>>12|0;f=f>>>0<=491520?491520:f;o=pn(k,c,d),p=(f|0)>=557055?557055:f,w[o>>1]=p;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:vx(e,yb(c));break a;default:break b}}vx(e,yb(c))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function r4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-96|0;hb=e;a:{if(Yc(c)){break a}f=y[iJ(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+84|0;Vr(f,c,0,Cb(c)-1|0);Eb(c,f);xb(f)}f=e+84|0;Gd(f);g=x[e+84>>2];Gd(e+72|0);g=hJ(g,x[e+76>>2],c);Gd(f);b:{c:{d:{e:{f:{if((g|0)==x[e+88>>2]){if(Rd(c,17381)){a=ec(8);x[114409]=0;b=O(122,e+84|0,6463)|0;c=x[114409];x[114409]=0;if((c|0)==1){break d}a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}c=N()|0;xb(b);break c}if(!d){break f}a=ec(8);x[114409]=0;T(2260,e+84|0,13519,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,e+84|0);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break b}c=N()|0;xb(e+84|0);break c}c=N()|0;ic(a);break c}f=Xb(e+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:Ei(e- -64|0,c);x[114409]=0;c=x[e+68>>2];x[e+8>>2]=x[e+64>>2];x[e+12>>2]=c;b=U(2200,b|0,e+8|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){x[114409]=0;v[e+72|0]=b;P(2265,a|0,e+72|0);a=x[114409];x[114409]=0;if((a|0)!=1){break g}}break i;case 1:Ei(e+56|0,c);x[114409]=0;c=x[e+60>>2];x[e+16>>2]=x[e+56>>2];x[e+20>>2]=c;b=eE(b,e+16|0,d);c=lb;d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;x[e+72>>2]=b;x[e+76>>2]=c;P(2267,a|0,e+72|0);a=x[114409];x[114409]=0;if((a|0)!=1){break g}}break i;case 2:Ei(e+48|0,c);x[114409]=0;c=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=c;h=+ka(2202,b|0,e+24|0,d|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[114409]=0;C[e+72>>3]=h;P(2268,a|0,e+72|0);a=x[114409];x[114409]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Ei(e+40|0,c);x[114409]=0;c=x[e+44>>2];x[e+32>>2]=x[e+40>>2];x[e+36>>2]=c;W(2203,a|0,b|0,e+32|0,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){break g}}c=N()|0;xb(f);break c}Jd(a,f)}xb(f);break e}Xb(a)}hb=e+96|0;return}c=N()|0;ic(a)}Q(c|0)}p()}function lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;u=x[a+16>>2];j=x[a+44>>2];x[e+32>>2]=j;o=x[a+48>>2];x[e+36>>2]=o;g=x[a+52>>2];x[e+40>>2]=g;m=x[a+56>>2];x[e+44>>2]=m;p=x[a+40>>2];q=x[a+36>>2];f=x[a+4>>2];k=f;h=x[a>>2];x[e+16>>2]=h;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;a:{if(!d){b=p>>12;i=q>>12;break a}v=b+24|0;while(1){o=1;b=x[e+16>>2];l=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=v+(((b>>>16|0)+4&131064)<<1)|0;r=w[b+14>>1];s=w[b+12>>1];n=w[b+10>>1];t=w[b+8>>1];m=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];h=w[b>>1];j=0;g=1;i=0;while(1){b=i<<1;x[(i<<2)+e>>2]=(((((D(w[l+(b|8)>>1],n)+D(w[l+(b|4)>>1],t)|0)+D(s,w[l+(b|12)>>1])|0)+D(r,w[l+(b|16)>>1])|0)/2|0)+((((D(w[l+(b|-8)>>1],f)+D(w[l+(b|-12)>>1],h)|0)+D(w[l+(b|-4)>>1],k)|0)+D(w[b+l>>1],m)|0)/2|0)|0)/16384;b=g&1;g=0;i=1;if(b){continue}break}while(1){b=(j<<2)+e|0;k=x[b>>2];i=x[a+60>>2];j=(e+28|0)+(j<<3)|0;f=x[j+4>>2];g=Yb(f,-16777216,16776704);n=x[a+64>>2];r=Yb(x[j+8>>2],-16777216,16776704);h=x[a+68>>2];t=h>>31;x[j+8>>2]=f;m=x[a+72>>2];s=k<<8;f=s;f=sqa(i,i>>31,f,f>>31);k=lb;i=f;f=sqa(n,n>>31,g,g>>31);n=i+f|0;g=lb+k|0;g=f>>>0>n>>>0?g+1|0:g;f=sqa(h,t,r,r>>31);k=f+n|0;h=lb+g|0;h=f>>>0>k>>>0?h+1|0:h;i=b;f=k+8388608|0;b=((f>>>0<8388608?h+1|0:h)&16777215)<<8|f>>>24;x[i>>2]=(b|0)/256;x[j+4>>2]=b-(m&s);j=1;b=o&1;o=0;if(b){continue}break}b=x[a+32>>2];q=x[a+28>>2]+q|0;i=q>>12;x[c>>2]=x[c>>2]+D(i,x[e>>2]);p=b+p|0;b=p>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}m=x[e+44>>2];g=x[e+40>>2];o=x[e+36>>2];j=x[e+32>>2];h=x[e+16>>2];k=x[e+20>>2]}x[a>>2]=h;x[a+4>>2]=k;x[a+40>>2]=p;x[a+20>>2]=i;x[a+36>>2]=q;x[a+56>>2]=m;x[a+52>>2]=g;x[a+48>>2]=o;x[a+44>>2]=j;x[a+24>>2]=b;hb=e+48|0}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=Mt(v[a+36|0],v[a+37|0]),x[i+24>>2]=j;w[a+36>>1]=0;if((b|0)!=1){break a}e=sqa(x[a+24>>2],0,8272,0);d=lb;e=e+4181|0;d=e>>>0<4181?d+1|0:d;i=a,j=id(vqa(e,d,8363,0),lb),x[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=sqa(x[a+24>>2],0,8363,0);d=lb;e=e+4136|0;d=e>>>0<4136?d+1|0:d;i=a,j=id(vqa(e,d,8272,0),lb),x[i+24>>2]=j}g=hb-16|0;hb=g;e=g+14|0;d=hb-16|0;hb=d;h=x[a+24>>2];b:{if(!h){v[e|0]=0;v[e+1|0]=0;break b}vH(d+8|0,Yb(Mn(mp(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);v[d+7|0]=x[d+8>>2];v[d+6|0]=x[d+12>>2];wz(e,d+7|0,d+6|0)}hb=d+16|0;d=g+4|0;Bb(Bb(d,a+36|0)+4|0,a+37|0);v[x[d>>2]]=y[e|0];v[x[d+4>>2]]=y[e+1|0];hb=g+16|0}if(c&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(c&7){w[a+32>>1]=64;d=z[a+34>>1];if(d&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;d=d&16?d|6:d&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=d&65511}c:{d:{e:{if(c&4){d=z[a+34>>1];if(!(d&32)){w[a+28>>1]=128;w[a+34>>1]=d|32}df(a+40|0,15);df(a+41|0,63);if(c&16777248?b&4:0){break e}if(!(b&16777248)){break c}if(y[a+41|0]){break d}break c}if(!(b&4)|!(c&16777248)){break c}if(y[a+41|0]){break d}break c}if(!y[a+41|0]){break c}}d=y[a+40|0];if(!d){break c}b=y[a+39|0];if(b){b=ll(id(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0))}else{b=255}v[a+39|0]=b}f:{g:{if((c|0)!=4){if((c|0)==16777216){break f}if((c|0)!=32|y[a+38|0]!=2){break g}v[a+38|0]=3;break g}if(y[a+38|0]!=4){break g}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}h:{if(!(!(y[a+35|0]&2)|c&16777218)){x[f+24>>2]=0;x[f+8>>2]=0;x[f+16>>2]=0;x[f+20>>2]=0;x[f>>2]=0;x[f+4>>2]=0;fq(a,0,f);break h}if(!(y[a+35|0]&2)|(c|0)!=2){break h}a=a+68|0;b=fc(a,8);v[b|0]=y[b|0]&3;a=fc(a,9);v[a|0]=y[a|0]&3}hb=f+32|0}function d3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;d=-2;a:{if(!a){break a}c=x[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=x[c+11e3>>2];k=x[a+4>>2];x[c+11e3>>2]=0;b:{if(x[c+43780>>2]<0){break b}h=(b|0)==4;g=x[c+11004>>2];if(!(g?h:1)){break a}d=x[c+11008>>2]>0?9:8;x[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){x[e+12>>2]=x[a+4>>2];x[e+8>>2]=x[a+16>>2];b=x[a+12>>2];b=VH(c,x[a>>2],e+12|0,b,b,e+8|0,d|4);x[c+43780>>2]=b;d=x[e+12>>2];x[a>>2]=d+x[a>>2];x[a+4>>2]=x[a+4>>2]-d;x[a+8>>2]=d+x[a+8>>2];x[a+48>>2]=x[c+28>>2];d=x[e+8>>2];x[a+12>>2]=d+x[a+12>>2];x[a+16>>2]=x[a+16>>2]-d;x[a+20>>2]=d+x[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}x[c+43780>>2]=-1;d=-5;break a}f=x[c+10996>>2];if(!f){j=(b|0)!=4;l=j?d|2:d;h=c+11012|0;g=x[c+10992>>2];while(1){b=x[a+4>>2];x[e+8>>2]=32768-g;x[e+12>>2]=b;f=VH(c,x[a>>2],e+12|0,h,h+g|0,e+8|0,l);x[c+43780>>2]=f;b=x[e+12>>2];x[a>>2]=b+x[a>>2];x[a+4>>2]=x[a+4>>2]-b;x[a+8>>2]=b+x[a+8>>2];x[a+48>>2]=x[c+28>>2];b=x[e+8>>2];x[c+10996>>2]=b;d=x[a+16>>2];b=b>>>0<d>>>0?b:d;sc(x[a+12>>2],h+x[c+10992>>2]|0,b);x[a+12>>2]=b+x[a+12>>2];x[a+16>>2]=x[a+16>>2]-b;x[a+20>>2]=b+x[a+20>>2];i=x[c+10996>>2];x[c+10996>>2]=i-b;g=b+x[c+10992>>2]&32767;x[c+10992>>2]=g;if((f|0)<0){break b}d=-5;if(!k&(f|0)==1){break a}if(!j){if(!f){d=(b|0)==(i|0)?1:-5;break a}if(x[a+16>>2]){continue}break a}if(f){d=0;if(!x[a+4>>2]|!x[a+16>>2]){break a}if((b|0)==(i|0)){continue}break a}break}d=(b|0)==(i|0);break a}b=x[a+16>>2];b=b>>>0>f>>>0?f:b;sc(x[a+12>>2],(x[c+10992>>2]+c|0)+11012|0,b);x[a+12>>2]=b+x[a+12>>2];x[a+16>>2]=x[a+16>>2]-b;x[a+20>>2]=b+x[a+20>>2];a=x[c+10996>>2];x[c+10996>>2]=a-b;x[c+10992>>2]=b+x[c+10992>>2]&32767;d=0;if(x[c+43780>>2]){break a}d=(a|0)==(b|0);break a}d=-3}hb=e+16|0;return d|0}function fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;l=e,m=Wf(f,b),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Ze(f,d),x[l+40>>2]=m;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=h>>12;j=i>>12;break c}while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=w[f+(x[e+44>>2]<<1)>>1];x[114409]=0;P(1113,x[e+24>>2],(g|0)/4<<16>>16);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=w[f+(x[e+44>>2]<<1)>>1];x[114409]=0;P(1113,b|0,(f|0)/4<<16>>16);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;f=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+D(f,j);h=b+h|0;b=h>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;Q(b|0);p()}function mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;f=hb-48|0;hb=f;u=x[a+16>>2];i=x[a+44>>2];x[f+32>>2]=i;o=x[a+48>>2];x[f+36>>2]=o;h=x[a+52>>2];x[f+40>>2]=h;m=x[a+56>>2];x[f+44>>2]=m;p=x[a+40>>2];q=x[a+36>>2];e=x[a+4>>2];j=e;g=x[a>>2];x[f+16>>2]=g;x[f+20>>2]=e;e=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=e;a:{if(!d){b=p>>12;e=q>>12;break a}y=b+24|0;while(1){b=x[f+16>>2];l=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+u|0;o=1;b=(((b>>>16|0)+4&131064)<<1)+y|0;k=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];n=w[b+8>>1];t=w[b+6>>1];m=w[b+4>>1];j=w[b+2>>1];e=w[b>>1];i=0;h=1;b=0;while(1){x[(b<<2)+f>>2]=((((D(v[l+(b|4)|0],s)+D(v[l+(b|2)|0],n)|0)+D(r,v[l+(b|6)|0])|0)+D(k,v[l+(b|8)|0])<<8>>1)+(((D(v[l+(b|-4)|0],j)+D(v[l+(b|-6)|0],e)|0)+D(v[l+(b|-2)|0],m)|0)+D(v[b+l|0],t)<<8>>1)|0)/16384;g=h&1;h=0;b=1;if(g){continue}break}while(1){b=(i<<2)+f|0;j=x[b>>2];h=x[a+60>>2];i=(f+28|0)+(i<<3)|0;e=x[i+4>>2];k=Yb(e,-16777216,16776704);n=x[a+64>>2];r=Yb(x[i+8>>2],-16777216,16776704);g=x[a+68>>2];t=g>>31;x[i+8>>2]=e;m=x[a+72>>2];s=j<<8;e=s;e=sqa(h,h>>31,e,e>>31);j=lb;h=e;e=sqa(n,n>>31,k,k>>31);n=h+e|0;k=lb+j|0;k=e>>>0>n>>>0?k+1|0:k;e=sqa(g,t,r,r>>31);j=e+n|0;g=lb+k|0;g=e>>>0>j>>>0?g+1|0:g;h=b;e=j+8388608|0;b=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[h>>2]=(b|0)/256;x[i+4>>2]=b-(m&s);i=1;b=o&1;o=0;if(b){continue}break}b=x[a+32>>2];q=x[a+28>>2]+q|0;e=q>>12;x[c>>2]=x[c>>2]+D(e,x[f>>2]);p=b+p|0;b=p>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+4>>2]);c=c+8|0;Tb(f+16|0,f+8|0);d=d-1|0;if(d){continue}break}m=x[f+44>>2];h=x[f+40>>2];o=x[f+36>>2];i=x[f+32>>2];g=x[f+16>>2];j=x[f+20>>2]}x[a>>2]=g;x[a+4>>2]=j;x[a+40>>2]=p;x[a+20>>2]=e;x[a+36>>2]=q;x[a+56>>2]=m;x[a+52>>2]=h;x[a+48>>2]=o;x[a+44>>2]=i;x[a+24>>2]=b;hb=f+48|0}function j0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=hb-416|0;hb=i;x[i+408>>2]=37;x[i+412>>2]=0;m=Nr(i+408|1,9666,x[c+4>>2]);x[i+364>>2]=i+368;a=me();a:{if(m){k=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;a=kf(i+368|0,30,a,i+408|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;a=kf(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=2580;k=Sd(i+356|0,0,i+128|0);l=i+368|0;j=l;b:{c:{d:{e:{if((a|0)>=30){f:{if(m){x[114409]=0;a=$(2603)|0;j=x[114409];x[114409]=0;if((j|0)==1){break d}j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i>>2]=j;x[114409]=0;x[i+8>>2]=e;x[i+12>>2]=f;a=Z(2623,i+364|0,a|0,i+408|0,i|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break f}break d}x[114409]=0;a=$(2603)|0;j=x[114409];x[114409]=0;if((j|0)==1){break d}x[i+32>>2]=e;x[i+36>>2]=f;x[114409]=0;x[i+40>>2]=g;x[i+44>>2]=h;a=Z(2623,i+364|0,a|0,i+408|0,i+32|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}}if((a|0)==-1){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)==1){break d}break e}Ce(k,x[i+364>>2]);j=x[i+364>>2]}f=a+j|0;g=yg(j,f,c);x[i+116>>2]=2580;e=Sd(i+120|0,0,i+116|0);g:{h:{if(x[i+364>>2]==(i+368|0)){a=i+128|0;break h}a=xd(a<<3);if(!a){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break e}b=N()|0;break g}Ce(e,a);l=x[i+364>>2]}x[114409]=0;Fc(i+108|0,c);h=x[114409];x[114409]=0;i:{j:{if((h|0)!=1){x[114409]=0;fa(2634,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+108|0);f=x[114409];x[114409]=0;if((f|0)==1){break j}Ob(i+108|0);x[114409]=0;a=ga(2635,b|0,a|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break i}Lc(e);Lc(k);hb=i+416|0;break b}b=N()|0;break g}b=N()|0;Ob(i+108|0);break g}b=N()|0}Lc(e);break c}p()}b=N()|0}Lc(k);Q(b|0);p()}return a|0}function fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-32|0;hb=f;i=c+484344|0;ig(i,y[b+70|0]|y[b+71|0]<<8);a:{if(y[b+70|0]|y[b+71|0]<<8){while(1){d=x[a+8>>2];g=Kf(a);cc(a,1);b:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=te(a)+1|0;break b}c=tg(a)}e=tg(a);Tc(a,d+g|0);Ad(f+16|0,a,e);x[114409]=0;c=U(378,i|0,h&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}c:{if(!(c&(e|0)!=0)){break c}c=Zb(i,h);k=f,l=bc(c),x[k+12>>2]=l;k=f,l=dc(c),x[k+8>>2]=l;if(!Hb(f+12|0,f+8|0)){break c}while(1){e=x[f+12>>2];x[114409]=0;c=S(425,f+16|0)|0;d=x[114409];x[114409]=0;d:{e:{f:{if((d|0)!=1){d=c<<24>>24;if((d|0)>=0){break f}if(d&1){x[114409]=0;c=S(425,f+16|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}v[e|0]=c}c=d&255;if(d&2){break e}break d}break a}v[e|0]=d;c=255}x[114409]=0;d=S(425,f+16|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}v[e+1|0]=d}d=0;if(c&4){x[114409]=0;d=S(425,f+16|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}}if(c&8){x[114409]=0;g=S(425,f+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}v[e+3|0]=g}if(c&16){x[114409]=0;c=S(425,f+16|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}v[e+5|0]=c}g:{h:{c=y[e|0];if(!c){break h}g=255;if((c|0)==97){break g}if(c>>>0>96){break h}g=c+12|0;break g}g=0}v[e|0]=g;i:{if(y[e+5|0]|y[e+3|0]){x[114409]=0;V(573,e|0);c=x[114409];x[114409]=0;if((c|0)!=1){break i}break a}v[e+3|0]=0}if(y[e+1|0]==255){v[e+1|0]=0}c=d-16|0;j:{if((c&255)>>>0<=64){v[e+4|0]=c;v[e+2|0]=1;break j}if(d>>>0<96){break j}c=d&15;v[e+4|0]=c;d=d-96>>>4|0;v[e+2|0]=y[d+24078|0];if((d|0)!=6){break j}v[e+4|0]=c<<2}c=f+12|0;Sj(c);if(Hb(c,f+8|0)){continue}break}}Ab(f+16|0);h=h+1|0;if(h>>>0<(y[b+70|0]|y[b+71|0]<<8)>>>0){continue}break}}hb=f+32|0;return}a=N()|0;Ab(f+16|0);Q(a|0);p()}function t0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=hb-256|0;hb=i;x[i+248>>2]=37;x[i+252>>2]=0;m=Nr(i+248|1,9666,x[c+4>>2]);x[i+204>>2]=i+208;a=me();a:{if(m){k=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;a=kf(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;a=kf(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=2580;k=Sd(i+196|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{e:{if((a|0)>=30){f:{if(m){x[114409]=0;a=$(2603)|0;j=x[114409];x[114409]=0;if((j|0)==1){break d}j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i>>2]=j;x[114409]=0;x[i+8>>2]=e;x[i+12>>2]=f;a=Z(2623,i+204|0,a|0,i+248|0,i|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){break f}break d}x[114409]=0;a=$(2603)|0;j=x[114409];x[114409]=0;if((j|0)==1){break d}x[i+32>>2]=e;x[i+36>>2]=f;x[114409]=0;x[i+40>>2]=g;x[i+44>>2]=h;a=Z(2623,i+204|0,a|0,i+248|0,i+32|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}}if((a|0)==-1){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)==1){break d}break e}Ce(k,x[i+204>>2]);j=x[i+204>>2]}f=a+j|0;g=yg(j,f,c);x[i+116>>2]=2580;e=Sd(i+120|0,0,i+116|0);g:{h:{if(x[i+204>>2]==(i+208|0)){a=i+128|0;break h}a=xd(a<<1);if(!a){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break e}b=N()|0;break g}Ce(e,a);l=x[i+204>>2]}x[114409]=0;Fc(i+108|0,c);h=x[114409];x[114409]=0;i:{j:{if((h|0)!=1){x[114409]=0;fa(2624,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+108|0);f=x[114409];x[114409]=0;if((f|0)==1){break j}Ob(i+108|0);x[114409]=0;a=ga(17,b|0,a|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break i}Lc(e);Lc(k);hb=i+256|0;break b}b=N()|0;break g}b=N()|0;Ob(i+108|0);break g}b=N()|0}Lc(e);break c}p()}b=N()|0}Lc(k);Q(b|0);p()}return a|0}function tI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;f=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;b=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=b;x[e+20>>2]=a;x[e+24>>2]=e+44;b=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=b;a:{b:{switch(x[f+40>>2]){case 0:c=hb-80|0;hb=c;b=x[e>>2];d=x[b+4>>2];i=x[b+24>>2];x[c+40>>2]=x[b+20>>2];x[c+44>>2]=i;i=x[b+16>>2];x[c+32>>2]=x[b+12>>2];x[c+36>>2]=i;Th(c- -64|0,c+32|0,d);b=Oc(c+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);i=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];d=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=d;d=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=d;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;if(i){b=c+16|0;while(1){d=0;if(h){while(1){j=C[ph(c,d,g)>>3];fc(f,d);l=Rn(b,d,g),m=E(j),B[l>>2]=m;d=d+1|0;if((h|0)!=(d|0)){continue}break}}g=g+1|0;if((i|0)!=(g|0)){continue}break}}hb=c+80|0;break a;case 2:wx(e,yb(f));break a;case 3:i=fh(f);d=0;b=hb-80|0;hb=b;c=x[e>>2];f=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Th(b- -64|0,b+32|0,f);c=Oc(b+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);f=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];h=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=h;h=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=h;x[b+8>>2]=x[c+8>>2];h=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=h;if(f){h=b+16|0;while(1){c=0;if(g){while(1){j=C[ph(b,c,d)>>3];ef(i,c);k=Kj(Td(j*134217728));l=Rn(h,c,d),m=E(+(k|0)*7.450580596923828e-9),B[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((f|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:wx(e,yb(f));break a;default:break b}}wx(e,yb(f))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function O9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=0,h=0,i=E(0),j=0,k=0,l=0,m=E(0),n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=E(0),v=0,w=0,y=E(0),z=0,A=0,C=E(0);a:{if(!x[a+4276>>2]){break a}j=a+44|0;if(!Eh(j)){break a}o=Qd(j,0);p=Qd(j,1);q=ld(j,0);r=ld(j,1);w=mb[x[x[a>>2]+188>>2]](a)|0;e=E(mb[x[x[a>>2]+196>>2]](a));u=E(mb[x[x[a>>2]+184>>2]](a));s=mb[x[x[a>>2]+208>>2]](a)|0;if(d){y=E(e*E(.009999999776482582));z=s&1;k=a+4260|0;h=x[a+4256>>2];l=x[a+4272>>2];t=d;while(1){i=B[o>>2];m=B[p>>2];h=wn(a,h+l|0);l=wn(a,l);e=B[Pb(k,h)>>2];A=Pb(k,l),C=E(E(y*e)+E(E(m+i)*E(.5))),B[A>>2]=C;b:{if(w){f=B[a+4244>>2];e=E(B[a+4236>>2]+f);B[a+4236>>2]=e;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(!(e<=E(1))){e=E(e+E(-2));B[a+4236>>2]=e}if(!(f<=E(1))){B[a+4240>>2]=f+E(-2)}e=E(F(e));e=E(E(e+e)+E(-1));f=E(F(B[a+4240>>2]));f=E(E(f+f)+E(-1));break b}f=B[a+4244>>2];n=B[a+4240>>2];e=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=e;f=E(n-E(e*f));B[a+4240>>2]=f}n=B[Pb(k,wn(a,x[a+4280>>2]+x[a+4272>>2]|0))>>2];A=q,C=E(E(E(E(n-i)+E(E(E(B[Pb(k,wn(a,x[a+4284>>2]+x[a+4272>>2]|0))>>2]-n)*E(.000244140625))*E(x[a+4280>>2]&4095)))*u)+i),B[A>>2]=C;i=B[Pb(k,wn(a,x[a+4288>>2]+x[a+4272>>2]|0))>>2];A=r,C=E(E(E(E(i-m)+E(E(E(B[Pb(k,wn(a,x[a+4292>>2]+x[a+4272>>2]|0))>>2]-i)*E(.000244140625))*E(x[a+4288>>2]&4095)))*u)+m),B[A>>2]=C;h=x[a+4272>>2];l=(((h|0)<=0?x[a+4276>>2]<<12:0)+h|0)-4096|0;x[a+4272>>2]=l;h=x[a+4256>>2];i=B[a+4248>>2];m=E(i*(z?f:e));c:{if(E(F(m))<E(2147483648)){g=~~m;break c}g=-2147483648}v=h+(s>>>0>1?g:0-g|0)|0;x[a+4288>>2]=v;p=p+4|0;o=o+4|0;e=E(i*e);d:{if(E(F(e))<E(2147483648)){g=~~e;break d}g=-2147483648}g=(s>>>0<4?g:0-g|0)+h|0;x[a+4280>>2]=g;x[a+4292>>2]=v+4096;x[a+4284>>2]=g+4096;r=r+4|0;q=q+4|0;t=t-1|0;if(t){continue}break}}Gi(a,b,c,ld(j,0),ld(j,1),d)}}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{switch(b|0){case 0:e=hb-16|0;hb=e;f=Xb(a);c:{d:{if(Cb(c)){while(1){a=x[yj(c,i)>>2];e:{if(a>>>0>=2097152){x[114409]=0;P(111,f|0,63);a=x[114409];x[114409]=0;if((a|0)!=1){break e}break d}d=0;f:{g:{while(1){h=a&63;v[(e+10|0)+d|0]=h;if(a>>>0<64){break g}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break f}if(d){b=d+1|0;if((b|0)!=2){break f}d=1;b=2;if((h|0)!=1){break f}a=y[e+10|0]|64}else{a=y[e+10|0]}x[114409]=0;P(111,f|0,a<<24>>24);a=x[114409];x[114409]=0;if((a|0)!=1){break e}break d}d=(2<<d)+255<<7-d;h=b+e|0;a=b;while(1){h:{if((a|0)==(b|0)){g=y[h+9|0];x[114409]=0;P(111,f|0,(d|g)<<24>>24);g=x[114409];x[114409]=0;if((g|0)==1){break d}a=a-1|0;break h}x[114409]=0;a=a-1|0;P(111,f|0,v[a+(e+10|0)|0]|-128);g=x[114409];x[114409]=0;if((g|0)==1){break d}}if(a){continue}break}}i=i+1|0;if(Cb(c)>>>0>i>>>0){continue}break}}hb=e+16|0;break c}a=N()|0;xb(f);Q(a|0);p()}return;case 1:b=0;a=Xb(a);d=Cb(c);x[114409]=0;P(112,a|0,d|0);d=x[114409];x[114409]=0;i:{if((d|0)!=1){j:{if(Cb(c)){while(1){d=x[yj(c,b)>>2];x[114409]=0;P(111,a|0,(d>>>0>=128?63:d)<<24>>24);d=x[114409];x[114409]=0;if((d|0)==1){break j}b=b+1|0;if(Cb(c)>>>0>b>>>0){continue}break}}break i}}break a}return;case 2:b=0;a=Xb(a);d=Cb(c);x[114409]=0;P(112,a|0,d|0);d=x[114409];x[114409]=0;k:{if((d|0)!=1){l:{if(Cb(c)){while(1){d=x[yj(c,b)>>2];x[114409]=0;P(111,a|0,(d>>>0>=256?63:d)<<24>>24);d=x[114409];x[114409]=0;if((d|0)==1){break l}b=b+1|0;if(Cb(c)>>>0>b>>>0){continue}break}}break k}}break a}return;case 3:zp(a,c,17600);return;case 4:zp(a,c,18624);return;case 5:zp(a,c,19648);return;case 6:zp(a,c,20672);return;case 7:zp(a,c,21696);return;default:break b}}Xb(a);return}b=N()|0;xb(a);Q(b|0);p()}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;l=e,m=Wf(f,b),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Ze(f,d),x[l+40>>2]=m;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=h>>12;j=i>>12;break c}while(1){g=x[e+36>>2]-1|0;x[e+36>>2]=g;b=x[e+8>>2];f=x[e+12>>2];if(!g){x[e+16>>2]=0;x[e+20>>2]=0}f=f+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=v[f+x[e+44>>2]|0];x[114409]=0;P(1113,x[e+24>>2],g<<6);g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;P(1114,x[e+24>>2],4);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=v[f+x[e+44>>2]|0];x[114409]=0;P(1113,b|0,f<<6);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1114,x[e+24>>2],g|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114409]=0;f=O(1115,b|0,x[e+28>>2])|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+D(f,j);h=b+h|0;b=h>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;Q(b|0);p()}function ft(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-128|0;hb=h;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}f=x[c+4>>2];if(!f&A[c>>2]>=$g(b)>>>0|f){break h}b=ec(8);x[114409]=0;a=O(29,b|0,17381)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break g}a=N()|0;ic(b);break a}if(!x[b>>2]){b=ec(8);x[114409]=0;a=O(1492,b|0,17381)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break f}a=N()|0;ic(b);break a}f=mi(h+100|0,b);d=hb-16|0;hb=d;g=d+8|0;Yo(g,mi(d,f));e=hb-16|0;hb=e;i=mi(e+8|0,g);g=hb-16|0;hb=g;f=h+108|0;yD(f,Dd(g+8|0,i));hb=g+16|0;hb=e+16|0;x[f+16>>2]=0;x[f+12>>2]=0;hb=d+16|0;i:{j:{if(a&2){d=Ip(h+80|0,f);x[114409]=0;j=O(1493,d|0,c|0)|0;e=x[114409];x[114409]=0;d=1;if((e|0)==1){break i}if((j|0)==1){break j}e=Ip(h+60|0,f);x[114409]=0;e=O(1494,e|0,c|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}k=(e|0)==1;if(k){break j}g=Ip(h+40|0,f);x[114409]=0;g=O(1495,g|0,c|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}l=(g|0)==1;if(l){break j}i=Ip(h+20|0,f);x[114409]=0;i=O(1496,i|0,c|0)|0;m=x[114409];x[114409]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(j|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(i|0)==-1?-1:l?d:(g|0)==-1?-1:d}if(a&1){a=76720;while(1){d=x[a>>2];if(d){e=Ip(h,f);x[114409]=0;e=O(d|0,e|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}j=(e|0)==-1?-1:j}a=a+12|0;if((a|0)!=77176){continue}break}}if(c){d=0;if((j|0)!=-1){break j}a=x[c+4>>2];c=x[c>>2];x[114409]=0;a=cg(418,c,a);c=x[114409];x[114409]=0;if((c|0)!=1){d=$g(b)>>>0<a>>>0?-1:0;break j}a=N()|0;break a}d=0;if((j|0)!=-1){break j}d=$g(b)>>>0>2047?1:-1}hb=h+128|0;return d}a=N()|0;break a}da(a|0,75256,25);p()}da(a|0,75152,25);p()}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}Q(a|0);p()}function G4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb+-64|0;hb=e;g=sh(a);a=b+24|0;f=Wb(x[a>>2]+484360|0);x[114409]=0;i=S(2317,f|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{if((f|0)==1){break c}x[114409]=0;P(1629,g|0,i|0);f=x[114409];x[114409]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=z[vc(Wb(x[a>>2]+484360|0),f)>>1];d=x[a>>2];x[114409]=0;d=O(941,d+484344|0,c|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}f:{if(d){c=Zb(x[a>>2]+484344|0,z[vc(Wb(x[a>>2]+484360|0),f)>>1]);x[114409]=0;P(2315,e+40|0,c|0);c=x[114409];x[114409]=0;g:{h:{i:{if((c|0)!=1){x[114409]=0;T(2309,e+52|0,b|0,e+40|0);c=x[114409];x[114409]=0;if((c|0)==1){break i}x[114409]=0;P(1631,g|0,e+52|0);c=x[114409];x[114409]=0;if((c|0)==1){break h}xb(e+52|0);xb(e+40|0);break f}a=N()|0;break a}a=N()|0;break g}a=N()|0;xb(e+52|0)}xb(e+40|0);break a}x[114409]=0;d=$(990)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}if((c|0)==(d|0)){x[114409]=0;c=O(122,e+28|0,5211)|0;d=x[114409];x[114409]=0;j:{if((d|0)!=1){x[114409]=0;P(1631,g|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break j}xb(c);break f}a=N()|0;break a}a=N()|0;xb(c);break a}x[114409]=0;d=$(989)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}if((c|0)==(d|0)){x[114409]=0;c=O(122,e+16|0,5173)|0;d=x[114409];x[114409]=0;k:{if((d|0)!=1){x[114409]=0;P(1631,g|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break k}xb(c);break f}a=N()|0;break a}a=N()|0;xb(c);break a}x[114409]=0;c=O(122,e+4|0,10152)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}x[114409]=0;P(1631,g|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}xb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}hb=e- -64|0;return}a=N()|0;break a}a=N()|0;xb(c);break a}a=N()|0;break a}a=N()|0}pd(g);Q(a|0);p()}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-48|0;hb=e;zd(b,2);d=e+24|0;$k(d,2,a+1|0);f=e+36|0;Kc(f,d);x[114409]=0;O(350,b+43|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){xb(e+36|0);a:{if(!(y[a|0]?y[a|0]!=1:0)){if(y[a|0]==1){d=a+16|0;x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+20|0;x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+24>>2]=x[b>>2]-1;f=e+36|0;h=b,i=x[Mb(f,e+24|0)>>2],x[h+4>>2]=i;d=a+24|0;x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);h=b,i=x[Mb(f,b)>>2],x[h+8>>2]=i;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}d=x[b+8>>2];if(d>>>0>=2&d>>>0>A[b+4>>2]){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}if(y[a|0]!=2){break a}f=e+24|0;Ih(f,a+16|0);d=e+36|0;g=x[f>>2];g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=g;v[d+1|0]=g>>>8;v[d+2|0]=g>>>16;v[d+3|0]=g>>>24;Ih(f,a+20|0);g=x[e+24>>2];g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d+4|0]=g;v[d+5|0]=g>>>8;v[d+6|0]=g>>>16;v[d+7|0]=g>>>24;Ih(f,a+24|0);f=x[e+24>>2];f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[d+8|0]=f;v[d+9|0]=f>>>8;v[d+10|0]=f>>>16;v[d+11|0]=f>>>24;x[e+16>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);d=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);x[e+8>>2]=y[e+36|0]|y[e+37|0]<<8|(y[e+38|0]<<16|y[e+39|0]<<24);x[e+12>>2]=d;fq(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;h=b,i=y[tc(e+36|0,e+24|0)|0]<<2,w[h+30>>1]=i;d=a+32|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(y[a|0]==2){d=z[b>>1];x[b>>2]=d;break b}zc(b,65535);d=x[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}x[b>>2]=a}hb=e+48|0;return}a=N()|0;xb(e+36|0);Q(a|0);p()}function Fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;x[g+28>>2]=d;i=_j(a,c);Af(g,x[a+28>>2]);d=x[g+12>>2];x[g+16>>2]=x[g+8>>2];x[g+20>>2]=d;a:{if(!i){if(Bd(a,5)){break a}}j=x[g+28>>2];d=hb-192|0;hb=d;h=vl(d+88|0,x[a+28>>2]);x[114409]=0;f=O(694,d+76|0,24359)|0;e=x[114409];x[114409]=0;b:{c:{d:{e:{if((e|0)!=1){x[114409]=0;x[d+16>>2]=19469602;x[d+20>>2]=0;T(695,h|0,f|0,d+16|0);e=x[114409];x[114409]=0;if((e|0)==1){break e}Gb(f);if(!(x[h>>2]&1073741824)){break d}break b}e=N()|0;break c}e=N()|0;Gb(f);break c}x[114409]=0;v[d+75|0]=0;v[d+74|0]=0;f=O(694,d+60|0,6080)|0;e=x[114409];x[114409]=0;f:{if((e|0)!=1){x[114409]=0;U(1241,h|0,d+75|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}Gb(f);if(!y[d+75|0]){break b}df(d+75|0,50);x[114409]=0;f=O(694,d+48|0,9079)|0;e=x[114409];x[114409]=0;g:{h:{i:{j:{if((e|0)!=1){x[114409]=0;U(1241,h|0,d+74|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break j}Gb(f);f=ai(b);e=y[d+75|0];if(f>>>0<e>>>0){f=vz(d+16|0,x[b+12>>2]);x[114409]=0;T(1242,b|0,e|0,f|0);e=x[114409];x[114409]=0;if((e|0)==1){break i}Qk(f)}e=0;f=z[Ti(b,0)+28>>1];v[d+15|0]=0;if(y[d+75|0]){while(1){Pe(Ti(b,e&255),f);e=Ti(b,y[d+15|0]);x[114409]=0;P(1243,d+16|0,d+15|0);k=x[114409];x[114409]=0;if((k|0)==1){break h}x[114409]=0;W(1244,h|0,e|0,d+16|0,j|0);e=x[114409];x[114409]=0;if((e|0)==1){break g}Gb(d+16|0);e=y[d+15|0]+1|0;v[d+15|0]=e;if(y[d+75|0]>(e&255)>>>0){continue}break}}e=y[d+74|0];f=ai(b);v[b+16|0]=e>>>0<f>>>0?y[d+74|0]:0;break b}e=N()|0;break c}e=N()|0;Gb(f);break c}e=N()|0;Qk(f);break c}e=N()|0;break c}e=N()|0;Gb(d+16|0);break c}e=N()|0;break c}e=N()|0;Gb(f)}Ig(h);Q(e|0);p()}Ig(h);hb=d+192|0}qj(a,i,c,g+16|0);hb=g+32|0}function Zba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-192|0;hb=c;e=vl(c+88|0,a);x[114409]=0;d=O(694,c+76|0,35963)|0;a=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[114409]=0;x[c+64>>2]=19469602;x[c+68>>2]=0;T(695,e|0,d|0,c- -64|0);a=x[114409];x[114409]=0;if((a|0)==1){break n}Gb(d);if(x[e>>2]&1073741824){break e}x[114409]=0;d=O(694,c- -64|0,9198)|0;a=x[114409];x[114409]=0;if((a|0)==1){break m}x[114409]=0;Z(1670,e|0,b|0,d|0,1671)|0;a=x[114409];x[114409]=0;if((a|0)==1){break l}Gb(d);x[114409]=0;x[c+60>>2]=0;x[c+56>>2]=0;d=O(694,c+44|0,12601)|0;a=x[114409];x[114409]=0;if((a|0)==1){break k}x[114409]=0;U(1672,e|0,c+60|0,d|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break j}Gb(d);x[114409]=0;d=O(694,c+32|0,12591)|0;a=x[114409];x[114409]=0;if((a|0)==1){break i}x[114409]=0;U(1672,e|0,c+56|0,d|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break h}Gb(d);a=x[c+56>>2];d=x[c+60>>2];o:{if(!d){break o}if(a>>>0<d>>>0|d>>>0>A[x[An(b)+8>>2]+40>>2]){break o}if(a>>>0>A[x[An(b)+8>>2]+40>>2]){break o}x[b+20>>2]=a;x[b+16>>2]=d}d=Jk(c+20|0);x[114409]=0;f=O(694,c+8|0,9885)|0;a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;Z(1673,e|0,d|0,f|0,684)|0;a=x[114409];x[114409]=0;if((a|0)==1){break g}Gb(f);if(kd(d)){break f}a=x[b+16>>2];x[114409]=0;T(1505,d|0,a|0,16777216);a=x[114409];x[114409]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;Gb(f);break b}x[114409]=0;P(1674,b|0,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Me(d)}Ig(e);hb=c+192|0;return}a=N()|0;break b}a=N()|0}Me(d)}Ig(e);Q(a|0);p()}function D0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-320|0;hb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Xb(a+196|0);x[114409]=0;Fc(a+16|0,d);b=x[114409];x[114409]=0;a:{b:{c:{d:{if((b|0)!=1){x[114409]=0;b=S(2606,a+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break d}x[114409]=0;Z(2619,b|0,64896,64922,a+208|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}Ob(a+16|0);c=Xb(a+184|0);b=Hc(c);x[114409]=0;P(1736,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=pc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[114409]=0;d=O(2611,a+316|0,a+312|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}if(d){break c}if(x[a+180>>2]==(Cb(c)+b|0)){d=Cb(c);b=Cb(c);x[114409]=0;P(1736,c|0,b<<1);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=Hc(c);x[114409]=0;P(1736,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=pc(c,0);x[a+180>>2]=d+b}x[114409]=0;d=S(2612,a+316|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;d=nk(d,16,b,a+180|0,a+8|0,0,h,a+16|0,a+12|0,a+208|0);g=x[114409];x[114409]=0;if((g|0)==1){break e}if(d){break c}x[114409]=0;S(2614,a+316|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;break a}b=N()|0;Ob(a+16|0);break a}x[114409]=0;P(1736,c|0,x[a+180>>2]-b|0);b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}b=Rb(c);x[114409]=0;d=$(2603)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}x[a>>2]=f;x[114409]=0;b=Z(2604,b|0,d|0,5233,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}if((b|0)!=1){x[e>>2]=4}x[114409]=0;b=O(2611,a+316|0,a+312|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];xb(c);xb(h);hb=a+320|0;return b|0}}b=N()|0;xb(c)}xb(h);Q(b|0);p()}function Uf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=h;i=y[a+79|0]?z[x[a>>2]+3836>>1]:i;g=z[a+20>>1];j=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=g+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;c=z[a+28>>1];if((c|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;c=z[x[a>>2]+3832>>1];c=g+(c&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((c>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=c;if(c<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;c=0;f=z[x[a>>2]+3832>>1];f=g+(f&z[a+34>>1]?0:z[a+24>>1]?D((g^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=c}g=((g+j|0)+k|0)+i<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+24944>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+24944>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+24944>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+24944>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+24944>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+24944>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+g&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+24432>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Xb(a+196|0);x[114409]=0;Fc(a+16|0,d);b=x[114409];x[114409]=0;a:{b:{c:{d:{if((b|0)!=1){x[114409]=0;b=S(21,a+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break d}x[114409]=0;Z(2599,b|0,64896,64922,a+208|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}Ob(a+16|0);c=Xb(a+184|0);b=Hc(c);x[114409]=0;P(1736,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=pc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[114409]=0;d=O(2582,a+252|0,a+248|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}if(d){break c}if(x[a+180>>2]==(Cb(c)+b|0)){d=Cb(c);b=Cb(c);x[114409]=0;P(1736,c|0,b<<1);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=Hc(c);x[114409]=0;P(1736,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}b=pc(c,0);x[a+180>>2]=d+b}x[114409]=0;d=S(2583,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}x[114409]=0;d=pk(d,16,b,a+180|0,a+8|0,0,h,a+16|0,a+12|0,a+208|0);g=x[114409];x[114409]=0;if((g|0)==1){break e}if(d){break c}x[114409]=0;S(2585,a+252|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;break a}b=N()|0;Ob(a+16|0);break a}x[114409]=0;P(1736,c|0,x[a+180>>2]-b|0);b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}b=Rb(c);x[114409]=0;d=$(2603)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}x[a>>2]=f;x[114409]=0;b=Z(2604,b|0,d|0,5233,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}if((b|0)!=1){x[e>>2]=4}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(c);xb(h);hb=a+256|0;return b|0}}b=N()|0;xb(c)}xb(h);Q(b|0);p()}function tP(a){a=a|0;var b=0,c=0,d=0;Sb(a,0,288);c=a+288|0;Ez(c);d=a+800|0;jq(d);v[a+2|0]=y[9928];b=y[9926]|y[9927]<<8;v[a|0]=b;v[a+1|0]=b>>>8;b=y[9985]|y[9986]<<8;v[a+32|0]=b;v[a+33|0]=b>>>8;v[a+34|0]=y[9987];b=y[1982]|y[1983]<<8|(y[1984]<<16|y[1985]<<24);v[a+96|0]=b;v[a+97|0]=b>>>8;v[a+98|0]=b>>>16;v[a+99|0]=b>>>24;b=y[1985]|y[1986]<<8|(y[1987]<<16|y[1988]<<24);v[a+99|0]=b;v[a+100|0]=b>>>8;v[a+101|0]=b>>>16;v[a+102|0]=b>>>24;b=y[11696]|y[11697]<<8|(y[11698]<<16|y[11699]<<24);v[a+128|0]=b;v[a+129|0]=b>>>8;v[a+130|0]=b>>>16;v[a+131|0]=b>>>24;b=y[11699]|y[11700]<<8|(y[11701]<<16|y[11702]<<24);v[a+131|0]=b;v[a+132|0]=b>>>8;v[a+133|0]=b>>>16;v[a+134|0]=b>>>24;v[a+260|0]=y[5240];b=y[5236]|y[5237]<<8|(y[5238]<<16|y[5239]<<24);v[a+256|0]=b;v[a+257|0]=b>>>8;v[a+258|0]=b>>>16;v[a+259|0]=b>>>24;a=hb+-64|0;hb=a;x[a+60>>2]=0;b=Vb(a+48|0,1439);x[114409]=0;P(492,a+36|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[114409]=0;O(450,a+36|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break d}xb(b);break c}a=N()|0;xb(b);break b}hb=a- -64|0;break a}Q(a|0);p()}b=0;a=hb-48|0;hb=a;e:{f:{g:{h:{i:{j:{while(1){x[a+44>>2]=b;x[a+44>>2]=b<<3;lB(a+20|0,b>>>0<16?11432:17381);x[114409]=0;P(490,a+8|0,a+44|0);c=x[114409];x[114409]=0;if((c|0)==1){break j}x[114409]=0;T(491,a+32|0,a+20|0,a+8|0);c=x[114409];x[114409]=0;if((c|0)==1){break i}x[114409]=0;P(492,a|0,(b<<5)+d|0);c=x[114409];x[114409]=0;if((c|0)==1){break h}x[114409]=0;O(450,a|0,a+32|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break h}xb(a+32|0);xb(a+8|0);Gb(a+20|0);b=b+1|0;if((b|0)!=128){continue}break}hb=a+48|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;xb(a+32|0)}xb(a+8|0)}Gb(a+20|0);Q(b|0);p()}}function Yda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-32|0;hb=h;b=a+8|0;it(b,Ve(b));l=yb(b),m=0,x[l>>2]=m;l=b,m=mc(b),x[l>>2]=m;l=mc(b),m=0,x[l>>2]=m;x[a+32>>2]=0;x[a+36>>2]=0;g=a+4|0;x[x[g>>2]>>2]=0;x[x[g>>2]+40>>2]=x[x[a>>2]+480196>>2];x[x[g>>2]+44>>2]=x[x[a>>2]+480204>>2];x[x[g>>2]+68>>2]=x[x[a>>2]+480200>>2];c=z[x[a>>2]+480188>>1];x[h+24>>2]=0;x[h+28>>2]=0;x[h+16>>2]=0;x[h+20>>2]=0;x[h+8>>2]=0;x[h+12>>2]=0;d=h+8|0;b=d;x[b>>2]=0;x[b+4>>2]=0;v[b+21|0]=255;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;x[b+8>>2]=0;x[b+12>>2]=0;i=hb-16|0;hb=i;x[i+12>>2]=c;b=a+20|0;a:{if(ff(b)>>>0>=c>>>0){l=i,m=vd(b),x[l+8>>2]=m;c=x[b>>2];e=x[Mb(i+12|0,i+8|0)>>2];if(e){while(1){f=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=f;f=z[d+18>>1]|z[d+20>>1]<<16;j=z[d+14>>1]|z[d+16>>1]<<16;w[c+14>>1]=j;w[c+16>>1]=j>>>16;w[c+18>>1]=f;w[c+20>>1]=f>>>16;f=x[d+12>>2];x[c+8>>2]=x[d+8>>2];x[c+12>>2]=f;c=c+24|0;e=e-1|0;if(e){continue}break}}c=x[i+12>>2];e=x[i+8>>2];if(c>>>0>e>>>0){aN(b,c-e|0,d);break a}d=x[b>>2]+D(c,24)|0;vd(b);bN(b,d);kq(b);break a}if(x[b>>2]){vd(b);cN(b);kq(b);Mp(yb(b),x[b>>2],ff(b));l=yb(b),m=0,x[l>>2]=m;x[b>>2]=0;x[b+4>>2]=0}f=bl(b,c);e=hb-16|0;hb=e;if(NU(b)>>>0<f>>>0){Xc();p()}_M(e+8|0,yb(b),f);f=x[e+8>>2];x[b+4>>2]=f;x[b>>2]=f;j=x[e+12>>2];l=yb(b),m=f+D(j,24)|0,x[l>>2]=m;al(b,0);hb=e+16|0;aN(b,c,d)}hb=i+16|0;if(z[x[a>>2]+480188>>1]){while(1){b=D(k,896);Qn((b+x[g>>2]|0)+608|0,7,x[a>>2],k&65535,1024);v[(b+x[g>>2]|0)+1445|0]=0;v[(b+x[g>>2]|0)+1444|0]=0;v[(b+x[g>>2]|0)+1429|0]=0;v[(b+x[g>>2]|0)+1432|0]=0;v[(b+x[g>>2]|0)+1427|0]=0;k=k+1|0;if(k>>>0<z[x[a>>2]+480188>>1]){continue}break}}hb=h+32|0}function pI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;c=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;b=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=b;x[e+20>>2]=a;x[e+24>>2]=e+44;b=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=b;a:{b:{switch(x[c+40>>2]){case 0:b=hb-80|0;hb=b;d=x[e>>2];g=x[d+4>>2];x[b+48>>2]=x[d+20>>2];i=x[d+16>>2];x[b+40>>2]=x[d+12>>2];x[b+44>>2]=i;tp(b+68|0,b+40|0,g);d=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];i=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[d+8>>2];f=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=f;if(g){f=b+24|0;j=b+8|0;while(1){d=0;if(i){while(1){k=C[ph(j,d,h)>>3];fc(c,d);m=Vf(f,d,h),n=E(k),B[m>>2]=n;d=d+1|0;if((i|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}hb=b+80|0;break a;case 2:tx(e,yb(c));break a;case 3:i=fh(c);d=0;b=hb-80|0;hb=b;c=x[e>>2];h=x[c+4>>2];x[b+48>>2]=x[c+20>>2];g=x[c+16>>2];x[b+40>>2]=x[c+12>>2];x[b+44>>2]=g;tp(b+68|0,b+40|0,h);c=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);h=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[c+8>>2];f=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=f;if(h){f=b+24|0;j=b+8|0;while(1){c=0;if(g){while(1){k=C[ph(j,c,d)>>3];ef(i,c);l=Kj(Td(k*134217728));m=Vf(f,c,d),n=E(+(l|0)*7.450580596923828e-9),B[m>>2]=n;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:tx(e,yb(c));break a;default:break b}}tx(e,yb(c))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;s=x[a+16>>2];m=x[a+44>>2];x[e+32>>2]=m;h=x[a+48>>2];x[e+36>>2]=h;i=x[a+52>>2];x[e+40>>2]=i;o=x[a+56>>2];x[e+44>>2]=o;t=x[a+24>>2];u=x[a+20>>2];f=x[a+4>>2];j=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){v=b+24|0;while(1){o=1;b=x[e+16>>2];l=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+s|0;b=(((b>>>16|0)+4&131064)<<1)+v|0;k=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];n=w[b+8>>1];r=w[b+6>>1];m=w[b+4>>1];j=w[b+2>>1];f=w[b>>1];i=0;b=1;h=0;while(1){g=h<<1;x[(h<<2)+e>>2]=(((((D(w[l+(g|8)>>1],q)+D(w[l+(g|4)>>1],n)|0)+D(p,w[l+(g|12)>>1])|0)+D(k,w[l+(g|16)>>1])|0)/2|0)+((((D(w[l+(g|-8)>>1],j)+D(w[l+(g|-12)>>1],f)|0)+D(w[l+(g|-4)>>1],m)|0)+D(w[g+l>>1],r)|0)/2|0)|0)/16384;g=b&1;b=0;h=1;if(g){continue}break}while(1){b=(i<<2)+e|0;j=x[b>>2];h=x[a+60>>2];i=(e+28|0)+(i<<3)|0;f=x[i+4>>2];k=Yb(f,-16777216,16776704);n=x[a+64>>2];p=Yb(x[i+8>>2],-16777216,16776704);g=x[a+68>>2];r=g>>31;x[i+8>>2]=f;m=x[a+72>>2];q=j<<8;f=q;f=sqa(h,h>>31,f,f>>31);j=lb;h=f;f=sqa(n,n>>31,k,k>>31);n=h+f|0;k=lb+j|0;k=f>>>0>n>>>0?k+1|0:k;f=sqa(g,r,p,p>>31);j=f+n|0;g=lb+k|0;g=f>>>0>j>>>0?g+1|0:g;h=b;f=j+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[h>>2]=(b|0)/256;x[i+4>>2]=b-(m&q);i=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],u);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],t);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+44>>2];i=x[e+40>>2];h=x[e+36>>2];j=x[e+20>>2];m=x[e+32>>2];g=x[e+16>>2]}x[a>>2]=g;x[a+4>>2]=j;x[a+56>>2]=o;x[a+52>>2]=i;x[a+48>>2]=h;x[a+44>>2]=m;hb=e+48|0}function O$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-624|0;hb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=2638;b=Sd(a+200|0,a+208|0,a+16|0);x[114409]=0;Fc(a+192|0,e);h=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){x[114409]=0;h=S(2606,a+192|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break j}v[a+191|0]=0;e=x[e+4>>2];x[114409]=0;c=pa(2650,a+620|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}if(!c){break f}c=y[10190]|y[10191]<<8|(y[10192]<<16|y[10193]<<24);v[a+183|0]=c;v[a+184|0]=c>>>8;v[a+185|0]=c>>>16;v[a+186|0]=c>>>24;c=y[10187]|y[10188]<<8|(y[10189]<<16|y[10190]<<24);x[a+176>>2]=y[10183]|y[10184]<<8|(y[10185]<<16|y[10186]<<24);x[a+180>>2]=c;x[114409]=0;Z(2619,h|0,a+176|0,a+186|0,a+128|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}x[a+4>>2]=2580;d=Sd(a+8|0,0,a+4|0);e=a+16|0;if((x[a+196>>2]-x[b>>2]|0)<393){break g}Ce(d,xd((x[a+196>>2]-x[b>>2]>>2)+2|0));if(x[d>>2]){break h}x[114409]=0;X(2581);c=x[114409];x[114409]=0;if((c|0)==1){break d}break a}c=N()|0;break b}c=N()|0;break c}c=N()|0;break c}e=x[d>>2]}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[b>>2];while(1){if(A[a+196>>2]<=c>>>0){v[e|0]=0;x[a>>2]=g;if((ZF(a+16|0,a)|0)!=1){x[114409]=0;V(2640,4205);c=x[114409];x[114409]=0;if((c|0)!=1){break a}break d}Lc(d)}else{h=a+128|0;j=e,k=y[(a+176|0)+(ow(h,h+40|0,c)-h>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;continue}break}}x[114409]=0;c=O(2611,a+620|0,a+616|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}if(c){x[f>>2]=x[f>>2]|2}c=x[a+620>>2];Ob(a+192|0);Lc(b);hb=a+624|0;return c|0}c=N()|0;break c}c=N()|0;Lc(d)}Ob(a+192|0)}Lc(b);Q(c|0);p()}p()}function vV(){var a=0,b=0,c=0,d=0,e=0,f=0;if(!y[460757]){c=x[15158];b=hb-16|0;hb=b;a=js(460404);x[a+40>>2]=460460;x[a+32>>2]=c;x[a>>2]=60648;v[a+52|0]=0;x[a+48>>2]=-1;d=b+12|0;cs(d,a);e=x[x[a>>2]+8>>2];x[114409]=0;P(e|0,a|0,d|0);d=x[114409];x[114409]=0;a:{if((d|0)!=1){Ob(b+12|0);hb=b+16|0;break a}c=N()|0;Ob(b+12|0);El(a);Q(c|0);p()}a=Es(459728);x[114930]=59148;x[a>>2]=59168;x[114931]=0;x[114409]=0;P(2547,a|0,460404);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}d=x[15159];tG(460468,d,460516);Ew(459896,460468);e=x[14644];tG(460524,e,460572);Ew(460064,460524);Ew(460232,x[(x[x[115016]-12>>2]+460064|0)+24>>2]);Xr(x[x[114930]-12>>2]+459720|0,459896);sG(x[x[115016]-12>>2]+460064|0);Xr(x[x[115016]-12>>2]+460064|0,459896);b=hb-16|0;hb=b;a=GG(460580);x[a+40>>2]=460636;x[a+32>>2]=c;x[a>>2]=60852;v[a+52|0]=0;x[a+48>>2]=-1;c=b+12|0;cs(c,a);f=x[x[a>>2]+8>>2];x[114409]=0;P(f|0,a|0,c|0);c=x[114409];x[114409]=0;d:{if((c|0)!=1){Ob(b+12|0);hb=b+16|0;break d}c=N()|0;Ob(b+12|0);kp(a);Q(c|0);p()}a=qG(459816);x[114952]=59308;x[a>>2]=59328;x[114953]=0;x[114409]=0;P(2549,a|0,460580);b=x[114409];x[114409]=0;if((b|0)==1){break c}rG(460644,d,460692);Dw(459980,460644);rG(460700,e,460748);Dw(460148,460700);Dw(460316,x[(x[x[115037]-12>>2]+460148|0)+24>>2]);Xr(x[x[114952]-12>>2]+459808|0,459980);sG(x[x[115037]-12>>2]+460148|0);Xr(x[x[115037]-12>>2]+460148|0,459980);break b}b=N()|0;lh(a);Q(b|0);p()}v[460757]=1}a=hb-16|0;hb=a;e:{if(Oa(a+12|0,a+8|0)|0){break e}b=xd((x[a+12>>2]<<2)+4|0);x[115191]=b;if(!b){break e}b=xd(x[a+8>>2]);if(b){x[x[115191]+(x[a+12>>2]<<2)>>2]=0;if(!(Na(x[115191],b|0)|0)){break e}}x[115191]=0}hb=a+16|0;UL();x[114276]=456984;x[114258]=42}function V$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-272|0;hb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=2638;b=Sd(a+152|0,a+160|0,a+16|0);x[114409]=0;Fc(a+144|0,e);h=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){x[114409]=0;h=S(21,a+144|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break j}v[a+143|0]=0;e=x[e+4>>2];x[114409]=0;c=pa(2639,a+268|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}if(!c){break f}c=y[10190]|y[10191]<<8|(y[10192]<<16|y[10193]<<24);v[a+135|0]=c;v[a+136|0]=c>>>8;v[a+137|0]=c>>>16;v[a+138|0]=c>>>24;c=y[10187]|y[10188]<<8|(y[10189]<<16|y[10190]<<24);x[a+128>>2]=y[10183]|y[10184]<<8|(y[10185]<<16|y[10186]<<24);x[a+132>>2]=c;x[114409]=0;Z(2599,h|0,a+128|0,a+138|0,a+118|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break i}x[a+4>>2]=2580;d=Sd(a+8|0,0,a+4|0);e=a+16|0;if((x[a+148>>2]-x[b>>2]|0)<99){break g}Ce(d,xd((x[a+148>>2]-x[b>>2]|0)+2|0));if(x[d>>2]){break h}x[114409]=0;X(2581);c=x[114409];x[114409]=0;if((c|0)==1){break d}break a}c=N()|0;break b}c=N()|0;break c}c=N()|0;break c}e=x[d>>2]}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[b>>2];while(1){if(A[a+148>>2]<=c>>>0){v[e|0]=0;x[a>>2]=g;if((ZF(a+16|0,a)|0)!=1){x[114409]=0;V(2640,4205);c=x[114409];x[114409]=0;if((c|0)!=1){break a}break d}Lc(d)}else{h=a+118|0;j=e,k=y[((Ll(h,h+10|0,c)-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;continue}break}}x[114409]=0;c=O(2582,a+268|0,a+264|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}if(c){x[f>>2]=x[f>>2]|2}c=x[a+268>>2];Ob(a+144|0);Lc(b);hb=a+272|0;return c|0}c=N()|0;break c}c=N()|0;Lc(d)}Ob(a+144|0)}Lc(b);Q(c|0);p()}p()}function QK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=hb-16|0;hb=i;a:{if((b|0)==(c|0)){break a}x[i+12>>2]=-1953789045;LK(b,c,i+12|0);k=c-b|0;d=k>>2;x[i+8>>2]=d;e=Lb(a);c=11;b:{if(k>>>0>2488){break b}c=7;if(k>>>0>268){break b}c=5;if(k>>>0>152){break b}c=3;if(k>>>0>24){break b}c=d-1>>>1|0}j=1;m=e+1|0;x[i+4>>2]=m;k=x[$c(i+4|0,i+8|0)>>2];g=d-c>>>1|0;d=(g<<2)+b|0;f=D(Xs(x[((x[i+8>>2]<<2)+b|0)-4>>2]^(x[d>>2]^x[b>>2])),1664525);x[d>>2]=f+x[d>>2];c=c+g|0;d=(c<<2)+b|0;l=d;h=x[d>>2];d=e+f|0;x[l>>2]=h+d;x[b>>2]=d;d=c;c=x[i+8>>2];d=(d>>>0)%(c>>>0)|0;g=(g>>>0)%(c>>>0)|0;f=c-1|0;c=0;if(e){while(1){g=g+1|0;h=x[i+8>>2];g=(h|0)!=(g|0)?g:0;l=(g<<2)+b|0;c=c+1|0;c=(c|0)!=(h|0)?c:0;n=(c<<2)+b|0;f=f+1|0;f=(f|0)!=(h|0)?f:0;o=D(Xs(x[l>>2]^x[n>>2]^x[(f<<2)+b>>2]),1664525);x[l>>2]=o+x[l>>2];l=x[Pb(a,j-1|0)>>2]+(c+o|0)|0;d=d+1|0;d=(d|0)!=(h|0)?d:0;h=(d<<2)+b|0;x[h>>2]=l+x[h>>2];x[n>>2]=l;j=j+1|0;if(e>>>0>=j>>>0){continue}break}}if(k>>>0>m>>>0){while(1){a=g+1|0;e=a;a=x[i+8>>2];g=(e|0)!=(a|0)?e:0;e=(g<<2)+b|0;c=c+1|0;c=(a|0)!=(c|0)?c:0;h=(c<<2)+b|0;f=f+1|0;f=(a|0)!=(f|0)?f:0;j=D(Xs(x[e>>2]^x[h>>2]^x[(f<<2)+b>>2]),1664525);x[e>>2]=j+x[e>>2];d=d+1|0;d=(a|0)!=(d|0)?d:0;a=(d<<2)+b|0;e=a;l=x[a>>2];a=c+j|0;x[e>>2]=l+a;x[h>>2]=a;m=m+1|0;if((k|0)!=(m|0)){continue}break}}e=x[i+8>>2];if(k>>>0>=k+e>>>0){break a}a=k;while(1){f=f+1|0;f=(e|0)!=(f|0)?f:0;g=g+1|0;g=(e|0)!=(g|0)?g:0;j=(g<<2)+b|0;c=c+1|0;c=(c|0)!=(e|0)?c:0;h=(c<<2)+b|0;m=D(Xs(x[(f<<2)+b>>2]+(x[j>>2]+x[h>>2]|0)|0),1566083941);x[j>>2]=m^x[j>>2];d=d+1|0;d=(d|0)!=(e|0)?d:0;e=(d<<2)+b|0;l=e;j=x[e>>2];e=m-c|0;x[l>>2]=j^e;x[h>>2]=e;a=a+1|0;e=x[i+8>>2];if(a>>>0<k+e>>>0){continue}break}}hb=i+16|0}function ky(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}v[a|0]=1;v[f+15|0]=64;i=b,j=y[tc(b,f+15|0)|0],v[i|0]=j;break a}d=y[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}v[b|0]=(d&252)>>>2;v[a|0]=12;e=1;break a}d=y[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}v[b|0]=(d&252)>>>2;v[a|0]=13;e=1;break a}g=y[b|0];if(g>>>0<240){d=0;while(1){h=y[d+25920|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}v[a|0]=11;v[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}v[a|0]=11;v[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=y[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}v[b|0]=0;v[a|0]=0;e=1;break a}v[a|0]=2;v[b|0]=y[b|0]<<2&60|2;e=1;break a}e=0;c=y[b|0];if(!c){break a}d=c&15;if(!d){v[b|0]=c>>>4;v[a|0]=3;e=1;break a}g=c&240;if(!g){v[a|0]=4;e=1;break a}if((d|0)==15){v[b|0]=c>>>4;v[a|0]=5;e=1;break a}if((g|0)!=240){break a}v[b|0]=d;v[a|0]=6;e=1;break a}c=b;b=y[b|0];v[c|0]=(b|0)==255?64:b>>>2|0;v[a|0]=2;break a}r:{if(c){v[b|0]=0;break r}e=0;if(y[b|0]){break a}}v[a|0]=8;e=1;break a}s:{if(c){v[f+14|0]=y[b|0]&15;v[f+13|0]=9;d=y[tc(f+14|0,f+13|0)|0];break s}e=0;d=y[b|0];if(d>>>0>15|(d&14)>>>0>9){break a}}v[b|0]=d&15;v[a|0]=8;e=1}hb=f+16|0;return e}function Dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;i=hb-16|0;hb=i;g=x[a+12>>2];f=g;a:{b:{c:{e=x[a+8>>2];d:{if((f|0)<=1&e>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&e>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&e>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&e>>>0>2147483648|f>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}m=b;n=x[a+16>>2];g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];j=x[a+44>>2];h=x[a+4>>2];b=x[a>>2];x[i+8>>2]=b;x[i+12>>2]=h;x[i>>2]=e;x[i+4>>2]=f;e:{if(!d){e=k>>12;f=l>>12;break e}while(1){b=(x[i+8>>2]>>>16&65520)+m|0;h=w[b>>1];e=(x[i+12>>2]<<1)+n|0;o=w[e-6>>1];p=w[b+2>>1];q=w[e-4>>1];r=w[b+4>>1];s=w[e-2>>1];t=w[b+6>>1];u=w[e>>1];v=w[b+8>>1];y=w[e+2>>1];z=w[b+10>>1];A=w[e+4>>1];B=w[b+12>>1];C=w[e+6>>1];E=w[b+14>>1];F=w[e+8>>1];e=x[a+60>>2];b=j;j=Yb(b,-16777216,16776704);f=x[a+64>>2];g=Yb(g,-16777216,16776704);G=x[a+72>>2];H=x[a+32>>2];I=x[c>>2];f=sqa(f,f>>31,j,j>>31);J=lb;j=(((((((D(p,q)+D(h,o)|0)+D(r,s)|0)+D(t,u)|0)+D(v,y)|0)+D(z,A)|0)+D(B,C)|0)+D(E,F)|0)/32768<<8;h=sqa(e,e>>31,j,j>>31);f=h+f|0;e=lb+J|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=x[a+68>>2];f=sqa(f,f>>31,g,g>>31);g=h+f|0;e=lb+e|0;e=f>>>0>g>>>0?e+1|0:e;l=x[a+28>>2]+l|0;f=l>>12;g=g+8388608|0;g=((g>>>0<8388608?e+1|0:e)&16777215)<<8|g>>>24;h=(g|0)/256|0;x[c>>2]=D(f,h)+I;k=k+H|0;e=k>>12;x[c+4>>2]=x[c+4>>2]+D(h,e);j=g-(j&G)|0;c=c+8|0;Tb(i+8|0,i);g=b;d=d-1|0;if(d){continue}break}b=x[i+8>>2];h=x[i+12>>2]}x[a>>2]=b;x[a+4>>2]=h;x[a+40>>2]=k;x[a+20>>2]=f;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=j;x[a+24>>2]=e;hb=i+16|0}function Eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=hb-16|0;hb=h;l=x[a+12>>2];g=l;a:{b:{c:{f=x[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}r=x[a+16>>2];j=x[a+48>>2];m=x[a+40>>2];n=x[a+36>>2];e=x[a+44>>2];k=x[a+4>>2];p=k;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=k;x[h>>2]=f;x[h+4>>2]=g;e:{if(!d){g=m>>12;k=n>>12;break e}while(1){f=x[h+12>>2]+r|0;s=v[f+4|0];b=(x[h+8>>2]>>>16&65520)+l|0;t=w[b+14>>1];u=v[f+3|0];y=w[b+12>>1];z=v[f+2|0];A=w[b+10>>1];B=v[f+1|0];C=w[b+8>>1];E=v[f|0];F=w[b+6>>1];G=v[f-1|0];H=w[b+4>>1];I=v[f-2|0];J=w[b+2>>1];K=v[f-3|0];q=w[b>>1];f=x[a+60>>2];b=e;i=Yb(e,-16777216,16776704);e=x[a+64>>2];o=Yb(j,-16777216,16776704);p=x[a+72>>2];g=x[a+32>>2];k=x[c>>2];e=sqa(e,e>>31,i,i>>31);j=lb;i=e;e=x[a+68>>2];e=sqa(e,e>>31,o,o>>31);o=i+e|0;i=lb+j|0;i=e>>>0>o>>>0?i+1|0:i;q=(((((((D(I,J)+D(q,K)|0)+D(G,H)|0)+D(E,F)|0)+D(B,C)|0)+D(z,A)|0)+D(u,y)|0)+D(s,t)<<8)/32768<<8;e=q;e=sqa(f,f>>31,e,e>>31);j=e+o|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;i=k;n=x[a+28>>2]+n|0;k=n>>12;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=i+D(k,f);m=g+m|0;g=m>>12;x[c+4>>2]=x[c+4>>2]+D(f,g);e=e-(p&q)|0;c=c+8|0;Tb(h+8|0,h);j=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];p=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=p;x[a+40>>2]=m;x[a+20>>2]=k;x[a+36>>2]=n;x[a+48>>2]=j;x[a+44>>2]=e;x[a+24>>2]=g;hb=h+16|0}function Wp(a,b,c,d){var e=E(0),f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=0;g=hb-16|0;hb=g;x[g+12>>2]=w[b+792>>1]+y[b+857|0];x[g+8>>2]=w[b+794>>1]+(y[b+858|0]&127);ce(g+12|0,0,127);ce(g+8|0,0,127);k=a+1074312|0;j=$b(k,1);i=x[g+12>>2];if(!j){w[b+792>>1]=0;v[b+857|0]=i;j=x[g+8>>2];w[b+794>>1]=0;v[b+858|0]=j}i=D(i,d+256|0);j=(i|0)/256|0;n=$b(k,36);l=x[g+8>>2];a:{if(!(l|!n|(i|0)<65024)){j=-1;a=b+810|0;if(!Ff(a)){break a}if(tt(a)|z[b+808>>1]|!(y[b+872|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;f=pe(E(10),E(E(0-l|0)*E(.00937500037252903)));i=hb-16|0;hb=i;e=E(D(x[g+12>>2],d+256|0)>>>0);b:{if(x[a+480180>>2]!=33554432){h=E(110);e=E(E(e/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}h=E(125);e=E(e*E(9227362170349807e-20))}o=i,p=_h(E(pe(E(2),e)*h)),x[o+12>>2]=p;ce(i+12|0,120,2e4);hb=i+16|0;d=x[a+24620>>2];i=x[i+12>>2];e=E(E(((d|0)<i<<1?d>>>1|0:i)>>>0)*E(6.2831854820251465));c:{if(!(!$b(k,36)|y[a+480209|0]&128)){h=E(E(A[a+24620>>2])/e);e=E(E(f+E(-1))+E(h*f));B[g+4>>2]=e;f=E(h*h);break c}h=E(e/E(A[a+24620>>2]));f=E(f+f);B[g+4>>2]=h*E(E(1)-f);PN(g+4|0,E(2));e=E(E(f-B[g+4>>2])/h);B[g+4>>2]=e;f=E(E(1)/E(h*h))}h=E(E(e+f)+E(1));e=E(E(E(f+f)+e)/h);m=E(E(16777216)/h);f=E(E(-f)/h);d:{if(y[b+865|0]==1){o=b,p=_h(E(E(16777216)-m)),x[o+60>>2]=p;o=b,p=_h(E(e*E(16777216))),x[o+64>>2]=p;o=b,p=_h(E(f*E(16777216))),x[o+68>>2]=p;a=-1;break d}o=b,p=_h(m),x[o+60>>2]=p;o=b,p=_h(E(e*E(16777216))),x[o+64>>2]=p;o=b,p=_h(E(f*E(16777216))),x[o+68>>2]=p;a=0;if(x[b+60>>2]){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}hb=g+16|0;return j}function qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;e=hb-48|0;hb=e;s=x[a+16>>2];g=x[a+44>>2];x[e+32>>2]=g;m=x[a+48>>2];x[e+36>>2]=m;i=x[a+52>>2];x[e+40>>2]=i;o=x[a+56>>2];x[e+44>>2]=o;t=x[a+24>>2];u=x[a+20>>2];f=x[a+4>>2];j=f;h=x[a>>2];x[e+16>>2]=h;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){y=b+24|0;while(1){b=x[e+16>>2];k=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+s|0;o=1;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];n=w[b+8>>1];r=w[b+6>>1];m=w[b+4>>1];j=w[b+2>>1];f=w[b>>1];i=0;b=1;g=0;while(1){x[(g<<2)+e>>2]=((((D(v[k+(g|4)|0],q)+D(v[k+(g|2)|0],n)|0)+D(p,v[k+(g|6)|0])|0)+D(l,v[k+(g|8)|0])<<8>>1)+(((D(v[k+(g|-4)|0],j)+D(v[k+(g|-6)|0],f)|0)+D(v[k+(g|-2)|0],m)|0)+D(v[g+k|0],r)<<8>>1)|0)/16384;h=b&1;b=0;g=1;if(h){continue}break}while(1){b=(i<<2)+e|0;j=x[b>>2];k=x[a+60>>2];i=(e+28|0)+(i<<3)|0;f=x[i+4>>2];l=Yb(f,-16777216,16776704);n=x[a+64>>2];p=Yb(x[i+8>>2],-16777216,16776704);h=x[a+68>>2];r=h>>31;x[i+8>>2]=f;m=x[a+72>>2];q=j<<8;f=q;f=sqa(k,k>>31,f,f>>31);j=lb;g=f;f=sqa(n,n>>31,l,l>>31);n=g+f|0;l=lb+j|0;l=f>>>0>n>>>0?l+1|0:l;f=sqa(h,r,p,p>>31);j=f+n|0;h=lb+l|0;h=f>>>0>j>>>0?h+1|0:h;g=b;f=j+8388608|0;b=((f>>>0<8388608?h+1|0:h)&16777215)<<8|f>>>24;x[g>>2]=(b|0)/256;x[i+4>>2]=b-(m&q);i=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],u);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],t);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+44>>2];i=x[e+40>>2];m=x[e+36>>2];j=x[e+20>>2];g=x[e+32>>2];h=x[e+16>>2]}x[a>>2]=h;x[a+4>>2]=j;x[a+56>>2]=o;x[a+52>>2]=i;x[a+48>>2]=m;x[a+44>>2]=g;hb=e+48|0}function zz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=hb-16|0;hb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}v[a+15|0]=y[a+16|0];b=y[a+12|0];v[a+12|0]=b&247;e=!(b&2);b=y[a+14|0];if(e|b>>>0<=y[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}while(1){d=Gc(a,b);w[d>>1]=z[d>>1]+1;b=b+1|0;if(Lb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=y[a+14|0];b:{if(b>>>0>=y[a+15|0]){break b}d=y[a+12|0];if(!(d&2)){break b}v[a+12|0]=d&251}if(!(y[a+12|0]&2)|b>>>0<=y[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}d=z[Gc(a,y[a+14|0])>>1];e=Gc(a,y[a+14|0]-1|0);b=y[a+14|0];if(z[e>>1]<(d-1|0)){b=z[Gc(a,b)>>1]-1&65535;d=gq(a,b,64,64);o=f,q=bc(a),x[o+4>>2]=q;o=f,q=Pn(f+4|0,y[a+14|0]),x[o+8>>2]=q;e=rd(f+12|0,f+8|0);h=uq(f,b,d&255);g=hb-32|0;hb=g;x[g+28>>2]=x[e>>2];b=x[a>>2];o=g,q=bc(a),x[o+8>>2]=q;b=b+(mu(g+28|0,g+8|0)<<2)|0;c:{d:{if(A[a+4>>2]<A[yb(a)>>2]){i=x[a+4>>2];if((i|0)!=(b|0)){break d}yS(a,h);break c}d=yb(a);d=Ao(g+8|0,Fe(a,Lb(a)+1|0),b-x[a>>2]>>2,d);x[114409]=0;P(1212,d|0,h|0);e=x[114409];x[114409]=0;e:{if((e|0)==1){break e}x[114409]=0;b=U(1213,a|0,d|0,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}fj(d);break c}a=N()|0;fj(d);Q(a|0);p()}l=hb-16|0;hb=l;n=x[a+4>>2];d=(n-(b+4|0)|0)+b|0;j=ne(l+4|0,a,i-d>>2);f:{g:{if(d>>>0<i>>>0){k=x[j+4>>2];e=d;while(1){m=yb(a);x[114409]=0;T(782,m|0,k|0,e|0);m=x[114409];x[114409]=0;if((m|0)==1){break g}k=k+4|0;x[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}Jb(j);qq(b,d,n);hb=l+16|0;break f}a=N()|0;Jb(j);Q(a|0);p()}v[b+2|0]=y[h+2|0];w[b>>1]=z[h>>1]}Rg(b);hb=g+32|0;break a}v[a+14|0]=b-1}if((c|0)!=16777216){v[a+17|0]=255}hb=f+16|0}function Rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];j=x[a+44>>2];x[b+32>>2]=j;m=x[a+48>>2];x[b+36>>2]=m;h=x[a+52>>2];x[b+40>>2]=h;i=x[a+56>>2];x[b+44>>2]=i;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];f=g;e=x[a>>2];x[b+16>>2]=e;x[b+20>>2]=f;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){g=p>>12;k=q>>12;break a}while(1){m=1;e=x[b+16>>2];n=((((x[b+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+t|0;e=(e>>>21&2040)+32976|0;s=w[e+6>>1];i=w[e+4>>1];f=w[e+2>>1];g=w[e>>1];j=0;h=1;k=0;while(1){e=k<<1;x[(k<<2)+b>>2]=(((D(w[e+n>>1],f)+D(w[n+(e|-4)>>1],g)|0)+D(i,w[n+(e|4)>>1])|0)+D(s,w[n+(e|8)>>1])|0)/16384;e=h&1;h=0;k=1;if(e){continue}break}while(1){e=(j<<2)+b|0;i=x[e>>2];o=x[a+60>>2];r=(b+28|0)+(j<<3)|0;f=x[r+4>>2];l=Yb(f,-16777216,16776704);h=x[a+64>>2];j=Yb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];n=g>>31;x[r+8>>2]=f;s=x[a+72>>2];k=i<<8;f=k;f=sqa(o,o>>31,f,f>>31);i=lb;o=f;f=sqa(h,h>>31,l,l>>31);h=o+f|0;l=lb+i|0;l=f>>>0>h>>>0?l+1|0:l;f=sqa(g,n,j,j>>31);i=f+h|0;g=lb+l|0;g=f>>>0>i>>>0?g+1|0:g;o=e;f=i+8388608|0;e=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[o>>2]=(e|0)/256;x[r+4>>2]=e-(k&s);j=1;e=m&1;m=0;if(e){continue}break}e=x[a+32>>2];q=x[a+28>>2]+q|0;k=q>>12;x[c>>2]=x[c>>2]+D(k,x[b>>2]);p=e+p|0;g=p>>12;x[c+4>>2]=x[c+4>>2]+D(g,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}i=x[b+44>>2];h=x[b+40>>2];m=x[b+36>>2];j=x[b+32>>2];e=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=e;x[a+4>>2]=f;x[a+40>>2]=p;x[a+20>>2]=k;x[a+36>>2]=q;x[a+56>>2]=i;x[a+52>>2]=h;x[a+48>>2]=m;x[a+44>>2]=j;x[a+24>>2]=g;hb=b+48|0}function Tr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+124>>2]=b;k=vt(c,d);x[i+4>>2]=2580;n=Sd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=xd(k);if(!j){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break a}break b}Ce(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[114409]=0;h=O(2582,a|0,i+124|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}if((h|!k)==1){x[114409]=0;b=O(2582,a|0,i+124|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}x[114409]=0;o=S(2583,a|0)|0;b=x[114409];x[114409]=0;g:{if((b|0)!=1){if(g){break g}x[114409]=0;o=O(2584,e|0,o|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break g}}break b}l=r+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){r=l;if(!s){continue e}x[114409]=0;S(2585,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(b)|0)==(l|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}q=v[pc(b,r)|0];j:{if(g){break j}x[114409]=0;q=O(2584,e|0,q<<24>>24)|0;t=x[114409];x[114409]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(q&255)){s=1;if((Cb(b)|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Yc(b);v[h|0]=l?2:1;h=h+1|0;b=b+12|0;m=l+m|0;k=k-l|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);hb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function E0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=hb-384|0;hb=a;x[a+376>>2]=c;x[a+380>>2]=b;pw(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Xb(a+208|0);b=Hc(d);x[114409]=0;P(1736,d|0,b|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;while(1){d:{x[114409]=0;b=O(2611,a+380|0,a+376|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}if(x[a+204>>2]==(Cb(d)+c|0)){b=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+204>>2]=b+c}x[114409]=0;b=S(2612,a+380|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;b=Qr(b,a+23|0,a+22|0,c,a+204|0,x[a+236>>2],x[a+232>>2],a+220|0,a+32|0,a+28|0,a+24|0,a+240|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}x[114409]=0;S(2614,a+380|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+220|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}x[114409]=0;W(2602,a|0,c|0,x[a+204>>2],e|0);b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}b=x[a+8>>2];c=x[a+12>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;x[f+8>>2]=b;x[f+12>>2]=c;x[114409]=0;Je(a+220|0,a+32|0,x[a+28>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+380|0,a+376|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];xb(d);xb(a+220|0);hb=a+384|0;break a}}b=N()|0;xb(d);xb(a+220|0);Q(b|0);p()}return b|0}function oqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;e=Fb(b);v[g+16|0]=0;k=rV(g+20|0,e,g+16|0);i=Fb(b);h=x[a>>2];e=x[k>>2];j=$g(a);f=Fb(b);x[g+16>>2]=f;a:{b:{if(!j|!f){break b}while(1){a=y[h|0];x[114409]=0;a=S(440,a|0)|0;d=x[114409];x[114409]=0;c:{d:{if((d|0)!=1){d=j-1|0;if(!(!d|(a|0)!=(c|0))){a=y[h+1|0];x[114409]=0;a=S(441,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;x[g+12>>2]=a;a=O(36,g+12|0,g+16|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}e:{d=j-2|0;if(!d){break e}a=x[a>>2];if(!(a&255)){break e}d=y[h+2|0];x[114409]=0;d=S(440,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}h=h+3|0;while(1){v[e|0]=d;f=x[g+16>>2]-1|0;x[g+16>>2]=f;e=e+1|0;a=a-1|0;if(a&255){continue}break}d=j-3|0;break c}h=h+2|0;v[e|0]=c;break d}h=h+1|0;v[e|0]=a;break d}break a}f=x[g+16>>2]-1|0;x[g+16>>2]=f;e=e+1|0}if(!d){break b}j=d;if(f){continue}break}}j=x[k>>2];a=x[b>>2];x[114409]=0;l=S(442,a|0)|0;a=x[114409];x[114409]=0;f:{g:{if((a|0)!=1){c=i-f|0;if(!c){break f}e=128;h=0;d=0;break g}break a}while(1){m=y[j|0];a=0;f=0;while(1){i=d+l|0;v[i|0]=y[i|0]|D(e&m,257)>>>(f-a&7);d=d+1|0;i=Fb(b)>>>0<=d>>>0;d=i?0:d;e=(e<<8|e)>>>1&255;f=f+i|0;i=a&65535;a=a+1|0;if(i>>>0<7){continue}break}e=(e<<8|e)>>>f&255;j=j+1|0;h=h+1|0;if((h|0)!=(c|0)){continue}break}}f=0;a=x[b>>2];x[114409]=0;e=S(442,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){if(c){while(1){d=f<<24>>24;b=v[e|0];a=128;h:{if((b|0)==-128){break h}a=b;if((a|0)>=0){break h}a=0-(b&127)|0}f=d-(a&255)|0;v[e|0]=f;e=e+1|0;c=c-1|0;if(c){continue}break}}$q(k);hb=g+32|0;return}}a=N()|0;$q(k);Q(a|0);p()}function S0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=hb-272|0;hb=a;x[a+264>>2]=c;x[a+268>>2]=b;rw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Xb(a+196|0);b=Hc(d);x[114409]=0;P(1736,d|0,b|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;while(1){d:{x[114409]=0;b=O(2582,a+268|0,a+264|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}if(x[a+192>>2]==(Cb(d)+c|0)){b=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+192>>2]=b+c}x[114409]=0;b=S(2583,a+268|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;b=Sr(b,a+23|0,a+22|0,c,a+192|0,v[a+223|0],v[a+222|0],a+208|0,a+32|0,a+28|0,a+24|0,a+224|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}x[114409]=0;S(2585,a+268|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+208|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}x[114409]=0;W(2602,a|0,c|0,x[a+192>>2],e|0);b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}b=x[a+8>>2];c=x[a+12>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;x[f+8>>2]=b;x[f+12>>2]=c;x[114409]=0;Je(a+208|0,a+32|0,x[a+28>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+268|0,a+264|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;a:{if(!Qb(a,2)){Zg(c+484344|0,b,64);break a}j=c+484344|0;h=Md(nB(a),1,1024);if(!Zg(j,b,h)|!h){break a}k=z[c+480188>>1];while(1){m=tm(Zb(j,b),i);g=0;if(k){while(1){d=e+12|0;qm(d,a);n=ed(d);o=wf(d);c=D(g,6)+m|0;f=y[fi(d)|0];v[c+5|0]=f;l=0;d=y[d|0];if((d-1&255)>>>0<=35){v[c|0]=d+48;l=y[n|0]+1|0}d=c+5|0;v[c+1|0]=l;b:{c:{d:{switch(y[o|0]){case 1:v[c+3|0]=2;v[d|0]=f&15;break b;case 2:v[c+3|0]=3;v[d|0]=f&15;break b;case 12:if(!f){break b}v[c+3|0]=1;break b;case 13:if(!f){break b}v[c+3|0]=36;v[e+11|0]=15;p=d,q=y[tc(e+11|0,d)|0]|16,v[p|0]=q;break b;case 30:if(!f){break b}v[c+3|0]=35;v[e+10|0]=15;p=d,q=y[tc(e+10|0,d)|0]|16,v[p|0]=q;break b;case 21:if(!f){break b}v[c+3|0]=36;v[e+9|0]=15;p=d,q=y[tc(e+9|0,d)|0]|80,v[p|0]=q;break b;case 17:if(!f){break b}v[c+3|0]=35;v[e+8|0]=15;p=d,q=y[tc(e+8|0,d)|0]|80,v[p|0]=q;break b;case 15:v[c+3|0]=19;v[d|0]=(f|0)!=0;break b;case 25:v[c+3|0]=12;break b;case 27:au(c);v[c|0]=255;break b;case 28:v[c+3|0]=16;break b;case 31:v[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}v[d|0]=f&15;break b;case 5:v[d|0]=f<<4;break b;case 6:v[e+7|0]=f&15;v[e+6|0]=14;p=d,q=y[tc(e+7|0,e+6|0)|0]|240,v[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}v[e+5|0]=f&15;v[e+4|0]=14;p=d,q=y[tc(e+5|0,e+4|0)|0]<<4|15,v[p|0]=q;break b}v[c+4|0]=f;v[c+2|0]=1}v[c+3|0]=0;break c;case 0:break c;default:break d}}v[c+3|0]=0}v[d|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}hb=e+16|0}function Rr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+124>>2]=b;k=vt(c,d);x[i+4>>2]=2580;n=Sd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=xd(k);if(!j){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break a}break b}Ce(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[114409]=0;h=O(2611,a|0,i+124|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}if((h|!k)==1){x[114409]=0;b=O(2611,a|0,i+124|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}x[114409]=0;o=S(2612,a|0)|0;b=x[114409];x[114409]=0;g:{if((b|0)!=1){if(g){break g}x[114409]=0;o=O(2613,e|0,o|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break g}}break b}l=r+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){r=l;if(!s){continue e}x[114409]=0;S(2614,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(b)|0)==(l|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}q=x[yj(b,r)>>2];j:{if(g){break j}x[114409]=0;q=O(2613,e|0,q|0)|0;t=x[114409];x[114409]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(q|0)){s=1;if((Cb(b)|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Yc(b);v[h|0]=l?2:1;h=h+1|0;b=b+12|0;m=l+m|0;k=k-l|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);hb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-48|0;hb=c;f=sh(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(Bi(b)){vp(c+44|0);break n}x[114409]=0;P(2313,c+32|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break m}x[114409]=0;a=S(2298,c+32|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}x[c+44>>2]=a;Qf(c+32|0)}if(Bi(b)){a=b+36|0}else{a=x[c+44>>2]}e=vd(a);x[114409]=0;P(1629,f|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break k}h=c,i=bc(a),x[h+28>>2]=i;h=c,i=dc(a),x[h+24>>2]=i;if(Hb(c+28|0,c+24|0)){a=b+24|0;while(1){e=x[c+28>>2];b=Ti(x[a>>2]+484360|0,y[e+16|0]);x[114409]=0;P(2314,c+12|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break j}x[114409]=0;T(9,c+32|0,0,c+12|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}x[114409]=0;P(1631,f|0,c+32|0);d=x[114409];x[114409]=0;if((d|0)==1){break h}xb(c+32|0);xb(c+12|0);o:{if(!Yc(OI(f))){break o}d=y[e+12|0];x[114409]=0;d=O(539,b|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break c}if(!d){break o}d=x[a>>2];x[114409]=0;d=S(697,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}b=Zb(x[a>>2]+484344|0,z[vc(b,x[e+12>>2])>>1]);x[114409]=0;P(2315,c+12|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;W(409,c+32|0,0,d|0,c+12|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}b=c+32|0;Eb(OI(f),b);xb(b);xb(c+12|0)}b=c+28|0;bj(b);if(Hb(b,c+24|0)){continue}break}}zk(c+44|0);hb=c+48|0;return}b=N()|0;break a}b=N()|0;Qf(c+32|0);break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break g}b=N()|0;xb(c+32|0)}xb(c+12|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;xb(c+12|0);break b}b=N()|0}zk(c+44|0)}pd(f);Q(b|0);p()}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];k=x[a+44>>2];x[b+32>>2]=k;m=x[a+48>>2];x[b+36>>2]=m;i=x[a+52>>2];x[b+40>>2]=i;j=x[a+56>>2];x[b+44>>2]=j;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];f=g;e=x[a>>2];x[b+16>>2]=e;x[b+20>>2]=f;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){h=p>>12;g=q>>12;break a}while(1){e=x[b+16>>2];n=(((x[b+20>>2]&2147483647)<<1|e>>>31)&-2)+t|0;e=(e>>>21&2040)+32976|0;s=w[e+6>>1];j=w[e+4>>1];f=w[e+2>>1];g=w[e>>1];k=0;m=1;i=1;h=0;while(1){x[(h<<2)+b>>2]=(((D(v[h+n|0],f)+D(v[n+(h|-2)|0],g)|0)+D(j,v[n+(h|2)|0])|0)+D(s,v[n+(h|4)|0])<<8)/16384;e=i&1;i=0;h=1;if(e){continue}break}while(1){e=(k<<2)+b|0;j=x[e>>2];o=x[a+60>>2];r=(b+28|0)+(k<<3)|0;f=x[r+4>>2];l=Yb(f,-16777216,16776704);i=x[a+64>>2];h=Yb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];n=g>>31;x[r+8>>2]=f;s=x[a+72>>2];k=j<<8;f=k;f=sqa(o,o>>31,f,f>>31);j=lb;o=f;f=sqa(i,i>>31,l,l>>31);i=o+f|0;l=lb+j|0;l=f>>>0>i>>>0?l+1|0:l;f=sqa(g,n,h,h>>31);j=f+i|0;g=lb+l|0;g=f>>>0>j>>>0?g+1|0:g;o=e;f=j+8388608|0;e=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[o>>2]=(e|0)/256;x[r+4>>2]=e-(k&s);k=1;e=m&1;m=0;if(e){continue}break}e=x[a+32>>2];q=x[a+28>>2]+q|0;g=q>>12;x[c>>2]=x[c>>2]+D(g,x[b>>2]);p=e+p|0;h=p>>12;x[c+4>>2]=x[c+4>>2]+D(h,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}j=x[b+44>>2];i=x[b+40>>2];m=x[b+36>>2];k=x[b+32>>2];e=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=e;x[a+4>>2]=f;x[a+40>>2]=p;x[a+20>>2]=g;x[a+36>>2]=q;x[a+56>>2]=j;x[a+52>>2]=i;x[a+48>>2]=m;x[a+44>>2]=k;x[a+24>>2]=h;hb=b+48|0}function Pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-48|0;hb=c;w[c+46>>1]=b;d=Jj(a);b=hb-16|0;hb=b;e=c+32|0;x[e>>2]=0;x[e+4>>2]=0;x[b+4>>2]=0;Zc(e+8|0);Yd(b+4|0,x[Bb(b,e)>>2]);a:{if(!d){break a}x[114409]=0;P(944,e|0,d|0);f=x[114409];x[114409]=0;if((f|0)!=1){x[114409]=0;P(1226,e|0,d|0);f=x[114409];x[114409]=0;if((f|0)!=1){break a}}a=N()|0;Vn(b+4|0);Q(a|0);p()}f=b+4|0;Xd(f);Vn(f);hb=b+16|0;b:{c:{if(!d){break c}b=0;while(1){i=vc(e,b),j=b-g|0,w[i>>1]=j;x[114409]=0;f=O(1223,a|0,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}g=(z[f>>1]==z[c+46>>1])+g|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}if(!(g&65535)){break c}b=bc(a);d=dc(a);x[114409]=0;b=U(1224,b|0,d|0,c+46|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}x[c+24>>2]=b;b=rd(c+28|0,c+24|0);i=c,j=dc(a),x[i+16>>2]=j;d=x[rd(c+20|0,c+16|0)>>2];b=x[b>>2];x[114409]=0;U(1225,a|0,b|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}i=c,j=bc(a),x[i+24>>2]=j;i=c,j=dc(a),x[i+16>>2]=j;if(Hb(c+24|0,c+16|0)){while(1){b=z[x[c+24>>2]>>1];d=x[a+24>>2];x[114409]=0;d=O(414,d+484344|0,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}d:{if(!d){break d}b=Zb(x[a+24>>2]+484344|0,b);i=c,j=bc(b),x[i+12>>2]=j;i=c,j=dc(b),x[i+8>>2]=j;if(!Hb(c+12|0,c+8|0)){break d}while(1){b=x[c+12>>2];e:{if(y[b+3|0]!=12){break e}d=y[b+5|0];if(rc(e)>>>0<=d>>>0){break e}i=b,j=y[vc(e,y[b+5|0])|0],v[i+5|0]=j}b=c+12|0;Sj(b);if(Hb(b,c+8|0)){continue}break}}b=c+24|0;ke(b);if(Hb(b,c+16|0)){continue}break}}b=z[a+28>>1];if(rc(e)>>>0<=b>>>0){break c}i=a,j=z[vc(e,z[a+28>>1])>>1],w[i+28>>1]=j}vf(e);hb=c+48|0;return}a=N()|0;vf(e);Q(a|0);p()}function th(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if((b|0)==189){v[a+3843|0]=c>>>7;v[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=D(b>>>0<3?b:b+6|0,44)+a|0;g=e+148|0;e=e+16|0;h=c&d;b:{if(h){Kn(e,g);break b}Kn(e,0)}v[g+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}v[a+3842|0]=c>>>6&1;b=0;while(1){oz((D(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if(d-160>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(D(b&256?d+9|0:d,44)+a|0)+16|0;x[f+8>>2]=a;d=x[a+36>>2];x[f+12>>2]=d;d=d?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}g=c&3;e=c>>>2&7;b=0;c=(c&32)!=0;while(1){a=x[(f+8|0)+(b<<2)>>2];EO(x[a>>2],c);EO(x[a+4>>2],c);w[a+22>>1]=e;nz(a);oz(a);v[a+21|0]=g;nz(a);oz(a);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}b=0;while(1){a=x[(f+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|c&255;nz(a);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}v[a+42|0]=(c&32)>>>5;v[a+41|0]=(c&16)>>>4;b=c>>>1&7;w[a+30>>1]=b?9-b|0:0;w[a+32>>1]=c&1;break a}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=v[(b&31)+25536|0];a=(e+D(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:v[a+79|0]=c>>>7;v[a+80|0]=(c&64)>>>6;v[a+78|0]=(c&32)>>>5;v[a+77|0]=(c&16)>>>4;Ln(a);w[a+14>>1]=z[((c&15)<<1)+25568>>1];break a;case 1:w[a+68>>1]=y[(c>>>6|0)+17378|0];FO(a);w[a+22>>1]=(c&63)<<2;break a;case 2:w[a+24>>1]=c>>>4;Ln(a);w[a+26>>1]=c&15;Ln(a);break a;case 3:b=c>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=c&15;Ln(a);break a;case 6:break d;default:break a}}w[a+12>>1]=c&7}hb=f+16|0}function WJ(a){var b=E(0),c=0,d=0,e=0,f=0,g=0,h=E(0),i=E(0),k=0,l=E(0);d=hb-16|0;hb=d;k=d,l=E(Nx(B[a+4216>>2])/E(cf(x[a+16>>2])>>>0)),B[k+12>>2]=l;x[d+8>>2]=1056964608;b=E(M(E(E(np(E(B[Ml(d+12|0,d+8|0)>>2]*E(6.2831854820251465)))*E(.4000000059604645))+E(.6000000238418579))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[a+4212>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}v[a+4272|0]=c;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}v[a+4273|0]=e;h=pe(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))*E(.05000000074505806)));k=d,l=E(Nx(B[a+4220>>2])/E(cf(x[a+16>>2])>>>0)),B[k+12>>2]=l;x[d+8>>2]=1056964608;i=B[Ml(d+12|0,d+8|0)>>2];k=d,l=E(Nx(B[a+4224>>2])/E(cf(x[a+16>>2])>>>0)),B[k+12>>2]=l;x[d+8>>2]=1056964608;b=E(B[Ml(d+12|0,d+8|0)>>2]*E(3.1415927410125732));g=hb-16|0;hb=g;e=(q(b),j(2));c=e&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=ln(+b,0);break c}if(c>>>0<=1081824209){f=+b;if(c>>>0<=1075235811){b=ln(((e|0)<0?1.5707963267948966:-1.5707963267948966)+f,1);break c}b=ln(((e|0)<0?3.141592653589793:-3.141592653589793)+f,0);break c}if(c>>>0<=1088565717){f=+b;if(c>>>0<=1085271519){b=ln(((e|0)<0?4.71238898038469:-4.71238898038469)+f,1);break c}b=ln(((e|0)<0?6.283185307179586:-6.283185307179586)+f,0);break c}if(c>>>0>=2139095040){b=E(b-b);break c}c=$w(b,g+8|0);b=ln(C[g+8>>3],c&1)}hb=g+16|0;B[a+4268>>2]=E(E(1)-b)/E(b+E(1));b=np(E(i*E(6.2831854820251465)));B[a+4264>>2]=-b;h=E(h*E(M(E(E(1)-E(b*b)))));b=B[a+4268>>2];B[a+4260>>2]=E(h*E(M(E(E(1)-E(b*b)))))*B[(y[a+4272|0]<<2)+36128>>2];hb=d+16|0}function l0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-368|0;hb=f;x[f+360>>2]=37;x[f+364>>2]=0;h=Nr(f+360|1,17381,x[c+4>>2]);x[f+316>>2]=f+320;a=me();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;a=kf(f+320|0,30,a,f+360|0,f+32|0);break a}C[f+48>>3]=e;a=kf(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=2580;i=Sd(f+308|0,0,f+80|0);j=f+320|0;g=j;b:{c:{d:{e:{if((a|0)>=30){f:{if(h){x[114409]=0;a=$(2603)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[f>>2]=x[c+8>>2];x[114409]=0;C[f+8>>3]=e;a=Z(2623,f+316|0,a|0,f+360|0,f|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break f}break d}x[114409]=0;a=$(2603)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}C[f+16>>3]=e;x[114409]=0;a=Z(2623,f+316|0,a|0,f+360|0,f+16|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}}if((a|0)==-1){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)==1){break d}break e}Ce(i,x[f+316>>2]);g=x[f+316>>2]}h=a+g|0;k=yg(g,h,c);x[f+68>>2]=2580;g=Sd(f+72|0,0,f+68|0);g:{h:{if(x[f+316>>2]==(f+320|0)){a=f+80|0;break h}a=xd(a<<3);if(!a){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break e}b=N()|0;break g}Ce(g,a);j=x[f+316>>2]}x[114409]=0;Fc(f+60|0,c);l=x[114409];x[114409]=0;i:{j:{if((l|0)!=1){x[114409]=0;fa(2634,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+60|0);h=x[114409];x[114409]=0;if((h|0)==1){break j}Ob(f+60|0);x[114409]=0;a=ga(2635,b|0,a|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break i}Lc(g);Lc(i);hb=f+368|0;break b}b=N()|0;break g}b=N()|0;Ob(f+60|0);break g}b=N()|0}Lc(g);break c}p()}b=N()|0}Lc(i);Q(b|0);p()}return a|0}function w0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-208|0;hb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=Nr(f+200|1,17381,x[c+4>>2]);x[f+156>>2]=f+160;a=me();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;a=kf(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;a=kf(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=2580;i=Sd(f+148|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{e:{if((a|0)>=30){f:{if(h){x[114409]=0;a=$(2603)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[f>>2]=x[c+8>>2];x[114409]=0;C[f+8>>3]=e;a=Z(2623,f+156|0,a|0,f+200|0,f|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){break f}break d}x[114409]=0;a=$(2603)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}C[f+16>>3]=e;x[114409]=0;a=Z(2623,f+156|0,a|0,f+200|0,f+16|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}}if((a|0)==-1){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)==1){break d}break e}Ce(i,x[f+156>>2]);g=x[f+156>>2]}h=a+g|0;k=yg(g,h,c);x[f+68>>2]=2580;g=Sd(f+72|0,0,f+68|0);g:{h:{if(x[f+156>>2]==(f+160|0)){a=f+80|0;break h}a=xd(a<<1);if(!a){x[114409]=0;X(2581);a=x[114409];x[114409]=0;if((a|0)!=1){break e}b=N()|0;break g}Ce(g,a);j=x[f+156>>2]}x[114409]=0;Fc(f+60|0,c);l=x[114409];x[114409]=0;i:{j:{if((l|0)!=1){x[114409]=0;fa(2624,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+60|0);h=x[114409];x[114409]=0;if((h|0)==1){break j}Ob(f+60|0);x[114409]=0;a=ga(17,b|0,a|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break i}Lc(g);Lc(i);hb=f+208|0;break b}b=N()|0;break g}b=N()|0;Ob(f+60|0);break g}b=N()|0}Lc(g);break c}p()}b=N()|0}Lc(i);Q(b|0);p()}return a|0}function poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-96|0;hb=d;b=b&4095;w[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=sqa(e,e>>31,1e4,0);b=lb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=tqa(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Vb(d+68|0,10658);x[114409]=0;P(192,d+80|0,e|0);f=x[114409];x[114409]=0;h=(D(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){x[114409]=0;g=b;b=h+2|0;f=(b|0)/12|0;x[d+52>>2]=g+f;P(163,d+56|0,d+52|0);g=x[114409];x[114409]=0;if((g|0)==1){break o}x[114409]=0;x[d+36>>2]=(b-D(f,12)|0)+1;P(165,d+40|0,d+36|0);b=x[114409];x[114409]=0;if((b|0)==1){break n}x[114409]=0;x[d+20>>2]=(((D(h,306)+5|0)/-10|0)+c|0)+1;P(165,d+24|0,d+20|0);b=x[114409];x[114409]=0;if((b|0)==1){break m}x[114409]=0;ba(629,a|0,d+80|0,d+56|0,d+40|0,d+24|0);a=x[114409];x[114409]=0;if((a|0)==1){break l}xb(d+24|0);xb(d+40|0);xb(d+56|0);Gb(d+80|0);xb(e);break g}b=N()|0;break h}b=N()|0;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0;xb(d+24|0)}xb(d+40|0)}xb(d+56|0)}Gb(d+80|0)}xb(e);break a}c=Vb(d+8|0,11479);x[114409]=0;P(192,d+80|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;P(630,d+56|0,d+94|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;T(220,a|0,d+80|0,d+56|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}xb(d+56|0);Gb(d+80|0);xb(c)}hb=d+96|0;return}b=N()|0;break b}b=N()|0;break c}b=N()|0;xb(d+56|0)}Gb(d+80|0)}xb(c)}Q(b|0);p()}function RD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-112|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=x[b>>2];l:{if(!b){Vb(a,5662);break l}if(!(b&65535)){e=Vb(c+88|0,11105);x[114409]=0;P(192,c+100|0,e|0);d=x[114409];x[114409]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){x[114409]=0;x[c+32>>2]=b>>>24;P(193,c+76|0,c+32|0);d=x[114409];x[114409]=0;if((d|0)==1){break r}x[114409]=0;x[c+16>>2]=b>>>16&255;P(194,c- -64|0,c+16|0);b=x[114409];x[114409]=0;if((b|0)==1){break q}x[114409]=0;W(195,a|0,c+100|0,c+76|0,c- -64|0);a=x[114409];x[114409]=0;if((a|0)==1){break p}xb(c- -64|0);xb(c+76|0);Gb(c+100|0);xb(e);break l}b=N()|0;break m}b=N()|0;break n}b=N()|0;break o}b=N()|0;xb(c- -64|0)}xb(c+76|0)}Gb(c+100|0)}break a}e=Vb(c+52|0,10572);x[114409]=0;P(192,c+100|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break k}x[114409]=0;x[c+48>>2]=b>>>24;P(193,c+76|0,c+48|0);d=x[114409];x[114409]=0;if((d|0)==1){break j}x[114409]=0;x[c+44>>2]=b>>>16&255;P(194,c- -64|0,c+44|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}x[114409]=0;x[c+28>>2]=b>>>8&255;P(194,c+32|0,c+28|0);d=x[114409];x[114409]=0;if((d|0)==1){break h}x[114409]=0;x[c+12>>2]=b&255;P(194,c+16|0,c+12|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}x[114409]=0;ia(196,a|0,c+100|0,c+76|0,c- -64|0,c+32|0,c+16|0);a=x[114409];x[114409]=0;if((a|0)==1){break f}xb(c+16|0);xb(c+32|0);xb(c- -64|0);xb(c+76|0);Gb(c+100|0);xb(e)}hb=c+112|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;break e}b=N()|0;xb(c+16|0)}xb(c+32|0)}xb(c- -64|0)}xb(c+76|0)}Gb(c+100|0)}xb(e);Q(b|0);p()}
function nJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);d=hb-48|0;hb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==x[x[a>>2]+24604>>2]){break d}c=d+8|0;sc(c,x[a>>2]+24604|0,40);x[d+8>>2]=b;Ay(x[a>>2],c);break d;case 2:b=a+24|0;a=x[b>>2];e=a+24664|0;f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;e=a+24656|0;f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;e=x[a+24652>>2];x[d+8>>2]=x[a+24648>>2];x[d+12>>2]=e;e=hb-16|0;hb=e;a=3;f:{g:{h:{if(!c|(c|0)>7){break h}a=2;if((c|0)>2){break h}a=1;if((c|0)==2){break h}a=0;if((c|0)>0){break h}b=ec(8);x[114409]=0;c=O(122,e+4|0,6770)|0;a=x[114409];x[114409]=0;i:{if((a|0)!=1){a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break g}a=N()|0;xb(c);break i}a=N()|0;ic(b)}Q(a|0);p()}hb=e+16|0;break f}p()}v[d+8|0]=a;if(!Gx(d+8|0,x[b>>2]+24648|0)){break d}zy(x[b>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;sc(b,x[a>>2]+24604|0,40);e=hb-48|0;hb=e;j:{if((c|0)==-1){Sl(b,x[hq(e+8|0)+32>>2]);Kn(b,x[hq(e+8|0)+36>>2]);break j}if((c|0)<=0){Sl(b,0);Kn(b,0);break j}c=D(c,1e3);Sl(b,c);Kn(b,c)}hb=e+48|0;if(x[x[a>>2]+24636>>2]==x[d+40>>2]&x[x[a>>2]+24640>>2]==x[d+44>>2]){break d}Ay(x[a>>2],d+8|0);break d;default:a=ec(8);x[114409]=0;c=O(122,d+8|0,6366)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b;case 0:break e}}g=a,h=pe(E(10),E(E(c|0)*E(.0005000000237487257))),B[g+48>>2]=h}hb=d+48|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function G0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=E(0);a=hb-368|0;hb=a;x[a+360>>2]=c;x[a+364>>2]=b;pw(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Xb(a+192|0);b=Hc(d);x[114409]=0;P(1736,d|0,b|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114409]=0;b=O(2611,a+364|0,a+360|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}if(x[a+188>>2]==(Cb(d)+c|0)){b=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=b+c}x[114409]=0;b=S(2612,a+364|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;b=Qr(b,a+7|0,a+6|0,c,a+188|0,x[a+220>>2],x[a+216>>2],a+204|0,a+16|0,a+12|0,a+8|0,a+224|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}x[114409]=0;S(2614,a+364|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+204|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114409]=0;h=E(sa(2598,c|0,x[a+188>>2],e|0));b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}B[f>>2]=h;x[114409]=0;Je(a+204|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+364|0,a+360|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];xb(d);xb(a+204|0);hb=a+368|0;break a}}b=N()|0;xb(d);xb(a+204|0);Q(b|0);p()}return b|0}function W0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=E(0);a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;rw(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Xb(a+180|0);b=Hc(d);x[114409]=0;P(1736,d|0,b|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}if(x[a+176>>2]==(Cb(d)+c|0)){b=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+176>>2]=b+c}x[114409]=0;b=S(2583,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;b=Sr(b,a+7|0,a+6|0,c,a+176|0,v[a+207|0],v[a+206|0],a+192|0,a+16|0,a+12|0,a+8|0,a+208|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}x[114409]=0;S(2585,a+252|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+192|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114409]=0;h=E(sa(2598,c|0,x[a+176>>2],e|0));b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}B[f>>2]=h;x[114409]=0;Je(a+192|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+192|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+192|0);Q(b|0);p()}return b|0}function F0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-368|0;hb=a;x[a+360>>2]=c;x[a+364>>2]=b;pw(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Xb(a+192|0);b=Hc(d);x[114409]=0;P(1736,d|0,b|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114409]=0;b=O(2611,a+364|0,a+360|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}if(x[a+188>>2]==(Cb(d)+c|0)){b=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=b+c}x[114409]=0;b=S(2612,a+364|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;b=Qr(b,a+7|0,a+6|0,c,a+188|0,x[a+220>>2],x[a+216>>2],a+204|0,a+16|0,a+12|0,a+8|0,a+224|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}x[114409]=0;S(2614,a+364|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+204|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114409]=0;h=+ka(2601,c|0,x[a+188>>2],e|0);b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}C[f>>3]=h;x[114409]=0;Je(a+204|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+364|0,a+360|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];xb(d);xb(a+204|0);hb=a+368|0;break a}}b=N()|0;xb(d);xb(a+204|0);Q(b|0);p()}return b|0}function C$(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;t=hb-16|0;hb=t;x[c>>2]=a;z=d&512;A=h<<2;while(1){if((u|0)==4){if(Cb(n)>>>0>1){C=t,D=td(n),x[C+12>>2]=D;C=c,D=rF(Pn(t+12|0,1),lk(n),x[c>>2]),x[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}hb=t+16|0}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=$r(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Yc(n)){break a}h=x[yj(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Yc(m)|!z){break a}C=c,D=rF(td(m),lk(m),x[c>>2]),x[C>>2]=D;break a;case 4:break b;default:break a}}B=x[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!rk(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];r=o;while(1){if(!(!r|e>>>0>=h>>>0)){r=r-1|0;h=h-4|0;s=x[h>>2];q=p+4|0;x[c>>2]=q;x[p>>2]=s;p=q;continue}break}d:{if(!r){q=0;break d}q=$r(g,48);p=x[c>>2]}while(1){s=p+4|0;if((r|0)>0){x[p>>2]=q;r=r-1|0;p=s;continue}break}x[c>>2]=s;x[p>>2]=j}e:{if((e|0)==(h|0)){p=$r(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(Yc(l)){q=-1}else{q=v[pc(l,0)|0]}p=0;r=0;while(1){if((e|0)!=(h|0)){f:{if((p|0)!=(q|0)){s=p;break f}q=x[c>>2];x[c>>2]=q+4;x[q>>2]=k;s=0;r=r+1|0;if(Cb(l)>>>0<=r>>>0){q=p;break f}if(y[pc(l,r)|0]==127){q=-1;break f}q=v[pc(l,r)|0]}h=h-4|0;p=x[h>>2];w=x[c>>2];x[c>>2]=w+4;x[w>>2]=p;p=s+1|0;continue}break}h=x[c>>2]}ip(B,h)}u=u+1|0;continue}break}}function Iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=hb-16|0;hb=g;e=x[a+12>>2];i=e;a:{b:{c:{k=x[a+8>>2];d:{if((e|0)<=1&k>>>0<=805306368|(e|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}p=x[a+16>>2];e=x[a+48>>2];q=x[a+24>>2];r=x[a+20>>2];h=x[a+44>>2];b=x[a+4>>2];m=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;x[g>>2]=k;x[g+4>>2]=i;e:{if(!d){b=e;break e}while(1){f=x[g+12>>2]+p|0;s=v[f+4|0];b=(x[g+8>>2]>>>16&65520)+o|0;t=w[b+14>>1];u=v[f+3|0];y=w[b+12>>1];z=v[f+2|0];A=w[b+10>>1];B=v[f+1|0];C=w[b+8>>1];E=v[f|0];F=w[b+6>>1];G=v[f-1|0];H=w[b+4>>1];I=v[f-2|0];J=w[b+2>>1];K=v[f-3|0];n=w[b>>1];f=x[a+60>>2];i=f>>31;b=h;j=Yb(b,-16777216,16776704);h=x[a+64>>2];l=Yb(e,-16777216,16776704);m=x[a+72>>2];k=x[c>>2];e=sqa(h,h>>31,j,j>>31);h=lb;j=e;e=x[a+68>>2];e=sqa(e,e>>31,l,l>>31);l=j+e|0;j=lb+h|0;j=e>>>0>l>>>0?j+1|0:j;n=(((((((D(I,J)+D(n,K)|0)+D(G,H)|0)+D(E,F)|0)+D(B,C)|0)+D(z,A)|0)+D(u,y)|0)+D(s,t)<<8)/32768<<8;e=n;e=sqa(f,i,e,e>>31);h=e+l|0;f=lb+j|0;f=e>>>0>h>>>0?f+1|0:f;e=h+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,r)+k;x[c+4>>2]=x[c+4>>2]+D(f,q);h=e-(m&n)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];m=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=m;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=hb-16|0;hb=g;f=x[a+12>>2];j=f;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((j|0)>=-2&h>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&h>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&h>>>0>2147483648|j>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];f=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];i=x[a+44>>2];b=x[a+4>>2];k=b;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=b;x[g>>2]=h;x[g+4>>2]=j;e:{if(!d){b=f;break e}while(1){b=(x[g+8>>2]>>>16&65520)+l|0;k=w[b>>1];e=(x[g+12>>2]<<1)+m|0;p=w[e-6>>1];q=w[b+2>>1];r=w[e-4>>1];s=w[b+4>>1];t=w[e-2>>1];u=w[b+6>>1];v=w[e>>1];y=w[b+8>>1];z=w[e+2>>1];A=w[b+10>>1];B=w[e+4>>1];C=w[b+12>>1];E=w[e+6>>1];F=w[b+14>>1];G=w[e+8>>1];e=x[a+60>>2];b=i;h=Yb(b,-16777216,16776704);i=x[a+64>>2];j=Yb(f,-16777216,16776704);H=x[a+72>>2];I=x[c>>2];f=sqa(i,i>>31,h,h>>31);i=lb;h=(((((((D(q,r)+D(k,p)|0)+D(s,t)|0)+D(u,v)|0)+D(y,z)|0)+D(A,B)|0)+D(C,E)|0)+D(F,G)|0)/32768<<8;k=sqa(e,e>>31,h,h>>31);e=k+f|0;f=lb+i|0;f=e>>>0<k>>>0?f+1|0:f;k=e;e=x[a+68>>2];i=sqa(e,e>>31,j,j>>31);e=k+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;e=(f|0)/256|0;x[c>>2]=D(e,o)+I;x[c+4>>2]=x[c+4>>2]+D(e,n);i=f-(h&H)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];k=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=k;x[a+48>>2]=b;x[a+44>>2]=i;hb=g+16|0}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];m=x[a+44>>2];x[b+32>>2]=m;o=x[a+48>>2];x[b+36>>2]=o;k=x[a+52>>2];x[b+40>>2]=k;h=x[a+56>>2];x[b+44>>2]=h;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){j=p>>12;i=q>>12;break a}while(1){e=x[b+16>>2];g=e>>>18|0;m=1;h=((((x[b+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+t|0;j=0;k=1;i=0;while(1){f=i<<1;e=w[f+h>>1];x[(i<<2)+b>>2]=e+((D(g,w[h+(f|4)>>1]-e|0)|0)/16384|0);f=k&1;k=0;i=1;if(f){continue}break}while(1){f=(j<<2)+b|0;h=x[f>>2];n=x[a+60>>2];r=(b+28|0)+(j<<3)|0;e=x[r+4>>2];l=Yb(e,-16777216,16776704);i=x[a+64>>2];s=Yb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];k=g>>31;x[r+8>>2]=e;o=x[a+72>>2];j=h<<8;e=j;e=sqa(n,n>>31,e,e>>31);h=lb;n=e;e=sqa(i,i>>31,l,l>>31);i=n+e|0;l=lb+h|0;l=e>>>0>i>>>0?l+1|0:l;e=sqa(g,k,s,s>>31);h=e+i|0;g=lb+l|0;g=e>>>0>h>>>0?g+1|0:g;n=f;e=h+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[n>>2]=(f|0)/256;x[r+4>>2]=f-(j&o);j=1;f=m&1;m=0;if(f){continue}break}f=x[a+32>>2];q=x[a+28>>2]+q|0;i=q>>12;x[c>>2]=x[c>>2]+D(i,x[b>>2]);p=f+p|0;j=p>>12;x[c+4>>2]=x[c+4>>2]+D(j,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+44>>2];k=x[b+40>>2];o=x[b+36>>2];m=x[b+32>>2];f=x[b+16>>2];e=x[b+20>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+40>>2]=p;x[a+20>>2]=i;x[a+36>>2]=q;x[a+56>>2]=h;x[a+52>>2]=k;x[a+48>>2]=o;x[a+44>>2]=m;x[a+24>>2]=j;hb=b+48|0}function U0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;rw(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Xb(a+180|0);b=Hc(d);x[114409]=0;P(1736,d|0,b|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}if(x[a+176>>2]==(Cb(d)+c|0)){b=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+176>>2]=b+c}x[114409]=0;b=S(2583,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;b=Sr(b,a+7|0,a+6|0,c,a+176|0,v[a+207|0],v[a+206|0],a+192|0,a+16|0,a+12|0,a+8|0,a+208|0);g=x[114409];x[114409]=0;if((g|0)==1){break d}if(b){break c}x[114409]=0;S(2585,a+252|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+192|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114409]=0;h=+ka(2601,c|0,x[a+176>>2],e|0);b=x[114409];x[114409]=0;f:{if((b|0)==1){break f}C[f>>3]=h;x[114409]=0;Je(a+192|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+192|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+192|0);Q(b|0);p()}return b|0}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=hb-32|0;hb=i;x[i+28>>2]=b;b=x[a>>2];o=i,q=bc(a),x[o+8>>2]=q;b=b+D(bt(i+28|0,i+8|0),6)|0;a:{b:{if(!c){break b}f=x[yb(a)>>2];e=x[a+4>>2];if((f-e|0)/6>>>0>=c>>>0){g=c;f=(e-b|0)/6|0;if(f>>>0<c>>>0){KA(a,c-f|0,d);g=f;if((b|0)==(e|0)){break b}}m=hb-16|0;hb=m;l=e;n=x[a+4>>2];f=D((n-(D(c,6)+b|0)|0)/6|0,6)+b|0;j=Gq(m+4|0,a,(e-f|0)/6|0);c:{d:{if(e>>>0>f>>>0){h=x[j+4>>2];e=f;while(1){k=yb(a);x[114409]=0;T(1668,k|0,h|0,e|0);k=x[114409];x[114409]=0;if((k|0)==1){break d}h=h+6|0;x[j+4>>2]=h;e=e+6|0;if(l>>>0>e>>>0){continue}break}}Jb(j);l=hb-16|0;hb=l;e=hb-32|0;hb=e;Ae(e+24|0,b,f);j=x[e+24>>2];f=hb-16|0;hb=f;h=x[e+28>>2];x[f+12>>2]=h;h=h-j|0;k=D((h|0)/-6|0,6)+n|0;x[f+8>>2]=k;vk(k,j,h);Dc(e+16|0,f+12|0,f+8|0);hb=f+16|0;o=e,q=rL(b,x[e+16>>2]),x[o+12>>2]=q;o=e,q=gy(n,x[e+20>>2]),x[o+8>>2]=q;Dc(l+8|0,e+12|0,e+8|0);hb=e+32|0;hb=l+16|0;hb=m+16|0;break c}a=N()|0;Jb(j);Q(a|0);p()}a=D(b>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;c=b;if(g){while(1){d=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[c|0]=d;v[c+1|0]=d>>>8;v[c+2|0]=d>>>16;v[c+3|0]=d>>>24;d=y[a+4|0]|y[a+5|0]<<8;v[c+4|0]=d;v[c+5|0]=d>>>8;c=c+6|0;g=g-1|0;if(g){continue}break}}break b}g=yb(a);g=RS(i+8|0,yA(a,ng(a)+c|0),(b-x[a>>2]|0)/6|0,g);x[114409]=0;T(719,g|0,c|0,d|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=U(1667,a|0,g|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}qu(g)}a=Rg(b);hb=i+32|0;return a|0}a=N()|0;qu(g);Q(a|0);p()}function W9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;f=b+1304396|0;if(!yd(f)){d=hb-16|0;hb=d;e=Re(12);x[114409]=0;g=S(1875,e|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=g;e=U(1881,d+12|0,c+12|0,c+11|0)|0;g=x[114409];x[114409]=0;b:{if((g|0)!=1){hb=c+16|0;break b}R(0)|0;zb();p()}hb=d+16|0;e=x[e>>2];break a}a=N()|0;_b(e);Q(a|0);p()}x[i+12>>2]=e;e=i+12|0;NM(f,oe(e));Ly(e)}e=x[f>>2];c=hb+-64|0;hb=c;f=Vb(c+40|0,GM(a));x[114409]=0;P(1718,c+52|0,f|0);d=x[114409];x[114409]=0;c:{d:{e:{if((d|0)!=1){xb(f);k=c,l=bc(e),x[k+36>>2]=l;k=c,l=dc(e),x[k+32>>2]=l;if(!Hb(c+36|0,c+32|0)){d=0;break c}f=0;e=0;while(1){d=0;g=x[c+36>>2];if(x[x[g>>2]+32>>2]==(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))){d=x[x[g>>2]+36>>2]==(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))}h=x[g>>2];x[114409]=0;P(1876,c+8|0,h+8|0);h=x[114409];x[114409]=0;f:{g:{h:{i:{if((h|0)!=1){x[114409]=0;P(1718,c+20|0,c+8|0);h=x[114409];x[114409]=0;if((h|0)==1){break i}j=c+20|0;h=Df(j,c+52|0);xb(j);xb(c+8|0);if((d&h)!=1){break g}f=x[g>>2];e=3;break f}d=N()|0;break h}d=N()|0;xb(c+8|0)}f=c+52|0;break d}if((e|0)<2&d){f=x[g>>2];e=2;break f}d=h&(e|0)<=0;f=d?x[g>>2]:f;e=d?1:e}d=c+36|0;je(d);if(Hb(d,c+32|0)){continue}break}break e}d=N()|0;break d}d=0;if(!f){break c}e=x[f+4>>2];if(!e){break c}x[114409]=0;a=U(e|0,f|0,b|0,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){d=(a|0)!=0;break c}d=N()|0;f=c+52|0}xb(f);Q(d|0);p()}xb(c+52|0);hb=c- -64|0;hb=i+16|0;return d|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];o=x[a+44>>2];x[b+32>>2]=o;m=x[a+48>>2];x[b+36>>2]=m;k=x[a+52>>2];x[b+40>>2]=k;j=x[a+56>>2];x[b+44>>2]=j;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){i=p>>12;h=q>>12;break a}while(1){e=x[b+16>>2];g=e>>>10&4194048;e=(((x[b+20>>2]&2147483647)<<1|e>>>31)&-2)+t|0;h=0;m=1;k=1;i=0;while(1){f=v[e+i|0];x[(i<<2)+b>>2]=((D(g,v[e+(i|2)|0]-f|0)|0)/16384|0)+(f<<8);f=k&1;k=0;i=1;if(f){continue}break}while(1){f=(h<<2)+b|0;j=x[f>>2];n=x[a+60>>2];r=(b+28|0)+(h<<3)|0;e=x[r+4>>2];l=Yb(e,-16777216,16776704);h=x[a+64>>2];s=Yb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];k=g>>31;x[r+8>>2]=e;o=x[a+72>>2];i=j<<8;e=i;e=sqa(n,n>>31,e,e>>31);j=lb;n=e;e=sqa(h,h>>31,l,l>>31);h=n+e|0;l=lb+j|0;l=e>>>0>h>>>0?l+1|0:l;e=sqa(g,k,s,s>>31);j=e+h|0;g=lb+l|0;g=e>>>0>j>>>0?g+1|0:g;n=f;e=j+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[n>>2]=(f|0)/256;x[r+4>>2]=f-(i&o);h=1;f=m&1;m=0;if(f){continue}break}f=x[a+32>>2];q=x[a+28>>2]+q|0;h=q>>12;x[c>>2]=x[c>>2]+D(h,x[b>>2]);p=f+p|0;i=p>>12;x[c+4>>2]=x[c+4>>2]+D(i,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}j=x[b+44>>2];k=x[b+40>>2];m=x[b+36>>2];o=x[b+32>>2];f=x[b+16>>2];e=x[b+20>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+40>>2]=p;x[a+20>>2]=h;x[a+36>>2]=q;x[a+56>>2]=j;x[a+52>>2]=k;x[a+48>>2]=m;x[a+44>>2]=o;x[a+24>>2]=i;hb=b+48|0}function M0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-336|0;hb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=hh(d);h=$m(d,a+208|0);_m(a+196|0,d,a+324|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2611,a+332|0,a+328|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2612,a+332|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;g=nk(g,b,c,a+180|0,a+8|0,x[a+324>>2],a+196|0,a+16|0,a+12|0,h);i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}x[114409]=0;S(2614,a+332|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114409]=0;b=Zo(2592,c,x[a+180>>2],e,b);c=lb;h=x[114409];x[114409]=0;f:{if((h|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+332|0,a+328|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];xb(d);xb(a+196|0);hb=a+336|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function I0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-336|0;hb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=hh(d);h=$m(d,a+208|0);_m(a+196|0,d,a+324|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2611,a+332|0,a+328|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2612,a+332|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;g=nk(g,b,c,a+180|0,a+8|0,x[a+324>>2],a+196|0,a+16|0,a+12|0,h);i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}x[114409]=0;S(2614,a+332|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114409]=0;b=Zo(2596,c,x[a+180>>2],e,b);c=lb;h=x[114409];x[114409]=0;f:{if((h|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+332|0,a+328|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];xb(d);xb(a+196|0);hb=a+336|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];b=x[a+44>>2];x[e+32>>2]=b;i=x[a+48>>2];x[e+36>>2]=i;j=x[a+52>>2];x[e+40>>2]=j;m=x[a+56>>2];x[e+44>>2]=m;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];h=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){m=1;b=x[e+16>>2];k=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>21&2040)+32976|0;p=w[b+6>>1];q=w[b+4>>1];h=w[b+2>>1];f=w[b>>1];j=0;b=1;i=0;while(1){g=i<<1;x[(i<<2)+e>>2]=(((D(w[g+k>>1],h)+D(w[k+(g|-4)>>1],f)|0)+D(w[k+(g|4)>>1],q)|0)+D(p,w[k+(g|8)>>1])|0)/16384;g=b;b=0;i=1;if(g){continue}break}while(1){b=(j<<2)+e|0;h=x[b>>2];n=x[a+60>>2];o=(e+28|0)+(j<<3)|0;f=x[o+4>>2];l=Yb(f,-16777216,16776704);k=x[a+64>>2];i=Yb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];p=g>>31;x[o+8>>2]=f;q=x[a+72>>2];j=h<<8;f=j;f=sqa(n,n>>31,f,f>>31);h=lb;n=f;f=sqa(k,k>>31,l,l>>31);k=n+f|0;l=lb+h|0;l=f>>>0>k>>>0?l+1|0:l;f=sqa(g,p,i,i>>31);h=f+k|0;g=lb+l|0;g=f>>>0>h>>>0?g+1|0:g;n=b;f=h+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[n>>2]=(b|0)/256;x[o+4>>2]=b-(j&q);j=1;b=m&1;m=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}m=x[e+44>>2];j=x[e+40>>2];i=x[e+36>>2];g=x[e+16>>2];h=x[e+20>>2];b=x[e+32>>2]}x[a>>2]=g;x[a+4>>2]=h;x[a+56>>2]=m;x[a+52>>2]=j;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0}function Zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=hb-32|0;hb=i;x[i+28>>2]=b;b=x[a>>2];m=i,n=bc(a),x[m+8>>2]=n;b=b+(Jq(i+28|0,i+8|0)<<1)|0;a:{b:{if(A[a+4>>2]<A[yb(a)>>2]){g=x[a+4>>2];if((g|0)!=(b|0)){break b}e=hb-16|0;hb=e;d=bh(e+4|0,a,1);a=yb(a);k=x[d+4>>2];x[114409]=0;T(505,a|0,k|0,c|0);a=x[114409];x[114409]=0;c:{if((a|0)!=1){x[d+4>>2]=x[d+4>>2]+2;Jb(d);hb=e+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}break a}d=yb(a);d=Mq(i+8|0,hj(a,rc(a)+1|0),b-x[a>>2]>>1,d);x[114409]=0;P(498,d|0,c|0);c=x[114409];x[114409]=0;d:{if((c|0)==1){break d}x[114409]=0;b=U(499,a|0,d|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break d}Ru(d);break a}a=N()|0;Ru(d);Q(a|0);p()}l=hb-16|0;hb=l;k=x[a+4>>2];d=(k-(b+2|0)|0)+b|0;f=bh(l+4|0,a,g-d>>1);e:{f:{if(d>>>0<g>>>0){h=x[f+4>>2];e=d;while(1){j=yb(a);x[114409]=0;T(507,j|0,h|0,e|0);j=x[114409];x[114409]=0;if((j|0)==1){break f}h=h+2|0;x[f+4>>2]=h;e=e+2|0;if(g>>>0>e>>>0){continue}break}}Jb(f);h=hb-16|0;hb=h;e=hb-32|0;hb=e;Ae(e+24|0,b,d);j=x[e+24>>2];g=x[e+28>>2];f=hb-16|0;hb=f;d=k;x[f+12>>2]=d;x[f+8>>2]=g;x[f+4>>2]=g;if((g|0)!=(j|0)){while(1){x[f+8>>2]=g-2;g=x[f+8>>2];d=d-2|0;x[f+12>>2]=d;jB(d,g);g=x[f+8>>2];if((j|0)!=(g|0)){continue}break}}Dc(e+16|0,f+4|0,f+12|0);hb=f+16|0;m=e,n=Wo(b,x[e+16>>2]),x[m+12>>2]=n;m=e,n=ji(k,x[e+20>>2]),x[m+8>>2]=n;Dc(h+8|0,e+12|0,e+8|0);hb=e+32|0;hb=h+16|0;hb=l+16|0;break e}a=N()|0;Jb(f);Q(a|0);p()}jB(b,((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0)}a=Rg(b);hb=i+32|0;return a|0}function N0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-336|0;hb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=hh(d);h=$m(d,a+208|0);_m(a+196|0,d,a+324|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2611,a+332|0,a+328|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2612,a+332|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;g=nk(g,b,c,a+180|0,a+8|0,x[a+324>>2],a+196|0,a+16|0,a+12|0,h);i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}x[114409]=0;S(2614,a+332|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114409]=0;b=Z(2588,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+332|0,a+328|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];xb(d);xb(a+196|0);hb=a+336|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function L0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-336|0;hb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=hh(d);h=$m(d,a+208|0);_m(a+196|0,d,a+324|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2611,a+332|0,a+328|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2612,a+332|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;g=nk(g,b,c,a+180|0,a+8|0,x[a+324>>2],a+196|0,a+16|0,a+12|0,h);i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}x[114409]=0;S(2614,a+332|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114409]=0;b=Z(2593,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}w[f>>1]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+332|0,a+328|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];xb(d);xb(a+196|0);hb=a+336|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function K0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-336|0;hb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=hh(d);h=$m(d,a+208|0);_m(a+196|0,d,a+324|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2611,a+332|0,a+328|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2612,a+332|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;g=nk(g,b,c,a+180|0,a+8|0,x[a+324>>2],a+196|0,a+16|0,a+12|0,h);i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}x[114409]=0;S(2614,a+332|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114409]=0;b=Z(2594,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+332|0,a+328|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];xb(d);xb(a+196|0);hb=a+336|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function J0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-336|0;hb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=hh(d);h=$m(d,a+208|0);_m(a+196|0,d,a+324|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2611,a+332|0,a+328|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2612,a+332|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}x[114409]=0;g=nk(g,b,c,a+180|0,a+8|0,x[a+324>>2],a+196|0,a+16|0,a+12|0,h);i=x[114409];x[114409]=0;if((i|0)==1){break d}if(g){break c}x[114409]=0;S(2614,a+332|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114409]=0;b=Z(2595,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2611,a+332|0,a+328|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];xb(d);xb(a+196|0);hb=a+336|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function c1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;b=hh(d);bn(a+196|0,d,a+247|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2582,a+252|0,a+248|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2583,a+252|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}x[114409]=0;g=pk(g,b,c,a+180|0,a+8|0,v[a+247|0],a+196|0,a+16|0,a+12|0,64896);h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}x[114409]=0;S(2585,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114409]=0;b=Zo(2592,c,x[a+180>>2],e,b);c=lb;g=x[114409];x[114409]=0;f:{if((g|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+196|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function Y0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;b=hh(d);bn(a+196|0,d,a+247|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2582,a+252|0,a+248|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2583,a+252|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}x[114409]=0;g=pk(g,b,c,a+180|0,a+8|0,v[a+247|0],a+196|0,a+16|0,a+12|0,64896);h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}x[114409]=0;S(2585,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114409]=0;b=Zo(2596,c,x[a+180>>2],e,b);c=lb;g=x[114409];x[114409]=0;f:{if((g|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+196|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function Iy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=89;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;x=7;a=gr(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Nb(a,0,1);Nb(a,7,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,11,1);Nb(a,12,1);Nb(a,13,1);Nb(a,14,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,19,1);Nb(a,20,1);Nb(a,21,1);Nb(a,22,1);Nb(a,23,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,27,1);Nb(a,28,1);Nb(a,29,1);Nb(a,30,1);Nb(a,31,1);Nb(a,32,1);Nb(a,33,1);Nb(a,34,1);Nb(a,35,1);Nb(a,36,1);Nb(a,37,1);Nb(a,38,1);Nb(a,39,1);Nb(a,40,1);Nb(a,41,1);Nb(a,42,1);Nb(a,43,1);Nb(a,44,1);Nb(a,45,1);Nb(a,46,1);Nb(a,47,1);Nb(a,48,1);Nb(a,103,1);Nb(a,50,1);Nb(a,87,1);Nb(a,88,1);Nb(a,100,1);Nb(a,102,1);Nb(a,104,1);if(!c){break a}d=105;e=99;break b;case 3:Nb(a,0,1);Nb(a,4,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,17,1);Nb(a,40,1);Nb(a,51,1);Nb(a,52,1);Nb(a,53,1);Nb(a,54,1);Nb(a,55,1);Nb(a,56,1);Nb(a,57,1);Nb(a,58,1);Nb(a,59,1);Nb(a,60,1);Nb(a,61,1);Nb(a,62,1);Nb(a,63,1);Nb(a,64,1);Nb(a,65,1);Nb(a,66,1);Nb(a,67,1);Nb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;f=69;case 1:Nb(a,f,1);Nb(a,e,1);Nb(a,d,1);Nb(a,w,1);Nb(a,v,1);Nb(a,u,1);m=t;l=s;k=r;j=q;i=c;h=p;c=o;g=n;break;case 2:break c;case 0:break d}}Nb(a,m,1);Nb(a,l,1);Nb(a,k,1);Nb(a,j,1);f=i;x=h;e=c;d=g}Nb(a,f,1);Nb(a,x,1)}Nb(a,e,1);Nb(a,d,1)}}function G$(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;u=hb-16|0;hb=u;x[c>>2]=a;A=d&512;while(1){if((w|0)==4){if(Cb(n)>>>0>1){C=u,D=td(n),x[C+12>>2]=D;C=c,D=sF(Le(u+12|0,1),nf(n),x[c>>2]),x[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}hb=u+16|0}else{a:{b:{switch(v[i+w|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];q=fl(g,32);p=x[c>>2];x[c>>2]=p+1;v[p|0]=q;break a;case 3:if(Yc(n)){break a}q=y[pc(n,0)|0];p=x[c>>2];x[c>>2]=p+1;v[p|0]=q;break a;case 2:if(Yc(m)|!A){break a}C=c,D=sF(td(m),nf(m),x[c>>2]),x[C>>2]=D;break a;case 4:break b;default:break a}}B=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Bg(g,64,v[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){q=q-1|0;r=r-1|0;p=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=p;continue}break}if(q){p=fl(g,48)}else{p=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((q|0)>0){v[s|0]=p;q=q-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){q=fl(g,48);p=x[c>>2];x[c>>2]=p+1;v[p|0]=q;break d}if(Yc(l)){p=-1}else{p=v[pc(l,0)|0]}q=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=x[c>>2];x[c>>2]=p+1;v[p|0]=k;s=0;t=t+1|0;if(Cb(l)>>>0<=t>>>0){p=q;break e}if(y[pc(l,t)|0]==127){p=-1;break e}p=v[pc(l,t)|0]}r=r-1|0;q=y[r|0];z=x[c>>2];x[c>>2]=z+1;v[z|0]=q;q=s+1|0;continue}}kk(B,x[c>>2])}w=w+1|0;continue}break}}function Bx(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-192|0;hb=d;a:{b:{c:{if(y[c|0]&2){if(x[b>>2]==-2147483648){e=Qj(d+40|0,1,45);b=x[b>>2];x[114409]=0;x[d+176>>2]=b;T(140,d+180|0,d+176|0,c|0);b=x[114409];x[114409]=0;d:{e:{if((b|0)!=1){x[114409]=0;T(141,a|0,e|0,d+180|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}xb(d+180|0);xb(e);break b}c=N()|0;break d}c=N()|0;xb(d+180|0)}xb(e);break a}e=x[b>>2];if((e|0)>=0){break c}e=Qj(d+40|0,1,45);b=x[b>>2];x[114409]=0;x[d+176>>2]=0-b;T(140,d+180|0,d+176|0,c|0);b=x[114409];x[114409]=0;f:{g:{if((b|0)!=1){x[114409]=0;T(141,a|0,e|0,d+180|0);a=x[114409];x[114409]=0;if((a|0)==1){break g}xb(d+180|0);xb(e);break b}c=N()|0;break f}c=N()|0;xb(d+180|0)}xb(e);break a}e=qh(d+40|0);f=x[x[e>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}x[114409]=0;T(126,d+36|0,e+f|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break l}Ob(d+36|0);x[114409]=0;P(142,e|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break l}x[114409]=0;P(127,e|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break l}x[114409]=0;P(128,d+12|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break l}x[114409]=0;T(143,d+24|0,d+12|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break k}x[114409]=0;T(144,a|0,d+24|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break j}xb(d+24|0);xb(d+12|0);ae(e);break b}c=N()|0;break h}c=N()|0;break i}c=N()|0;xb(d+24|0)}xb(d+12|0)}ae(e);break a}x[d+40>>2]=e;Is(a,d+40|0,c)}hb=d+192|0;return}Q(c|0);p()}function e1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;b=hh(d);bn(a+196|0,d,a+247|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2582,a+252|0,a+248|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2583,a+252|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}x[114409]=0;g=pk(g,b,c,a+180|0,a+8|0,v[a+247|0],a+196|0,a+16|0,a+12|0,64896);h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}x[114409]=0;S(2585,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114409]=0;b=Z(2588,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+196|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function a1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;b=hh(d);bn(a+196|0,d,a+247|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2582,a+252|0,a+248|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2583,a+252|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}x[114409]=0;g=pk(g,b,c,a+180|0,a+8|0,v[a+247|0],a+196|0,a+16|0,a+12|0,64896);h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}x[114409]=0;S(2585,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114409]=0;b=Z(2593,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}w[f>>1]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+196|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function _0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;b=hh(d);bn(a+196|0,d,a+247|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2582,a+252|0,a+248|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2583,a+252|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}x[114409]=0;g=pk(g,b,c,a+180|0,a+8|0,v[a+247|0],a+196|0,a+16|0,a+12|0,64896);h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}x[114409]=0;S(2585,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114409]=0;b=Z(2594,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+196|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function Z0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=c;x[a+252>>2]=b;b=hh(d);bn(a+196|0,d,a+247|0);d=Xb(a+184|0);c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114409]=0;g=O(2582,a+252|0,a+248|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}if(x[a+180>>2]==(Cb(d)+c|0)){g=Cb(d);c=Cb(d);x[114409]=0;P(1736,d|0,c<<1);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=Hc(d);x[114409]=0;P(1736,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=g+c}x[114409]=0;g=S(2583,a+252|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break d}x[114409]=0;g=pk(g,b,c,a+180|0,a+8|0,v[a+247|0],a+196|0,a+16|0,a+12|0,64896);h=x[114409];x[114409]=0;if((h|0)==1){break d}if(g){break c}x[114409]=0;S(2585,a+252|0)|0;g=x[114409];x[114409]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(a+196|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114409]=0;b=Z(2595,c|0,x[a+180>>2],e|0,b|0)|0;c=x[114409];x[114409]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114409]=0;Je(a+196|0,a+16|0,x[a+12>>2],e);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;b=O(2582,a+252|0,a+248|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];xb(d);xb(a+196|0);hb=a+256|0;break a}}b=N()|0;xb(d);xb(a+196|0);Q(b|0);p()}return b|0}function Xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];h=x[a+44>>2];x[e+32>>2]=h;b=x[a+48>>2];x[e+36>>2]=b;j=x[a+52>>2];x[e+40>>2]=j;m=x[a+56>>2];x[e+44>>2]=m;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];i=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){b=x[e+16>>2];k=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>21&2040)+32976|0;p=w[b+6>>1];q=w[b+4>>1];i=w[b+2>>1];f=w[b>>1];j=0;m=1;b=1;h=0;while(1){x[(h<<2)+e>>2]=(((D(v[h+k|0],i)+D(v[k+(h|-2)|0],f)|0)+D(v[k+(h|2)|0],q)|0)+D(p,v[k+(h|4)|0])<<8)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){b=(j<<2)+e|0;i=x[b>>2];n=x[a+60>>2];o=(e+28|0)+(j<<3)|0;f=x[o+4>>2];l=Yb(f,-16777216,16776704);k=x[a+64>>2];h=Yb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];p=g>>31;x[o+8>>2]=f;q=x[a+72>>2];j=i<<8;f=j;f=sqa(n,n>>31,f,f>>31);i=lb;n=f;f=sqa(k,k>>31,l,l>>31);k=n+f|0;l=lb+i|0;l=f>>>0>k>>>0?l+1|0:l;f=sqa(g,p,h,h>>31);i=f+k|0;g=lb+l|0;g=f>>>0>i>>>0?g+1|0:g;n=b;f=i+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[n>>2]=(b|0)/256;x[o+4>>2]=b-(j&q);j=1;b=m&1;m=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}m=x[e+44>>2];j=x[e+40>>2];h=x[e+32>>2];g=x[e+16>>2];i=x[e+20>>2];b=x[e+36>>2]}x[a>>2]=g;x[a+4>>2]=i;x[a+56>>2]=m;x[a+52>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=e+48|0}function _W(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=hb-48|0;hb=g;Nc(b);sr(a);a:{if(!Mf(b,g+40|0)){break a}if(!UC(g+40|0)){break a}if(!c){i=1;break a}if(!Qb(b,4)){break a}Ov(a);o=g,q=Nv(),x[o+24>>2]=q;c=g+24|0;Mv(eh(a)+28|0,c);rr(c);j=x[eh(a)+28>>2];c=oj(b);if(c&1){break a}h=c-4|0;Tc(b,h);c=te(b);c=te(b)<<8|c<<16|te(b);if(!c){break a}x[114409]=0;P(304,j|0,c|0);d=x[114409];x[114409]=0;i=1;if((d|0)==1){a=R(74984)|0;if((ib|0)==(ca(74984)|0)){Y(a|0)|0;_();i=0;break a}Q(a|0);p()}Tc(b,4);b=TC(b);k=Db(x[j>>2]);d=hb-32|0;hb=d;v[d+28|0]=y[b|0];v[d+29|0]=y[b+1|0];v[d+30|0]=y[b+2|0];v[d+31|0]=y[b+3|0];f=gr(d+12|0);h=b+h|0;x[f+12>>2]=h-4;x[f+8>>2]=b;kj(f,y[h-1|0]);b:{if(!c){break b}h=c;while(1){if(!kj(f,1)){b=1;x[d+8>>2]=1;while(1){e=kj(f,2);b=e+b|0;x[d+8>>2]=b;if((e|0)==3){continue}break}zc(d+8|0,c);b=0;e=x[d+8>>2];if(e){while(1){c=c-1|0;o=k+c|0,q=kj(f,8),v[o|0]=q;b=b+1|0;if((e|0)!=(b|0)){continue}break}}if(!c){break b}}b=kj(f,2);x[d+8>>2]=b+2;c:{if((b|0)==3){d:{if(!kj(f,1)){e=7;b=5;break d}e=y[fc(d+28|0,3)|0];b=x[d+8>>2]}l=kj(f,e);while(1){e=kj(f,3);b=e+b|0;x[d+8>>2]=b;if((e|0)==7){continue}break}break c}l=kj(f,y[fc(d+28|0,b)|0])}zc(d+8|0,c);e=0;m=x[d+8>>2];if(m){while(1){b=0;n=c+l|0;if(h>>>0>n>>>0){b=y[k+n|0]}c=c-1|0;v[k+c|0]=b;e=e+1|0;if((m|0)!=(e|0)){continue}break}}if(c){continue}break}}hb=d+32|0;b=g+8|0;nj(b,j);c=g+16|0;Jv(c,b);b=To(g+24|0,c,0);Zd(eh(a)+12|0,b);Ab(b)}hb=g+48|0;return i|0}function bga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-48|0;hb=d;e=qO(d+36|0,1<<x[b+12>>2]);if(Tg(a)){while(1){g=C[ol(a,c)>>3];pO(wc(e,c),g);c=c+1|0;if(Tg(a)>>>0>c>>>0){continue}break}}x[114409]=0;P(1275,b|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}h=d,i=bc(e),x[h+8>>2]=i;h=d,i=dc(e),x[h+32>>2]=i;b:{if(Hb(d+8|0,d+32|0)){while(1){c=x[d+8>>2];x[114409]=0;g=+ha(1276,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}pO(c,mp(g));c=d+8|0;sf(c);if(Hb(c,d+32|0)){continue}break}}x[114409]=0;P(1277,b|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;V(1278,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}if(qd(e)>>>0>3){c=1;while(1){kz(wc(e,c),2);kz(wc(e,(qd(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<qd(e)>>>1>>>0){continue}break}}x[114409]=0;P(1275,b|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}h=d,i=bc(e),x[h+32>>2]=i;h=d,i=dc(e),x[h+28>>2]=i;if(Hb(d+32|0,d+28|0)){while(1){c=x[d+32>>2];x[114409]=0;P(1279,d+8|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}f=x[d+12>>2];x[c>>2]=x[d+8>>2];x[c+4>>2]=f;f=x[d+20>>2];x[c+8>>2]=x[d+16>>2];x[c+12>>2]=f;c=d+32|0;sf(c);if(Hb(c,d+28|0)){continue}break}}x[114409]=0;P(1277,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;V(1278,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}if(Tg(a)){c=0;while(1){g=C[wc(e,c)>>3];h=ol(a,c),j=g,C[h>>3]=j;c=c+1|0;if(Tg(a)>>>0>c>>>0){continue}break}}_p(e);hb=d+48|0;return}}a=N()|0;_p(e);Q(a|0);p()}function dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=y[f+4|0];j=fc(h,d),k=i+1|0,v[j|0]=k;f=f+6|0;f=y[f|0]|y[f+1|0]<<8;j=fd(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=y[h|0]|y[h+1|0]<<8;j=fd(g,d+12|0),k=h+1|0,w[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}gA(a+484|0,b+48|0,0,c);gA(a+590|0,b+68|0,0,c);gA(a+696|0,b+88|0,5,c);d=a+806|0;x[b>>2]=y[d|0]|y[d+1|0]<<8;d=a+808|0;g=y[d|0];b:{if(v[d|0]<0){v[b+34|0]=g-127;break b}if(!(!(v[a|0]&1)|g>>>0>16)){v[b+31|0]=y[d|0]+1;break b}if(!y[d|0]|y[d|0]>16){break b}v[b+31|0]=y[d|0]+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(v[d|0]>=0){w[b+28>>1]=y[d|0]+1}d=a+810|0;if(v[d|0]<0){break c}}v[b+30|0]=y[d|0]+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[tc(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=a+813|0;if((y[c|0]|y[c+1|0]<<8)>>>0<=256){x[b+8>>2]=y[c|0]|y[c+1|0]<<8;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];c=a+820|0;w[e+12>>1]=y[c|0]|y[c+1|0]<<8;w[e+10>>1]=100;j=b,k=y[Gf(e+12|0,e+10|0)|0],v[j+20|0]=k;c=a+822|0;w[e+8>>1]=y[c|0]|y[c+1|0]<<8;w[e+6>>1]=256;j=b,k=z[Gf(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=a+824|0;ov(b,y[c|0]&127,y[c|0]>>>7|0);a=a+825|0;nv(b,y[a|0]&127,y[a|0]>>>7|0);hb=e+16|0}function p0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Lw(g);j=k+4|0;g=qw(g);zg(j,g);a:{b:{if(Yc(j)){x[114409]=0;Z(2619,l|0,a|0,c|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[114409]=0;j=O(2631,l|0,h<<24>>24)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[114409]=0;h=O(2631,l|0,48)|0;i=x[114409];x[114409]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[114409]=0;h=O(2631,l|0,h|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}i=0;x[114409]=0;kk(j,c);h=x[114409];x[114409]=0;if((h|0)==1){break b}x[114409]=0;o=S(2616,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=x[f>>2];x[114409]=0;ip((j-a<<2)+d|0,g);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=x[f>>2];break a}f:{if(!y[pc(k+4|0,h)|0]){break f}if(v[pc(k+4|0,h)|0]!=(i|0)){break f}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Cb(k+4|0)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[114409]=0;n=O(2631,l|0,n|0)|0;m=x[114409];x[114409]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=N()|0;xb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;xb(k+4|0);hb=k+16|0}function aM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=hb-16|0;hb=c;d=D(b,896)+a|0;a:{if(x[d+1075072>>2]&134218752){break a}if(!Ej(d+1074984|0)){break a}h=x[(D(b,896)+a|0)+1075640>>2];if(y[h+15|0]&2){break a}d=Ul(a,b,2,1);if((d-1&255)>>>0>249){break a}g=x[(D(d,160)+a|0)+906140>>2];if(!g){break a}f=D(b,896)+a|0;d=y[f+1075794|0];b:{if(y[f+1075796|0]==1){v[c+8|0]=64;e=y[tc(f+1075798|0,c+8|0)|0];break b}e=255;if(y[f+1075797|0]!=13){break b}v[c+8|0]=64;e=y[tc((D(b,896)+a|0)+1075799|0,c+8|0)|0]}f=e;e=c+8|0;j=a+1074312|0;Kb(e,j,2);if(Ib(e)){if(d){if(be(d)){d=y[fc(h+108|0,d-1|0)|0]}Vl(a,b,d&255,z[(D(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}mb[x[x[g>>2]+76>>2]](g,39,f,b);break a}k=x[h+4>>2];if(d){l=y[h+35|0]?k<<2:x[(D(b,896)+a|0)+1075672>>2];i=w[(D(b,896)+a|0)+1075772>>1];e=c+8|0;Kb(e,j,28);m=c,n=(Ib(e)?i<<2:i)+l|0,x[m+4>>2]=n;ce(c+4|0,0,256);e=a;if(be(d)){a=y[fc(h+108|0,d-1|0)|0]}else{a=d}Vl(e,b,a&255,z[c+4>>1])}a=y[h+35|0];i=c+8|0;Kb(i,j,101);e=(a|0)==1;a=(f|0)!=255;if(!Ib(i)){d=be(d)}if(((d?e:a)|0)!=1){break a}c:{switch(y[h+36|0]){case 1:if((f|0)!=255){oK(g,f<<1);break a}oK(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){v[c+8|0]=127;v[c+4|0]=f<<1;n=g,o=7,p=y[tc(c+8|0,c+4|0)|0],q=b,m=x[x[g>>2]+76>>2],mb[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=g,p=7,o=y[Mb(c+8|0,c+4|0)|0],n=b,m=x[x[g>>2]+76>>2],mb[m](q|0,p|0,o|0,n|0)}hb=c+16|0}function WV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;Nc(c);a:{if(!Qb(c,3)){break a}while(1){d=f+13|0;Sq(d,c);i=ed(d);h=wf(d);if(A[a+12>>2]<=y[d|0]){break a}g=Hf(a,y[d|0],b);d=y[i|0];b:{if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;break b}v[g|0]=d+1;if(y[h|0]==255){break b}v[g+2|0]=1;v[g+4|0]=y[h|0];break b}c:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;break b;case 0:break b;default:break c}}e=v[h|0];v[f+12|0]=e;h=0;d=d&127;if(d>>>0<=23){h=y[d+23328|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=y[i|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((e|0)>=0){break g}d=0-e&15;break f}v[f+8|0]=64;e=y[tc(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break e}v[g+4|0]=e;v[g+2|0]=1;break b}d=3;if((e|0)>=0){break d}d=0-e&127;break f}if(!e){break b}d=0-e|-16;if((e|0)<0){break f}d=e<<4|15;break f}if(!e){break b}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break d}d=e&15|-48;break f}d=e&15|-64;break f}d=164;if((e|0)==100){break f}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[gl(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break e}p:{switch(y[g+2|0]){case 0:case 2:break p;default:break b}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;break b}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){break b}}v[g+5|0]=e;v[g+3|0]=d}if(Qb(c,3)){continue}break}}hb=f+16|0}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];i=x[a+44>>2];x[b+32>>2]=i;m=x[a+48>>2];x[b+36>>2]=m;n=x[a+52>>2];x[b+40>>2]=n;h=x[a+56>>2];x[b+44>>2]=h;o=x[a+40>>2];p=x[a+36>>2];e=x[a+4>>2];f=e;g=x[a>>2];x[b+16>>2]=g;x[b+20>>2]=e;e=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=e;a:{if(!d){e=o>>12;k=p>>12;break a}while(1){g=x[b+16>>2];g=((((x[b+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;x[b>>2]=w[g>>1];x[b+4>>2]=w[g+2>>1];e=0;k=1;while(1){g=(e<<2)+b|0;h=x[g>>2];l=x[a+60>>2];q=(b+28|0)+(e<<3)|0;f=x[q+4>>2];j=Yb(f,-16777216,16776704);i=x[a+64>>2];r=Yb(x[q+8>>2],-16777216,16776704);e=x[a+68>>2];m=e>>31;x[q+8>>2]=f;n=x[a+72>>2];s=h<<8;f=s;f=sqa(l,l>>31,f,f>>31);h=lb;l=f;f=sqa(i,i>>31,j,j>>31);i=l+f|0;j=lb+h|0;j=f>>>0>i>>>0?j+1|0:j;f=sqa(e,m,r,r>>31);h=f+i|0;e=lb+j|0;e=f>>>0>h>>>0?e+1|0:e;l=g;f=h+8388608|0;g=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;x[l>>2]=(g|0)/256;x[q+4>>2]=g-(n&s);g=k&1;k=0;e=1;if(g){continue}break}g=x[a+32>>2];p=x[a+28>>2]+p|0;k=p>>12;x[c>>2]=x[c>>2]+D(k,x[b>>2]);o=g+o|0;e=o>>12;x[c+4>>2]=x[c+4>>2]+D(e,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+44>>2];n=x[b+40>>2];m=x[b+36>>2];i=x[b+32>>2];g=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=g;x[a+4>>2]=f;x[a+40>>2]=o;x[a+20>>2]=k;x[a+36>>2]=p;x[a+56>>2]=h;x[a+52>>2]=n;x[a+48>>2]=m;x[a+44>>2]=i;x[a+24>>2]=e;hb=b+48|0}function nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;g=hb-16|0;hb=g;j=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];i=x[a+4>>2];o=i;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=i;i=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=i;a:{if(!d){m=k>>12;i=l>>12;break a}r=b+24|0;while(1){f=(x[g+12>>2]<<1)+q|0;s=w[f-6>>1];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+r|0;t=w[b>>1];u=w[f-4>>1];v=w[b+2>>1];y=w[f-2>>1];z=w[b+4>>1];A=w[f>>1];B=w[b+6>>1];C=w[f+2>>1];E=w[b+8>>1];F=w[f+4>>1];G=w[b+10>>1];H=w[f+6>>1];I=w[b+12>>1];J=w[f+8>>1];p=w[b+14>>1];f=x[a+60>>2];b=e;h=Yb(e,-16777216,16776704);e=x[a+64>>2];n=Yb(j,-16777216,16776704);o=x[a+72>>2];m=x[a+32>>2];i=x[c>>2];e=sqa(e,e>>31,h,h>>31);j=lb;h=e;e=x[a+68>>2];e=sqa(e,e>>31,n,n>>31);n=h+e|0;h=lb+j|0;h=e>>>0>n>>>0?h+1|0:h;p=(((((D(F,G)+D(C,E)|0)+D(H,I)|0)+D(p,J)|0)/2|0)+((((D(u,v)+D(s,t)|0)+D(y,z)|0)+D(A,B)|0)/2|0)|0)/16384<<8;e=p;e=sqa(f,f>>31,e,e>>31);j=e+n|0;f=lb+h|0;f=e>>>0>j>>>0?f+1|0:f;h=i;l=x[a+28>>2]+l|0;i=l>>12;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=h+D(i,f);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(f,m);e=e-(o&p)|0;c=c+8|0;Tb(g+8|0,g);j=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];o=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=o;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=j;x[a+44>>2]=e;x[a+24>>2]=m;hb=g+16|0}function uK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=hb-80|0;hb=c;e=To(c- -64|0,Dd(c+56|0,b),0);x[114409]=0;b=S(305,e|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}x[114409]=0;b=U(1823,e|0,c+23|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}b:{c:{if(!b|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24))!=542066252){break c}b=c+27|0;if(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)){break c}b=c+31|0;x[c+16>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[114409]=0;x[c+8>>2]=1065353216;x[c+12>>2]=0;b=U(713,c+16|0,c+12|0,c+8|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}B[a+4220>>2]=B[b>>2];b=c+35|0;x[c+12>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[114409]=0;x[c+4>>2]=1065353216;x[c+8>>2]=0;b=U(713,c+12|0,c+8|0,c+4|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}B[a+4224>>2]=B[b>>2];b=c+39|0;x[c+8>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[114409]=0;x[c>>2]=1065353216;x[c+4>>2]=0;b=U(713,c+8|0,c+4|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}B[a+4228>>2]=B[b>>2];b=c+43|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0<=5){x[a+4232>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)}b=c+47|0;x[a+4236>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+4240|0]=y[c+51|0]!=0;v[a+4241|0]=y[c+52|0]!=0;v[a+4242|0]=y[c+53|0]!=0;v[a+4243|0]=y[c+54|0]!=0;v[a+4244|0]=y[c+55|0]!=0;Ts(a)}Ab(e);hb=c+80|0;return}}a=N()|0;Ab(e);Q(a|0);p()}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];i=x[a+44>>2];x[b+32>>2]=i;m=x[a+48>>2];x[b+36>>2]=m;n=x[a+52>>2];x[b+40>>2]=n;h=x[a+56>>2];x[b+44>>2]=h;o=x[a+40>>2];p=x[a+36>>2];e=x[a+4>>2];f=e;g=x[a>>2];x[b+16>>2]=g;x[b+20>>2]=e;e=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=e;a:{if(!d){e=o>>12;k=p>>12;break a}while(1){g=x[b+16>>2];g=(((x[b+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;x[b>>2]=v[g|0]<<8;x[b+4>>2]=v[g+1|0]<<8;e=0;k=1;while(1){g=(e<<2)+b|0;h=x[g>>2];l=x[a+60>>2];q=(b+28|0)+(e<<3)|0;f=x[q+4>>2];j=Yb(f,-16777216,16776704);i=x[a+64>>2];r=Yb(x[q+8>>2],-16777216,16776704);e=x[a+68>>2];m=e>>31;x[q+8>>2]=f;n=x[a+72>>2];s=h<<8;f=s;f=sqa(l,l>>31,f,f>>31);h=lb;l=f;f=sqa(i,i>>31,j,j>>31);i=l+f|0;j=lb+h|0;j=f>>>0>i>>>0?j+1|0:j;f=sqa(e,m,r,r>>31);h=f+i|0;e=lb+j|0;e=f>>>0>h>>>0?e+1|0:e;l=g;f=h+8388608|0;g=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;x[l>>2]=(g|0)/256;x[q+4>>2]=g-(n&s);g=k&1;k=0;e=1;if(g){continue}break}g=x[a+32>>2];p=x[a+28>>2]+p|0;k=p>>12;x[c>>2]=x[c>>2]+D(k,x[b>>2]);o=g+o|0;e=o>>12;x[c+4>>2]=x[c+4>>2]+D(e,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+44>>2];n=x[b+40>>2];m=x[b+36>>2];i=x[b+32>>2];g=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=g;x[a+4>>2]=f;x[a+40>>2]=o;x[a+20>>2]=k;x[a+36>>2]=p;x[a+56>>2]=h;x[a+52>>2]=n;x[a+48>>2]=m;x[a+44>>2]=i;x[a+24>>2]=e;hb=b+48|0}function A0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Wu(g);j=k+4|0;g=tw(g);zg(j,g);a:{b:{if(Yc(j)){x[114409]=0;Z(2599,l|0,a|0,c|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[114409]=0;j=O(22,l|0,h<<24>>24)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[114409]=0;h=O(22,l|0,48)|0;i=x[114409];x[114409]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[114409]=0;h=O(22,l|0,h|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}i=0;x[114409]=0;kk(j,c);h=x[114409];x[114409]=0;if((h|0)==1){break b}x[114409]=0;o=S(2590,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=x[f>>2];x[114409]=0;kk((j-a|0)+d|0,g);g=x[114409];x[114409]=0;if((g|0)==1){break e}g=x[f>>2];break a}f:{if(!y[pc(k+4|0,h)|0]){break f}if(v[pc(k+4|0,h)|0]!=(i|0)){break f}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Cb(k+4|0)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[114409]=0;n=O(22,l|0,n|0)|0;m=x[114409];x[114409]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=N()|0;xb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;xb(k+4|0);hb=k+16|0}function d5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=hb-176|0;hb=e;d=Vb(e+12|0,7480);x[114409]=0;b=d+12|0;O(122,b|0,6945)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;b=d+24|0;O(122,b|0,7310)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+36|0;O(122,b|0,6937)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+48|0;O(122,b|0,4448)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+60|0;O(122,b|0,6922)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+72|0;O(122,b|0,4514)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+84|0;O(122,b|0,2106)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+96|0;O(122,b|0,7848)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+108|0;O(122,b|0,7253)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+120|0;O(122,b|0,8039)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+132|0;O(122,b|0,1958)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;b=d+144|0;O(122,b|0,3559)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;x[e+172>>2]=13;x[e+168>>2]=d;b=x[e+172>>2];x[e>>2]=x[e+168>>2];x[e+4>>2]=b;O(2303,a|0,e|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){b=d+156|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}hb=e+176|0;return}b=d+156|0}a=N()|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=hb-16|0;hb=g;j=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];i=x[a+4>>2];o=i;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=i;i=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=i;a:{if(!d){m=k>>12;i=l>>12;break a}r=b+24|0;while(1){f=x[g+12>>2]+q|0;s=v[f-3|0];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+r|0;t=w[b>>1];u=v[f-2|0];y=w[b+2>>1];z=v[f-1|0];A=w[b+4>>1];B=v[f|0];C=w[b+6>>1];E=v[f+1|0];F=w[b+8>>1];G=v[f+2|0];H=w[b+10>>1];I=v[f+3|0];J=w[b+12>>1];K=v[f+4|0];p=w[b+14>>1];f=x[a+60>>2];b=e;h=Yb(e,-16777216,16776704);e=x[a+64>>2];n=Yb(j,-16777216,16776704);o=x[a+72>>2];m=x[a+32>>2];i=x[c>>2];e=sqa(e,e>>31,h,h>>31);j=lb;h=e;e=x[a+68>>2];e=sqa(e,e>>31,n,n>>31);n=h+e|0;h=lb+j|0;h=e>>>0>n>>>0?h+1|0:h;p=((((D(G,H)+D(E,F)|0)+D(I,J)|0)+D(p,K)<<8>>1)+(((D(u,y)+D(s,t)|0)+D(z,A)|0)+D(B,C)<<8>>1)|0)/16384<<8;e=p;e=sqa(f,f>>31,e,e>>31);j=e+n|0;f=lb+h|0;f=e>>>0>j>>>0?f+1|0:f;h=i;l=x[a+28>>2]+l|0;i=l>>12;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=h+D(i,f);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(f,m);e=e-(o&p)|0;c=c+8|0;Tb(g+8|0,g);j=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];o=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=o;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=j;x[a+44>>2]=e;x[a+24>>2]=m;hb=g+16|0}function YH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;a:{b:{c:{f=a+8|0;d:{if(Kl(f)){g=Kl(f);break d}g=Gs(f)}if(!((g|0)>(b|0)&(b|0)>=0)){b=ec(8);x[114409]=0;c=O(122,h+4|0,2427)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}if(c>>>0>=120){b=ec(8);x[114409]=0;c=O(122,h+4|0,7198)|0;a=x[114409];x[114409]=0;if((a|0)!=1){a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}a=N()|0;ic(b);break b}f=a+32|0;a=Wy(x[f>>2],65535);a=(a|0)==65535?255:a;w[h+4>>1]=a;a=x[f>>2]+D(a,896)|0;g=a+1074984|0;Qn(g,7,x[f>>2],65535,1024);c=c+1|0;v[a+1075808|0]=c;v[a+1075805|0]=c;w[a+1075792>>1]=0;Wl(g);Up(x[f>>2],g,b+1|0,0,1,1);x[a+1075680>>2]=65536;qt(x[f>>2],g,c,0,1,1,65535);j=a+1075676|0,k=Mn(az(e*128,-128,128)+128),x[j>>2]=k;j=a+1075672|0,k=Mn(az(d*256,0,256)),x[j>>2]=k;b=x[f>>2]+1074466|0;g=b;a=(z[x[f>>2]+480212>>1]<<1)+b|0;e:{if((a|0)==(b|0)){break e}c=z[h+4>>1];while(1){if((c|0)==z[b>>1]){break e}b=b+2|0;if((a|0)!=(b|0)){continue}break}b=a}f:{if((a|0)==(b|0)){break f}c=b+2|0;if((a|0)==(c|0)){break f}while(1){i=z[c>>1];if((i|0)!=z[h+4>>1]){w[b>>1]=i;b=b+2|0}c=c+2|0;if((a|0)!=(c|0)){continue}break}}a=gz(g,b);w[x[f>>2]+480212>>1]=a;hb=h+16|0;return z[h+4>>1]}a=N()|0;ic(b)}Q(a|0)}p()}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];h=x[a+44>>2];x[e+32>>2]=h;j=x[a+48>>2];x[e+36>>2]=j;l=x[a+52>>2];x[e+40>>2]=l;b=x[a+56>>2];x[e+44>>2]=b;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];i=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){g=x[e+16>>2];f=g>>>18|0;l=1;n=((((x[e+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;h=0;b=1;j=0;while(1){g=j<<1;i=w[g+n>>1];x[(j<<2)+e>>2]=i+((D(f,w[n+(g|4)>>1]-i|0)|0)/16384|0);g=b;b=0;j=1;if(g){continue}break}while(1){b=(h<<2)+e|0;i=x[b>>2];m=x[a+60>>2];o=(e+28|0)+(h<<3)|0;f=x[o+4>>2];k=Yb(f,-16777216,16776704);h=x[a+64>>2];p=Yb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];j=g>>31;x[o+8>>2]=f;n=x[a+72>>2];q=i<<8;f=q;f=sqa(m,m>>31,f,f>>31);i=lb;m=f;f=sqa(h,h>>31,k,k>>31);h=m+f|0;k=lb+i|0;k=f>>>0>h>>>0?k+1|0:k;f=sqa(g,j,p,p>>31);i=f+h|0;g=lb+k|0;g=f>>>0>i>>>0?g+1|0:g;m=b;f=i+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[m>>2]=(b|0)/256;x[o+4>>2]=b-(n&q);h=1;b=l&1;l=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}l=x[e+40>>2];j=x[e+36>>2];h=x[e+32>>2];g=x[e+16>>2];i=x[e+20>>2];b=x[e+44>>2]}x[a>>2]=g;x[a+4>>2]=i;x[a+56>>2]=b;x[a+52>>2]=l;x[a+48>>2]=j;x[a+44>>2]=h;hb=e+48|0}function zba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=E(0),l=E(0),m=0,n=0,o=E(0);i=hb-16|0;hb=i;a:{if(w[d>>1]>w[d+2>>1]){break a}if(!Lb(b)){break a}g=w[e>>1];if((g|0)<w[d>>1]){break a}h=w[d+2>>1];if((h|0)<(g|0)){break a}if((Lb(b)-1&65535)>>>0>(h-g&65535)>>>0|A[a+36>>2]>65535){break a}b:{if(!Lb(b)){break b}while(1){if(!(B[Pb(b,f)>>2]<E(0))){f=f+1|0;if(Lb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(B[c>>2]<=E(0)){break a}w[a>>1]=1;w[a+28>>1]=z[d>>1];m=a,n=dL(Lb(b)),w[m+30>>1]=n;B[a+32>>2]=F(B[c>>2]);f=a+4|0;Nl(f,(w[d+2>>1]-w[d>>1]|0)+1|0);c=bc(b);j=dc(b);m=i,n=bc(f),x[m+12>>2]=n;g=Pn(i+12|0,w[e>>1]-w[d>>1]|0);h=hb-16|0;hb=h;b=hb-32|0;hb=b;Qt(b+24|0,c,j);j=b+12|0;pl(b+16|0,j,x[b+24>>2],x[b+28>>2],Pt(g));m=b,n=Xx(c,x[b+16>>2]),x[m+12>>2]=n;m=b,n=WK(g,x[b+20>>2]),x[m+8>>2]=n;Dc(h+8|0,j,b+8|0);hb=b+32|0;hb=h+16|0;b=w[e>>1];g=w[a+28>>1];c:{if((b|0)<=(g|0)){c=b;break c}while(1){b=b-1|0;k=B[Pb(f,w[a+30>>1]+(b-g|0)|0)>>2];l=B[a+32>>2];m=Pb(f,b-w[a+28>>1]|0),o=E(k/l),B[m>>2]=o;c=w[e>>1];g=w[a+28>>1];if((g|0)>=(b|0)){break c}if((c|0)!=-32768){continue}break}}b=w[a+30>>1]+c|0;d:{if((b|0)>w[d+2>>1]){break d}while(1){c=w[a+30>>1];if(w[e>>1]>(32767-c|0)){break d}k=B[a+32>>2];l=B[Pb(f,b-(c+w[a+28>>1]|0)|0)>>2];m=Pb(f,b-w[a+28>>1]|0),o=E(l*k),B[m>>2]=o;c=w[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}Bp(a);f=1}hb=i+16|0;return f|0}function pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-32|0;hb=d;c=z[a+480190>>1];v[d+20|0]=0;fO(b,c+1|0,d+20|0);if(z[a+480192>>1]){h=br(d+20|0);c=a+484344|0;l=d,m=bc(c),x[l+16>>2]=m;l=d,m=dc(c),x[l+12>>2]=m;if(Hb(d+16|0,d+12|0)){while(1){a:{i=x[d+16>>2];if(!Ah(i)){break a}c=z[a+480188>>1];x[114409]=0;v[d|0]=0;T(1520,h|0,c|0,d|0);c=x[114409];x[114409]=0;if((c|0)!=1){b:{l=d,m=bc(i),x[l+8>>2]=m;j=0;if(!x[i+12>>2]){break a}while(1){g=0;c:{if(!z[a+480188>>1]){break c}while(1){d:{c=x[d+8>>2];x[114409]=0;c=S(546,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}e:{if(!c){break e}c=y[x[d+8>>2]+1|0];if(!c){c=y[Cc(h,g)|0]}e=z[a+480192>>1];f=c&255;if(f){k=z[a+480192>>1];l=Cc(h,g),m=c,v[l|0]=m;c=f>>>0>k>>>0;e=c?e:f;c=c?1:f}else{c=1}if(c>>>0>e>>>0){break e}while(1){f=x[(((c&65535)<<2)+a|0)+900380>>2];f:{if(!f){break f}f=z[fd(f+236|0,y[x[d+8>>2]]-1|0)>>1];if(f>>>0>z[a+480190>>1]){break f}se(d,b,f);le(d,1)}c=c+1|0;if((c&65535)>>>0<=e>>>0){continue}break}}Sj(d+8|0);g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<A[i+12>>2]){continue}break}break a}}a=N()|0;de(h);Q(a|0);p()}c=d+16|0;dm(c);if(Hb(c,d+12|0)){continue}break}}c=z[a+480190>>1];g:{if(!c){e=0;break g}e=0;g=c;while(1){se(d,b,c);if(!Ib(d)){e=He((D(c,104)+a|0)+484380|0)+e|0}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}de(h)}hb=d+32|0;return e&65535}function hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;i=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;l=e,m=Wf(b,f),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Ze(b,d),x[l+40>>2]=m;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}j=x[a+24>>2];k=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;a=x[e+8>>2];b=(((x[e+12>>2]&2147483647)<<1|a>>>31)&2147483646)<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=b+i|0;x[e+40>>2]=a;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;Hj(x[e+24>>2],(w[(a<<1|2)+f>>1]+w[f+((a&2147483646)<<1)>>1]|0)/8<<16>>16);Gj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];h=x[b+4>>2];if(h){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;Hj(b,(w[(a<<1|2)+f>>1]+w[f+((a&2147483646)<<1)>>1]|0)/8<<16>>16);Gj(x[e+24>>2],h);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Zp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,k);x[c+4>>2]=x[c+4>>2]+D(a,j);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];i=x[a+44>>2];x[e+32>>2]=i;j=x[a+48>>2];x[e+36>>2]=j;b=x[a+52>>2];x[e+40>>2]=b;l=x[a+56>>2];x[e+44>>2]=l;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];h=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){g=x[e+16>>2];f=g>>>10&4194048;h=(((x[e+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;j=0;l=1;b=1;i=0;while(1){g=v[h+i|0];x[(i<<2)+e>>2]=((D(f,v[h+(i|2)|0]-g|0)|0)/16384|0)+(g<<8);g=b;b=0;i=1;if(g){continue}break}while(1){b=(j<<2)+e|0;h=x[b>>2];m=x[a+60>>2];o=(e+28|0)+(j<<3)|0;f=x[o+4>>2];k=Yb(f,-16777216,16776704);n=x[a+64>>2];p=Yb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];i=g>>31;x[o+8>>2]=f;j=x[a+72>>2];q=h<<8;f=q;f=sqa(m,m>>31,f,f>>31);h=lb;m=f;f=sqa(n,n>>31,k,k>>31);n=m+f|0;k=lb+h|0;k=f>>>0>n>>>0?k+1|0:k;f=sqa(g,i,p,p>>31);h=f+n|0;g=lb+k|0;g=f>>>0>h>>>0?g+1|0:g;m=b;f=h+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[m>>2]=(b|0)/256;x[o+4>>2]=b-(j&q);j=1;b=l&1;l=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}l=x[e+44>>2];j=x[e+36>>2];i=x[e+32>>2];g=x[e+16>>2];h=x[e+20>>2];b=x[e+40>>2]}x[a>>2]=g;x[a+4>>2]=h;x[a+56>>2]=l;x[a+52>>2]=b;x[a+48>>2]=j;x[a+44>>2]=i;hb=e+48|0}function Vma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=Vk(a);if(d>>>0<b>>>0){j=hb-32|0;hb=j;a:{b:{i=b-d|0;c:{if(i>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/33>>>0){g=hb-16|0;hb=g;c=g+4|0;x[c>>2]=a;b=x[a+4>>2];x[c+4>>2]=b;x[c+8>>2]=b+D(i,33);d:{e=x[c+4>>2];d=x[c+8>>2];if((e|0)!=(d|0)){while(1){b=yb(a);x[114409]=0;P(780,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}e=e+33|0;x[c+4>>2]=e;if((d|0)!=(e|0)){continue}break}}Jb(c);hb=g+16|0;break c}a=N()|0;Jb(c);Q(a|0);p()}e=yb(a);f=j+12|0;b=Vk(a)+i|0;h=hb-16|0;hb=h;x[h+12>>2]=b;c=hb-16|0;hb=c;yb(a);x[c+12>>2]=130150524;x[114409]=0;x[c+8>>2]=2147483647;g=O(36,c+12|0,c+8|0)|0;d=x[114409];x[114409]=0;e:{if((d|0)!=1){hb=c+16|0;d=x[g>>2];break e}R(0)|0;zb();p()}f:{if(b>>>0<=d>>>0){b=gm(a);if(b>>>0<d>>>1>>>0){x[h+8>>2]=b<<1;d=x[$c(h+8|0,h+12|0)>>2]}hb=h+16|0;b=d;break f}Xc();p()}g=Vk(a);d=0;c=hb-16|0;hb=c;x[c+12>>2]=0;We(f+12|0,e);if(b){if(b>>>0>130150524){Be();p()}d=_d(D(b,33),1);x[c+8>>2]=b;x[c+4>>2]=d;d=x[c+4>>2];e=x[c+8>>2]}else{e=0}x[f>>2]=d;b=D(g,33)+d|0;x[f+8>>2]=b;x[f+4>>2]=b;k=hc(f),l=D(e,33)+d|0,x[k>>2]=l;hb=c+16|0;x[114409]=0;P(778,f|0,i|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(779,a|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}IS(f)}hb=j+32|0;break a}a=N()|0;IS(f);Q(a|0);p()}return}if(b>>>0<d>>>0){b=x[a>>2]+D(b,33)|0;Vk(a);HS(a,b);gm(a);Vk(a)}}function VE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){d:{c=x[a+12>>2];if(c>>>0>=d>>>0){break d}j=x[a+8>>2];if(j>>>0>=g>>>0){break d}b=2;f=y[c|0];e:{if(f<<24>>24>=0){w[j>>1]=f;b=c+1|0;break e}if(f>>>0<194){break b}if(f>>>0<=223){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[j>>1]=i&63|f<<6&1984;b=c+2|0;break e}if(f>>>0<=239){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];f:{g:{if((f|0)!=237){if((f|0)!=224){break g}if((i&224)==160){break f}break a}if((i&224)==128){break f}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[j>>1]=k&63|((i&63)<<6|f<<12);b=c+3|0;break e}if(f>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];h:{i:{switch(f-240|0){case 0:if((c+112&255)>>>0>=48){break b}break h;case 4:if((c&240)!=128){break b}break h;default:break i}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-j|0)<4){break a}b=2;k=k&63;l=i<<6;f=f&7;if((k|(l&4032|(c<<12&258048|f<<18)))>>>0>1114111){break a}b=c<<2;w[j>>1]=(i>>>4&3|(b&192|f<<8|b&60))+16320|55296;x[a+8>>2]=j+2;w[j+2>>1]=k|l&960|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;x[a+8>>2]=x[a+8>>2]+2;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function soa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=y[a+3|0];switch(b-14|0){case 0:break j;case 19:break d;case 17:break e;case 9:break f;case 8:break g;case 6:case 7:break h;case 1:break i;default:break b}}k:{l:{b=y[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}v[a+3|0]=11;break a}v[a+5|0]=239;break c}v[a+5|0]=254;break c}if(b>>>0>=16){v[a+5|0]=b|15;break c}v[a+5|0]=b|240;break c}v[c+15|0]=y[a+5|0]>>>4;v[c+14|0]=15;e=a,f=y[tc(c+15|0,c+14|0)|0]|32,v[e+5|0]=f;break c}b=y[a+5|0];if(b>>>0>=16){v[a+5|0]=b>>>4|240;break c}v[a+5|0]=b|224;break c}v[a+5|0]=((y[a+5|0]^-1)&254)>>>1;break c}v[a+5|0]=y[a+5|0]&15|128;break c}e=a,f=_k(y[a+5|0]<<1),v[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=y[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}v[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}v[a+3|0]=0;break c}u:{switch(d&15){case 0:v[a+5|0]=119;break c;case 1:v[a+5|0]=119;break c;case 2:v[a+5|0]=121;break c;case 3:break u;default:break c}}v[a+5|0]=123;break c}b=48}v[a+5|0]=d&15|b}b=y[a+3|0]}if(b>>>0>=36){v[a+3|0]=0;break a}v[a+3|0]=y[b+23664|0];if(y[a+2|0]|(b|0)!=12){break a}v[a+2|0]=1;v[a+3|0]=0;b=y[a+5|0];v[a+5|0]=0;v[a+4|0]=b}hb=c+16|0}function $8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=E(0),q=0,r=E(0);f=hb-16|0;hb=f;m=a+44|0;if(Eh(m)){j=Qd(m,0);k=Qd(m,1);h=ld(m,0);i=ld(m,1);r=B[a+4212>>2];x[f+12>>2]=d;if(d){e=x[a+4224>>2];while(1){g=x[a+4220>>2];a:{if(g>>>0>e>>>0){x[f+8>>2]=g-e;l=x[Mb(f+12|0,f+8|0)>>2];b:{if(!(r<E(1))){e=0;if(!l){break b}while(1){B[h>>2]=B[j>>2];B[i>>2]=B[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}break b}e=x[a+4224>>2];g=l+e|0;if(e>>>0>=g>>>0){break b}p=E(E(1)/E(A[a+4220>>2]));while(1){o=E(E(e>>>0)*p);B[h>>2]=o*B[j>>2];B[i>>2]=o*B[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((g|0)!=(e|0)){continue}break}}g=x[f+12>>2]-l|0;x[f+12>>2]=g;e=l+x[a+4224>>2]|0;break a}x[f+4>>2]=x[a+4216>>2]-e;n=x[Mb(f+12|0,f+4|0)>>2];c:{d:{e:{if(!(r<E(1))){e=0;if(n){break e}break d}q=x[a+4216>>2];l=x[a+4224>>2];e=q-l|0;g=e-n|0;if(e>>>0<=g>>>0){break c}p=E(E(1)/E(A[a+4220>>2]));while(1){o=E(E(e>>>0)*p);B[h>>2]=o*B[j>>2];B[i>>2]=o*B[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(g>>>0<e>>>0){continue}break}break c}while(1){x[h>>2]=0;x[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((n|0)!=(e|0)){continue}break}}e=n<<2;k=e+k|0;j=e+j|0;q=x[a+4216>>2];l=x[a+4224>>2]}g=x[f+12>>2]-n|0;x[f+12>>2]=g;e=l+n|0;e=e>>>0<q>>>0?e:0}x[a+4224>>2]=e;if(g){continue}break}}Gi(a,b,c,ld(m,0),ld(m,1),d)}hb=f+16|0}function WE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;c:{b=z[c>>1];d:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break d}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break d}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break c}if((g-x[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))>>>0>1048575){break c}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;v[j|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=2;break a}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return f|0}function $pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=hb-144|0;hb=g;x[114409]=0;k=S(464,a|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){a:{if(k){o=g+12|0;q=g+14|0;r=g+13|0;j=g+10|0;l=g+11|0;while(1){x[114409]=0;O(495,a|0,g+8|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}e=g+8|0;e=y[e|0]|y[e+1|0]<<8;b:{if(!e){break b}e=(e<<8|e>>>8)&65535;if(e>>>0>z[c+480192>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}x[114409]=0;e=O(354,e|0,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}c:{if(!y[l|0]){break c}if(v[j|0]&1){v[e+12|0]=y[e+12|0]|1}if(y[j|0]&2){v[e+12|0]=y[e+12|0]|4}if(!(y[j|0]&4)){break c}v[e+12|0]=y[e+12|0]|2}f=y[l|0];x[114409]=0;v[g+4|0]=f;v[g+7|0]=31;f=O(431,g+4|0,g+7|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break a}f=y[f|0];x[114409]=0;i=f+1&255;P(496,e|0,i|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}v[e+13|0]=y[r|0];v[e+14|0]=y[q|0];f=y[o|0];v[e+15|0]=f;v[e+16|0]=f;f=0;if(!i){break b}while(1){m=(g+8|0)+(f<<2)|0;h=m+8|0;h=y[h|0]|y[h+1|0]<<8;s=Pb(e,f),t=h<<8|h>>>8,w[s>>1]=t;h=m+10|0;h=y[h|0]|y[h+1|0]<<8;h=h<<8|h>>>8;w[g+4>>1]=d?(h&65535)+128>>>2|0:h;dg(g+4|0,64);h=y[g+4|0];s=Pb(e,f),t=h,v[s+2|0]=t;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<k>>>0){continue}break}}Ab(a);hb=g+144|0;return}}b=N()|0;Ab(a);Q(b|0);p()}function GH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0);e=(b<<2)+a|0;i=e+1068|0;l=c<<1&-4;q=i,r=Ud(a,l),x[q>>2]=r;h=e+1076|0;q=h,r=Ud(a,l),x[q>>2]=r;k=e+1084|0;e=Ud(a,c&-4);x[k>>2]=e;a:{i=x[i>>2];if(!i){break a}h=x[h>>2];if(!h|!e){break a}b:{if((c|0)<4){break b}p=c>>>2|0;m=E(c|0);j=E(E(1)/m);while(1){k=d<<2;g=+E(E(E(f<<2)*E(3.1415927410125732))*j);q=i+k|0,s=E(De(g)),B[q>>2]=s;n=d|1;o=n<<2;q=i+o|0,s=E(-E(vi(g))),B[q>>2]=s;g=+E(E(E(n|0)*E(1.5707963705062866))*j);q=h+k|0,s=E(E(De(g))*E(.5)),B[q>>2]=s;q=h+o|0,s=E(E(vi(g))*E(.5)),B[q>>2]=s;d=d+2|0;f=f+1|0;if((p|0)!=(f|0)){continue}break}if((c|0)<8){break b}d=c>>3;i=(d|0)<=1?1:d;j=E(E(1)/m);d=0;f=0;while(1){h=d|1;g=+E(E(E(h<<1)*E(3.1415927410125732))*j);q=e+(d<<2)|0,s=E(De(g)),B[q>>2]=s;q=e+(h<<2)|0,s=E(-E(vi(g))),B[q>>2]=s;d=d+2|0;f=f+1|0;if((i|0)!=(f|0)){continue}break}}f=(b<<2)+a|0;d=Ud(a,l);x[f+1092>>2]=d;if(!d){break a}if((c|0)>=2){e=c>>>1|0;g=1/+(e|0);b=0;while(1){j=E(vi((+(b|0)*1.5707963705062866+.7853981852531433)*g));q=d+(b<<2)|0,s=E(vi(+E(j*j)*1.5707963705062866)),B[q>>2]=s;b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=Ud(a,c>>2&-2);x[f+1100>>2]=b;if(!b){break a}if((c|0)>=8){d=c>>>3|0;c=36-Jl(c)|0;a=0;while(1){q=b+(a<<1)|0,r=Hl(a)>>>c<<2,w[q>>1]=r;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}gc(a,3);return 0}function lz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{h=255;b:{c:{g=a+58|0;d=b;b=y[fc(g,d)|0];if((b|0)==255){break c}if(v[fc(g,d)|0]>=0){break b}e=a+22|0;b=b&127;if(z[fd(e,b)>>1]!=65535){if((d|0)!=z[fd(e,b)>>1]){break c}}j=fd(e,b),k=d,w[j>>1]=k;j=fc(g,d),k=b,v[j|0]=k;break b}i=a+4|0;f=a+22|0;b=0;e=255;d:{while(1){if(z[fd(f,b)>>1]==65535){break d}if(!(y[fc(i,b)|0]&32)){h=v[fc(g,z[fd(f,b)>>1])|0]<0?b:h;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(h&255)==255?e:h;e=b&255;j=fc(g,z[fd(f,e)>>1]),k=255,v[j|0]=k;j=fd(f,e),k=d,w[j>>1]=k;j=fc(g,d),k=b,v[j|0]=k}b=Pk(a,d);break b}j=fd(f,b),k=d,w[j>>1]=k;j=fc(g,d),k=b,v[j|0]=k}g=b&255;if((g|0)==255){break a}b=0;if(Ij(a)){break a}e=Ui(a+314|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=AO(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;th(x[a>>2],d|32,y[fc(c,b)|0]);th(x[a>>2],d|64,y[fc(c,b|2)|0]);th(x[a>>2],d|96,y[fc(c,b|4)|0]);th(x[a>>2],d|128,y[fc(c,b|6)|0]);th(x[a>>2],d|224,y[fc(c,b|8)|0]);d=0;b=1;if(e){continue}break}th(x[a>>2],Ft(g)|192,y[fc(c,10)|0])}}function Jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-32|0;hb=f;e=x[a+12>>2];g=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];k=b;e=x[a>>2];x[f+24>>2]=e;x[f+28>>2]=b;x[f+16>>2]=h;x[f+20>>2]=g;e:{if(!d){b=i>>12;g=j>>12;break e}while(1){b=x[f+24>>2];h=((((x[f+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=(b>>>16&65520)+l|0;k=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];g=0;b=1;while(1){e=g<<1;x[(f+8|0)+(g<<2)>>2]=(((((((D(w[(e|-8)+h>>1],s)+D(w[(e|-12)+h>>1],t)|0)+D(w[(e|-4)+h>>1],r)|0)+D(w[e+h>>1],q)|0)+D(w[(e|4)+h>>1],p)|0)+D(w[(e|8)+h>>1],o)|0)+D(w[(e|12)+h>>1],n)|0)+D(w[(e|16)+h>>1],k)|0)/32768;e=b;b=0;g=1;if(e){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;g=j>>12;x[c>>2]=x[c>>2]+D(g,x[f+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+12>>2]);c=c+8|0;Tb(f+24|0,f+16|0);d=d-1|0;if(d){continue}break}e=x[f+24>>2];k=x[f+28>>2]}x[a>>2]=e;x[a+4>>2]=k;x[a+40>>2]=i;x[a+20>>2]=g;x[a+36>>2]=j;x[a+24>>2]=b;hb=f+32|0}function BW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){zd(b,32);c=d+8|0;Bh(c,1,a+4|0);e=d+20|0;Kc(e,c);x[114409]=0;O(350,b+43|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}xb(d+20|0);w[b+30>>1]=y[a+19|0]<<2;dg(b+30|0,256);w[b+32>>1]=y[a+17|0];dg(b+32|0,64);c=a+47|0;w[b+28>>1]=(y[c|0]&127)<<2;dg(b+28|0,256);if(v[c|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=a+18|0;if(y[c|0]&16){w[b+34>>1]=z[b+34>>1]|2}if(y[c|0]&32){w[b+34>>1]=z[b+34>>1]|8}if(y[c|0]&64){w[b+34>>1]=z[b+34>>1]|4}if(v[c|0]<0){w[b+34>>1]=z[b+34>>1]|16}c=a+60|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;c=a+48|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+52|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+56|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a- -64|0;x[b+12>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+68|0;x[b+16>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);Nn(b);v[b+38|0]=y[(y[a+79|0]&7)+32960|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=512;e=a+46|0;b:{if(y[e|0]!=64){c=16384;if(y[e|0]!=128){break b}}w[b+34>>1]=z[b+34>>1]|c}a=a+72|0;c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}hb=d+32|0;return c|0}a=N()|0;xb(d+20|0);Q(a|0);p()}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;i=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;l=e,m=Wf(b,f),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Ze(b,d),x[l+40>>2]=m;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}j=x[a+24>>2];k=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;a=x[e+8>>2];b=((x[e+12>>2]&2147483647)<<1|a>>>31)&-2;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=b+i|0;x[e+40>>2]=a;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;Hj(x[e+24>>2],v[(a|1)+f|0]+v[f+(a&-2)|0]<<5);Gj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];h=x[b+4>>2];if(h){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;Hj(b,v[(a|1)+f|0]+v[f+(a&-2)|0]<<5);Gj(x[e+24>>2],h);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Zp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,k);x[c+4>>2]=x[c+4>>2]+D(a,j);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function Kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-16|0;hb=h;x[h+12>>2]=d;a:{if(y[a+8|0]){d=a+12|0;n=h,o=xc(d)-c|0,x[n+8>>2]=o;f=h+8|0;a=x[Mb(f,h+12|0)>>2];n=h,o=bc(d),x[n+8>>2]=o;f=Le(f,c);n=h,o=bc(d),x[n>>2]=o;n=h,o=Le(h,c),x[n+4>>2]=o;AR(f,Le(h+4|0,a),b);break a}f=hb-32|0;hb=f;x[f+28>>2]=d;b:{c:{if(y[a+24|0]){if(!d){break b}k=a+40|0;break c}l=mb[x[x[a>>2]+44>>2]](a,b,c,d)|0;break b}while(1){g=0;i=hb-16|0;hb=i;j=a+40|0;e=a+232|0;m=c-(c&4095)|0;d:{e:{while(1){d=x[ef(e,g)>>2];if(y[Ui(j,d)+8|0]){if(x[Ui(j,d)>>2]==(m|0)){break e}}g=g+1|0;if((g|0)!=16){continue}break}d=x[ef(e,15)>>2];qq(e,e+60|0,e- -64|0);n=ef(e,0),o=d,x[n>>2]=o;d=x[ef(e,0)>>2];e=Ui(j,d);x[e>>2]=m;kA(i+8|0,a,d);n=e,o=mb[x[x[a>>2]+44>>2]](a,x[i+8>>2],m,4096)|0,x[n+4>>2]=o;v[e+8|0]=1;break d}j=x[ef(e,g)>>2];g=g<<2;qq(e,g+e|0,(e+g|0)+4|0);n=ef(e,0),o=j,x[n>>2]=o}hb=i+16|0;g=c-x[Ui(k,d)>>2]|0;x[f+12>>2]=4096-g;n=f,o=x[Mb(f+12|0,f+28|0)>>2],x[n+24>>2]=o;if(g>>>0<A[Ui(k,d)+4>>2]){e=x[Ui(k,d)+4>>2]-g|0}else{e=0}x[f+20>>2]=e;e=x[Mb(f+24|0,f+20|0)>>2];kA(f+12|0,a,d);i=x[f+12>>2];kA(f+4|0,a,d);ue(g+i|0,e+(g+x[f+4>>2]|0)|0,b);d=x[f+28>>2];x[f+28>>2]=d-e;l=e+l|0;if(e>>>0<A[f+24>>2]){break b}c=c+e|0;b=b+e|0;if((d|0)!=(e|0)){continue}break}}hb=f+32|0;a=l}hb=h+16|0;return a|0}function jg(a,b,c,d){var e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;h=Bq(a);g=x[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((e-D(a,12)&255)<<1)+26512>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(!(!(y[a+480208|0]&16)&x[a+480180>>2]!=64)){if(!(!$b(a+1074312|0,7)&x[a+480180>>2]!=64)){a=((e&255)>>>0)/12|0;b=sqa(x[((a<<2)+e<<6&960)+30400>>2]<<a,0,d,0);a=lb;c=a>>>21|0;e=id((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;e=z[((e-D(a,12)&255)<<1)+26512>>1]<<5>>>a|0;break a}a=((e&255)>>>0)/12|0;zc(f+12|0,-1>>>a|0);e=id(vqa(sqa(z[((e-D(a,12)&255)<<1)+26512>>1],0,267616,0),lb,x[f+12>>2]<<a,0),lb);break a}if(g&20){d=e>>>0>12;if(x[a+480180>>2]==16){b=c<<4}else{b=$b(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-D(a,12)<<3&248)|0;x[f+8>>2]=d+8;ce(f+8|0,0,103);c=b;b=b>>31;c=(c^b)-b&15;b=d+(b|1)|0;b=(b|0)<=-8?-8:b;e=D(c,z[((((b|0)>=95?95:b)<<1)+26992|0)+16>>1])+D(z[(x[f+8>>2]<<1)+26992>>1],16-c|0)<<1>>>a|0;break a}a=c&255;if(!(!(e>>>0<24|a>>>0>15)&e>>>0<108)){b=D(a>>>4|0,12);a=((e&255)>>>0)/12|0;e=z[(b+(e-D(a,12)&255)<<1)+26112>>1]<<5>>>a|0;break a}e=z[(b<<1)+25886>>1]<<2}hb=f+16|0;return e}function Kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-32|0;hb=f;h=x[a+12>>2];e=h;a:{b:{c:{g=x[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|(e|0)==-1){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];k=b;h=x[a>>2];x[f+24>>2]=h;x[f+28>>2]=b;x[f+16>>2]=g;x[f+20>>2]=e;e:{if(!d){b=i>>12;g=j>>12;break e}while(1){b=x[f+24>>2];e=(((x[f+28>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=(b>>>16&65520)+l|0;k=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];b=0;g=1;while(1){x[(f+8|0)+(b<<2)>>2]=(((((((D(v[(b|-4)+e|0],s)+D(v[(b|-6)+e|0],t)|0)+D(v[(b|-2)+e|0],r)|0)+D(v[b+e|0],q)|0)+D(v[(b|2)+e|0],p)|0)+D(v[(b|4)+e|0],o)|0)+D(v[(b|6)+e|0],n)|0)+D(v[(b|8)+e|0],k)<<8)/32768;h=g;g=0;b=1;if(h){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;g=j>>12;x[c>>2]=x[c>>2]+D(g,x[f+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+12>>2]);c=c+8|0;Tb(f+24|0,f+16|0);d=d-1|0;if(d){continue}break}h=x[f+24>>2];k=x[f+28>>2]}x[a>>2]=h;x[a+4>>2]=k;x[a+40>>2]=i;x[a+20>>2]=g;x[a+36>>2]=j;x[a+24>>2]=b;hb=f+32|0}function B$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-480|0;hb=a;g=a+476|0;Fc(g,d);x[114409]=0;m=S(2606,g|0)|0;g=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Cb(f)){g=x[yj(f,0)>>2];x[114409]=0;h=O(2631,m|0,45)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}n=(g|0)==(h|0)}j=Xb(a+452|0);h=Dg(a+440|0);i=Dg(a+428|0);x[114409]=0;ja(2660,c|0,n|0,a+476|0,a+472|0,a+468|0,a+464|0,j|0,h|0,i|0,a+424|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}x[a+4>>2]=2580;k=Sd(a+8|0,0,a+4|0);c=a+16|0;h:{if((Cb(f)|0)>x[a+424>>2]){g=Cb(f);l=x[a+424>>2];g=(((Cb(i)+(g-l<<1)|0)+Cb(h)|0)+x[a+424>>2]|0)+1|0;break h}g=((Cb(i)+Cb(h)|0)+x[a+424>>2]|0)+2|0}if(g>>>0<101){break e}Ce(k,xd(g<<2));c=x[k>>2];if(c){break e}x[114409]=0;X(2581);b=x[114409];x[114409]=0;if((b|0)==1){break d}p()}f=N()|0;break b}f=N()|0;break b}f=N()|0;break c}g=x[d+4>>2];l=Rb(f);o=Rb(f);f=Cb(f);x[114409]=0;oa(2661,c|0,a+4|0,a|0,g|0,l|0,(f<<2)+o|0,m|0,n|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,h|0,i|0,x[a+424>>2]);f=x[114409];x[114409]=0;if((f|0)!=1){x[114409]=0;b=ga(2635,b|0,c|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break a}}}f=N()|0;Lc(k)}Pc(i);Pc(h);xb(j)}Ob(a+476|0);Q(f|0);p()}Lc(k);Pc(i);Pc(h);xb(j);Ob(a+476|0);hb=a+480|0;return b|0}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=hb-16|0;hb=g;f=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];h=x[a+44>>2];p=x[a+16>>2];j=x[a+4>>2];l=j;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=j;j=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=j;a:{if(!d){b=f;break a}q=b+24|0;while(1){e=(x[g+12>>2]<<1)+p|0;r=w[e-6>>1];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+q|0;s=w[b>>1];t=w[e-4>>1];u=w[b+2>>1];v=w[e-2>>1];y=w[b+4>>1];z=w[e>>1];A=w[b+6>>1];B=w[e+2>>1];C=w[b+8>>1];E=w[e+4>>1];F=w[b+10>>1];G=w[e+6>>1];H=w[b+12>>1];I=w[e+8>>1];m=w[b+14>>1];e=x[a+60>>2];b=h;i=Yb(b,-16777216,16776704);h=x[a+64>>2];k=Yb(f,-16777216,16776704);l=x[a+72>>2];j=x[c>>2];f=sqa(h,h>>31,i,i>>31);h=lb;i=f;f=x[a+68>>2];f=sqa(f,f>>31,k,k>>31);k=i+f|0;i=lb+h|0;i=f>>>0>k>>>0?i+1|0:i;m=(((((D(E,F)+D(B,C)|0)+D(G,H)|0)+D(m,I)|0)/2|0)+((((D(t,u)+D(r,s)|0)+D(v,y)|0)+D(z,A)|0)/2|0)|0)/16384<<8;f=m;f=sqa(e,e>>31,f,f>>31);h=f+k|0;e=lb+i|0;e=f>>>0>h>>>0?e+1|0:e;f=h+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=D(e,o)+j;x[c+4>>2]=x[c+4>>2]+D(e,n);h=f-(l&m)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];l=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=l;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function Qpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;ij(a);j=x[b+4>>2];g=yb(a);d=Bb(h+8|0,c);e=Bb(h+4|0,x[a>>2]);f=Bb(h,x[b+4>>2]);i=x[d>>2];f=x[f>>2];d=hb+-64|0;hb=d;x[d+56>>2]=x[e>>2];x[d+60>>2]=i;x[d+52>>2]=f;x[d+48>>2]=f;f=Oc(d+20|0,g,d+48|0,d+52|0);x[d+16>>2]=x[f+8>>2];e=x[f+4>>2];x[d+8>>2]=x[f>>2];x[d+12>>2]=e;Od(d+32|0,d+8|0);a:{while(1){b:{x[114409]=0;f=O(521,d+60|0,d+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!f){break a}f=LU(d+52|0);e=Wj(d+60|0);x[114409]=0;T(507,g|0,f|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}Ch(d+60|0);Ch(d+52|0);continue}break}a=N()|0;KU(d+32|0);Q(a|0);p()}g=d+32|0;Nd(g);f=x[d+52>>2];KU(g);hb=d- -64|0;x[h+12>>2]=f;x[b+4>>2]=x[h+12>>2];g=yb(a);f=x[a+4>>2];d=hb-48|0;hb=d;e=x[b+8>>2];x[d+44>>2]=e;x[d+40>>2]=e;e=Oc(d+12|0,g,d+40|0,d+44|0);x[d+8>>2]=x[e+8>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;Od(d+24|0,d);c:{d:{if((c|0)!=(f|0)){e=x[d+44>>2];while(1){x[114409]=0;T(507,g|0,e|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}e=x[d+44>>2]+2|0;x[d+44>>2]=e;c=c+2|0;if((f|0)!=(c|0)){continue}break}}g=d+24|0;Nd(g);c=x[d+44>>2];JU(g);hb=d+48|0;break c}a=N()|0;JU(d+24|0);Q(a|0);p()}x[b+8>>2]=c;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Do(a,rc(a));hb=h+16|0;return j|0}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;r=x[a+16>>2];i=x[a+44>>2];x[b+32>>2]=i;k=x[a+48>>2];x[b+36>>2]=k;m=x[a+52>>2];x[b+40>>2]=m;h=x[a+56>>2];x[b+44>>2]=h;s=x[a+24>>2];t=x[a+20>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;if(d){while(1){f=x[b+16>>2];f=((((x[b+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+r|0;x[b>>2]=w[f>>1];x[b+4>>2]=w[f+2>>1];i=0;k=1;while(1){f=(i<<2)+b|0;h=x[f>>2];l=x[a+60>>2];o=(b+28|0)+(i<<3)|0;e=x[o+4>>2];j=Yb(e,-16777216,16776704);n=x[a+64>>2];p=Yb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];i=g>>31;x[o+8>>2]=e;m=x[a+72>>2];q=h<<8;e=q;e=sqa(l,l>>31,e,e>>31);h=lb;l=e;e=sqa(n,n>>31,j,j>>31);n=l+e|0;j=lb+h|0;j=e>>>0>n>>>0?j+1|0:j;e=sqa(g,i,p,p>>31);h=e+n|0;g=lb+j|0;g=e>>>0>h>>>0?g+1|0:g;l=f;e=h+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[l>>2]=(f|0)/256;x[o+4>>2]=f-(m&q);f=k&1;k=0;i=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],s);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+44>>2];m=x[b+40>>2];k=x[b+36>>2];e=x[b+20>>2];i=x[b+32>>2];f=x[b+16>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+56>>2]=h;x[a+52>>2]=m;x[a+48>>2]=k;x[a+44>>2]=i;hb=b+48|0}function MH(a){var b=0,c=0,d=0;ie(a,x[a+20>>2]);if(x[a+24>>2]>0){while(1){ie(a,x[x[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<x[a+24>>2]){continue}break}}ie(a,x[a+28>>2]);if(!(!x[a+396>>2]|x[a+264>>2]<=0)){while(1){c=x[a+396>>2]+D(d,24)|0;b=x[c+16>>2];if(b){if(x[(x[a+124>>2]+D(y[c+13|0],2096)|0)+4>>2]>0){b=0;while(1){ie(a,x[x[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<x[(x[a+124>>2]+D(y[c+13|0],2096)|0)+4>>2]){continue}break}b=x[c+16>>2]}ie(a,b)}ie(a,x[c+20>>2]);d=d+1|0;if((d|0)<x[a+264>>2]){continue}break}}b=x[a+124>>2];if(b){if(x[a+120>>2]>0){c=0;while(1){b=x[a+124>>2]+D(c,2096)|0;ie(a,x[b+8>>2]);ie(a,x[b+28>>2]);ie(a,x[b+32>>2]);ie(a,x[b+2084>>2]);b=x[b+2088>>2];ie(a,b?b-4|0:0);c=c+1|0;if((c|0)<x[a+120>>2]){continue}break}b=x[a+124>>2]}ie(a,b)}ie(a,x[a+260>>2]);ie(a,x[a+396>>2]);b=x[a+404>>2];if(b){if(x[a+400>>2]>0){b=0;while(1){ie(a,x[(x[a+404>>2]+D(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<x[a+400>>2]){continue}break}b=x[a+404>>2]}ie(a,b)}c=1;a:{if(x[a+4>>2]<=0){break a}b=0;while(1){d=(b<<2)+a|0;ie(a,x[d+800>>2]);ie(a,x[d+928>>2]);ie(a,x[d+996>>2]);if(b>>>0>14){break a}b=b+1|0;if((b|0)<x[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;ie(a,x[b+1068>>2]);ie(a,x[b+1076>>2]);ie(a,x[b+1084>>2]);ie(a,x[b+1092>>2]);ie(a,x[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function F$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-176|0;hb=a;g=a+172|0;Fc(g,d);x[114409]=0;m=S(21,g|0)|0;g=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Cb(f)){g=y[pc(f,0)|0];x[114409]=0;h=O(22,m|0,45)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}n=(g|0)==(h&255)}j=Xb(a+152|0);h=Xb(a+140|0);i=Xb(a+128|0);x[114409]=0;ja(2658,c|0,n|0,a+172|0,a+168|0,a+167|0,a+166|0,j|0,h|0,i|0,a+124|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}x[a+4>>2]=2580;k=Sd(a+8|0,0,a+4|0);c=a+16|0;h:{if((Cb(f)|0)>x[a+124>>2]){g=Cb(f);l=x[a+124>>2];g=(((Cb(i)+(g-l<<1)|0)+Cb(h)|0)+x[a+124>>2]|0)+1|0;break h}g=((Cb(i)+Cb(h)|0)+x[a+124>>2]|0)+2|0}if(g>>>0<101){break e}Ce(k,xd(g));c=x[k>>2];if(c){break e}x[114409]=0;X(2581);b=x[114409];x[114409]=0;if((b|0)==1){break d}p()}f=N()|0;break b}f=N()|0;break b}f=N()|0;break c}g=x[d+4>>2];l=Rb(f);o=Rb(f);f=Cb(f);x[114409]=0;oa(2659,c|0,a+4|0,a|0,g|0,l|0,f+o|0,m|0,n|0,a+168|0,v[a+167|0],v[a+166|0],j|0,h|0,i|0,x[a+124>>2]);f=x[114409];x[114409]=0;if((f|0)!=1){x[114409]=0;b=ga(17,b|0,c|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break a}}}f=N()|0;Lc(k)}xb(i);xb(h);xb(j)}Ob(a+172|0);Q(f|0);p()}Lc(k);xb(i);xb(h);xb(j);Ob(a+172|0);hb=a+176|0;return b|0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;r=x[a+16>>2];i=x[a+44>>2];x[b+32>>2]=i;k=x[a+48>>2];x[b+36>>2]=k;m=x[a+52>>2];x[b+40>>2]=m;h=x[a+56>>2];x[b+44>>2]=h;s=x[a+24>>2];t=x[a+20>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;if(d){while(1){f=x[b+16>>2];f=(((x[b+20>>2]&2147483647)<<1|f>>>31)&-2)+r|0;x[b>>2]=v[f|0]<<8;x[b+4>>2]=v[f+1|0]<<8;i=0;k=1;while(1){f=(i<<2)+b|0;h=x[f>>2];l=x[a+60>>2];o=(b+28|0)+(i<<3)|0;e=x[o+4>>2];j=Yb(e,-16777216,16776704);n=x[a+64>>2];p=Yb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];i=g>>31;x[o+8>>2]=e;m=x[a+72>>2];q=h<<8;e=q;e=sqa(l,l>>31,e,e>>31);h=lb;l=e;e=sqa(n,n>>31,j,j>>31);n=l+e|0;j=lb+h|0;j=e>>>0>n>>>0?j+1|0:j;e=sqa(g,i,p,p>>31);h=e+n|0;g=lb+j|0;g=e>>>0>h>>>0?g+1|0:g;l=f;e=h+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[l>>2]=(f|0)/256;x[o+4>>2]=f-(m&q);f=k&1;k=0;i=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],s);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+44>>2];m=x[b+40>>2];k=x[b+36>>2];e=x[b+20>>2];i=x[b+32>>2];f=x[b+16>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+56>>2]=h;x[a+52>>2]=m;x[a+48>>2]=k;x[a+44>>2]=i;hb=b+48|0}function sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;g=hb-16|0;hb=g;f=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];h=x[a+44>>2];p=x[a+16>>2];j=x[a+4>>2];l=j;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=j;j=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=j;a:{if(!d){b=f;break a}q=b+24|0;while(1){e=x[g+12>>2]+p|0;r=v[e-3|0];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+q|0;s=w[b>>1];t=v[e-2|0];u=w[b+2>>1];y=v[e-1|0];z=w[b+4>>1];A=v[e|0];B=w[b+6>>1];C=v[e+1|0];E=w[b+8>>1];F=v[e+2|0];G=w[b+10>>1];H=v[e+3|0];I=w[b+12>>1];J=v[e+4|0];m=w[b+14>>1];e=x[a+60>>2];b=h;i=Yb(b,-16777216,16776704);h=x[a+64>>2];k=Yb(f,-16777216,16776704);l=x[a+72>>2];j=x[c>>2];f=sqa(h,h>>31,i,i>>31);h=lb;i=f;f=x[a+68>>2];f=sqa(f,f>>31,k,k>>31);k=i+f|0;i=lb+h|0;i=f>>>0>k>>>0?i+1|0:i;m=((((D(F,G)+D(C,E)|0)+D(H,I)|0)+D(m,J)<<8>>1)+(((D(t,u)+D(r,s)|0)+D(y,z)|0)+D(A,B)<<8>>1)|0)/16384<<8;f=m;f=sqa(e,e>>31,f,f>>31);h=f+k|0;e=lb+i|0;e=f>>>0>h>>>0?e+1|0:e;f=h+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=D(e,o)+j;x[c+4>>2]=x[c+4>>2]+D(e,n);h=f-(l&m)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];l=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=l;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function K$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-448|0;hb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=2638;h=Sd(a+24|0,a+32|0,a+20|0);x[114409]=0;Fc(a+16|0,e);b=x[114409];x[114409]=0;a:{b:{c:{d:{if((b|0)!=1){x[114409]=0;i=S(2606,a+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}v[a+15|0]=0;b=x[e+4>>2];x[114409]=0;b=pa(2650,a+444|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}if(!b){break c}b=hb-16|0;hb=b;e:{if(we(g)){c=x[g>>2];x[b+12>>2]=0;wg(c,b+12|0);ee(g,0);break e}x[b+8>>2]=0;wg(g,b+8|0);Ie(g,0)}hb=b+16|0;if(!y[a+15|0]){break d}x[114409]=0;b=O(2631,i|0,45)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(113,g|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break d}break b}c=N()|0;break a}x[114409]=0;b=O(2631,i|0,48)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}c=x[h>>2];d=x[a+20>>2];e=d-4|0;while(1){if(!((b|0)!=x[c>>2]|c>>>0>=e>>>0)){c=c+4|0;continue}break}x[114409]=0;U(2656,g|0,c|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break c}break b}x[114409]=0;b=O(2611,a+444|0,a+440|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}if(b){x[f>>2]=x[f>>2]|2}b=x[a+444>>2];Ob(a+16|0);Lc(h);hb=a+448|0;return b|0}c=N()|0;Ob(a+16|0)}Lc(h);Q(c|0);p()}function V9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=hb+-64|0;hb=b;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(1882,a+8|0,d+12|0,d+11|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){hb=d+16|0;break a}R(0)|0;zb();p()}x[114409]=0;d=a;P(1877,a|0,11);a=x[114409];x[114409]=0;b:{if((a|0)!=1){a=78864;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){g=Vg(44);if(g){x[114409]=0;c=O(122,b+36|0,x[a+4>>2])|0;e=x[114409];x[114409]=0;if((e|0)==1){break l}h=x[a>>2];x[114409]=0;P(1878,b+48|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break k}x[114409]=0;e=O(122,b+12|0,x[a+8>>2])|0;f=x[114409];x[114409]=0;if((f|0)==1){break j}x[114409]=0;P(1878,b+24|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break i}x[114409]=0;h=aa(1879,g|0,h|0,1,b+48|0,b+24|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}Gb(b+24|0);xb(e);Gb(b+48|0);xb(c);x[114409]=0;x[b+60>>2]=h;P(1880,d|0,b+60|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}c=x[b+60>>2];v[c+40|0]=y[a+20|0];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;if((a|0)!=79128){continue}break}hb=b- -64|0;return d|0}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;Gb(b+24|0)}xb(e)}Gb(b+48|0)}xb(c)}_b(g);break b}a=N()|0;break b}a=N()|0}iK(d);Q(a|0);p()}function SE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){c:{i=x[a+12>>2];if(i>>>0>=d>>>0){break c}l=x[a+8>>2];if(l>>>0>=g>>>0){break c}f=v[i|0];c=f&255;d:{if((f|0)>=0){if(c>>>0<=1114111){f=1;break d}b=2;break a}b=2;if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-i|0)<2){break b}j=y[i+1|0];if((j&192)!=128){break a}f=2;c=j&63|c<<6&1984;break d}if(f>>>0<=4294967279){if((d-i|0)<3){break b}k=y[i+2|0];j=y[i+1|0];e:{f:{if((c|0)!=237){if((c|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}f=3;c=k&63|(c<<12&61440|(j&63)<<6);break d}if(f>>>0>4294967284){break a}if((d-i|0)<4){break b}k=y[i+3|0];m=y[i+2|0];j=y[i+1|0];g:{h:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break g}break a;case 4:if((j&240)==128){break g}break a;default:break h}}if((j&192)!=128){break a}}if((m&192)!=128|(k&192)!=128){break a}f=4;c=k&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}x[l>>2]=c;x[a+12>>2]=f+i;x[a+8>>2]=x[a+8>>2]+4;continue}break}b=d>>>0>i>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function Nk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;j=Yp(a);g=Jj(j);d=g;c=Ac(a);a:{if(d>>>0>c>>>0){f=hb-32|0;hb=f;b:{c=d-c|0;c:{if(c>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/12>>>0){h=hb-16|0;hb=h;d:{d=xl(h+4|0,a,c);c=x[d+4>>2];k=x[d+8>>2];if((c|0)!=(k|0)){while(1){i=yb(a);x[114409]=0;P(1302,i|0,c|0);i=x[114409];x[114409]=0;if((i|0)==1){break d}c=c+12|0;x[d+4>>2]=c;if((c|0)!=(k|0)){continue}break}}Jb(d);hb=h+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}d=yb(a);d=ok(f+12|0,an(a,Ac(a)+c|0),Ac(a),d);x[114409]=0;P(1299,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1300,a|0,d|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}_N(d)}hb=f+32|0;break a}a=N()|0;_N(d);Q(a|0);p()}if(d>>>0<c>>>0){d=x[a>>2]+D(d,12)|0;Ac(a);$N(a,d);Vt(a)}}e:{if(!b){break e}d=a+12|0;Bt(d);if(sd(d)>>>0>1023){break e}x[e+12>>2]=0;c=x[a+24>>2]+484344|0;l=e,m=bc(c),x[l+8>>2]=m;l=e,m=dc(c),x[l+4>>2]=m;if(Hb(e+8|0,e+4|0)){while(1){c=e+8|0;x[e>>2]=x[x[c>>2]+12>>2];l=e,m=x[$c(e+12|0,e)>>2],x[l+12>>2]=m;dm(c);if(Hb(c,e+4|0)){continue}break}c=x[e+12>>2]}else{c=0}gO(d,c)}if(g){d=0;while(1){c=ud(a,d);f=iz(a,z[vc(j,d)>>1]);f:{if(b){v[e+12|0]=0;fO(c,f,e+12|0);break f}Sz(c,f,0)}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=e+16|0}function coa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(!Qb(b,9)){break a}h=a+484344|0;i=a+480280|0;while(1){eo(b,c+28|0);d=Kf(b);b:{e=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}if(Qb(b,d)){break b}}rg(b,8);break a}Ad(c+12|0,b,d);d=i;d:{e:{f:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))==1481001027){while(1){x[114409]=0;e=S(413,c+12|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}v[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}if(y[c+28|0]!=70){break e}e=y[c+29|0];g=(e|0)==88;g:{if(!g){if((e-48&255)>>>0>9){break e}d=v[c+30|0];if((d|0)>47){break g}break e}d=v[c+30|0];if((d|0)<48){break e}}if(d>>>0>57){break e}f=v[c+31|0];if((f|0)<48|(f|0)>57){break e}d=((f&255)+(g?-528:D(e,100)-5328|0)|0)+D(d&255,10)&65535;if(d>>>0>249){break d}x[114409]=0;P(676,c+12|0,(D(d,160)+a|0)+906300|0);d=x[114409];x[114409]=0;if((d|0)!=1){break d}}a=N()|0;Ab(c+12|0);Q(a|0);p()}if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))!=1430540109){break d}x[a+1074308>>2]=0;j=1}Ab(c+12|0);if(Qb(b,9)){continue}break}}hb=c+32|0;return j|0}function FR(a,b){var c=0,d=0;a:{b:{c:{d:{if(Wd(a,12596)){break d}if(Wd(a,13268)){break d}if(Wd(a,9448)){break d}if(Wd(a,9535)){break d}if(!Wd(a,9953)){break c}}w[b+10>>1]=4;x[b>>2]=7880;break b}e:{f:{if(Wd(a,13263)){break f}if(Wd(a,9453)){break f}if(!Wd(a,12586)){break e}}v[b+15|0]=1;v[b+12|0]=1;w[b+10>>1]=4;x[b>>2]=4610;return 1}g:{if(!Wd(a,9988)){if(!Wd(a,9993)){break g}}w[b+10>>1]=8;x[b>>2]=4374;break b}h:{if(!Wd(a,11202)){if(!Wd(a,11207)){break h}}x[b>>2]=12972;w[b+10>>1]=v[a+2|0]-48;break b}i:{if(!Wd(a,23928)){if(!Wd(a,23933)){break i}}x[b+4>>2]=1;x[b>>2]=12778;w[b+10>>1]=y[a|0]==56?8:4;return 1}if(!(dd(a,11565,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=4728;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break b}j:{if(dd(a,9473,3)){if(dd(a,9592,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=4473;w[b+10>>1]=v[a+3|0]-48;return 1}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!dd(a+1|0,9600,3)){v[b+14|0]=1;x[b>>2]=4776;w[b+10>>1]=v[a|0]-48;return 1}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=4776;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;return 1}if(dd(a,9295,3)|(y[a+3|0]-52&255)>>>0>5){break a}x[b>>2]=4637;w[b+10>>1]=v[a+3|0]-48}d=1}return d}function eG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{c=x[a+4>>2];f:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break f}c=_c(a)}switch(c-43|0){case 0:case 2:break e;default:break d}}f=(c|0)==45;g=!b;c=x[a+4>>2];g:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break g}c=_c(a)}b=c-58|0;if(g|b>>>0>4294967285){break c}if(x[a+116>>2]<0){break b}x[a+4>>2]=x[a+4>>2]-1;break b}b=c-58|0}if(b>>>0<4294967286){break b}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=_c(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}i:{if(b>>>0>=10){break i}while(1){b=sqa(e,d,10,0);d=b+c|0;c=lb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];j:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break j}c=_c(a)}b=c-48|0;if(b>>>0>9){break i}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];k:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break k}b=_c(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break a}d=-2147483648;if(x[a+116>>2]<0){break a}x[a+4>>2]=x[a+4>>2]-1;lb=-2147483648;return 0}lb=d;return e}function $J(a){var b=0,c=E(0),d=0,e=0,f=E(0),g=0,h=0,i=E(0),k=0,m=0,n=E(0);d=hb-16|0;hb=d;b=cf(x[a+16>>2]);m=a,n=pe(E(10),E(E(E(B[a+4208>>2]*E(120))+E(-60))*E(.05000000074505806))),B[m+4232>>2]=n;i=E(E(b>>>0)*E(.0010000000474974513));m=a,n=pe(E(10),E(E(-1)/E(E(E(B[a+4212>>2]*E(499.989990234375))+E(.009999999776482582))*i))),B[m+4236>>2]=n;m=a,n=pe(E(10),E(E(-1)/E(E(E(B[a+4216>>2]*E(2950))+E(50))*i))),B[m+4240>>2]=n;x[d+12>>2]=1325400064;c=E(pe(E(10),E(E(E(B[a+4220>>2]*E(60))+E(-60))*E(.05000000074505806)))*E(2147483648));b=(q(c),j(2));f=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){e=b<<1;if(!e){f=E(_w(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(e>>>0<4278190080&(b|0)>=0)){f=nH(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}e=b-1060306944|0;g=e>>>15&240;h=+(l(2,b-(e&-8388608)|0),r())*C[g+57664>>3]+-1;k=h*h;c=E((C[7241]*k+(C[7242]*h+C[7243]))*k+(+(e>>23)*C[7240]+C[g+57672>>3]+h))}f=c}B[d+8>>2]=E(f*E(96817624))+E(67108864);m=a,n=E(B[Ml(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[m+4244>>2]=n;B[a+4248>>2]=E(E(-1)/E(E(B[a+4224>>2]*E(99))+E(1)))+E(1);c=E(E(E(B[a+4228>>2]*E(4))*i)+E(2));c:{if(E(F(c))<E(2147483648)){g=~~c;break c}g=-2147483648}x[a+4252>>2]=g;hb=d+16|0}function baa(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=0,h=0;c=hb-32|0;hb=c;a:{b=x[a+20>>2];b:{if(!b){break b}x[b+148>>2]=-1;g=c,h=mb[x[x[a>>2]+40>>2]](a)|0,x[g+16>>2]=h;x[c+8>>2]=1073741822;e=x[fe(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=x[a+20>>2];x[114409]=0;P(488,d+4|0,b+4|0);b=x[114409];x[114409]=0;c:{d:{e:{f:{if((b|0)!=1){b=x[a+20>>2];x[114409]=0;P(709,c+8|0,b+4|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;x[c>>2]=0;x[c+4>>2]=0;T(1864,c+16|0,c+8|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;O(1865,c+16|0,0)|0;b=x[114409];x[114409]=0;g:{if((b|0)==1){break g}d=x[x[a>>2]+176>>2];b=0;x[114409]=0;P(d|0,a|0,-1);d=x[114409];x[114409]=0;if((d|0)==1){break g}if((e|0)>0){while(1){d=x[x[a>>2]+48>>2];x[114409]=0;f=E(la(d|0,a|0,b|0));d=x[114409];x[114409]=0;if((d|0)==1){break e}x[114409]=0;B[c+8>>2]=f;O(1866,c+16|0,c+8|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=x[x[a>>2]+180>>2];x[114409]=0;V(b|0,a|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}b=R(74984)|0;break c}b=R(74984)|0;break c}b=R(74984)|0;break c}b=R(74984)|0;break c}b=R(74984)|0}if((ib|0)!=(ca(74984)|0)){break a}Y(b|0)|0;ut(x[a+20>>2]+4|0);_()}hb=c+32|0;return}Q(b|0);p()}function Hma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-432|0;hb=e;Nc(b);rA(b,e+380|0,e+300|0,e+16|0);g=e+412|0;m=e,n=_k(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)?y[e+431|0]+1|0:1),v[m+12|0]=n;h=y[tc(23856,e+12|0)|0];v[e+15|0]=h;w[e+12>>1]=4;a:{b:{if(!h){break b}g=e+396|0;j=e+299|0;while(1){c:{d=e+16|0;d=y[d|0]|y[d+1|0]<<8;f=(d<<8|d>>>8)<<16>>16;if(!((f|0)<0|y[j|0]>63)){if(d){d=f&65535;k=d>>>0<=1?1:d;d=0;while(1){f=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d:{if(!Tc(b,(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))+(d<<2)|0)){break d}if(!Tc(b,mB(b))){break d}e:{if(!c){f=te(b);break e}f=nB(b)}w[e+10>>1]=f;m=e,n=z[jj(e+12|0,e+10|0)>>1],w[m+12>>1]=n}d=d+1|0;if((k|0)!=(d|0)){continue}break}}d=e+300|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if((d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))>>>0>l>>>0){d=e+300|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(Tc(b,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))){break c}}v[e+15|0]=i+1;break b}pC(a);break a}d=e+300|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);rA(b,e+380|0,d,e+16|0);l=f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}w[a>>1]=z[e+12>>1];v[a+2|0]=y[e+15|0]}hb=e+432|0}function nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=hb-16|0;hb=j;d=Tg(b);a:{if(d>>>0<c>>>0){k=hb-32|0;hb=k;b:{c:{h=c-d|0;d:{if(h>>>0<=x[yb(b)>>2]-x[b+4>>2]>>3>>>0){g=hb-16|0;hb=g;e:{d=kr(g+4|0,b,h);e=x[d+4>>2];f=x[d+8>>2];if((e|0)!=(f|0)){while(1){h=yb(b);x[114409]=0;P(951,h|0,e|0);h=x[114409];x[114409]=0;if((h|0)==1){break e}e=e+8|0;x[d+4>>2]=e;if((e|0)!=(f|0)){continue}break}}Jb(d);hb=g+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}i=yb(b);g=k+12|0;f=Tg(b)+h|0;d=hb-16|0;hb=d;x[d+12>>2]=f;f:{e=Dv(b);if(f>>>0<=e>>>0){f=lj(b);if(f>>>0<e>>>1>>>0){x[d+8>>2]=f<<1;e=x[$c(d+8|0,d+12|0)>>2]}hb=d+16|0;d=e;break f}Xc();p()}l=Tg(b);e=0;f=hb-16|0;hb=f;x[f+12>>2]=0;We(g+12|0,i);if(d){bD(f+4|0,x[g+16>>2],d);e=x[f+4>>2];d=x[f+8>>2]}else{d=0}x[g>>2]=e;i=(l<<3)+e|0;x[g+8>>2]=i;x[g+4>>2]=i;m=hc(g),n=(d<<3)+e|0,x[m>>2]=n;hb=f+16|0;x[114409]=0;P(949,g|0,h|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;P(950,b|0,g|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}ZQ(g)}hb=k+32|0;break b}a=N()|0;ZQ(g);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<3)|0;Tg(b);_Q(b,d);lj(b);Tg(b)}}c=Qb(a,c<<3);if(c){d=hb-16|0;hb=d;e=j+8|0;jc(e,x[b>>2],Tg(b)<<3);hb=d+16|0;Cd(a,e)}hb=j+16|0;return c|0}function Jp(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=x[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(z[a+480192>>1]){break a}a=a+484344|0;f=c,g=bc(a),x[f+12>>2]=g;f=c,g=dc(a),x[f+8>>2]=g;d=1;if(!Hb(c+12|0,c+8|0)){break a}while(1){a=x[c+12>>2];if(!(!Ah(a)|x[a+12>>2]==64)){d=4;break a}a=c+12|0;dm(a);if(Hb(a,c+8|0)){continue}break}break a}d=32;if(z[a+480188>>1]>16){break a}if(!z[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(v[e+480281|0]&1|z[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}hb=c+16|0;return d}function vy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=eM(b,c);a:{if(!x[b+656>>2]|!(v[g|0]&1)){break a}f=x[g+4>>2];h=a+1074312|0;e=$b(h,31);d=ev(x[b+656>>2],c);if(kd(d)){break a}f=f+(e^1)|0;i=$b(h,31);e=y[d+12|0];b:{c:{if(!i){d:{if(!(e&2)){break d}e=z[Pb(d,y[d+14|0])>>1]+!(x[a+480180>>2]&1048580)|0;if(!(!(y[b+89|0]&8)|(!(y[d+12|0]&4)|y[d+14|0]!=y[d+16|0]))){j=$b(h,70)}if((f|0)!=(e|0)|j){break d}f=z[Pb(d,y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){if((z[Pb(d,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[Pb(d,y[d+15|0])>>1];if(!$b(h,93)|(c|0)!=1|y[b+89|0]&8){break b}v[g|0]=y[g|0]&254;break b}if(z[Fj(d)>>1]>=f>>>0){break b}j=1;f=z[Fj(d)>>1];break c}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(x[g+8>>2]==-1){break f}if($b(h,97)){break f}e=y[d+12|0]}if(e&2){e=z[Pb(d,y[d+13|0])>>1];i=z[Pb(d,y[d+14|0])>>1]+1|0;break e}e=z[Fj(d)>>1];j=f>>>0>e>>>0;i=e;break e}e=z[Pb(d,y[d+15|0])>>1];i=z[Pb(d,y[d+16|0])>>1]+1|0}f=f>>>0<i>>>0?f:e}if(!j|c){break b}if(!(!(x[a+480180>>2]&16777248)&(!(y[b+89|0]&8)|x[a+480180>>2]==16384))){x[b+88>>2]=x[b+88>>2]|4096}if(y[Fj(d)+2|0]|!(z[b+808>>1]|x[a+480180>>2]&16777248)){break b}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=x[b+88>>2]|4096}k=g,l=$b(h,31)+f|0,x[k+4>>2]=l}}function pe(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=jH(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(jH(e)){h=E(a*a);if((e|0)<0){h=(iH(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=_w(E(E(1)/h));break a}if((e|0)<0){c=iH(d);if(!c){a=nH(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+58280>>3]+-1;g=f*f;f=((C[7317]*f+C[7318])*(g*g)+((C[7319]*f+C[7320])*g+(C[7321]*f+(C[c+58288>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=lH(i);break a}if(!(f<=-150)){break f}a=kH(i);break a}k=f;g=C[7276];f=g+f;g=k-(f-g);g=(C[7277]*g+C[7278])*(g*g)+(C[7279]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+57952|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function DM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{d=a+484360|0;if(rc(Wb(d))>>>0<=b>>>0){break b}if(dq(Wb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(rc(Wb(d))>>>0<=c>>>0){break a}if(!dq(Wb(d),b&65535)){continue}break}break a}c=b}if(rc(Wb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1304360|0;c=a+1074984|0;while(1){v[c+819|0]=0;x[c+700>>2]=0;v[c+861|0]=0;v[c+827|0]=0;x[c+708>>2]=0;v[c+841|0]=0;x[c+804>>2]=0;v[c+839|0]=0;v[c+840|0]=0;f=e+8|0;Kb(f,d,23);if(Ib(f)){w[c+798>>1]=0;w[c+800>>1]=1}v[c+859|0]=0;c=c+896|0;if((g|0)!=(c|0)){continue}break}CM(a);c:{if(!(b&65535)){b=0;while(1){Qn((D(b,896)+a|0)+1074984|0,7,a,b&65535,1024);b=b+1|0;if((b|0)!=256){continue}break}Nk(a+1304360|0,1);x[a+1074444>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;Xy(a+1074376|0);w[a+1074440>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0;break c}w[a+1074440>>1]=b;w[a+1074436>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}hb=e+16|0}function g_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-16|0;hb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!x[i>>2]){break a}i=i+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){k=x[b+4>>2];x[j+8>>2]=x[b>>2];x[j+12>>2]=k;m=1;l=hb-16|0;hb=l;x[l+12>>2]=x[a+8>>2];n=Nh(l+8|0,l+12|0);x[114409]=0;k=aa(2719,f|0,e|0,i-c>>2,g-f|0,b|0)|0;o=x[114409];x[114409]=0;d:{if((o|0)!=1){Te(n);hb=l+16|0;break d}a=N()|0;Te(n);Q(a|0);p()}e:{f:{g:{h:{switch(k+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=lw(f,x[c>>2],j+8|0,x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=k+x[h>>2]|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=x[e>>2];i=d;continue}i=lw(j+4|0,0,b,x[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-x[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=y[c|0];k=x[h>>2];x[h>>2]=k+1;v[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!x[i>>2]){break b}i=i+4|0;continue}}c=x[e>>2]}m=(c|0)!=(d|0)}hb=j+16|0;return m|0}f=x[h>>2];continue}}function qqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}if(!d){break i}e=G(d)-G(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;jb=a-D(b,c)|0;kb=0;lb=0;return b}if(!a){break g}if(!d){break f}f=d-1|0;if(f&d){break f}jb=a;kb=e&f;a=e>>>rqa(d)|0;lb=0;return a}f=c-1|0;if(!(f&c)){break e}j=(G(c)+33|0)-G(e)|0;h=0-j|0;break c}j=e+1|0;h=63-e|0;break c}jb=0;a=(e>>>0)/(d>>>0)|0;kb=e-D(a,d)|0;lb=0;return a}e=G(d)-G(e)|0;if(e>>>0<31){break d}break b}jb=a&f;kb=0;if((c|0)==1){break a}c=rqa(c);d=c&31;if((c&63)>>>0>=32){e=0;a=b>>>d|0}else{e=b>>>d|0;a=((1<<d)-1&b)<<32-d|a>>>d}lb=e;return a}j=e+1|0;h=63-e|0}f=a;e=j&63;g=e&31;if((e&63)>>>0>=32){e=0;f=b>>>g|0}else{e=b>>>g|0;f=((1<<g)-1&b)<<32-g|f>>>g}h=h&63;g=h&31;if((h&63)>>>0>=32){i=a<<g;a=0}else{i=(1<<g)-1&a>>>32-g|b<<g;a=a<<g}b=i;if(j){h=d-1|0;k=c-1|0;h=(k|0)!=-1?h+1|0:h;g=k;while(1){e=e<<1|f>>>31;f=f<<1|b>>>31;k=e;l=h-(e+(f>>>0>g>>>0)|0)|0;m=l>>31;i=m;e=f;l=c&i;f=e-l|0;e=k-((d&i)+(e>>>0<l>>>0)|0)|0;i=b<<1|a>>>31;a=n|a<<1;b=i|o;k=m&1;n=k;j=j-1|0;if(j){continue}break}}jb=f;kb=e;i=b<<1|a>>>31;a=k|a<<1;lb=i|o;return a}jb=a;kb=b;a=0;b=0}lb=b;return a}function Jba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-160|0;hb=c;e=vl(c+56|0,a);x[114409]=0;d=O(694,c+44|0,35968)|0;a=x[114409];x[114409]=0;a:{b:{c:{d:{if((a|0)!=1){x[114409]=0;x[c+24>>2]=19469602;x[c+28>>2]=0;T(695,e|0,d|0,c+24|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}Gb(d);if(!(x[e>>2]&1073741824)){break c}break a}a=N()|0;break b}a=N()|0;Gb(d);break b}a=Ne(b);x[114409]=0;w[c+42>>1]=a;w[c+40>>1]=65535;d=O(694,c+24|0,6086)|0;a=x[114409];x[114409]=0;e:{if((a|0)!=1){x[114409]=0;a=U(1237,e|0,c+40|0,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}Gb(d);if((a|0)!=1){w[c+42>>1]=z[c+40>>1]}dg(c+42|0,z[x[19555]+10>>1]);f:{if(z[c+42>>1]<=Ne(b)>>>0){break f}x[114409]=0;P(377,b|0,z[c+42>>1]);a=x[114409];x[114409]=0;if((a|0)!=1){break f}a=N()|0;break b}a=0;w[c+22>>1]=0;if(!z[c+42>>1]){break a}g:{while(1){h:{a=Zb(b,a&65535);x[114409]=0;P(1695,c+8|0,c+22|0);d=x[114409];x[114409]=0;if((d|0)==1){break h}x[114409]=0;Z(1670,e|0,a|0,c+8|0,1696)|0;a=x[114409];x[114409]=0;if((a|0)==1){break g}Gb(c+8|0);a=z[c+22>>1]+1|0;w[c+22>>1]=a;if(z[c+42>>1]>(a&65535)>>>0){continue}break a}break}a=N()|0;break b}a=N()|0;Gb(c+8|0);break b}a=N()|0;break b}a=N()|0;Gb(d)}Ig(e);Q(a|0);p()}Ig(e);hb=c+160|0}function Poa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;zd(b,32);e=a+4|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[b>>2]=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);e=a+10|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);x[b+4>>2]=e;g=e;e=a+14|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[b+8>>2]=g+(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));if(!(d?0:c)){c=a+46|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24)}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;e=y[d+1|0]<<8;if(!(y[d|0]|e)|(e|y[d|0])==12288){break a}e=c;c=y[d|0]|y[d+1|0]<<8;c=(e-(((c<<8|c>>>8)&65535)<<7)|0)+6144|0}Lt(b,+(c|0)*.0006510416666666666);v[f+15|0]=y[a+9|0];v[f+14|0]=64;h=b,i=y[tc(f+15|0,f+14|0)|0]<<2,w[h+30>>1]=i;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}b:{if(y[a+41|0]<=8){a=x[b+4>>2];c=x[b+8>>2];break b}w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;a=x[b+4>>2]>>>1|0;x[b+4>>2]=a;c=x[b+8>>2]>>>1|0;x[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break c}x[b+4>>2]=0;x[b+8>>2]=0}hb=f+16|0}function KW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-1072|0;hb=f;e=ii(f+16|0);a=Lm(a,e);Ab(e);x[a+1060>>2]=0;x[a+1064>>2]=0;x[a+1056>>2]=c;e=a+1068|0;x[e>>2]=0;x[e+4>>2]=0;e=0;x[a+1076>>2]=0;v[a+1080|0]=d;a:{b:{if(Qe(c)){h=a+1060|0;while(1){x[a+1060>>2]=0;x[a+1064>>2]=0;c:{if(!x[c>>2]){break c}while(1){x[114409]=0;d=O(231,b|0,2)|0;g=x[114409];x[114409]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}x[114409]=0;d=S(335,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break g}if(!d){break d}x[114409]=0;T(316,f|0,b|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break f}d=Lm(f+16|0,f);Zd(a,d);sc(a+16|0,d+16|0,1040);Ab(d);Ab(f);x[a+1072>>2]=0;x[a+1076>>2]=0;g=cr(x[a+1056>>2]);d=x[x[a+1056>>2]+20>>2];if(g>>>0>=2){x[114409]=0;P(336,a|0,d+(e<<1)|0);d=x[114409];x[114409]=0;if((d|0)!=1){break d}break e}x[114409]=0;P(337,a|0,d+e|0);d=x[114409];x[114409]=0;if((d|0)==1){break e}break d}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}d=R(75852)|0;if((ib|0)!=(ca(75852)|0)){break a}Y(d|0)|0;x[114409]=0;X(20);d=x[114409];x[114409]=0;if((d|0)==1){break b}}if(A[h>>2]<A[c>>2]){continue}break}}e=e+1|0;if(Qe(x[a+1056>>2])>>>0>e>>>0){continue}break}}hb=f+1072|0;return a|0}d=N()|0}Ab(a);Q(d|0);p()}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=hb-16|0;hb=h;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];i=x[a+44>>2];o=x[a+16>>2];e=x[a+4>>2];b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;g=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=g;a:{if(!d){g=k>>12;j=l>>12;break a}while(1){b=(x[h+8>>2]>>>21&2040)+32976|0;m=w[b+2>>1];e=(x[h+12>>2]<<1)+o|0;p=w[e>>1];q=w[b>>1];r=w[e-2>>1];s=w[b+4>>1];t=w[e+2>>1];u=w[b+6>>1];n=w[e+4>>1];e=x[a+60>>2];b=i;i=Yb(b,-16777216,16776704);g=x[a+64>>2];j=Yb(f,-16777216,16776704);v=x[a+72>>2];y=x[a+32>>2];z=x[c>>2];f=sqa(g,g>>31,i,i>>31);g=lb;i=(((D(m,p)+D(q,r)|0)+D(s,t)|0)+D(u,n)|0)/16384<<8;m=sqa(e,e>>31,i,i>>31);e=m+f|0;f=lb+g|0;f=e>>>0<m>>>0?f+1|0:f;n=e;e=x[a+68>>2];g=sqa(e,e>>31,j,j>>31);e=n+g|0;f=lb+f|0;f=e>>>0<g>>>0?f+1|0:f;l=x[a+28>>2]+l|0;j=l>>12;e=e+8388608|0;f=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;e=(f|0)/256|0;x[c>>2]=D(j,e)+z;k=k+y|0;g=k>>12;x[c+4>>2]=x[c+4>>2]+D(e,g);i=f-(i&v)|0;c=c+8|0;Tb(h+8|0,h);f=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];e=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=j;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=i;x[a+24>>2]=g;hb=h+16|0}function JS(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=y[a|0];a:{if(d>>>0>21){break a}v[a|0]=y[d+23728|0];b:{switch(d-8|0){case 0:v[b|0]=y[b|0]<<1;break a;case 4:v[b|0]=y[b|0]+1>>>1;break a;case 5:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 3:break i;case 1:break j;case 0:break k;case 14:break c;case 10:break d;default:break l}}v[a|0]=0;break a}v[a|0]=29;v[c+15|0]=y[b|0]&15;v[c+14|0]=14;e=b,f=y[tc(c+15|0,c+14|0)|0]<<4|15,v[e|0]=f;break a}v[a|0]=29;v[c+13|0]=y[b|0]&15;v[c+12|0]=14;e=b,f=y[tc(c+13|0,c+12|0)|0]|240,v[e|0]=f;break a}v[b|0]=d&15|48;break a}v[b|0]=d&15|176;break a}v[b|0]=d&15|64;break a}v[a|0]=15;v[b|0]=y[b|0]&15;break a}v[a|0]=24;v[b|0]=(y[b|0]<<3&120)+8&240;break a}v[a|0]=24;v[b|0]=(y[b|0]&15)+1>>>1;break a}v[a|0]=10;break a;case 8:a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){v[b|0]=a<<2&48|15;break a}v[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}v[b|0]=a>>>2&3|240}hb=c+16|0}function Nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;i=x[a+12>>2];f=i;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}l=x[a+16>>2];m=x[a+24>>2];n=x[a+20>>2];j=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=j;x[e+16>>2]=g;x[e+20>>2]=f;g=a;if(d){while(1){a=x[e+24>>2];h=((((x[e+28>>2]&2147483647)<<1|a>>>31)&2147483646)<<1)+l|0;a=(a>>>16&65520)+i|0;o=w[a+14>>1];p=w[a+12>>1];q=w[a+10>>1];r=w[a+8>>1];s=w[a+6>>1];t=w[a+4>>1];f=w[a+2>>1];j=w[a>>1];k=0;b=1;while(1){a=k<<1;x[(e+8|0)+(k<<2)>>2]=(((((((D(w[(a|-8)+h>>1],f)+D(w[(a|-12)+h>>1],j)|0)+D(w[(a|-4)+h>>1],t)|0)+D(w[a+h>>1],s)|0)+D(w[(a|4)+h>>1],r)|0)+D(w[(a|8)+h>>1],q)|0)+D(w[(a|12)+h>>1],p)|0)+D(w[(a|16)+h>>1],o)|0)/32768;a=b;b=0;k=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],n);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],m);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];j=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=j;hb=e+32|0}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=hb-16|0;hb=g;a:{if(y[d|0]){e=Dd(g+8|0,b);b=Sk(c,b);d=hb-16|0;hb=d;x[d+12>>2]=b;c=x[e+4>>2];b:{if(c){x[d+8>>2]=32-c;b=Mb(d+8|0,d+12|0);c=x[e>>2];b=x[b>>2];f=x[c>>2]&(-1<<x[e+4>>2]&-1>>>x[d+8>>2]-b);if(f){Hd(a,c,rqa(f));break b}f=x[d+12>>2];if((f|0)==(b|0)){Gz(a,e,b);break b}b=f-b|0;x[d+12>>2]=b;x[e>>2]=c+4}if(b>>>0>=32){c=x[e>>2];while(1){f=x[c>>2];if(f){Hd(a,c,rqa(f));break b}c=c+4|0;x[e>>2]=c;b=b-32|0;x[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=x[e>>2];break c}c=x[e>>2];e=x[c>>2]&-1>>>32-b;if(!e){break c}Hd(a,c,rqa(e));break b}Hd(a,c,b)}break a}e=Dd(g,b);b=Sk(c,b);d=hb-16|0;hb=d;x[d+12>>2]=b;c=x[e+4>>2];d:{if(c){x[d+8>>2]=32-c;b=x[Mb(d+8|0,d+12|0)>>2];c=x[e>>2];f=-1<<x[e+4>>2]&-1>>>x[d+8>>2]-b&(x[c>>2]^-1);if(f){Hd(a,c,rqa(f));break d}f=x[d+12>>2];if((f|0)==(b|0)){Gz(a,e,b);break d}b=f-b|0;x[d+12>>2]=b;x[e>>2]=c+4}if(b>>>0>=32){c=x[e>>2];while(1){f=x[c>>2];if((f|0)!=-1){Hd(a,c,rqa(f^-1));break d}c=c+4|0;x[e>>2]=c;b=b-32|0;x[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=x[e>>2];break e}c=x[e>>2];e=(x[c>>2]^-1)&-1>>>32-b;if(!e){break e}Hd(a,c,rqa(e));break d}Hd(a,c,b)}}hb=d+16|0;hb=g+16|0}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;h=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;k=e,l=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[k+28>>2]=l;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;k=e,l=Wf(b,f),x[k+16>>2]=l;x[e+20>>2]=lb;k=e,l=Ze(b,d),x[k+40>>2]=l;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+24>>2];j=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;a=x[e+8>>2];b=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=b+h|0;x[e+40>>2]=a;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){Hj(x[e+24>>2],w[f+(x[e+44>>2]<<1)>>1]/4<<16>>16);Gj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];a=x[b+4>>2];if(a){Hj(b,w[f+(x[e+44>>2]<<1)>>1]/4<<16>>16);Gj(x[e+24>>2],a);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Zp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[yb(a)>>2]){e=hb-16|0;hb=e;c=e+4|0;x[c>>2]=a;d=x[a+4>>2];x[c+4>>2]=d;x[c+8>>2]=d+56;a=yb(a);d=x[c+4>>2];x[114409]=0;T(1007,a|0,d|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;Jb(c);hb=e+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}h=hb-32|0;hb=h;i=yb(a);d=h+12|0;c=Rk(a)+1|0;f=hb-16|0;hb=f;x[f+12>>2]=c;e=c;c=hb-16|0;hb=c;yb(a);x[c+12>>2]=76695844;x[114409]=0;x[c+8>>2]=2147483647;g=O(36,c+12|0,c+8|0)|0;j=x[114409];x[114409]=0;b:{if((j|0)!=1){hb=c+16|0;c=x[g>>2];break b}R(0)|0;zb();p()}c:{if(c>>>0>=e>>>0){e=Un(a);if(e>>>0<c>>>1>>>0){x[f+8>>2]=e<<1;c=x[$c(f+8|0,f+12|0)>>2]}hb=f+16|0;e=c;break c}Xc();p()}g=Rk(a);c=0;f=hb-16|0;hb=f;x[f+12>>2]=0;We(d+12|0,i);if(e){c=oQ(e);x[f+8>>2]=e;x[f+4>>2]=c;c=x[f+4>>2];e=x[f+8>>2]}else{e=0}x[d>>2]=c;g=D(g,56)+c|0;x[d+8>>2]=g;x[d+4>>2]=g;k=hc(d),l=D(e,56)+c|0,x[k>>2]=l;hb=f+16|0;c=x[d+8>>2];x[114409]=0;T(1007,i|0,c|0,b|0);b=x[114409];x[114409]=0;d:{e:{if((b|0)==1){break e}x[d+8>>2]=x[d+8>>2]+56;x[114409]=0;P(1008,a|0,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}uQ(d);hb=h+32|0;break d}a=N()|0;uQ(d);Q(a|0);p()}}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=hb-16|0;hb=h;j=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];g=x[a+4>>2];e=g;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;g=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=g;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){e=x[h+8>>2];b=x[h+12>>2]+p|0;q=v[b+2|0];r=v[b+1|0];s=v[b|0];t=v[b-1|0];g=x[a+60>>2];b=f;i=Yb(f,-16777216,16776704);f=x[a+64>>2];o=Yb(j,-16777216,16776704);u=x[a+72>>2];m=x[a+32>>2];n=x[c>>2];f=sqa(f,f>>31,i,i>>31);j=lb;i=f;f=x[a+68>>2];f=sqa(f,f>>31,o,o>>31);o=i+f|0;i=lb+j|0;i=f>>>0>o>>>0?i+1|0:i;e=(e>>>21&2040)+32976|0;j=(((D(s,w[e+2>>1])+D(w[e>>1],t)|0)+D(r,w[e+4>>1])|0)+D(q,w[e+6>>1])<<8)/16384<<8;e=j;e=sqa(g,g>>31,e,e>>31);f=e+o|0;g=lb+i|0;g=e>>>0>f>>>0?g+1|0:g;i=n;l=x[a+28>>2]+l|0;n=l>>12;e=f+8388608|0;e=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;g=(e|0)/256|0;x[c>>2]=i+D(n,g);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(g,m);f=e-(j&u)|0;c=c+8|0;Tb(h+8|0,h);j=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];e=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=n;x[a+36>>2]=l;x[a+48>>2]=j;x[a+44>>2]=f;x[a+24>>2]=m;hb=h+16|0}function Pd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;x[a+480180>>2]=b;b=Jp(a);JM(d,b);e=x[d+12>>2];c=a+1074320|0;x[c>>2]=x[d+8>>2];x[c+4>>2]=e;c=x[d+4>>2];x[a+1074312>>2]=x[d>>2];x[a+1074316>>2]=c;gt(a+8|0,b);c=z[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=x[e>>2];if(f){_b(nu(f));c=z[a+480192>>1]}x[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;Jy(a,4);e=hb+-64|0;hb=e;b=a+484344|0;dy(b);f=Lg(b);c=ey(e+12|0,b);x[114409]=0;T(1687,b|0,f|0,c|0);b=x[114409];x[114409]=0;a:{if((b|0)!=1){Ik(c);hb=e- -64|0;break a}a=N()|0;Ik(c);Q(a|0);p()}OO(a+484360|0);Xe(a+1304400|0);Xe(a+1304412|0);Xe(a+1304424|0);c=a+1304436|0;d=Sb(d,0,64);b=SM(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);x[c+60>>2]=x[b+60>>2];My(b);bB(a+1304500|0);Bt(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}hb=d- -64|0}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-32|0;hb=g;x[g+28>>2]=b;b=x[a>>2];n=g,o=bc(a),x[n+8>>2]=o;b=b+(Jq(g+28|0,g+8|0)<<1)|0;a:{b:{e=gz(c,d);c:{if((e|0)<=0){break c}f=x[yb(a)>>2];k=x[a+4>>2];if(f-k>>1>=(e|0)){x[g+8>>2]=d;i=k-b|0;f=i>>1;if((f|0)<(e|0)){x[g+8>>2]=c;x[g+8>>2]=x[g+8>>2]+(f<<1);j=x[g+8>>2];h=hb-16|0;hb=h;f=bh(h+4|0,a,e-f|0);l=yb(a);m=x[f+4>>2];x[114409]=0;d=Z(1323,l|0,j|0,d|0,m|0)|0;j=x[114409];x[114409]=0;d:{if((j|0)!=1){x[f+4>>2]=d;Jb(f);hb=h+16|0;break d}break a}if((i|0)<=0){break c}}i=hb-16|0;hb=i;j=x[a+4>>2];e=(j-((e<<1)+b|0)|0)+b|0;f=bh(i+4|0,a,k-e>>1);if(e>>>0<k>>>0){h=x[f+4>>2];d=e;while(1){l=yb(a);x[114409]=0;T(1324,l|0,h|0,d|0);l=x[114409];x[114409]=0;if((l|0)==1){break a}h=h+2|0;x[f+4>>2]=h;d=d+2|0;if(k>>>0>d>>>0){continue}break}}Jb(f);qq(b,e,j);hb=i+16|0;ue(c,x[g+8>>2],b);break c}f=yb(a);e=Eo(g+8|0,hj(a,rc(a)+e|0),b-x[a>>2]>>1,f);x[114409]=0;T(1320,e|0,c|0,d|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;b=U(1321,a|0,e|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}FC(e)}a=Rg(b);hb=g+32|0;return a|0}a=N()|0;FC(e);Q(a|0);p()}a=N()|0;Jb(f);Q(a|0);p()}function bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;zd(b,0);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=mg(oh(+(f+1408|0)*.0006510416666666666)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[tc(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=a+6|0;if((y[d|0]|y[d+1|0]<<8)>>>0<=256){w[b+28>>1]=y[d|0]|y[d+1|0]<<8;w[b+34>>1]=z[b+34>>1]|32}d=a+8|0;x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+12|0;x[b+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+16|0;x[b+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+20|0;if(y[d|0]&16){w[b+34>>1]=z[b+34>>1]|2}if(y[d|0]&32){w[b+34>>1]=z[b+34>>1]|4}if(v[d+1|0]&1){w[b+34>>1]=z[b+34>>1]|8}if(y[d+1|0]&2){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+32960|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[tc(e+13|0,e+12|0)|0],w[g+32>>1]=h}c=a+27|0;x[b+12>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);a=a+31|0;x[b+16>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);hb=e+16|0}function SF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=hb-16|0;hb=l;a:{b:{c:{if((c|0)<=36){g=y[a|0];if(g){break c}f=a;break b}x[114232]=28;d=0;e=0;break a}f=a;d:{while(1){if(!qk(g<<24>>24)){break d}g=y[f+1|0];f=f+1|0;if(g){continue}break}break b}e:{g=y[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}j=(g|0)==45?-1:0;f=f+1|0}f:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break f}f=f+1|0;m=c?c:8;break f}m=c?c:10}c=0;while(1){g:{g=-48;i=v[f|0];h:{if((i-48&255)>>>0<10){break h}g=-87;if((i-97&255)>>>0<26){break h}g=-55;if((i-65&255)>>>0>25){break g}}i=g+i|0;if((i|0)>=(m|0)){break g}$e(l,m,0,0,0,k,h,0,0);g=1;i:{if(x[l+8>>2]|x[l+12>>2]){break i}o=sqa(k,h,m,0);p=lb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break i}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}j:{k:{if(c){x[114232]=68;a=d&1;j=a?0:j;k=d;h=e;break k}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break j}a=d&1}if(!(a|j)){x[114232]=68;a=d;d=a-1|0;e=e-!a|0;break a}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break j}x[114232]=68;break a}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}hb=l+16|0;lb=e;return d}function e5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb+-64|0;hb=e;a:{b:{c:{if(Bi(a)){vp(e+60|0);break c}c=e+24|0;tn(c,a);x[114409]=0;c=S(2298,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}x[e+60>>2]=c;Qf(e+24|0)}if(Bi(a)){c=a+36|0}else{c=x[e+60>>2]}d=x[a+8>>2];d:{if((d|0)==-1){d=Mu(c);e:{if(!vd(c)){break e}while(1){if(!(C[Vc(c,f)>>3]+h<=b)){d=Vc(c,f);break e}h=C[d>>3]+h;f=f+1|0;if(vd(c)>>>0>f>>>0){continue}break}}b=b-h;break d}d=Vc(c,d)}f=a+24|0;c=x[f>>2];g=z[d+12>>1];x[114409]=0;P(2302,c|0,g|0);c=x[114409];x[114409]=0;if((c|0)!=1){f:{g=x[f>>2];i=y[a+64|0];c=mJ(zR(e+24|0,b),y[d+16|0],z[d+12>>1],x[d+8>>2]);x[114409]=0;d=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=d;d=x[c+20>>2];x[e+16>>2]=x[c+16>>2];x[e+20>>2]=d;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;W(2252,e+48|0,g|0,(i?7:1)|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}g=e+48|0;c=eh(g);d=v[c+26|0]&1;i=x[(d?c+8|0:c+12|0)>>2];d=z[(d?c+20|0:c+22|0)>>1];b=C[c>>3];em(g);w[x[f>>2]+1074438>>1]=d;w[x[f>>2]+1074440>>1]=d;x[x[f>>2]+1074428>>2]=i;x[x[f>>2]+1074392>>2]=-2;b=b+h;C[a+16>>3]=b;zk(e+60|0);hb=e- -64|0;return+b}}f=N()|0;zk(e+60|0);break a}f=N()|0;Qf(e+24|0)}Q(f|0);p()}function Oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;i=x[a+12>>2];f=i;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}k=x[a+16>>2];l=x[a+24>>2];m=x[a+20>>2];j=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=j;x[e+16>>2]=g;x[e+20>>2]=f;g=a;if(d){while(1){a=x[e+24>>2];h=(((x[e+28>>2]&2147483647)<<1|a>>>31)&-2)+k|0;a=(a>>>16&65520)+i|0;n=w[a+14>>1];o=w[a+12>>1];p=w[a+10>>1];q=w[a+8>>1];r=w[a+6>>1];s=w[a+4>>1];t=w[a+2>>1];f=w[a>>1];b=0;a=1;while(1){x[(e+8|0)+(b<<2)>>2]=(((((((D(v[(b|-4)+h|0],t)+D(v[(b|-6)+h|0],f)|0)+D(v[(b|-2)+h|0],s)|0)+D(v[b+h|0],r)|0)+D(v[(b|2)+h|0],q)|0)+D(v[(b|4)+h|0],p)|0)+D(v[(b|6)+h|0],o)|0)+D(v[(b|8)+h|0],n)<<8)/32768;j=a;a=0;b=1;if(j){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],m);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],l);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];j=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=j;hb=e+32|0}function jea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0;i=hb-16|0;hb=i;r=i,s=D(x[a>>2],Qe(a)),x[r+12>>2]=s;zc(i+12|0,c>>>3|0);c=Db(b);j=C[e+8>>3];e=x[i+12>>2];if(e){while(1){f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);k=f&16711680;h=k>>>8|0;p=k<<24;m=f&-16777216;k=m>>>24|0;g=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,p|m<<8|(((g&255)<<24|f>>>8)&-16777216|((g&16777215)<<8|f>>>24)&16711680|(g>>>8&65280|g>>>24)));f=h|k|(f<<24|(f&65280)<<8);h=0;l(1,f|(h|h));o=F(+n());j=j<o?o:j;c=c+8|0;e=e-1|0;if(e){continue}break}}c=j==0;a:{if(c){break a}e=x[i+12>>2];if(!e){break a}o=c?1:1/j;c=x[a+20>>2];while(1){g=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);m=g<<24|(g&65280)<<8;f=g&16711680;h=f>>>8|0;p=f<<24;f=g&-16777216;k=f>>>24|0;a=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);l(0,p|f<<8|(((a&255)<<24|g>>>8)&-16777216|((a&16777215)<<8|g>>>24)&16711680|(a>>>8&65280|a>>>24)));a=h|k|m;h=0;l(1,a|(h|h));q=Td(Gg(+n()*o)*32768);b:{if(F(q)<2147483648){a=~~q;break b}a=-2147483648}r=c,s=Wc(a),w[r>>1]=s;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){C[d>>3]=j}hb=i+16|0;return x[i+12>>2]<<3}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;h=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;k=e,l=Sf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[k+28>>2]=l;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;k=e,l=Wf(b,f),x[k+16>>2]=l;x[e+20>>2]=lb;k=e,l=Ze(b,d),x[k+40>>2]=l;x[e+44>>2]=lb;yf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+24>>2];j=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];a=x[e+12>>2];if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=a+h|0;x[e+40>>2]=b;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){Hj(x[e+24>>2],v[f+x[e+44>>2]|0]<<6);Gj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];a=x[b+4>>2];if(a){Hj(b,v[f+x[e+44>>2]|0]<<6);Gj(x[e+24>>2],a);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Zp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+808|0;d=a+16|0;while(1){x[d+16>>2]=0;x[d+20>>2]=0;x[d+36>>2]=0;v[d+42|0]=1;w[d+40>>1]=257;x[d+24>>2]=0;x[d+28>>2]=0;w[d+32>>1]=0;d=d+44|0;if((c|0)!=(d|0)){continue}break}d=a+3832|0;while(1){x[c>>2]=0;x[c+4>>2]=0;x[c+68>>2]=0;x[c+72>>2]=0;x[c+24>>2]=0;x[c+28>>2]=0;w[c+20>>1]=511;x[c+16>>2]=-1;w[c+14>>1]=1;w[c+6>>1]=0;w[c+8>>1]=0;w[c+10>>1]=0;w[c+12>>1]=0;v[c+73|0]=0;v[c+74|0]=0;v[c+75|0]=0;v[c+76|0]=0;v[c+77|0]=0;v[c+78|0]=0;v[c+79|0]=0;v[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}d=0;x[a+3832>>2]=0;x[a+3836>>2]=0;c=a+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){_e((D(d,84)+a|0)+808|0,a);d=d+1|0;if((d|0)!=36){continue}break}while(1){x[(D(e,44)+a|0)+32>>2]=a;e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){d=x[(e<<2)+25456>>2];c=(D(e,44)+a|0)+16|0;a:{if(!(!(1<<e&3591)|e>>>0>11)){f=c;c=D(d,84)+a|0;HO(f,c+808|0,c+1060|0,c+1312|0,c+1564|0);break a}f=c;c=D(d,84)+a|0;HO(f,c+808|0,c+1060|0,0,0)}e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){Ln((D(e,84)+a|0)+808|0);e=e+1|0;if((e|0)!=36){continue}break}GO(a,b);return a|0}function Q$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-144|0;hb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=2638;b=Sd(a+24|0,a+32|0,a+20|0);x[114409]=0;Fc(a+16|0,e);h=x[114409];x[114409]=0;a:{b:{c:{d:{if((h|0)!=1){x[114409]=0;h=S(21,a+16|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break b}v[a+15|0]=0;e=x[e+4>>2];x[114409]=0;c=pa(2639,a+140|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}if(!c){break c}Xe(g);if(!y[a+15|0]){break d}x[114409]=0;c=O(22,h|0,45)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}x[114409]=0;P(111,g|0,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){break d}break b}c=N()|0;break a}x[114409]=0;d=O(22,h|0,48)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}c=x[b>>2];e=x[a+20>>2];h=e-1|0;d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[114409]=0;U(2648,g|0,c|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break c}break b}x[114409]=0;c=O(2582,a+140|0,a+136|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Ob(a+16|0);Lc(b);hb=a+144|0;return c|0}c=N()|0;Ob(a+16|0)}Lc(b);Q(c|0);p()}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;if(!y[a+4242|0]){Tx(a);a:{if(!y[a+4240|0]){break a}e=EM(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;Ss(a)}g=a+4256|0;b:{if(y[a+4244|0]){if(!(C[g>>3]<=1)){C[g>>3]=1}break b}i=(x[a+4232>>2]&-2)!=4;e=C[g>>3];c:{if(F(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<=0)){Sx(a);e=C[a+4256>>3]}C[g>>3]=e-+(f|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=vi(C[a+4256>>3]*6.283185307179586);break d;case 1:e=F(C[a+4256>>3]+-.5)*-4+1;break d;case 2:e=C[a+4256>>3];e=e+e+-1;break d;case 3:e=C[a+4256>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];j=e*e*e*((e*6+-15)*e+10);e=C[a+4272>>3];e=j*(C[a+4280>>3]-e)+e}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];QN(h+8|0,1);f=Aj(a);f:{if(!f){break f}g=x[a+4236>>2];if(y[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|lu(C[h+8>>3]*127)<<16,k=x[x[f>>2]+68>>2],mb[k](l|0,m|0)|0;break f}if((g|0)<0){break f}mb[x[x[f>>2]+44>>2]](f,g,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4256>>3]+C[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;Gi(f,b,c,Qd(a,0),Qd(a,1),d);hb=h+16|0}function f_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=hb-16|0;hb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!y[i|0]){break a}i=i+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}l=x[b+4>>2];x[j+8>>2]=x[b>>2];x[j+12>>2]=l;k=hb-16|0;hb=k;x[k+12>>2]=x[a+8>>2];m=Nh(k+8|0,k+12|0);x[114409]=0;l=XF(f,e,i-c|0,g-f>>2,b);n=x[114409];x[114409]=0;e:{if((n|0)!=1){Te(m);hb=k+16|0;break e}a=N()|0;Te(m);Q(a|0);p()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{x[h>>2]=f;if(x[e>>2]==(c|0)){break j}g=1;k:{l:{m:{b=XE(f,c,i-c|0,j+8|0,x[a+8>>2]);switch(b+2|0){case 2:break k;case 1:break m;case 0:break g;default:break l}}x[e>>2]=c;break i}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(l<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break f}c=x[e>>2];if((d|0)==(i|0)){i=d;continue}if(!XE(f,c,1,b,x[a+8>>2])){break h}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!y[i|0]){break b}i=i+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}hb=j+16|0;return a|0}f=x[h>>2];continue}}function uI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;b=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;c=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=c;x[e+20>>2]=a;x[e+24>>2]=e+44;c=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=c;a:{b:{switch(x[b+40>>2]){case 0:zs(e,b);break a;case 2:zs(e,yb(b));break a;case 3:i=fh(b);d=0;b=hb-80|0;hb=b;c=x[e>>2];h=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Th(b- -64|0,b+32|0,h);c=Oc(b+52|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);h=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];f=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=f;f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(h){f=b+16|0;while(1){c=0;if(g){while(1){j=x[Vf(b,c,d)>>2];ef(i,c);k=Rn(f,c,d),l=E(E(j|0)*E(7.450580596923828e-9)),B[k>>2]=l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:zs(e,yb(b));break a;default:break b}}zs(e,yb(b))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function B5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=hb-2144|0;hb=b;Sb(b+96|0,0,2048);a:{b:{c:{f=x[c+4>>2];if(!f){a=ec(8);x[114409]=0;b=O(122,b+84|0,6434)|0;c=x[114409];x[114409]=0;if((c|0)==1){break c}a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}c=N()|0;xb(b);break b}g=x[c>>2];d=x[c+12>>2];c=x[c+8>>2];x[b+76>>2]=c;x[b+80>>2]=d;e=x[b+80>>2];x[b+24>>2]=x[b+76>>2];x[b+28>>2]=e;x[b+72>>2]=f;x[b+68>>2]=g;e=x[b+72>>2];x[b+16>>2]=x[b+68>>2];x[b+20>>2]=e;h=wQ(b+16|0);if(h){x[b+48>>2]=c;x[b+52>>2]=d;c=x[b+52>>2];x[b+8>>2]=x[b+48>>2];x[b+12>>2]=c;x[b+44>>2]=f;x[b+40>>2]=g;c=x[b+44>>2];x[b>>2]=x[b+40>>2];x[b+4>>2]=c;c=rQ(b)}else{c=0}x[b+56>>2]=c;x[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=mb[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}a=ft(a,fm(b+32|0,Db(b+96|0),d),h?b+56|0:0);if(a+1>>>0>=3){a=ec(8);x[114409]=0;b=O(122,b+84|0,4262)|0;c=x[114409];x[114409]=0;if((c|0)!=1){a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}c=N()|0;xb(b);break b}c=N()|0;ic(a);break b}hb=b+2144|0;return a|0}c=N()|0;ic(a)}Q(c|0)}p()}function RY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(vg(a,x[b+8>>2],e)){Yv(b,c,d);return}a:{if(vg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Xv(f,b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;Br(h,b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Br(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Br(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Br(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Bp(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=E(0),i=0,j=0,k=0,l=E(0);c=x[a+36>>2];if(!c){Ki(a+16|0);return}a:{b:{c:{switch(z[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){Ki(d);return}Nl(d,c);c=z[a+28>>1];e=a+4|0;Lb(e);b=1;g=Ol(a,c+1<<16>>16);c=w[a+28>>1];Lb(e);g=pe(E(g/Ol(a,c)),E(E(1)/E(x[a+36>>2]+1>>>0)));if(!x[a+36>>2]){break b}while(1){h=pe(g,E(b>>>0));k=Pb(d,b-1|0),l=h,B[k>>2]=l;b=b+1|0;if(b>>>0<=A[a+36>>2]){continue}break};break b;case 1:d=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(c>>>0)>>>0){Ki(d);return}Nl(d,D(c,e));c=w[a+28>>1];Lb(a+4|0);b=z[a+30>>1];if((c|0)>=0){c=(c>>>0)%(b>>>0)|0}else{c=b+(((c^-1)>>>0)%(b>>>0)^-1)|0}if(!e){break b}while(1){b=z[a+30>>1];f=c+i<<16>>16;d:{if((f|0)>=0){b=(f>>>0)%(b>>>0)|0;break d}b=b+(((f^-1)>>>0)%(b>>>0)^-1)|0}f=1;j=b<<16>>16;g=pe(E(Ol(a,b+1<<16>>16)/Ol(a,j)),E(E(1)/E(x[a+36>>2]+1>>>0)));b=1;if(x[a+36>>2]){while(1){h=pe(g,E((b&65535)>>>0));k=Pb(d,(D(x[a+36>>2],j)+f|0)-1|0),l=h,B[k>>2]=l;b=b+1|0;f=b&65535;if(f>>>0<=A[a+36>>2]){continue}break}}i=i+1|0;if(e>>>0>(i&65535)>>>0){continue}break};break b;case 0:break a;default:break c}}Ki(a+16|0);x[a+36>>2]=0}return}Ki(a+16|0)}function tn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-80|0;hb=c;g=Fx(a);e=b+24|0;a:{b:{if(ai(x[e>>2]+484360|0)){if(ai(x[e>>2]+484360|0)){a=0;while(1){f=x[e>>2];b=mJ(BR(c+40|0,1),a&255,0,0);x[114409]=0;d=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=d;d=x[b+20>>2];x[c+24>>2]=x[b+16>>2];x[c+28>>2]=d;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;W(2252,c+68|0,f|0,0,c+8|0);b=x[114409];x[114409]=0;c:{d:{if((b|0)!=1){b=c+68|0;i=c,j=bc(b),x[i+36>>2]=j;i=c,j=dc(b),x[i+32>>2]=j;if(Hb(c+36|0,c+32|0)){break d}break c}b=N()|0;break b}while(1){e:{b=x[c+36>>2];f=z[b+24>>1];h=C[b>>3];d=x[b+16>>2];b=c+40|0;x[b+16>>2]=a;x[b+12>>2]=f;x[b+8>>2]=d;C[b>>3]=h;x[114409]=0;P(2253,g|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}b=c+36|0;Mo(b);if(Hb(b,c+32|0)){continue}break c}break}b=N()|0;em(c+68|0);break b}em(c+68|0);a=a+1|0;if(ai(x[e>>2]+484360|0)>>>0>a>>>0){continue}break}}hb=c+80|0;return}a=ec(8);x[114409]=0;c=O(122,c+40|0,3534)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}b=N()|0;ic(a)}Qf(g);Q(b|0)}p()}function bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb+-64|0;hb=e;o=e,q=zf(a)>>>5|0,w[o+32>>1]=q;w[e+20>>1]=3999;o=c,q=z[Gf(e+32|0,e+20|0)>>1],w[o+480190>>1]=q;Sz(b,z[c+480190>>1],0);a:{if(z[c+480190>>1]){h=e+62|0;l=e+58|0;m=e+56|0;i=e+52|0;n=e+60|0;j=1;k=1;while(1){g=mq(c,k&65535);d=e+32|0;du(a,d);zd(g,0);f=e+8|0;mo(f,2,d);d=e+20|0;Kc(d,f);x[114409]=0;O(348,((j<<5)+c|0)+946304|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}d=e+20|0;xb(d);w[g+32>>1]=64;x[g+24>>2]=8287;f=y[n|0]|y[n+1|0]<<8;w[e+20>>1]=f<<8|f>>>8;w[e+8>>1]=64;o=g,q=z[Gf(d,e+8|0)>>1]<<2,w[o+30>>1]=q;d=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);x[g>>2]=d<<24|(d&65280)<<8|(d>>>8&65280|(d&-33554432)>>>24);d=y[m|0]|y[m+1|0]<<8;f=y[l|0]|y[l+1|0]<<8;f=(f<<8|f>>>8)&65535;b:{if(f>>>0<2){break b}d=(d<<8|d>>>8)&65535;f=d+f<<1;if(f>>>0>A[g>>2]){break b}x[g+16>>2]=f;x[g+12>>2]=d<<1;w[g+34>>1]=z[g+34>>1]|8}g=y[h|0]|y[h+1|0]<<8?(y[h|0]|y[h+1|0]<<8)==512:1;d=e+20|0;se(d,b,j-1|0);le(d,g);k=k+1|0;j=k&65535;if(j>>>0<=z[c+480190>>1]){continue}break}}hb=e- -64|0;return}a=N()|0;xb(e+20|0);Q(a|0);p()}function Fda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;i=hb-16|0;hb=i;while(1){f=hb-32|0;hb=f;b=bP(f);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(g<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;hb=f+32|0;g=g+1|0;if((g|0)!=4e3){continue}break}hb=i+16|0;hb=h+16|0}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=xf(a);if(c>>>0<b>>>0){j=hb-32|0;hb=j;a:{b:{h=b-c|0;c:{if(h>>>0<=x[yb(a)>>2]-x[a+4>>2]>>11>>>0){g=hb-16|0;hb=g;d=g+4|0;x[d>>2]=a;b=x[a+4>>2];x[d+4>>2]=b;x[d+8>>2]=b+(h<<11);d:{b=x[d+4>>2];i=x[d+8>>2];if((b|0)!=(i|0)){while(1){c=yb(a);x[114409]=0;P(1771,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}b=b+2048|0;x[d+4>>2]=b;if((b|0)!=(i|0)){continue}break}}Jb(d);hb=g+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}d=yb(a);g=j+12|0;c=xf(a)+h|0;e=hb-16|0;hb=e;x[e+12>>2]=c;f=hb-16|0;hb=f;yb(a);x[f+12>>2]=2097151;x[114409]=0;x[f+8>>2]=2147483647;i=O(36,f+12|0,f+8|0)|0;b=x[114409];x[114409]=0;e:{if((b|0)!=1){hb=f+16|0;b=x[i>>2];break e}R(0)|0;zb();p()}f:{if(b>>>0>=c>>>0){c=Bk(a);if(c>>>0<b>>>1>>>0){x[e+8>>2]=c<<1;b=x[$c(e+8|0,e+12|0)>>2]}hb=e+16|0;break f}Xc();p()}c=HK(g,b,xf(a),d);x[114409]=0;P(1769,c|0,h|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(1765,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Vs(c)}hb=j+32|0;break a}a=N()|0;Vs(c);Q(a|0);p()}return}if(b>>>0<c>>>0){c=x[a>>2]+(b<<11)|0;xf(a);FK(a,c);IK(a)}}function Cl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[a+4>>2]=0;vj(e+15|0,a,1);if(y[e+15|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+24>>2];d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;b=S(2450,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}if(re(b,-1)){break b}x[a+4>>2]=x[a+4>>2]+1;if(!re(b,c)){continue}break}d=0;break a}if(x[a+4>>2]>=(b|0)){break a}while(1){d:{d=x[x[a>>2]-12>>2];x[114409]=0;d=x[(a+d|0)+24>>2];f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;f=S(2450,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}if(re(f,-1)){break b}x[a+4>>2]=x[a+4>>2]+1;d=0;if(re(f,c)){break a}if(x[a+4>>2]<(b|0)){continue}break a}break}}Y(R(0)|0)|0;uj(x[x[a>>2]-12>>2]+a|0,1);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];c=x[114409];x[114409]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break e}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break f}Q(a|0);p()}_();d=1;break a}R(0)|0;zb()}p()}d=2}Mg(x[x[a>>2]-12>>2]+a|0,d)}hb=e+16|0;return a|0}function sc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Xa(a|0,b|0,c|0);return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if(!c){c=a;break b}c=a;while(1){v[c|0]=y[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){x[c>>2]=x[b>>2];x[c+4>>2]=x[b+4>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=x[b+12>>2];x[c+16>>2]=x[b+16>>2];x[c+20>>2]=x[b+20>>2];x[c+24>>2]=x[b+24>>2];x[c+28>>2]=x[b+28>>2];x[c+32>>2]=x[b+32>>2];x[c+36>>2]=x[b+36>>2];x[c+40>>2]=x[b+40>>2];x[c+44>>2]=x[b+44>>2];x[c+48>>2]=x[b+48>>2];x[c+52>>2]=x[b+52>>2];x[c+56>>2]=x[b+56>>2];x[c+60>>2]=x[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){x[c>>2]=x[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){v[c|0]=y[b|0];v[c+1|0]=y[b+1|0];v[c+2|0]=y[b+2|0];v[c+3|0]=y[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){v[c|0]=y[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=b&63;if(Vk(c)>>>0>e>>>0){e=KS(c,e);g=hb-16|0;hb=g;v[a+12|0]=0;AS(a);f=hb-32|0;hb=f;b:{c:{if(sd(a)>>>0<15){if(Dk(a)>>>0<15){break c}c=yb(a);c=Ao(f+12|0,15,Lb(a),c);x[114409]=0;P(347,a|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}fj(c)}hb=f+32|0;break b}Xc();p()}f=0-y[e+1|0]|0;while(1){c=e+(h<<1)|0;d=y[c+1|0];if(d){v[g+11|0]=64;f=d+(f<<16>>16)|0;d=uq(g+12|0,f&65535,y[tc(c+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[yb(a)>>2]){yS(a,d);break d}i=hb-32|0;hb=i;j=yb(a);c=Ao(i+12|0,Fe(a,Lb(a)+1|0),Lb(a),j);k=x[c+8>>2];x[114409]=0;T(782,j|0,k|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(347,a|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}fj(c);hb=i+32|0}h=h+1|0;if((h|0)!=15){continue}}break}c=y[e+32|0];v[a+14|0]=c>>>4;v[a+13|0]=c&15;c=y[e+31|0];e=c&15;v[a+15|0]=e;v[a+16|0]=e;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}hb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}b=kd(a);c=y[a+12|0]&-2|b^1;a=a+12|0}v[a|0]=c;return}a=N()|0;fj(c);Q(a|0);p()}function D9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=0,r=0,s=0,t=E(0);a:{if(!x[a+4272>>2]){break a}i=a+44|0;if(!Eh(i)){break a}k=Qd(i,0);l=Qd(i,1);m=ld(i,0);n=ld(i,1);if(d){j=a+4256|0;f=x[a+4268>>2];o=d;while(1){e=B[l>>2];g=B[k>>2];s=Pb(j,f<<1),t=g,B[s>>2]=t;s=Pb(j,x[a+4268>>2]<<1|1),t=e,B[s>>2]=t;e=E(F(XJ(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)));g=B[a+4276>>2];e=E(e*E(4.656612873077393e-10));e=E(E(B[(g>e?4240:4236)+a>>2]*E(g-e))+e);B[a+4276>>2]=e;p=E(B[a+4232>>2]*E(4.656612873077393e-10));g=B[a+4244>>2];e=E(E(E(B[a+4248>>2]*E(2147483648))*E(g-(e<g?g:e)))+E(2147483392));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}h=f<<5;q=h;r=h|-2147483648;h=f>>>0<67108864;e=E(p*E((h?q:r)>>>(h?31:32-(f>>>26|0)|0)>>>0));f=x[a+4272>>2];f=(((f+(x[a+4252>>2]+(x[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(f|0)<<1;s=m,t=E(e*B[Pb(j,f)>>2]),B[s>>2]=t;s=n,t=E(e*B[Pb(j,f|1)>>2]),B[s>>2]=t;h=x[a+4268>>2];f=h-1|0;x[a+4268>>2]=f;if(!h){f=x[a+4272>>2]+f|0;x[a+4268>>2]=f}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}Gi(a,b,c,ld(i,0),ld(i,1),d)}}function S5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=w[b>>1];b=hb-16|0;hb=b;x[114409]=0;O(15,b+8|0,a|0)|0;d=x[114409];x[114409]=0;b:{c:{d:{if((d|0)!=1){e:{if(!y[b+8|0]){break e}d=x[x[a>>2]-12>>2];h=x[(d+a|0)+4>>2];x[114409]=0;Fc(b+4|0,a+d|0);d=x[114409];x[114409]=0;f:{g:{h:{if((d|0)!=1){x[114409]=0;d=S(2455,b+4|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}Ob(b+4|0);e=jl(b,a);f=x[x[a>>2]-12>>2];x[114409]=0;f=a+f|0;i=S(16,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break g}e=x[e>>2];x[114409]=0;j=d;d=c&65535;g=c;c=h&74;c=aa(2456,j|0,e|0,f|0,i|0,((c|0)==64?d:(c|0)==8?d:g)|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}x[b+4>>2]=c;if(!hl(b+4|0)){break e}c=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+c|0,5);c=x[114409];x[114409]=0;if((c|0)!=1){break e}c=R(0)|0;break f}c=R(0)|0;break f}c=R(0)|0;Ob(b+4|0);break f}c=R(0)|0}Of(b+8|0);break d}Of(b+8|0);break c}c=R(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_()}hb=b+16|0;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}}function qI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;b=x[a+8>>2];x[e+32>>2]=e+36;x[e+28>>2]=e+40;c=x[e+32>>2];x[e+8>>2]=x[e+28>>2];x[e+12>>2]=c;x[e+20>>2]=a;x[e+24>>2]=e+44;c=x[e+24>>2];x[e>>2]=x[e+20>>2];x[e+4>>2]=c;a:{b:{switch(x[b+40>>2]){case 0:ws(e,b);break a;case 2:ws(e,yb(b));break a;case 3:i=fh(b);d=0;b=hb-80|0;hb=b;c=x[e>>2];g=x[c+4>>2];x[b+48>>2]=x[c+20>>2];h=x[c+16>>2];x[b+40>>2]=x[c+12>>2];x[b+44>>2]=h;tp(b+68|0,b+40|0,g);c=Oc(b+56|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+32>>2]=x[b+76>>2];f=x[b+72>>2];x[b+24>>2]=x[b+68>>2];x[b+28>>2]=f;x[b+16>>2]=x[c+8>>2];f=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=f;if(g){f=b+24|0;j=b+8|0;while(1){c=0;if(h){while(1){k=x[Vf(j,c,d)>>2];ef(i,c);l=Vf(f,c,d),m=E(E(k|0)*E(7.450580596923828e-9)),B[l>>2]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:ws(e,yb(b));break a;default:break b}}ws(e,yb(b))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function fV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((y[a|0]-16&255)>>>0<241){break a}b=a+1954|0;d=a+1698|0;while(1){if(v[d|0]<=-2){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}if(y[a+14|0]){break a}d=0;while(1){b:{e=(d<<4)+a|0;b=e+418|0;if(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)){break b}b=e+422|0;if(y[(D(d,13)+a|0)+942|0]|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0>1048575){break b}c=D(d,11)+a|0;g=c+1346|0;if(y[g|0]>15|y[c+1351|0]>3|y[c+1356|0]>3){break b}c:{if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break c}c=e+430|0;if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>1048574){break c}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0){break b}e=e+426|0;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))>>>0>(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0){break b}}d:{e:{if(f&1|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break e}if(dd(g,23389,11)){break e}f=0;break d}f=1}h=d>>>0>30;d=d+1|0;if((d|0)==32){break b}if(!y[(D(d,13)+a|0)+14|0]){continue}}break}f=f&h}return f&1}function EH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,q=0;a:{if(y[b+21|0]){o=1;j=x[e>>2];l=x[f>>2];b:{if((h|0)>0){q=D(d,g);m=x[b>>2];while(1){if(x[a+1396>>2]<=9){wk(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:k;break c}g=Il(a,b)}if((g|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((g|0)<0){if(!y[a+1376|0]){o=0;if(x[a+1384>>2]){break b}}gc(a,21);return 0}k=D(d,l);m=((m+k|0)+j|0)>(q|0)?(q-k|0)+j|0:m;k=D(g,x[b>>2]);d:{if(y[b+22|0]){g=0;n=E(0);if((m|0)<=0){break d}while(1){n=E(B[x[b+28>>2]+(g+k<<2)>>2]+n);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+B[x[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}x[e>>2]=j;x[f>>2]=l}return o}gc(a,21);return 0}ea(3764,9049,1887,2880);p()}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];i=x[a+44>>2];q=x[a+16>>2];e=x[a+4>>2];f=e;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;e=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=e;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){f=x[h+8>>2];b=x[h+12>>2]+q|0;r=v[b+1|0];p=v[b|0];e=x[a+60>>2];b=i;j=Yb(i,-16777216,16776704);i=x[a+64>>2];o=Yb(g,-16777216,16776704);s=x[a+72>>2];m=x[a+32>>2];n=x[c>>2];g=sqa(i,i>>31,j,j>>31);i=lb;j=g;g=x[a+68>>2];g=sqa(g,g>>31,o,o>>31);o=j+g|0;j=lb+i|0;j=g>>>0>o>>>0?j+1|0:j;i=((D(r-p|0,f>>>10&4194048)|0)/16384<<8)+(p<<16)|0;f=i;f=sqa(e,e>>31,f,f>>31);g=f+o|0;e=lb+j|0;e=g>>>0<f>>>0?e+1|0:e;j=n;l=x[a+28>>2]+l|0;n=l>>12;f=g+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=j+D(n,e);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(e,m);i=f-(i&s)|0;c=c+8|0;Tb(h+8|0,h);g=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];f=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=n;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=i;x[a+24>>2]=m;hb=h+16|0}function tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;i=x[a+40>>2];j=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=g;h=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=h;a:{if(!d){b=i>>12;h=j>>12;break a}l=b+24|0;while(1){b=x[e+24>>2];g=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;m=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];h=0;b=1;while(1){f=h<<1;x[(e+8|0)+(h<<2)>>2]=(((((D(w[(f|8)+g>>1],o)+D(w[(f|4)+g>>1],p)|0)+D(w[(f|12)+g>>1],n)|0)+D(w[(f|16)+g>>1],m)|0)/2|0)+((((D(w[(f|-8)+g>>1],s)+D(w[(f|-12)+g>>1],t)|0)+D(w[(f|-4)+g>>1],r)|0)+D(w[g+f>>1],q)|0)/2|0)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(h,x[e+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];g=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+32|0}function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;j=hb-16|0;hb=j;x[j+12>>2]=c>>>4;x[j+8>>2]=x[a>>2];d=x[Mb(j+12|0,j+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);m=f<<24|(f&65280)<<8;g=f&16711680;h=g>>>8|0;i=g<<24;e=f&-16777216;g=e>>>24|0;i=i|e<<8;e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,i|(((e&255)<<24|f>>>8)&-16777216|((e&16777215)<<8|f>>>24)&16711680|(e>>>8&65280|e>>>24)));e=g|h|m;h=0;l(1,e|(h|h));k=Td(Gg(+n())*32768);a:{if(F(k)<2147483648){e=~~k;break a}e=-2147483648}o=a,p=Wc(e),w[o>>1]=p;f=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);m=f<<24|(f&65280)<<8;g=f&16711680;h=g>>>8|0;i=g<<24;e=f&-16777216;g=e>>>24|0;i=i|e<<8;e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);l(0,i|(((e&255)<<24|f>>>8)&-16777216|((e&16777215)<<8|f>>>24)&16711680|(e>>>8&65280|e>>>24)));e=g|h|m;h=0;l(1,e|(h|h));k=Td(Gg(+n())*32768);b:{if(F(k)<2147483648){e=~~k;break b}e=-2147483648}o=a,p=Wc(e),w[o+2>>1]=p;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=j+16|0;return d<<4}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;e=x[a+12>>2];g=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}m=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];l=b;e=x[a>>2];x[f+8>>2]=e;x[f+12>>2]=b;x[f>>2]=h;x[f+4>>2]=g;e:{if(!d){b=i>>12;h=j>>12;break e}while(1){g=x[a+32>>2];b=x[f+8>>2];j=x[a+28>>2]+j|0;h=j>>12;e=(x[f+12>>2]<<1)+m|0;b=(b>>>16&65520)+k|0;e=(((((((D(w[e-4>>1],w[b+2>>1])+D(w[e-6>>1],w[b>>1])|0)+D(w[e-2>>1],w[b+4>>1])|0)+D(w[e>>1],w[b+6>>1])|0)+D(w[e+2>>1],w[b+8>>1])|0)+D(w[e+4>>1],w[b+10>>1])|0)+D(w[e+6>>1],w[b+12>>1])|0)+D(w[e+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(h,e);i=g+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(e,b);c=c+8|0;Tb(f+8|0,f);d=d-1|0;if(d){continue}break}e=x[f+8>>2];l=x[f+12>>2]}x[a>>2]=e;x[a+4>>2]=l;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=f+16|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-48|0;hb=e;g=An(a);a:{if(b-1025>>>0<4294966272){break a}f=x[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=x[g+8>>2];if(A[c+40>>2]<b>>>0|A[c+36>>2]>b>>>0){break a}f=x[a+12>>2]}c=D(Fk(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(A[a+12>>2]<b>>>0){d:{if(d){d=dc(a);break d}d=bc(a)}x[e+40>>2]=d;d=rd(e+44|0,e+40|0);f=e+32|0;di(f);d=x[d>>2];x[114409]=0;Z(1665,a|0,d|0,c|0,f|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}a=R(74984)|0;break c}if(d){i=e,j=dc(a),x[i+40>>2]=j;i=e,j=xL(e+40|0,0-c|0),x[i+32>>2]=j;c=rd(e+28|0,e+32|0);i=e,j=dc(a),x[i+20>>2]=j;d=x[rd(e+24|0,e+20|0)>>2];c=x[c>>2];x[114409]=0;U(1666,a|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}a=R(74984)|0;break c}i=e,j=bc(a),x[i+32>>2]=j;d=rd(e+16|0,e+32|0);i=e,j=bc(a),x[i+20>>2]=j;i=e,j=xL(e+20|0,c),x[i+40>>2]=j;c=x[rd(e+12|0,e+40|0)>>2];d=x[d>>2];x[114409]=0;U(1666,a|0,d|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}a=R(74984)|0}if((ib|0)==(ca(74984)|0)){Y(a|0)|0;_();break a}Q(a|0);p()}x[a+12>>2]=b;h=1}hb=e+48|0;return h|0}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];i=x[a+44>>2];q=x[a+16>>2];e=x[a+4>>2];f=e;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;e=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=e;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){f=x[h+8>>2];b=(x[h+12>>2]<<1)+q|0;r=w[b+2>>1];p=w[b>>1];e=x[a+60>>2];b=i;j=Yb(i,-16777216,16776704);i=x[a+64>>2];o=Yb(g,-16777216,16776704);s=x[a+72>>2];m=x[a+32>>2];n=x[c>>2];g=sqa(i,i>>31,j,j>>31);i=lb;j=g;g=x[a+68>>2];g=sqa(g,g>>31,o,o>>31);o=j+g|0;j=lb+i|0;j=g>>>0>o>>>0?j+1|0:j;i=p+((D(r-p|0,f>>>18|0)|0)/16384|0)<<8;f=i;f=sqa(e,e>>31,f,f>>31);g=f+o|0;e=lb+j|0;e=g>>>0<f>>>0?e+1|0:e;j=n;l=x[a+28>>2]+l|0;n=l>>12;f=g+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=j+D(n,e);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(e,m);i=f-(i&s)|0;c=c+8|0;Tb(h+8|0,h);g=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];f=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=n;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=i;x[a+24>>2]=m;hb=h+16|0}function hpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-2608|0;hb=f;a=Lm(f+8|0,a);x[a+1056>>2]=0;x[a+1060>>2]=0;Sb(a+1064|0,0,1536);x[114409]=0;V(561,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)!=1){if((w[a+1064>>1]|w[a+1066>>1])>=0){if(!c){break d}while(1){x[114409]=0;j=O(233,a|0,1)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}d=0;while(1){x[114409]=0;e=O(233,a|0,1)|0;k=x[114409];x[114409]=0;if((k|0)==1){break g}d=w[(a+D(d,6)|0)+(e?1066:1064)>>1];h:{if((d|0)>255){break h}e=a+D(d,6)|0;g=y[e+1068|0];if(w[e+1064>>1]<0){break h}if(w[e+1066>>1]>=0){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;v[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}x[114409]=0;d=S(562,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break c}}b=R(75852)|0;break e}b=R(75852)|0;break e}b=R(75852)|0}if((ib|0)!=(ca(75852)|0)){break a}Y(b|0)|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}}x[114409]=0;d=S(562,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break c}b=N()|0;break a}Ab(a);hb=f+2608|0;return d|0}b=N()|0}Ab(a);Q(b|0);p()}function KR(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=z[c>>1];a:{if(y[d|0]<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Ue(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Ue(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Ue(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Ue(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Ue(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}hb=f+16|0}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];h=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];i=b;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=f;break a}while(1){b=(x[g+8>>2]>>>21&2040)+32976|0;j=w[b+2>>1];e=(x[g+12>>2]<<1)+n|0;o=w[e>>1];p=w[b>>1];q=w[e-2>>1];r=w[b+4>>1];s=w[e+2>>1];t=w[b+6>>1];u=w[e+4>>1];e=x[a+60>>2];b=h;h=Yb(b,-16777216,16776704);i=x[a+64>>2];k=Yb(f,-16777216,16776704);v=x[a+72>>2];y=x[c>>2];f=sqa(i,i>>31,h,h>>31);i=lb;h=(((D(j,o)+D(p,q)|0)+D(r,s)|0)+D(t,u)|0)/16384<<8;j=sqa(e,e>>31,h,h>>31);e=j+f|0;f=lb+i|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=x[a+68>>2];i=sqa(e,e>>31,k,k>>31);e=j+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;e=(f|0)/256|0;x[c>>2]=D(e,m)+y;x[c+4>>2]=x[c+4>>2]+D(e,l);h=f-(h&v)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];i=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=i;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function Tp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=a+1074312|0;d=$b(e,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;a:{if(!(y[b+88|0]&2)|(!(x[a+480180>>2]&18)|A[b+84>>2]>c>>>0)){break a}d=x[b+84>>2];if(!d){break a}f=c;c=x[b+80>>2];c=((f-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&x[a+480180>>2]==16384)|0;b:{if(Ff(b+810|0)){d=x[b+656>>2];if(d){d=z[fd(d+236|0,y[b+810|0]-1|0)>>1];if(!d|d>>>0>z[a+480190>>1]){break b}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break b}if(!(!$b(e,57)&x[a+480180>>2]!=16)){x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(x[a+480180>>2]&1048581)){if($b(e,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break b}a=x[b+76>>2];if(a>>>0<5){break b}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|x[a+480180>>2]!=1){break b}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break b}x[b>>2]=0;x[b+4>>2]=c}}function Mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=x[a+12>>2];f=h;a:{b:{c:{e=x[a+8>>2];d:{if((f|0)<=1&e>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&e>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&e>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&e>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];k=x[a+4>>2];b=x[a>>2];x[g+8>>2]=b;x[g+12>>2]=k;x[g>>2]=e;x[g+4>>2]=f;e:{if(!d){e=i>>12;f=j>>12;break e}while(1){k=x[a+32>>2];b=x[g+8>>2];j=x[a+28>>2]+j|0;f=j>>12;e=x[g+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[e-2|0],w[b+2>>1])+D(v[e-3|0],w[b>>1])|0)+D(v[e-1|0],w[b+4>>1])|0)+D(v[e|0],w[b+6>>1])|0)+D(v[e+1|0],w[b+8>>1])|0)+D(v[e+2|0],w[b+10>>1])|0)+D(v[e+3|0],w[b+12>>1])|0)+D(v[e+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(f,b);i=k+i|0;e=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,e);c=c+8|0;Tb(g+8|0,g);d=d-1|0;if(d){continue}break}b=x[g+8>>2];k=x[g+12>>2]}x[a>>2]=b;x[a+4>>2]=k;x[a+40>>2]=i;x[a+20>>2]=f;x[a+36>>2]=j;x[a+24>>2]=e;hb=g+16|0}function dA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;yR(a,b);i=hb-16|0;hb=i;zd(c,1);a=b+22|0;a=y[a|0]|y[a+1|0]<<8;x[c>>2]=((a<<8|a>>>8)&65535)<<1;v[c+37|0]=y[b+24|0]<<4;v[i+15|0]=y[b+25|0];v[i+14|0]=64;k=c,l=y[tc(i+15|0,i+14|0)|0]<<2,w[k+30>>1]=l;a=b+26|0;a=y[a|0]|y[a+1|0]<<8;j=(a<<8|a>>>8)&65535;a=j<<1;f=b+28|0;f=y[f|0]|y[f+1|0]<<8;g=(f<<8|f>>>8)&65535;f=g<<1;a:{if(g>>>0<=1){g=x[c>>2];break a}g=x[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:x[c>>2]=0;break b;case 0:break b;default:break c}}x[c+4>>2]=a;f=a+f|0;x[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;x[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){x[c+4>>2]=0;x[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!e|a))){x[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}w[c+34>>1]=z[c+34>>1]|2}hb=i+16|0;a=h+8|0;rm(a,3,b);c=h+20|0;Kc(c,a);a=0;x[114409]=0;O(348,d|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(h+20|0);e=d;while(1){if((y[e|0]-1&255)>>>0<=30){v[e|0]=32}a=a+1|0;e=d+a|0;if((a|0)!=32){continue}break}a=eA(b);hb=h+32|0;return a}a=N()|0;xb(h+20|0);Q(a|0);p()}function Rpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-32|0;hb=e;a:{b:{if(x[a+8>>2]!=x[hc(a)>>2]){break b}j=a+8|0;k=a+4|0;g=x[a+4>>2];f=x[a>>2];if(g>>>0>f>>>0){i=hb-16|0;hb=i;c=hb-32|0;hb=c;Ae(c+24|0,g,x[j>>2]);h=x[c+24>>2];l=x[c+28>>2];d=hb-16|0;hb=d;m=((g-f>>1)+1|0)/-2<<1;n=g+m|0;f=n;x[d+8>>2]=f;x[d+12>>2]=h;if((h|0)!=(l|0)){while(1){jB(f,x[d+12>>2]);f=f+2|0;x[d+8>>2]=f;h=x[d+12>>2]+2|0;x[d+12>>2]=h;if((h|0)!=(l|0)){continue}break}}Dc(c+16|0,d+12|0,d+8|0);hb=d+16|0;o=c,q=Wo(g,x[c+16>>2]),x[o+12>>2]=q;o=c,q=ji(n,x[c+20>>2]),x[o+8>>2]=q;Dc(i+8|0,c+12|0,c+8|0);hb=c+32|0;hb=i+16|0;x[j>>2]=x[i+12>>2];x[k>>2]=x[k>>2]+m;break b}o=e,q=x[hc(a)>>2]-x[a>>2]|0,x[o+8>>2]=q;x[e+28>>2]=1;d=e+8|0;c=x[$c(d,e+28|0)>>2];c=Mq(d,c,c>>>2|0,x[a+16>>2]);d=Bb(e+4|0,x[a+4>>2]);g=x[Bb(e,x[a+8>>2])>>2];d=x[d>>2];x[114409]=0;T(506,c|0,d|0,g|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}Ub(a,c);Ub(k,c+4|0);Ub(j,c+8|0);Ub(hc(a),hc(c));Ru(c)}gB(x[a+16>>2],x[a+8>>2],b);x[a+8>>2]=x[a+8>>2]+2;hb=e+32|0;return}a=N()|0;Ru(c);Q(a|0);p()}function qE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=hb-1040|0;hb=i;r=x[114232];a:{b:{c:{a=i+16|0;l=z[((b>>>0<=153?b:0)<<1)+73840>>1]+71917|0;c=x[x[114276]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=yl(x[c+8>>2],e);g=yl(x[c+12>>2],e);d=yl(x[c+16>>2],e);d:{if(j>>>2>>>0<=h>>>0){break d}k=j-(h<<2)|0;if((d|g)&3|(k>>>0<=g>>>0|d>>>0>=k>>>0)){break d}s=d>>>2|0;t=g>>>2|0;g=0;while(1){k=h>>>1|0;m=k+g|0;n=m<<1;d=c+(n+t<<2)|0;o=yl(x[d>>2],e);d=yl(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break d}d=xj(l,c+d|0);if(!d){g=c+(s+n<<2)|0;h=yl(x[g>>2],e);e=yl(x[g+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break d}f=y[c+(e+h|0)|0]?0:c+e|0;break d}if((h|0)==1){break d}d=(d|0)<0;h=d?k:h-k|0;g=d?g:m;continue}}}f=f?f:l;c=Bf(f);e:{if(c>>>0>=1024){sc(a,f,1023);v[a+1023|0]=0;f=68;break e}sc(a,f,c+1|0);f=0}switch(f+1|0){case 1:break a;case 0:break c;default:break b}}f=x[114232]}a=17381;if((f|0)==28){break a}ra();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;yw(a,1024,8876,i)}x[114232]=r;Vb(q,a);hb=i+1040|0}function uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];f=g;j=x[a>>2];x[e+24>>2]=j;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;a:{if(!d){b=h>>12;g=i>>12;break a}l=b+24|0;while(1){b=x[e+24>>2];f=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;m=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];b=0;g=1;while(1){x[(e+8|0)+(b<<2)>>2]=((((D(v[(b|4)+f|0],o)+D(v[(b|2)+f|0],p)|0)+D(v[(b|6)+f|0],n)|0)+D(v[(b|8)+f|0],m)<<8>>1)+(((D(v[(b|-4)+f|0],s)+D(v[(b|-6)+f|0],t)|0)+D(v[(b|-2)+f|0],r)|0)+D(v[b+f|0],q)<<8>>1)|0)/16384;j=g;g=0;b=1;if(j){continue}break}b=x[a+32>>2];i=x[a+28>>2]+i|0;g=i>>12;x[c>>2]=x[c>>2]+D(g,x[e+8>>2]);h=b+h|0;b=h>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}j=x[e+24>>2];f=x[e+28>>2]}x[a>>2]=j;x[a+4>>2]=f;x[a+40>>2]=h;x[a+20>>2]=g;x[a+36>>2]=i;x[a+24>>2]=b;hb=e+32|0}function noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-32|0;hb=d;v[d+24|0]=44;x[d+16>>2]=-1;x[d+20>>2]=0;x[d+8>>2]=1042;x[d+12>>2]=2;h=d+8|0;f=hb-16|0;hb=f;i=f+4|0;c=hb-176|0;hb=c;e=qh(c+40|0);g=x[x[e>>2]-12>>2];x[114409]=0;j=$(125)|0;k=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{if((k|0)==1){break f}x[114409]=0;T(126,c+36|0,e+g|0,j|0);g=x[114409];x[114409]=0;if((g|0)==1){break f}Ob(c+36|0);x[114409]=0;P(151,e|0,h|0);g=x[114409];x[114409]=0;if((g|0)==1){break f}x[114409]=0;P(135,e|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;P(128,c+12|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break f}x[114409]=0;T(143,c+24|0,c+12|0,h|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;T(144,i|0,c+24|0,h|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}xb(c+24|0);xb(c+12|0);ae(e);hb=c+176|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;xb(c+24|0)}xb(c+12|0)}ae(e);Q(a|0);p()}x[114409]=0;T(13,a|0,0,i|0);a=x[114409];x[114409]=0;g:{if((a|0)!=1){xb(f+4|0);hb=f+16|0;break g}a=N()|0;xb(f+4|0);Q(a|0);p()}hb=d+32|0}function Zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=hb-16|0;hb=g;e=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];h=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=x[g+8>>2];b=x[g+12>>2]+n|0;o=v[b+2|0];p=v[b+1|0];q=v[b|0];r=v[b-1|0];f=x[a+60>>2];b=h;i=Yb(b,-16777216,16776704);h=x[a+64>>2];k=Yb(e,-16777216,16776704);s=x[a+72>>2];t=x[c>>2];e=sqa(h,h>>31,i,i>>31);h=lb;i=e;e=x[a+68>>2];e=sqa(e,e>>31,k,k>>31);k=i+e|0;i=lb+h|0;i=e>>>0>k>>>0?i+1|0:i;e=(j>>>21&2040)+32976|0;h=(((D(w[e+2>>1],q)+D(w[e>>1],r)|0)+D(w[e+4>>1],p)|0)+D(o,w[e+6>>1])<<8)/16384<<8;e=h;e=sqa(f,f>>31,e,e>>31);j=e+k|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,m)+t;x[c+4>>2]=x[c+4>>2]+D(f,l);h=e-(h&s)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];j=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{g=x[b>>2];b=x[b+4>>2];c=hb-16|0;hb=c;x[114409]=0;O(15,c+8|0,a|0)|0;d=x[114409];x[114409]=0;b:{c:{d:{if((d|0)!=1){e:{if(!y[c+8|0]){break e}d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+4|0,a+d|0);d=x[114409];x[114409]=0;f:{g:{h:{if((d|0)!=1){x[114409]=0;d=S(2455,c+4|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}Ob(c+4|0);e=jl(c,a);f=x[x[a>>2]-12>>2];x[114409]=0;f=a+f|0;h=S(16,f|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break g}e=x[e>>2];x[114409]=0;b=za(2458,d|0,e|0,f|0,h|0,g|0,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break g}x[c+4>>2]=b;if(!hl(c+4|0)){break e}b=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+b|0,5);b=x[114409];x[114409]=0;if((b|0)!=1){break e}b=R(0)|0;break f}b=R(0)|0;break f}b=R(0)|0;Ob(c+4|0);break f}b=R(0)|0}Of(c+8|0);break d}Of(c+8|0);break c}b=R(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_()}hb=c+16|0;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}}function DH(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){if((a|0)>=4){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>>2|0;while(1){b=d-4|0;h=B[b>>2];j=B[d>>2];k=B[c>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=B[b>>2]+f;j=E(k-j);f=E(f-h);B[d>>2]=E(B[e>>2]*j)-E(B[e+4>>2]*f);B[b>>2]=E(B[e+4>>2]*j)+E(B[e>>2]*f);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=k+f;i=c-12|0;h=B[i>>2];B[i>>2]=B[b>>2]+h;f=E(f-k);h=E(h-j);B[g>>2]=E(B[e+32>>2]*f)-E(B[e+36>>2]*h);B[b>>2]=E(B[e+36>>2]*f)+E(B[e+32>>2]*h);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=k+f;i=c-20|0;h=B[i>>2];B[i>>2]=B[b>>2]+h;f=E(f-k);h=E(h-j);B[g>>2]=E(B[e+64>>2]*f)-E(B[e+68>>2]*h);B[b>>2]=E(B[e+68>>2]*f)+E(B[e+64>>2]*h);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=k+f;i=c-28|0;h=B[i>>2];B[i>>2]=B[b>>2]+h;f=E(f-k);h=E(h-j);B[g>>2]=E(B[e+96>>2]*f)-E(B[e+100>>2]*h);B[b>>2]=E(B[e+100>>2]*f)+E(B[e+96>>2]*h);d=d-32|0;c=c-32|0;e=e+128|0;b=a>>>0>1;a=a-1|0;if(b){continue}break}}return}ea(11785,9049,2423,5182);p()}function hP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0;if(Lj(a)){f=y[(be(y[a+819|0])?a+819|0:a+821|0)|0];if(!(!$b(d+1074312|0,34)|(!f|f>>>0>120))){f=y[fc(x[a+656>>2]+108|0,f-1|0)|0]}d=a;j=E(E(b*E(16))*E(x[a+704>>2]));e=x[x[a+656>>2]+44>>2];c=(c+f|0)-61<<16>>16;a:{b:{a=x[a+876>>2]+x[a+768>>2]|0;if(a){h=x[e+36>>2];if(h){break b}}b=Ol(e,a+c<<16>>16);break a}g=h+1|0;c:{if((a|0)>=0){f=a;a=(a|0)/(g|0)|0;f=f-D(g,a)|0;break c}f=h-((a^-1)%(g|0)|0)|0;a=((a+1|0)/(g|0)|0)-1|0}k=w[e+28>>1];i=e+4|0;Lb(i);b=E(1);c=a+c<<16>>16;d:{if((c|0)<(k|0)){break d}if((c|0)>(z[e+28>>1]+Lb(i)|0)-1<<16>>16){break d}if(!f){b=B[Pb(i,c-w[e+28>>1]|0)>>2];break a}a=z[e>>1];e:{if((a|0)==3){a=e+16|0;if(Lb(a)){b=B[Pb(a,f-1|0)>>2];break e}a=z[e>>1]}f:{if((a&65535)!=1){break f}a=e+16|0;if(!Lb(a)){break f}g=z[e+30>>1];if((c|0)>=0){g=(c>>>0)%(g>>>0)|0}else{g=g+(((c^-1)>>>0)%(g>>>0)^-1)|0}b=B[Pb(a,(D(g<<16>>16,h)+f|0)-1|0)>>2];break e}b=pe(E(Ol(e,c+1<<16>>16)/Ol(e,c)),E(E(f|0)/E(g|0)))}b=E(B[Pb(i,c-w[e+28>>1]|0)>>2]*b)}}l=d,m=Si(E(j*b)),x[l+700>>2]=m}}function ly(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;f=a+2|0;if(!(y[f|0]==255|!y[f|0])){x[e+12>>2]=y[f|0]+1;x[e+8>>2]=10;Qg(b,x[fe(e+12|0,e+8|0)>>2]);f=y[a+3|0];v[b+15|0]=f;v[b+16|0]=f;v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];g=511;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}if(Lb(b)){i=g>>>1|d;d=0;while(1){h=(d<<2)+a|0;c=h+6|0;c=y[c|0]|y[c+1|0]<<8;j=Pb(b,d),k=c>>>4|0,w[j>>1]=k;c:{d:{if(!d){f=0;c=0;break d}c=d-1|0;if(z[Pb(b,d)>>1]>=z[Pb(b,c)>>1]){break c}f=d;c=z[Pb(b,c)>>1]+1|0}j=Pb(b,f),k=c,w[j>>1]=k}c=h+8|0;x[e+12>>2]=(((y[c|0]|y[c+1|0]<<8)<<16>>16)+i|0)/(g|0);x[e+8>>2]=0;x[e+4>>2]=64;c=x[gl(e+12|0,e+8|0,e+4|0)>>2];j=Pb(b,d),k=c,v[j+2|0]=k;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}v[b+12|0]=y[b+12|0]&254|v[a|0]&1;if(y[a|0]&2){c=y[b+15|0];c=(Lb(b)>>>0>=c>>>0)<<2|y[b+12|0]&-5}else{c=y[b+12|0]&-5}v[b+12|0]=c;e:{f:{if(y[a|0]&4){c=y[b+13|0];if(c>>>0<=y[b+14|0]){break f}}a=y[b+12|0]&-3;break e}a=Lb(b);a=y[b+12|0]&-3|(a>>>0>=c>>>0)<<1}v[b+12|0]=a}hb=e+16|0}function Tq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;a:{if(!b){break a}if(c){d=Dd(g+8|0,a);c=hb-16|0;hb=c;x[c+12>>2]=b;a=x[d+4>>2];b:{if(!a){a=x[d>>2];break b}x[c+8>>2]=32-a;b=Mb(c+8|0,c+12|0);a=x[d>>2];b=x[b>>2];x[a>>2]=x[a>>2]|-1<<x[d+4>>2]&-1>>>x[c+8>>2]-b;b=x[c+12>>2]-b|0;x[c+12>>2]=b;a=a+4|0;x[d>>2]=a}x[c+4>>2]=-1;f=b>>>5|0;e=f;if(e){while(1){x[a>>2]=x[c+4>>2];a=a+4|0;e=e-1|0;if(e){continue}break}}a=x[c+12>>2];b=b&-32;e=a-b|0;x[c+12>>2]=e;if((a|0)!=(b|0)){a=x[d>>2]+(f<<2)|0;x[d>>2]=a;x[a>>2]=x[a>>2]|-1>>>32-e}hb=c+16|0;break a}d=Dd(g,a);c=hb-16|0;hb=c;x[c+12>>2]=b;a=x[d+4>>2];c:{if(!a){a=x[d>>2];break c}x[c+8>>2]=32-a;b=Mb(c+8|0,c+12|0);a=x[d>>2];b=x[b>>2];x[a>>2]=x[a>>2]&(-1<<x[d+4>>2]&-1>>>x[c+8>>2]-b^-1);b=x[c+12>>2]-b|0;x[c+12>>2]=b;a=a+4|0;x[d>>2]=a}x[c+4>>2]=0;f=b>>>5|0;e=f;if(e){h=x[c+4>>2];while(1){x[a>>2]=h;a=a+4|0;e=e-1|0;if(e){continue}break}}a=x[c+12>>2];b=b&-32;e=a-b|0;x[c+12>>2]=e;if((a|0)!=(b|0)){a=x[d>>2]+(f<<2)|0;x[d>>2]=a;x[a>>2]=x[a>>2]&(-1>>>32-e^-1)}hb=c+16|0}hb=g+16|0}function d2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;a=Gw(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Wr(b,c,0)|0)!=-1){while(1){f=Wr(b,c,e);x[114409]=0;W(168,d+8|0,b|0,e|0,f-e|0);f=x[114409];x[114409]=0;if((f|0)==1){break j}x[114409]=0;P(169,d+20|0,d+8|0);f=x[114409];x[114409]=0;if((f|0)==1){break i}x[114409]=0;P(170,a|0,d+20|0);f=x[114409];x[114409]=0;if((f|0)==1){break h}xb(d+20|0);xb(d+8|0);e=Wr(b,c,e)+Cb(c)|0;if((Wr(b,c,e)|0)!=-1){continue}break}}k:{if(kd(a)){x[114409]=0;W(168,d+20|0,b|0,e|0,-1);c=x[114409];x[114409]=0;if((c|0)==1){break f}c=d+20|0;f=Cb(c);xb(c);if(!f){break k}}x[114409]=0;W(168,d+8|0,b|0,e|0,-1);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;P(169,d+20|0,d+8|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;P(170,a|0,d+20|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+20|0);xb(d+8|0)}hb=d+32|0;return}e=N()|0;break a}e=N()|0;break g}e=N()|0;xb(d+20|0)}xb(d+8|0);break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break b}e=N()|0;xb(d+20|0)}xb(d+8|0)}Al(a);Q(e|0);p()}function xM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{switch(x[a+480224>>2]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=sqa(c,c>>31,5e4,0);f=lb;b=x[$c(d+12|0,d+8|0)>>2];c=Ec(tqa(c,f,b,b>>31),lb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=sqa(c,c>>31,1e4,0);f=lb;b=x[$c(d+12|0,d+8|0)>>2];c=Ec(tqa(c,f,b,b>>31),lb);break a;case 1:break b}}e=+A[a+24620>>2]*60/(+A[b+44>>2]*1e-4*(+(sqa(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(lb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!pg(c,z[b+60>>1])){break d}if(!(kd(Zb(c,z[b+60>>1])+24|0)^1)){break d}c=wM(Zb(c,z[b+60>>1]));break c}c=a+480248|0}if(!kd(c)){e=e*5.960464477539063e-8*+A[Pb(c,A[b+48>>2]%(Lb(c)>>>0)|0)>>2]}e:{if(F(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+C[b+8>>3];C[b+8>>3]=e;if(!(e<1)){C[b+8>>3]=e+-1;c=c+1|0;break a}if(C[a+1074384>>3]>-1){break a}C[b+8>>3]=e+1;c=c-1|0}b=sqa(x[a+480244>>2],0,c,0);a=lb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=id((a&65535)<<16|b>>>16,a>>>16|0);hb=d+16|0;return(a>>>0<=1?1:a)|0}function Ed(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;x[c+16>>2]=0;x[c+12>>2]=2710;b=x[c+16>>2];x[c>>2]=x[c+12>>2];x[c+4>>2]=b;d=x[c+4>>2];b=c+20|0;x[b+4>>2]=x[c>>2];x[b+8>>2]=d;x[b>>2]=a;d=hb-16|0;hb=d;if(x[a>>2]!=-1){a:{b=Bb(d+8|0,gT(d+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{c:{if(!x[a>>2]){_e(a,1);x[114409]=0;e=x[114409];x[114409]=0;d:{if((e|0)==1){break d}x[114409]=0;V(2716,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;b=x[114409];x[114409]=0;if((b|0)==1){break d}x[a>>2]=-1;x[114409]=0;b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;b=x[114409];x[114409]=0;if((b|0)!=1){break a}}Y(R(0)|0)|0;x[114409]=0;c=x[114409];x[114409]=0;e:{if((c|0)==1){break e}_e(a,0);x[114409]=0;a=x[114409];x[114409]=0;if((a|0)==1){break e}x[114409]=0;a=x[114409];x[114409]=0;if((a|0)==1){break e}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)==1){break c}Q(a|0);p()}break a}R(0)|0;zb()}p()}}hb=d+16|0;hb=c+32|0;return x[a+4>>2]-1|0}function q6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=x[b>>2];b=hb-16|0;hb=b;x[114409]=0;O(15,b+8|0,a|0)|0;d=x[114409];x[114409]=0;b:{c:{d:{if((d|0)!=1){e:{if(!y[b+8|0]){break e}d=x[x[a>>2]-12>>2];x[114409]=0;Fc(b+4|0,a+d|0);d=x[114409];x[114409]=0;f:{g:{h:{if((d|0)!=1){x[114409]=0;d=S(2455,b+4|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}Ob(b+4|0);e=jl(b,a);f=x[x[a>>2]-12>>2];x[114409]=0;f=a+f|0;g=S(16,f|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break g}e=x[e>>2];x[114409]=0;c=aa(2456,d|0,e|0,f|0,g|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}x[b+4>>2]=c;if(!hl(b+4|0)){break e}c=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+c|0,5);c=x[114409];x[114409]=0;if((c|0)!=1){break e}c=R(0)|0;break f}c=R(0)|0;break f}c=R(0)|0;Ob(b+4|0);break f}c=R(0)|0}Of(b+8|0);break d}Of(b+8|0);break c}c=R(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_()}hb=b+16|0;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}}function Qr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=hb-16|0;hb=m;x[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break b}a=0;v[b|0]=0;b=x[e>>2];x[e>>2]=b+1;v[b|0]=46;if(!Cb(h)){break a}b=x[j>>2];if((b-i|0)>159){break a}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Cb(h)){break c}if(!y[b|0]){break b}a=0;b=x[j>>2];if((b-i|0)>159){break a}a=x[k>>2];x[j>>2]=b+4;x[b>>2]=a;a=0;x[k>>2]=0;break a}a=-1;f=ow(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=v[(f>>2)+64896|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=x[e>>2];if((b|0)!=(d|0)){a=-1;if((cn(v[b-1|0])|0)!=(cn(v[c|0])|0)){break a}}x[e>>2]=b+1;v[b|0]=g;a=0;break a}v[c|0]=80;break d}a=cn(g);if((a|0)!=v[c|0]){break d}n=c,o=_F(a),v[n|0]=o;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(h)){break d}a=x[j>>2];if((a-i|0)>159){break d}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b}a=x[e>>2];x[e>>2]=a+1;v[a|0]=g;a=0;if((f|0)>84){break a}x[k>>2]=x[k>>2]+1;break a}a=-1}hb=m+16|0;return a|0}function p5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=C[b>>3];b=hb-16|0;hb=b;x[114409]=0;O(15,b+8|0,a|0)|0;c=x[114409];x[114409]=0;b:{c:{d:{if((c|0)!=1){e:{if(!y[b+8|0]){break e}c=x[x[a>>2]-12>>2];x[114409]=0;Fc(b+4|0,a+c|0);c=x[114409];x[114409]=0;f:{g:{h:{if((c|0)!=1){x[114409]=0;c=S(2455,b+4|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break h}Ob(b+4|0);d=jl(b,a);e=x[x[a>>2]-12>>2];x[114409]=0;e=a+e|0;g=S(16,e|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break g}d=x[d>>2];x[114409]=0;c=Qa(2459,c|0,d|0,e|0,g|0,+f)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}x[b+4>>2]=c;if(!hl(b+4|0)){break e}c=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+c|0,5);c=x[114409];x[114409]=0;if((c|0)!=1){break e}c=R(0)|0;break f}c=R(0)|0;break f}c=R(0)|0;Ob(b+4|0);break f}c=R(0)|0}Of(b+8|0);break d}Of(b+8|0);break c}c=R(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_()}hb=b+16|0;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}}function Iz(a,b){a=a|0;b=b|0;a:{b:{switch((y[a+3|0]|64)+-64|0){case 0:v[a+3|0]=y[a+5|0]?42:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(b){break a}b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=b?32:31;return;case 29:v[a+3|0]=33;return;case 27:v[a+3|0]=34;return;case 50:v[a+3|0]=b?25:0;return;case 51:v[a+3|0]=b?30:0;return;default:break b}}v[a+3|0]=0}}function Sr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=hb-16|0;hb=m;v[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break b}a=0;v[b|0]=0;b=x[e>>2];x[e>>2]=b+1;v[b|0]=46;if(!Cb(h)){break a}b=x[j>>2];if((b-i|0)>159){break a}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Cb(h)){break c}if(!y[b|0]){break b}a=0;b=x[j>>2];if((b-i|0)>159){break a}a=x[k>>2];x[j>>2]=b+4;x[b>>2]=a;a=0;x[k>>2]=0;break a}a=-1;f=Ll(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=v[f+64896|0];d:{e:{switch((f&-2)-22|0){case 2:b=x[e>>2];if((b|0)!=(d|0)){if((cn(v[b-1|0])|0)!=(cn(v[c|0])|0)){break a}}x[e>>2]=b+1;v[b|0]=g;a=0;break a;case 0:v[c|0]=80;break d;default:break e}}a=cn(g);if((a|0)!=v[c|0]){break d}n=c,o=_F(a),v[n|0]=o;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(h)){break d}a=x[j>>2];if((a-i|0)>159){break d}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b}a=x[e>>2];x[e>>2]=a+1;v[a|0]=g;a=0;if((f|0)>21){break a}x[k>>2]=x[k>>2]+1;break a}a=-1}hb=m+16|0;return a|0}function zE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=(a+b|0)-1&0-a;c=b>>>0<d>>>0?d:b;b=0;f=hb-16|0;hb=f;if(!((c>>>0)%(a>>>0)|a&3)){a:{b:{if((a|0)==8){a=xd(c);break b}b=28;if(a&3|a>>>0<4){break a}d=a>>>2|0;if(d-1&d){break a}b=48;if(c>>>0>-64-a>>>0){break a}d=16;a=a>>>0<=16?16:a;b=a>>>0<=16?16:a;c:{if(!(b-1&b)){a=b;break c}while(1){a=d;d=a<<1;if(a>>>0<b>>>0){continue}break}}d:{if(c>>>0>=-64-a>>>0){x[114232]=48;b=0;break d}d=c>>>0<11?16:c+11&-8;c=xd((d+a|0)+12|0);b=0;if(!c){break d}b=c-8|0;e:{if(!(c&a-1)){a=b;break e}g=c-4|0;h=x[g>>2];e=a;a=((a+c|0)-1&0-a)-8|0;a=(a-b>>>0<=15?e:0)+a|0;c=a-b|0;e=(h&-8)-c|0;if(!(h&3)){b=x[b>>2];x[a+4>>2]=e;x[a>>2]=b+c;break e}x[a+4>>2]=e|x[a+4>>2]&1|2;e=a+e|0;x[e+4>>2]=x[e+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;e=b+c|0;x[e+4>>2]=x[e+4>>2]|1;ks(b,c)}b=x[a+4>>2];f:{if(!(b&3)){break f}c=b&-8;if(c>>>0<=d+16>>>0){break f}x[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;x[b+4>>2]=d|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;ks(b,d)}b=a+8|0}a=b}b=48;if(!a){break a}x[f+12>>2]=a;b=0}b=b?0:x[f+12>>2]}hb=f+16|0;return b}function Qn(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(b&2){v[a+861|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;v[a+819|0]=0;x[a+804>>2]=0;x[a+824>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if($b(c+1074312|0,23)){w[a+798>>1]=0;w[a+800>>1]=1}v[a+866|0]=0;v[a+859|0]=0;v[a+871|0]=255;x[a+660>>2]=0;v[a+872|0]=y[a+872|0]&248;au(a+810|0)}if(b&4){x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;v[a+865|0]=0;v[a+858|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+840>>1]=0;v[a+839|0]=0;w[a+856>>1]=32512;w[a+862>>1]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+876>>2]=0;x[a+880>>2]=0;v[a+872|0]=y[a+872|0]&231}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+760>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|e;break a}x[a+760>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+796>>1]=0;v[a+817|0]=0;v[a+818|0]=0}}function Kc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=x[b>>2];f=hb-48|0;hb=f;e=x[b+4>>2];d=y[b+8|0];e=e-(((d|0)==1|(d|0)==4)&(e|0)!=0)|0;b=Xb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){v[f+36|0]=0;a=Ll(c,c+e|0,f+36|0);x[114409]=0;U(120,b|0,c|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break h}a=N()|0;break b}if((d-3&255)>>>0>1){break h}x[114409]=0;U(120,b|0,c|0,c+e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break g}c=td(b);d=nf(b);e=td(b);a=hb-16|0;hb=a;x[a+8>>2]=d;x[a+12>>2]=c;x[a+4>>2]=e;if(Hb(a+12|0,a+8|0)){while(1){d=a+4|0;c=a+12|0;e=v[x[c>>2]];v[x[d>>2]]=e?e:32;gg(c);gg(d);if(Hb(c,a+8|0)){continue}break}}hb=a+16|0;x[114409]=0;c=O(121,f+24|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;d=O(122,f+12|0,13666)|0;a=x[114409];x[114409]=0;if((a|0)==1){break e}x[114409]=0;T(123,f+36|0,c|0,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}a=f+36|0;Eb(b,a);xb(a);xb(d);xb(c)}hb=f+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;xb(d)}xb(c)}xb(b);Q(a|0);p()}}function sQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-48|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+44>>2]=0;yb(b);Id(a+8|0,d+44|0,d+43|0);if(x[b+4>>2]){Uq(a,x[b+4>>2]);cm(d+32|0,b);lq(d+24|0,b);b=x[d+36>>2];x[d+16>>2]=x[d+32>>2];x[d+20>>2]=b;b=x[d+28>>2];x[d+8>>2]=x[d+24>>2];x[d+12>>2]=b;c=hb-80|0;hb=c;g=x[a+4>>2];b=x[d+20>>2];i=b;e=x[d+16>>2];x[c+72>>2]=e;x[c+76>>2]=b;b=x[d+12>>2];m=b;h=x[d+8>>2];x[c+64>>2]=h;x[c+68>>2]=b;x[c+24>>2]=e;x[c+28>>2]=i;x[c+16>>2]=h;x[c+20>>2]=b;b=hb-32|0;hb=b;j=x[c+28>>2];f=x[c+24>>2];x[b+24>>2]=f;x[b+28>>2]=j;k=x[c+20>>2];l=x[c+16>>2];x[b+16>>2]=l;x[b+20>>2]=k;x[b+8>>2]=f;x[b+12>>2]=j;x[b>>2]=l;x[b+4>>2]=k;f=TQ(b+8|0,b);hb=b+32|0;b=x[a+4>>2]+f|0;x[a+4>>2]=b;if(!((b-1^g-1)>>>0<32?g:0)){x[x[a>>2]+((b>>>0>=33?b-1>>>5|0:0)<<2)>>2]=0}x[c+48>>2]=h;x[c+52>>2]=m;x[c+56>>2]=e;x[c+60>>2]=i;b=c+40|0;zo(b,a,g);e=x[c+60>>2];x[c+8>>2]=x[c+56>>2];x[c+12>>2]=e;e=x[c+52>>2];x[c>>2]=x[c+48>>2];x[c+4>>2]=e;UQ(c+32|0,c+8|0,c,b);hb=c+80|0}hb=d+48|0;return a|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[i+8>>2]=b;x[i+12>>2]=f;j=x[a+12>>2];x[i>>2]=x[a+8>>2];x[i+4>>2]=j;a:{if(!d){j=k>>12;h=l>>12;break a}while(1){h=w[(x[i+12>>2]<<1)+n>>1];f=x[a+60>>2];b=e;e=Yb(e,-16777216,16776704);j=x[a+64>>2];g=Yb(g,-16777216,16776704);o=x[a+72>>2];p=x[a+32>>2];q=x[c>>2];m=h<<8;h=m;f=sqa(f,f>>31,h,h>>31);h=lb;j=sqa(j,j>>31,e,e>>31);f=j+f|0;e=lb+h|0;e=f>>>0<j>>>0?e+1|0:e;h=f;f=x[a+68>>2];f=sqa(f,f>>31,g,g>>31);g=h+f|0;e=lb+e|0;e=f>>>0>g>>>0?e+1|0:e;l=x[a+28>>2]+l|0;h=l>>12;g=g+8388608|0;e=((g>>>0<8388608?e+1|0:e)&16777215)<<8|g>>>24;g=(e|0)/256|0;x[c>>2]=D(h,g)+q;k=k+p|0;j=k>>12;x[c+4>>2]=x[c+4>>2]+D(g,j);e=e-(m&o)|0;c=c+8|0;Tb(i+8|0,i);g=b;d=d-1|0;if(d){continue}break}b=x[i+8>>2];f=x[i+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=h;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=e;x[a+24>>2]=j;hb=i+16|0}function Dx(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=hb-96|0;hb=g;h=a+24|0;Gp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;x[g+92>>2]=f;x[g+88>>2]=e;x[g+84>>2]=d;x[g+80>>2]=c;c=g+80|0;c=$I(g+32|0,c,aJ(c),b);d=x[a+32>>2];i=B[a+48>>2];e=x[c+12>>2];x[g+8>>2]=x[c+8>>2];x[g+12>>2]=e;e=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=e;c=hb-16|0;hb=c;e=x[g+12>>2];x[c+8>>2]=x[g+8>>2];x[c+12>>2]=e;e=x[g+4>>2];x[c>>2]=x[g>>2];x[c+4>>2]=e;e=Ds(g+48|0);x[e+8>>2]=d;x[e+4>>2]=0;x[e>>2]=82864;d=x[c+4>>2];x[e+12>>2]=x[c>>2];x[e+16>>2]=d;d=x[c+12>>2];x[e+20>>2]=x[c+8>>2];x[e+24>>2]=d;B[e+28>>2]=i;x[e>>2]=82808;hb=c+16|0;d=0;a:{while(1){if(b){c=x[h>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[114409]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;f=O(2278,g+24|0,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}f=x[f>>2];x[114409]=0;c=U(2279,c|0,f|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}d=c+d|0;b=b-c|0;if(c){continue}}break}if(!(x[a+52>>2]!=1|d)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=g+96|0;return d}Q(N()|0);p()}function Cx(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=hb-96|0;hb=g;h=a+24|0;Gp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;x[g+92>>2]=f;x[g+88>>2]=e;x[g+84>>2]=d;x[g+80>>2]=c;c=g+80|0;c=$I(g+32|0,c,aJ(c),b);d=x[a+32>>2];i=B[a+48>>2];e=x[c+12>>2];x[g+8>>2]=x[c+8>>2];x[g+12>>2]=e;e=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=e;c=hb-16|0;hb=c;e=x[g+12>>2];x[c+8>>2]=x[g+8>>2];x[c+12>>2]=e;e=x[g+4>>2];x[c>>2]=x[g>>2];x[c+4>>2]=e;e=Ds(g+48|0);x[e+8>>2]=d;x[e+4>>2]=0;x[e>>2]=82960;d=x[c+4>>2];x[e+12>>2]=x[c>>2];x[e+16>>2]=d;d=x[c+12>>2];x[e+20>>2]=x[c+8>>2];x[e+24>>2]=d;B[e+28>>2]=i;x[e>>2]=82912;hb=c+16|0;d=0;a:{while(1){if(b){c=x[h>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[114409]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;f=O(2278,g+24|0,g+16|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}f=x[f>>2];x[114409]=0;c=U(2279,c|0,f|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}d=c+d|0;b=b-c|0;if(c){continue}}break}if(!(x[a+52>>2]!=1|d)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=g+96|0;return d}Q(N()|0);p()}function oh(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=wi(a)&2047;c=wi(5551115123125783e-32);a:{if(e-c>>>0>=wi(512)-c>>>0){if(c>>>0>e>>>0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(wi(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(wi(Infinity)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return ss(3105036184601418e216)}if(c>>>0<3230714880){break b}return ss(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[6416];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[6421]+C[6420]);b=b*(a*C[6419]+C[6418]);a=a*C[6417];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+51376>>3]));d=d+51384|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){qH(rH()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[i+8>>2]=b;x[i+12>>2]=f;j=x[a+12>>2];x[i>>2]=x[a+8>>2];x[i+4>>2]=j;a:{if(!d){j=k>>12;h=l>>12;break a}while(1){h=v[x[i+12>>2]+n|0];f=x[a+60>>2];b=e;e=Yb(e,-16777216,16776704);j=x[a+64>>2];g=Yb(g,-16777216,16776704);o=x[a+72>>2];p=x[a+32>>2];q=x[c>>2];m=h<<16;h=m;f=sqa(f,f>>31,h,h>>31);h=lb;j=sqa(j,j>>31,e,e>>31);f=j+f|0;e=lb+h|0;e=f>>>0<j>>>0?e+1|0:e;h=f;f=x[a+68>>2];f=sqa(f,f>>31,g,g>>31);g=h+f|0;e=lb+e|0;e=f>>>0>g>>>0?e+1|0:e;l=x[a+28>>2]+l|0;h=l>>12;g=g+8388608|0;e=((g>>>0<8388608?e+1|0:e)&16777215)<<8|g>>>24;g=(e|0)/256|0;x[c>>2]=D(h,g)+q;k=k+p|0;j=k>>12;x[c+4>>2]=x[c+4>>2]+D(g,j);e=e-(m&o)|0;c=c+8|0;Tb(i+8|0,i);g=b;d=d-1|0;if(d){continue}break}b=x[i+8>>2];f=x[i+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=h;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=e;x[a+24>>2]=j;hb=i+16|0}function qp(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);if((a|0)>=4){c=(c<<2)+b|0;d=c+(d<<2)|0;b=a>>>2|0;a=f<<2;while(1){f=d-4|0;i=B[f>>2];k=B[d>>2];l=B[c>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=B[f>>2]+g;k=E(l-k);g=E(g-i);B[d>>2]=E(B[e>>2]*k)-E(B[e+4>>2]*g);B[f>>2]=E(B[e+4>>2]*k)+E(B[e>>2]*g);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=l+g;j=c-12|0;i=B[j>>2];B[j>>2]=B[f>>2]+i;e=a+e|0;g=E(g-l);i=E(i-k);B[h>>2]=E(B[e>>2]*g)-E(B[e+4>>2]*i);B[f>>2]=E(B[e+4>>2]*g)+E(B[e>>2]*i);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=l+g;j=c-20|0;i=B[j>>2];B[j>>2]=B[f>>2]+i;e=a+e|0;g=E(g-l);i=E(i-k);B[h>>2]=E(B[e>>2]*g)-E(B[e+4>>2]*i);B[f>>2]=E(B[e+4>>2]*g)+E(B[e>>2]*i);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=l+g;j=c-28|0;i=B[j>>2];B[j>>2]=B[f>>2]+i;e=a+e|0;g=E(g-l);i=E(i-k);B[h>>2]=E(B[e>>2]*g)-E(B[e+4>>2]*i);B[f>>2]=E(B[e+4>>2]*g)+E(B[e>>2]*i);e=a+e|0;d=d-32|0;c=c-32|0;f=b>>>0>1;b=b-1|0;if(f){continue}break}}}function Nw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;x[114409]=0;O(15,c+8|0,a|0)|0;d=x[114409];x[114409]=0;a:{b:{c:{if((d|0)!=1){d:{if(!y[c+8|0]){break d}d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+4|0,a+d|0);d=x[114409];x[114409]=0;e:{f:{g:{if((d|0)!=1){x[114409]=0;d=S(2455,c+4|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}Ob(c+4|0);e=jl(c,a);f=x[x[a>>2]-12>>2];x[114409]=0;f=a+f|0;g=S(16,f|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break f}e=x[e>>2];x[114409]=0;b=aa(2457,d|0,e|0,f|0,g|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}x[c+4>>2]=b;if(!hl(c+4|0)){break d}b=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+b|0,5);b=x[114409];x[114409]=0;if((b|0)!=1){break d}b=R(0)|0;break e}b=R(0)|0;break e}b=R(0)|0;Ob(c+4|0);break e}b=R(0)|0}Of(c+8|0);break c}Of(c+8|0);break b}b=R(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=c+16|0;return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function eH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=a;d=hb-208|0;hb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;e=4;f=2;while(1){a=b;b=(e+4|0)+b|0;x[(d+16|0)+(f<<2)>>2]=b;f=f+1|0;e=a;if(b>>>0<h>>>0){continue}break}a=(g+h|0)-4|0;b:{if(a>>>0<=g>>>0){f=0;b=1;a=0;break b}f=1;b=1;while(1){c:{if((f&3)==3){Yw(g,c,b,d+16|0);qs(d+8|0,2);b=b+2|0;break c}e=b-1|0;d:{if(A[(d+16|0)+(e<<2)>>2]>=a-g>>>0){ps(g,c,d+8|0,b,0,d+16|0);break d}Yw(g,c,b,d+16|0)}if((b|0)==1){os(d+8|0,1);b=0;break c}os(d+8|0,e);b=1}e=x[d+8>>2];f=e|1;x[d+8>>2]=f;g=g+4|0;if(a>>>0>g>>>0){continue}break}f=e>>>0>1;a=x[d+12>>2]!=0}ps(g,c,d+8|0,b,0,d+16|0);if(!(a|((b|0)!=1|f))){break a}while(1){e:{if((b|0)<=1){e=d+8|0;a=hH(e);qs(e,a);f=x[d+8>>2];a=a+b|0;break e}e=d+8|0;os(e,2);x[d+8>>2]=x[d+8>>2]^7;qs(e,1);i=g-4|0;h=d+16|0;a=b-2|0;ps(i-x[h+(a<<2)>>2]|0,c,e,b-1|0,1,h);os(e,1);f=x[d+8>>2]|1;x[d+8>>2]=f;ps(i,c,e,a,1,h)}b=a;g=g-4|0;if(x[d+12>>2]|((b|0)!=1|(f|0)!=1)){continue}break}}hb=d+208|0}function tN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;e=D(b,896)+a|0;a:{if(c){f=g+8|0;Kb(f,a+1074312|0,90);if(!Ib(f)){v[(D(b,896)+a|0)+1075815|0]=c}v[(D(b,896)+a|0)+1075816|0]=c;break a}c=y[e+1075816|0]}e=e+1074984|0;f=c&255;i=0-f|0;h=d?h:!(x[a+480180>>2]&204473357);oN(a,b,i,h);b:{c:{if(x[a+480180>>2]!=16777216){break c}j=x[(D(b,896)+a|0)+1075640>>2];if(!j|!x[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){nN(a,e,240-f|0);break b}if(!(b>>>0<224|d)){mN(e,224-f|0);break b}lN(e,i);break b}if(x[a+480180>>2]==268435456){x[(D(b,896)+a|0)+1075692>>2]=65535}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}iN(a,e,d);break b}if(x[a+480180>>2]==524288){break d}qN(a,e,d);break b}if(x[a+480180>>2]!=524288){break b}}e:{if(!(v[(D(b,896)+a|0)+1075856|0]&1)){break e}if(x[a+1074416>>2]==1){b=g+8|0;Kb(b,a+1074312|0,6);if(Ib(b)){break e}}if(x[a+480180>>2]&32832){break e}if(!(x[a+480208>>2]&2)|x[a+480180>>2]!=8){break b}}jN(a,e,f<<2)}hb=g+16|0}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;f=Xb(e+20|0);a:{b:{c:{if(c>>>0<=63){break c}x[114409]=0;c=S(314,b|0)|0;d=x[114409];x[114409]=0;d:{if((d|0)!=1){x[e+16>>2]=c;if((c|0)>0){break d}x[114409]=0;O(122,a|0,17381)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break b}}break a}x[114409]=0;c=S(305,b|0)|0;d=x[114409];x[114409]=0;e:{if((d|0)==1){break e}x[114409]=0;c=S(880,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}x[114409]=0;x[e+12>>2]=c;c=O(436,e+16|0,e+12|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break e}c=x[c>>2];x[114409]=0;P(112,f|0,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{x[114409]=0;c=S(425,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}if(!c){break f}x[114409]=0;U(1628,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[114409];x[114409]=0;if((c|0)!=1){continue}}break}break a}x[114409]=0;O(313,b|0,4)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}Jd(a,f)}xb(f);hb=e+32|0;return}a=N()|0;xb(f);Q(a|0);p()}function vM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-560|0;hb=f;w[f+558>>1]=b;a:{b:{if((b-256&65535)>>>0<65281){break b}b=((b<<2)+a|0)+900380|0;d=x[b>>2];c:{if(d){b=dP(f,c);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=y[b+11|0]|y[b+12|0]<<8|(y[b+13|0]<<16|y[b+14|0]<<24);e=y[b+7|0]|y[b+8|0]<<8|(y[b+9|0]<<16|y[b+10|0]<<24);v[d+7|0]=e;v[d+8|0]=e>>>8;v[d+9|0]=e>>>16;v[d+10|0]=e>>>24;v[d+11|0]=c;v[d+12|0]=c>>>8;v[d+13|0]=c>>>16;v[d+14|0]=c>>>24;v[d+15|0]=y[b+15|0];c=x[b+44>>2];x[d+40>>2]=x[b+40>>2];x[d+44>>2]=c;c=x[b+36>>2];x[d+32>>2]=x[b+32>>2];x[d+36>>2]=c;c=x[b+28>>2];x[d+24>>2]=x[b+24>>2];x[d+28>>2]=c;c=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=c;Dy(d+48|0,b+48|0);Dy(d+68|0,b+68|0);Dy(d+88|0,b+88|0);sc(d+108|0,b+108|0,448);nu(b);break c}e=Vg(556);if(!e){d=0;x[b>>2]=0;break b}x[114409]=0;d=O(1531,e|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[b>>2]=d}g=a,h=z[jj(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}hb=f+560|0;return d|0}a=N()|0;_b(e);Q(a|0);p()}function O0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+28>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Fc(g,d);x[114409]=0;b=S(2606,g|0)|0;a=x[114409];x[114409]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Fc(g,d);x[114409]=0;a=S(2607,g|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}Ob(g);x[114409]=0;P(2608,g|0,a|0);d=x[114409];x[114409]=0;if((d|0)==1){b=N()|0;break d}x[114409]=0;P(2609,g|12,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;d=g+24|0;a=qa(2610,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Pc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Ob(g);break d}b=N()|0;Ob(g);break d}b=N()|0;Pc(g);break d}b=N()|0;while(1){d=Pc(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function uN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=D(b,896)+a|0;a:{if(c){f=g+8|0;Kb(f,a+1074312|0,90);if(!Ib(f)){v[(D(b,896)+a|0)+1075816|0]=c}v[(D(b,896)+a|0)+1075815|0]=c;break a}c=y[e+1075815|0]}e=e+1074984|0;f=c&255;h=d?h:!(x[a+480180>>2]&204473357);oN(a,b,f,h);b:{c:{if(x[a+480180>>2]!=16777216){break c}i=x[(D(b,896)+a|0)+1075640>>2];if(!i|!x[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){nN(a,e,f-240|0);break b}if(!(b>>>0<224|d)){mN(e,f-224|0);break b}lN(e,f);break b}if(x[a+480180>>2]==268435456){x[(D(b,896)+a|0)+1075692>>2]=1}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}kN(a,e,d);break b}if(x[a+480180>>2]==524288){break d}pN(a,e,d);break b}if(x[a+480180>>2]!=524288){break b}}e:{if(!(v[(D(b,896)+a|0)+1075856|0]&1)){break e}if(x[a+1074416>>2]==1){b=g+8|0;Kb(b,a+1074312|0,6);if(Ib(b)){break e}}if(x[a+480180>>2]&32832){break e}if(!(x[a+480208>>2]&2)|x[a+480180>>2]!=8){break b}}jN(a,e,0-(f<<2)|0)}hb=g+16|0}function Uw(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;lf(g+16|0,a,b,c,e,h-15233|0);Fl(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}hb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function f1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+28>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Fc(g,d);x[114409]=0;b=S(21,g|0)|0;a=x[114409];x[114409]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Fc(g,d);x[114409]=0;a=S(2576,g|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break g}Ob(g);x[114409]=0;P(2577,g|0,a|0);d=x[114409];x[114409]=0;if((d|0)==1){b=N()|0;break d}x[114409]=0;P(2578,g|12,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break f}x[114409]=0;d=g+24|0;a=qa(2579,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Ob(g);break d}b=N()|0;Ob(g);break d}b=N()|0;xb(g);break d}b=N()|0;while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function Mj(a){a=a|0;var b=0;a:{b:{switch(y[a+3|0]){case 0:if(!y[a+5|0]){break a}v[a+3|0]=1;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 14:v[a+3|0]=19;return;case 15:if(y[a+5|0]<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=42;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break b}}v[a+3|0]=0}}function mca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;zd(c,0);d=a+36|0;w[e+14>>1]=y[d|0]|y[d+1|0]<<8;w[e+12>>1]=32767;f=c,g=(z[Gf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,w[f+28>>1]=g;d=a+38|0;w[e+10>>1]=y[d|0]|y[d+1|0]<<8;w[e+8>>1]=32767;f=c,g=(z[Gf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,w[f+30>>1]=g;w[c+32>>1]=64;d=a+44|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+48|0;x[c+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+52|0;x[c+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+56|0;x[c+24>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=b+166|0;if(y[d|0]<=4){v[c+38|0]=y[y[d|0]+35850|0]}v[c+39|0]=y[b+167|0];d=b+171|0;v[c+41|0]=(y[d|0]|y[d+1|0]<<8)>>>4;b=b+169|0;b=(y[b|0]|y[b+1|0]<<8)>>>2|0;v[c+40|0]=b;if(y[c+41|0]|b&255){v[c+39|0]=y[c+39|0]^-1}a=a+40|0;if(y[a|0]&4){w[c+34>>1]=z[c+34>>1]|1}if(y[a|0]&8){w[c+34>>1]=z[c+34>>1]|2}if(y[a|0]&16){w[c+34>>1]=z[c+34>>1]|4}if(y[a|0]&32){w[c+34>>1]=z[c+34>>1]|32}hb=e+16|0}function bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;x[a>>2]=b;c=hb-16|0;hb=c;e=c+12|0;d=b+1074376|0;f=sc(Re(229984),d,602);h=f+608|0;b=0;while(1){g=D(b,896);Qp(g+h|0,(d+g|0)+608|0);b=b+1|0;if((b|0)!=256){continue}break}d=hb-16|0;hb=d;x[114409]=0;x[d+12>>2]=f;b=U(1462,e|0,d+12|0,d+11|0)|0;e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){hb=d+16|0;break b}break a}hb=c+16|0;x[a+4>>2]=x[b>>2];c=hb-16|0;hb=c;e=c+15|0;d=hb-16|0;hb=d;x[114409]=0;b=a+8|0;S(1463,b+4|0)|0;f=x[114409];x[114409]=0;c:{if((f|0)==1){break a}x[114409]=0;x[d+12>>2]=0;U(1464,b+8|0,d+12|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}i=b,j=mc(b),x[i>>2]=j;hb=d+16|0;break c}d=b;hb=c+16|0;c=hb-16|0;hb=c;b=a+20|0;x[b>>2]=0;x[b+4>>2]=0;x[114409]=0;x[c+12>>2]=0;U(1456,b+8|0,c+12|0,c+11|0)|0;e=x[114409];x[114409]=0;d:{if((e|0)!=1){hb=c+16|0;break d}break a}x[114409]=0;V(1421,a|0);c=x[114409];x[114409]=0;if((c|0)!=1){return a|0}c=N()|0;EN(b);dN(d);kg(a+4|0);Q(c|0);p()}R(0)|0;zb();p()}function _j(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-80|0;hb=c;d=x[a+28>>2];bo(x[x[d>>2]-12>>2]+d|0,0);if(!Bd(a,4)){Uv(a)}a:{if(!x[a+4>>2]){break a}if(Bd(a,6)){break a}if(Bd(a,7)){break a}g=x[a+28>>2];f=c- -64|0;e=x[a+84>>2];h=D(x[a+20>>2],x[a+4>>2]);d=h+x[a+80>>2]|0;e=h>>>0>d>>>0?e+1|0:e;f=_g(f,d,e);d=x[f+12>>2];x[c+24>>2]=x[f+8>>2];x[c+28>>2]=d;d=x[f+4>>2];x[c+16>>2]=x[f>>2];x[c+20>>2]=d;tj(g,c+16|0)}b:{if(!Bd(a,5)){break b}i=a+44|0;h=qd(i);if(!h){break b}g=a+32|0;while(1){c:{e=(x[a+96>>2]+j>>>0)%(h>>>0)|0;if(A[wc(i,e)>>2]>=xc(g)>>>0){break c}f=Sm(c+52|0,Cc(g,x[wc(i,e)>>2]),z[wc(i,e)+12>>1]);d=Wv(b,f);Gb(f);if(!d){break c}b=e+1|0;x[a+96>>2]=(b|0)!=(h|0)?b:0;if(x[wc(i,e)+4>>2]){f=x[a+28>>2];b=x[a+12>>2];d=x[a+8>>2];a=x[wc(i,e)+4>>2];g=d+a|0;b=_g(c+32|0,g,a>>>0>g>>>0?b+1|0:b);a=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=a;a=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=a;tj(f,c)}j=wc(i,e);break b}j=j+1|0;if((h|0)!=(j|0)){continue}break}j=0}hb=c+80|0;return j}function QW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-80|0;hb=d;Nc(b);sr(a);a:{if(!yv(b,d+44|0)){break a}if(!PC(d+44|0)){break a}b:{if(!c){break b}c=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);if(!Qb(b,(c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))-28|0)){break a}Ov(a);g=d,h=Nv(),x[g+28>>2]=h;c=d+28|0;Mv(eh(a)+28|0,c);rr(c);f=x[eh(a)+28>>2];x[114409]=0;e=S(326,b|0)|0;b=x[114409];x[114409]=0;c:{if((b|0)==1){break c}b=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);c=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);x[114409]=0;b=Z(327,e|0,(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))-28|0,f|0,c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))|0;c=x[114409];x[114409]=0;if((c|0)==1){break c}e=0;if(!b){break a}b=d+12|0;nj(b,f);c=d+20|0;Jv(c,b);b=To(d+28|0,c,0);Zd(eh(a)+12|0,b);Ab(b);break b}a=ya(74984,76196)|0;b=ib;d:{if((ca(74984)|0)==(b|0)){break d}if((ca(76196)|0)==(b|0)){break d}Q(a|0);p()}Y(a|0)|0;_();e=0;break a}e=1}hb=d+80|0;return e|0}function UI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;a:{b:{c:{d:{e:{f:{g:{if(Bi(a)){vp(c+12|0);break g}tn(c,a);x[114409]=0;d=S(2298,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}x[c+12>>2]=d;Qf(c)}if(Bi(a)){d=a+36|0}else{d=x[c+12>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((vd(d)|0)>(b|0)){break d}}b=ec(8);x[114409]=0;d=O(122,c|0,6906)|0;a=x[114409];x[114409]=0;if((a|0)==1){break e}a=oc(b,d);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(d);break c}a=N()|0;Qf(c);break b}a=N()|0;ic(b);break c}x[a+8>>2]=b;b=a+24|0;g=x[b>>2];x[g+480208>>2]=x[g+480208>>2]&-4194305|f;b=x[b>>2];f=y[Vc(d,e)+16|0];x[114409]=0;P(468,b+484360|0,f|0);b=x[114409];x[114409]=0;h:{if((b|0)==1){break h}b=x[Vc(d,e)+12>>2];d=x[Vc(d,e)+8>>2];x[114409]=0;+ka(2148,a|0,b|0,d|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}x[a+16>>2]=0;x[a+20>>2]=0;zk(c+12|0);hb=c+16|0;return}a=N()|0}zk(c+12|0)}Q(a|0)}p()}function SX(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-48|0;hb=c;a=gd(a);x[114409]=0;b=$(201)|0;d=x[114409];x[114409]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}x[114409]=0;d=O(2,c+24|0,5084)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;b=$(201)|0;e=x[114409];x[114409]=0;e:{f:{g:{h:{if((e|0)==1){break h}x[114409]=0;x[c+8>>2]=b;P(207,c+12|0,c+8|0);b=x[114409];x[114409]=0;if((b|0)==1){break h}x[114409]=0;T(3,c+36|0,d|0,c+12|0);b=x[114409];x[114409]=0;if((b|0)==1){break g}b=c+36|0;Eb(a,b);xb(b);xb(c+12|0);xb(d);x[114409]=0;b=$(203)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}if(!b){break e}x[114409]=0;O(208,a|0,13271)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break e}break b}b=N()|0;break f}b=N()|0;xb(c+12|0)}xb(d);break a}x[114409]=0;b=$(202)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}if(!b){break d}x[114409]=0;O(208,a|0,12740)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}}hb=c+48|0;return}b=N()|0;break a}b=N()|0}xb(a);Q(b|0);p()}function jda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-32|0;hb=d;b=hb-32|0;hb=b;B[b+20>>2]=2;w[b+26>>1]=12;x[b+16>>2]=15;c=Re(64);x[114409]=0;e=S(1523,c|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{if((f|0)!=1){c=Fy(b+12|0,e);e=x[c>>2];x[114409]=0;P(1524,e|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}a=x[c>>2];x[114409]=0;a=U(1525,a|0,b+26|0,b+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}d:{if(!a){Ey(b+28|0);break d}a=x[c>>2];x[114409]=0;P(1526,a|0,b+16|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}yq(b+28|0,c)}Xf(c);hb=b+32|0;a=x[b+28>>2];break a}a=N()|0;_b(c);break b}a=N()|0;Xf(c)}Q(a|0);p()}x[d+28>>2]=a;a=0;e:{f:{g:{while(1){c=x[d+28>>2];x[114409]=0;w[d+26>>1]=a;b=O(2,d+12|0,(a<<2)+25872|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(1522,c|0,d+26|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}xb(b);a=a+1|0;if((a|0)!=12){continue}break}hb=d+32|0;return x[d+28>>2]}a=N()|0;break e}a=N()|0;xb(b)}Xf(d+28|0);Q(a|0);p()}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-16|0;hb=g;e=x[a+48>>2];m=x[a+24>>2];n=x[a+20>>2];h=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=x[g+8>>2];b=x[g+12>>2]+o|0;p=v[b+1|0];l=v[b|0];f=x[a+60>>2];b=h;i=Yb(h,-16777216,16776704);h=x[a+64>>2];k=Yb(e,-16777216,16776704);q=x[a+72>>2];r=x[c>>2];e=sqa(h,h>>31,i,i>>31);h=lb;i=e;e=x[a+68>>2];e=sqa(e,e>>31,k,k>>31);k=i+e|0;i=lb+h|0;i=e>>>0>k>>>0?i+1|0:i;h=((D(p-l|0,j>>>10&4194048)|0)/16384<<8)+(l<<16)|0;e=h;e=sqa(f,f>>31,e,e>>31);j=e+k|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,n)+r;x[c+4>>2]=x[c+4>>2]+D(f,m);h=e-(h&q)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];j=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function Dca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;e=hb-16|0;hb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;OL(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);OL(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){i=y[c+d|0];j=fd(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;d=1;f=y[b+31|0];a:{if(f){d=16;if(f>>>0<=16){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Gf(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];hb=e+16|0;e=b+236|0;while(1){d=0;f=c+h|0;if(y[f|0]<(y[a+27|0]|y[a+28|0]<<8)>>>0){d=y[f|0]}j=fd(e,h+12|0),k=d,w[j>>1]=k;h=h+1|0;if((h|0)!=96){continue}break}c=g+8|0;rm(c,3,a+4|0);d=g+20|0;Kc(d,c);x[114409]=0;O(348,b+492|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(g+20|0);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}hb=g+32|0;return}a=N()|0;xb(g+20|0);Q(a|0);p()}function FP(a,b,c){var d=0;d=y[a|0]&15;v[a|0]=y[d+24016|0];a:{b:{c:{switch(d|0){case 0:if(y[b|0]?c>>>0>=51:0){break b}v[a|0]=0;return;case 5:d=y[b|0];if(!((d&15)!=2&(d&240)!=32)){v[a|0]=20;v[b|0]=159;return}d:{if((d&15)!=12){if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}v[a|0]=25;v[b|0]=0;return;case 7:if(c>>>0>51){break b}v[a|0]=0;return;case 10:a=y[b|0]&240;if(!a){break b}v[b|0]=a;return;case 11:v[b|0]=D(y[b|0]&15,17);return;case 12:v[b|0]=y[b|0]>>>2;return;case 13:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 14:e:{switch((y[b|0]>>>4|0)-1|0){case 0:v[a|0]=2;break a;case 1:v[a|0]=3;break a;case 7:if(c>>>0<52){break b}v[a|0]=20;v[b|0]=y[b|0]&15|96;return;case 8:v[a|0]=15;v[b|0]=y[b|0]&15;return;case 9:v[a|0]=11;v[b|0]=y[b|0]<<4|15;return;case 10:v[a|0]=11;break a;case 11:case 12:break e;default:break b}}v[a|0]=20;return;case 15:break c;default:break b}}if(y[b|0]<48){break b}v[a|0]=17}return}v[b|0]=y[b|0]|240}function h8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;m=f,n=ao(b),x[m+4>>2]=n;d=hb-32|0;hb=d;e=b;c=Ve(a);g=mc(a);a:{if(c){while(1){b=c;c=b+16|0;if(yt(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!yt(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+4|0;l=f+3|0;i=hb-16|0;hb=i;j=mc(a);b=_d(40,4);h=Xk(i+8|0,j);c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=b;e=d+12|0;b=U(1336,e|0,c+12|0,h|0)|0;h=x[114409];x[114409]=0;b:{if((h|0)!=1){hb=c+16|0;break b}R(0)|0;zb();p()}c=x[b>>2];x[114409]=0;c=S(1335,c+16|0)|0;h=x[114409];x[114409]=0;c:{d:{if((h|0)==1){break d}x[114409]=0;ba(2232,j|0,c|0,36692,k|0,l|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;UN(b);Q(a|0);p()}Yk(a,x[d+28>>2],g,x[e>>2]);b=oe(e);v[d+27|0]=1;UN(e)}a=f+8|0;Wi(a,Bb(d+12|0,b),d+27|0);hb=d+32|0;a=vh(a);hb=f+16|0;return a+12|0}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;m=f,n=ao(b),x[m+4>>2]=n;d=hb-32|0;hb=d;e=b;c=Ve(a);g=mc(a);a:{if(c){while(1){yb(a);b=c;c=b+16|0;if(Tt(e,c)){g=b;c=x[b>>2];if(c){continue}break a}yb(a);if(!Tt(c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+4|0;l=f+3|0;i=hb-16|0;hb=i;j=mc(a);b=YM(j,1);h=Xk(i+8|0,j);c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=b;e=d+12|0;b=U(1472,e|0,c+12|0,h|0)|0;h=x[114409];x[114409]=0;b:{if((h|0)!=1){hb=c+16|0;break b}R(0)|0;zb();p()}c=x[b>>2];x[114409]=0;c=S(1470,c+16|0)|0;h=x[114409];x[114409]=0;c:{d:{if((h|0)==1){break d}x[114409]=0;ba(1471,j|0,c|0,25776,k|0,l|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;VM(b);Q(a|0);p()}Yk(a,x[d+28>>2],g,x[e>>2]);b=oe(e);v[d+27|0]=1;VM(e)}a=f+8|0;Wi(a,Bb(d+12|0,b),d+27|0);hb=d+32|0;a=vh(a);hb=f+16|0;return a+8|0}function TE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return c|0}function Oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;c=f+44|0;eo(b,c);a:{if(!rP(c)){break a}d=y[f+46|0];g=y[f+47|0];e=y[f+45|0];v[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e^-1)>>>1&3;g=g>>>0<192;w[a+2>>1]=z[(D(c,6)+24312|0)+(e<<1)>>1]<<g;i=D(D(y[e+(D(c,3)+24088|0)|0],z[((D(c,90)+24096|0)+D(e,30)|0)+(d>>>3&30)>>1]),1e3);d=d>>>1|0;d=((i>>>0)/z[(D(h,6)+24288|0)+(d&6)>>1]|0)+(d&1)<<(!e<<1);w[a>>1]=d;e=y[g+((c<<1)+24324|0)|0];if(e+8>>>0>(d&65535)>>>0){break a}c=hb-16|0;hb=c;x[c+12>>2]=e+4;x[c+4>>2]=36;d=x[Mb(c+12|0,c+4|0)>>2];if(!Qb(b,d)){d=zf(b)}g=c+4|0;dr(g,f);qg(b,x[g>>2],d);dr(g,f);Sb(x[g>>2]+d|0,0,36-d|0);cc(b,x[c+12>>2]);hb=c+16|0;b=2;if(e>>>0>2){while(1){if(y[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=e+f|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}hb=f+48|0;return a|0}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-16|0;hb=g;e=x[a+48>>2];m=x[a+24>>2];n=x[a+20>>2];h=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=x[g+8>>2];b=(x[g+12>>2]<<1)+o|0;p=w[b+2>>1];l=w[b>>1];f=x[a+60>>2];b=h;i=Yb(h,-16777216,16776704);h=x[a+64>>2];k=Yb(e,-16777216,16776704);q=x[a+72>>2];r=x[c>>2];e=sqa(h,h>>31,i,i>>31);h=lb;i=e;e=x[a+68>>2];e=sqa(e,e>>31,k,k>>31);k=i+e|0;i=lb+h|0;i=e>>>0>k>>>0?i+1|0:i;h=l+((D(p-l|0,j>>>18|0)|0)/16384|0)<<8;e=h;e=sqa(f,f>>31,e,e>>31);j=e+k|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,n)+r;x[c+4>>2]=x[c+4>>2]+D(f,m);h=e-(h&q)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];j=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;k=x[a+24>>2];l=x[a+20>>2];m=x[a+16>>2];g=x[a+4>>2];h=x[a>>2];x[e+24>>2]=h;x[e+28>>2]=g;i=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=i;i=a;if(d){n=b+24|0;while(1){a=x[e+24>>2];f=((((x[e+28>>2]&2147483647)<<1|a>>>31)&2147483646)<<1)+m|0;a=(((a>>>16|0)+4&131064)<<1)+n|0;o=w[a+14>>1];p=w[a+12>>1];q=w[a+10>>1];r=w[a+8>>1];s=w[a+6>>1];t=w[a+4>>1];g=w[a+2>>1];h=w[a>>1];j=0;b=1;while(1){a=j<<1;x[(e+8|0)+(j<<2)>>2]=(((((D(w[(a|8)+f>>1],q)+D(w[(a|4)+f>>1],r)|0)+D(w[(a|12)+f>>1],p)|0)+D(w[(a|16)+f>>1],o)|0)/2|0)+((((D(w[(a|-8)+f>>1],g)+D(w[(a|-12)+f>>1],h)|0)+D(w[(a|-4)+f>>1],t)|0)+D(w[a+f>>1],s)|0)/2|0)|0)/16384;a=b;b=0;j=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],k);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}h=x[e+24>>2];g=x[e+28>>2]}x[i>>2]=h;x[i+4>>2]=g;hb=e+32|0}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;m=f,n=ao(b),x[m+4>>2]=n;d=hb-32|0;hb=d;e=b;c=Ve(a);g=mc(a);a:{if(c){while(1){yb(a);b=c;c=b+14|0;if(WM(e,c)){g=b;c=x[b>>2];if(c){continue}break a}yb(a);if(!WM(c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+4|0;l=f+3|0;i=hb-16|0;hb=i;j=mc(a);b=WR(j);h=Xk(i+8|0,j);c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=b;e=d+12|0;b=U(1469,e|0,c+12|0,h|0)|0;h=x[114409];x[114409]=0;b:{if((h|0)!=1){hb=c+16|0;break b}R(0)|0;zb();p()}c=x[b>>2];x[114409]=0;c=S(1466,c+14|0)|0;h=x[114409];x[114409]=0;c:{d:{if((h|0)==1){break d}x[114409]=0;ba(1468,j|0,c|0,25776,k|0,l|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;XM(b);Q(a|0);p()}Yk(a,x[d+28>>2],g,x[e>>2]);b=oe(e);v[d+27|0]=1;XM(e)}a=f+8|0;Wi(a,Bb(d+12|0,b),d+27|0);hb=d+32|0;a=pu(a);hb=f+16|0;return a+4|0}function bL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;m=f,n=ao(b),x[m+4>>2]=n;d=hb-32|0;hb=d;e=b;c=Ve(a);g=mc(a);a:{if(c){while(1){b=c;c=b+16|0;if(_s(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!_s(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+4|0;l=f+3|0;h=hb-16|0;hb=h;j=mc(a);c=jD(1);e=Xk(h+8|0,j);b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=c;c=d+12|0;e=U(1740,c|0,b+12|0,e|0)|0;i=x[114409];x[114409]=0;b:{if((i|0)!=1){hb=b+16|0;break b}R(0)|0;zb();p()}b=x[e>>2];x[114409]=0;b=S(745,b+16|0)|0;i=x[114409];x[114409]=0;c:{d:{if((i|0)==1){break d}x[114409]=0;ba(1739,j|0,b|0,35980,k|0,l|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}m=mc(e),n=1,v[m+4|0]=n;hb=h+16|0;break c}a=N()|0;VK(e);Q(a|0);p()}Yk(a,x[d+28>>2],g,x[c>>2]);b=oe(c);v[d+27|0]=1;VK(c)}a=f+8|0;Wi(a,Bb(d+12|0,b),d+27|0);hb=d+32|0;a=vh(a);hb=f+16|0;return a+4|0}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;v[e+15|0]=8;w[e+12>>1]=0;x[e+8>>2]=0;if(d){k=D(c,d);c=0;while(1){if((k|0)>0){h=(j<<1)+b|0;m=h+(k<<1)|0;while(1){n=c;w[e+6>>1]=0;KR(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Ue(a,e+5|0)){break b}c=y[e+5|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=z[e+6>>1]<<1|f;w[e+6>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=z[e+6>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;l=c&255;if(l>>>0<2){break c}f=c-1|0;if(!(g&1<<l)){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;f=c-1^(i&65534)>>>1;c=f+z[e+8>>1]|0;w[e+6>>1]=c;w[h>>1]=c;x[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);ce(e+8|0,-32768,32767);h=(d<<1)+h|0;if(m>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;m=f,n=ao(b),x[m+4>>2]=n;d=hb-32|0;hb=d;e=b;c=Ve(a);g=mc(a);a:{if(c){while(1){b=c;c=b+16|0;if($n(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!$n(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+4|0;l=f+3|0;h=hb-16|0;hb=h;j=mc(a);c=jD(1);e=Xk(h+8|0,j);b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=c;c=d+12|0;e=U(743,c|0,b+12|0,e|0)|0;i=x[114409];x[114409]=0;b:{if((i|0)!=1){hb=b+16|0;break b}R(0)|0;zb();p()}b=x[e>>2];x[114409]=0;b=S(741,b+16|0)|0;i=x[114409];x[114409]=0;c:{d:{if((i|0)==1){break d}x[114409]=0;ba(742,j|0,b|0,23716,k|0,l|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}m=mc(e),n=1,v[m+4|0]=n;hb=h+16|0;break c}a=N()|0;eT(e);Q(a|0);p()}Yk(a,x[d+28>>2],g,x[c>>2]);b=oe(c);v[d+27|0]=1;eT(c)}a=f+8|0;Wi(a,Bb(d+12|0,b),d+27|0);hb=d+32|0;a=vh(a);hb=f+16|0;return a+4|0}function wma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;m=f,n=ao(b),x[m+4>>2]=n;d=hb-32|0;hb=d;e=b;c=Ve(a);g=mc(a);a:{if(c){while(1){b=c;c=b+14|0;if($n(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!$n(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+4|0;l=f+3|0;i=hb-16|0;hb=i;j=mc(a);b=WR(j);h=Xk(i+8|0,j);c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=b;e=d+12|0;b=U(853,e|0,c+12|0,h|0)|0;h=x[114409];x[114409]=0;b:{if((h|0)!=1){hb=c+16|0;break b}R(0)|0;zb();p()}c=x[b>>2];x[114409]=0;c=S(847,c+14|0)|0;h=x[114409];x[114409]=0;c:{d:{if((h|0)==1){break d}x[114409]=0;ba(852,j|0,c|0,23867,k|0,l|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;VR(b);Q(a|0);p()}Yk(a,x[d+28>>2],g,x[e>>2]);b=oe(e);v[d+27|0]=1;VR(e)}a=f+8|0;Wi(a,Bb(d+12|0,b),d+27|0);hb=d+32|0;a=pu(a);hb=f+16|0;return a+2|0}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;vj(c+27|0,a,0);a:{b:{c:{if(y[c+27|0]){d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+16|0,a+d|0);d=x[114409];x[114409]=0;d:{e:{f:{g:{h:{if((d|0)!=1){x[114409]=0;d=S(2443,c+16|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break h}e=hn(c+12|0,a);f=Zc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114409]=0;ga(2446,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break h}Ob(c+16|0);break f}b=R(0)|0;break g}b=R(0)|0;Ob(c+16|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;uj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];d=x[114409];x[114409]=0;if((d|0)!=1){if(!(b&1)){break e}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break c}Q(a|0);p()}d=x[c+20>>2];x[b>>2]=d;break d}_()}Mg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}R(0)|0;zb()}p()}return a|0}function T5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;i=c,j=lJ(),x[i+28>>2]=j;f=c+28|0;jJ(a+24|0,oe(f));Ai(f);w[a+28>>1]=0;e=hM();g=hb-16|0;hb=g;d=Re(44);x[114409]=0;h=O(2259,d|0,e|0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){e=hb-16|0;hb=e;x[114409]=0;x[e+12>>2]=h;d=U(2263,g+12|0,e+12|0,e+11|0)|0;h=x[114409];x[114409]=0;b:{if((h|0)!=1){hb=e+16|0;break b}R(0)|0;zb();p()}hb=g+16|0;d=x[d>>2];break a}a=N()|0;_b(d);Q(a|0);p()}x[c+28>>2]=d;ht(a+32|0,f);kg(f);i=c,j=kJ(x[a>>2]),x[i+28>>2]=j;uJ(a+4|0,oe(f));od(f);sn(x[a+24>>2],x[a+4>>2]);x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;v[a- -64|0]=0;i=c,j=Xn(b),x[i+28>>2]=j;i=c,j=Zi(b),x[i+24>>2]=j;c:{if(Yi(f,c+24|0)){while(1){d=vh(c+28|0);b=Zf(c+12|0,d);x[114409]=0;W(2204,a|0,b|0,d+12|0,0);d=x[114409];x[114409]=0;if((d|0)==1){break c}xb(b);b=c+28|0;tq(b);if(Yi(b,c+24|0)){continue}break}}hb=c+32|0;return}a=N()|0;xb(b);Q(a|0);p()}function rj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-16|0;hb=i;x[i+8>>2]=c;x[i+12>>2]=b;b=i+4|0;Fc(b,d);x[114409]=0;j=S(2606,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){Ob(i+4|0);x[e>>2]=0;b=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(mh(i+12|0,i+8|0)){break b}c:{if((Xm(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}k=0;c=Xm(j,x[b>>2]);d:{if(!((c|0)==69|(c&255)==48)){b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=Xm(j,x[g+8>>2])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,k)|0,x[l+12>>2]=m;g=b+8|0;break c}if(rk(j,1,x[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(rk(j,1,x[g>>2])){continue}}break}while(1){if(mh(i+12|0,i+8|0)){break c}if(!rk(j,1,Bl(i+12|0))){break c}gn(i+12|0);continue}}if((fl(j,Bl(i+12|0))|0)==(fl(j,x[g>>2])|0)){g=g+4|0;gn(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(mh(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}hb=i+16|0;return x[i+12>>2]}a=N()|0;Ob(i+4|0);Q(a|0);p()}function Pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=i;x[e>>2]=g;x[e+4>>2]=f;g=a;if(d){while(1){a=x[e+8>>2];b=(x[e+12>>2]<<1)+j|0;a=(a>>>16&65520)+h|0;a=(((((((D(w[b-4>>1],w[a+2>>1])+D(w[b-6>>1],w[a>>1])|0)+D(w[b-2>>1],w[a+4>>1])|0)+D(w[b>>1],w[a+6>>1])|0)+D(w[b+2>>1],w[a+8>>1])|0)+D(w[b+4>>1],w[a+10>>1])|0)+D(w[b+6>>1],w[a+12>>1])|0)+D(w[b+8>>1],w[a+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(a,l);x[c+4>>2]=x[c+4>>2]+D(a,k);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];i=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=i;hb=e+16|0}function rs(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=wi(a)&2047;c=wi(5551115123125783e-32);if(d-c>>>0<wi(512)-c>>>0){i=d;break b}if(c>>>0>d>>>0){return a+1}if(wi(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;b=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(wi(Infinity)>>>0<=d>>>0){return a+1}if((c|0)<0){return ss(12882297539194267e-247)}return ss(3105036184601418e216)}b=C[6409];e=C[6408]*a+b;b=e-b;a=b*C[6411]+(b*C[6410]+a);b=a*a;f=b*b*(a*C[6415]+C[6414]);b=b*(a*C[6413]+C[6412]);o(+e);j(1)|0;h=j(0)|0;c=h<<4&2032;a=f+(b+(C[c+51376>>3]+a));c=c+51384|0;g=x[c>>2];d=x[c+4>>2];c=g;g=0;c=c+g|0;d=(h<<13)+d|0;d=c>>>0<g>>>0?d+1|0:d;if(!i){c:{if(!(h&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();e=b*a;a=e+b;if(a<1){qH(rH()*22250738585072014e-324);f=a+1;a=f+(e+(b-a)+(a+(1-f)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function sj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-16|0;hb=i;x[i+8>>2]=c;x[i+12>>2]=b;b=i+4|0;Fc(b,d);x[114409]=0;j=S(21,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){Ob(i+4|0);x[e>>2]=0;b=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Cg(i+12|0,i+8|0)){break b}c:{if((Ym(j,v[g|0])|0)==37){b=g+1|0;if((h|0)==(b|0)){break b}k=0;c=Ym(j,v[b|0]);d:{if(!((c|0)==69|(c&255)==48)){b=g;break d}if((g+2|0)==(h|0)){break b}k=c;c=Ym(j,v[g+2|0])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,k)|0,x[l+12>>2]=m;g=b+2|0;break c}if(Bg(j,1,v[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Bg(j,1,v[g|0])){continue}}break}while(1){if(Cg(i+12|0,i+8|0)){break c}if(!Bg(j,1,tk(i+12|0))){break c}Dl(i+12|0);continue}}if((sw(j,tk(i+12|0))|0)==(sw(j,v[g|0])|0)){g=g+1|0;Dl(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(Cg(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}hb=i+16|0;return x[i+12>>2]}a=N()|0;Ob(i+4|0);Q(a|0);p()}function Qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=i;x[e>>2]=g;x[e+4>>2]=f;g=a;if(d){while(1){a=x[e+8>>2];b=x[e+12>>2]+j|0;a=(a>>>16&65520)+h|0;a=(((((((D(v[b-2|0],w[a+2>>1])+D(v[b-3|0],w[a>>1])|0)+D(v[b-1|0],w[a+4>>1])|0)+D(v[b|0],w[a+6>>1])|0)+D(v[b+1|0],w[a+8>>1])|0)+D(v[b+2|0],w[a+10>>1])|0)+D(v[b+3|0],w[a+12>>1])|0)+D(v[b+4|0],w[a+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(a,l);x[c+4>>2]=x[c+4>>2]+D(a,k);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];i=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=i;hb=e+16|0}
function dP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;d=xz(a+48|0);e=xz(a+68|0);f=xz(a+88|0);x[114409]=0;S(1215,a+492|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;S(1215,a+524|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;T(933,a|0,0,0);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;T(934,a|0,0,0);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[a+40>>2]=0;x[a+44>>2]=0;x[114409]=0;P(796,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=fc(d,b);b=b+1|0;v[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=N()|0;Wn(f);Wn(e);Wn(d);Q(a|0);p()}function rS(a){var b=0,c=0,d=0,e=0;c=hb-48|0;hb=c;b=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[c+8>>2]=(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))+788;x[c+12>>2]=0;b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[c+16>>2]=b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24);x[c+20>>2]=0;if(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24)){b=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);b=b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)}else{b=52}x[c+24>>2]=b;x[c+28>>2]=0;a=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[c+44>>2]=4;x[c+40>>2]=c+8;b=x[c+44>>2];x[c>>2]=x[c+40>>2];x[c+4>>2]=b;x[c+32>>2]=(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))+80;x[c+36>>2]=0;e=hb-16|0;hb=e;a=x[c>>2];d=x[c>>2]+(x[c+4>>2]<<3)|0;a:{if((a|0)==(d|0)){break a}b=a+8|0;if((d|0)==(b|0)){break a}while(1){a=lv(a,b)?b:a;b=b+8|0;if((d|0)!=(b|0)){continue}break}}hb=e+16|0;hb=c+48|0;b=x[a>>2];c=b-52|0;lb=x[a+4>>2]-(b>>>0<52)|0;return c}function mp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;o(+a);e=j(1)|0;j(0)|0;b=e>>>16|0;o(+a);d=j(1)|0;e=j(0)|0;i=d-1072562176|0;if((i|0)==198911|i>>>0<198911){if(!e&(d|0)==1072693248){return 0}a=a+-1;c=a*134217728;c=a+c-c;h=C[6685];k=c*c*h;m=a+k;f=a*a;g=a*f;return m+(g*(g*(g*(g*C[6695]+(f*C[6694]+(a*C[6693]+C[6692])))+(f*C[6691]+(a*C[6690]+C[6689])))+(f*C[6688]+(a*C[6687]+C[6686])))+((a-c)*h*(a+c)+(k+(a-m))))}a:{if(b-32752>>>0<=4294934559){if(!(d&2147483647|e)){return sH(-1)/0}if(!e&(d|0)==2146435072){break a}if(!((b&32752)!=32752&b>>>0<=32767)){a=a-a;return a/a}o(+(a*4503599627370496));d=j(1)|0;e=j(0)|0;d=d-54525952|0}b=d-1072037888|0;i=b;f=+(b>>20);b=(b>>>13&127)<<4;g=f*C[6678]+C[b+53576>>3];a=C[b+53568>>3];l(0,e-0|0);l(1,d-((i&-1048576)+(e>>>0<p>>>0)|0)|0);a=a*(+n()-C[b+55616>>3]-C[b+55624>>3]);h=g+a;c=a*a;a=h+(a*c*(c*(a*C[6684]+C[6683])+(a*C[6682]+C[6681]))+(c*C[6680]+(f*C[6679]+(a+(g-h)))))}return a}function QE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=h>>>0|a>>>0>=d>>>0){break b}b=v[a|0];g=b&255;c:{if((b|0)>=0){b=1;break c}if(b>>>0<4294967234){break b}if(b>>>0<=4294967263){if((y[a+1|0]&192)!=128|(d-a|0)<2){break b}b=2;break c}if(b>>>0<=4294967279){if((d-a|0)<3){break b}f=y[a+2|0];b=y[a+1|0];d:{e:{if((g|0)!=237){if((g|0)!=224){break e}if((b&224)==160){break d}break b}if((b&224)!=128){break b}break d}if((b&192)!=128){break b}}if((f&192)!=128){break b}b=3;break c}if((d-a|0)<4|b>>>0>4294967284){break b}i=y[a+3|0];j=y[a+2|0];f=y[a+1|0];f:{g:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break b}break f;case 4:if((f&240)!=128){break b}break f;default:break g}}if((f&192)!=128){break b}}if((j&192)!=128|(i&192)!=128){break b}b=4;if((i&63|(j<<6&4032|(g<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}}h=h+1|0;a=a+b|0;continue}break}return a-c|0}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=Db(b);a:{b:{c:{d:{while(1){b=c;if(!c){break d}c=b-1|0;if(!y[h+c|0]){continue}break}if((d|0)!=4){break b}c=0;while(1){e:{f:{g:{d=c+h|0;f=y[d|0];switch(f-10|0){case 0:break f;case 3:break g;default:break e}}e=e+1|0;break e}g=g+1|0}i=c?((f|0)==10&y[d-1|0]==13)+i|0:i;c=c+1|0;if((c|0)!=(b|0)){continue}break}break c}f=1;b=0;if((d|0)!=4){break a}}h:{if((e|0)==(g|0)){d=2;if((e|0)==(i|0)){break h}}if(e){d=0;if(!g){break h}}d=e?3:g?1:3}if(b){break b}b=0;f=1;e=0;break a}f=0;g=(d|0)==2;c=0;e=0;while(1){e=e+1|0;c=((g&y[c+h|0]==13)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}Xe(a);Dr(a,e);if(!f){g=(d|0)==1?32:13;f=d&-3?13:32;d=(d|0)==2;c=0;while(1){i:{j:{k:{l:{e=v[c+h|0];switch(e-10|0){case 1:case 2:break i;case 0:break j;case 3:break k;default:break l}}if(e){break i}e=32;break i}c=c+d|0;e=g;break i}e=f}$o(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function Iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;x[f+12>>2]=b;a:{if(Gh(a)>>>0>=b>>>0){j=f,k=ze(a),x[j+8>>2]=k;b=x[a>>2];i=x[Mb(f+12|0,f+8|0)>>2];if(i){while(1){if((b|0)!=(c|0)){d=bc(c);g=dc(c);e=hb-16|0;hb=e;h=fB(d,g);b:{if(h>>>0<=_f(b)>>>0){if(rc(b)>>>0<h>>>0){x[e+12>>2]=d;MO(e+12|0,rc(b));uz(d,x[e+12>>2],x[b>>2]);RO(b,x[e+12>>2],g,h-rc(b)|0);break b}vo(b,uz(d,g,x[b>>2]));break b}QO(b);cu(b,hj(b,h));RO(b,d,g,h)}hb=e+16|0;pj(b+12|0,c+12|0);w[b+28>>1]=z[c+28>>1]}b=b+32|0;i=i-1|0;if(i){continue}break}}b=x[f+12>>2];d=x[f+8>>2];if(b>>>0>d>>>0){rz(a,b-d|0,c);break a}NO(a,x[a>>2]+(b<<5)|0);break a}if(x[a>>2]){ze(a);LO(a);Iv(a);dh(yb(a),x[a>>2],Gh(a));j=yb(a),k=0,x[j>>2]=k;x[a>>2]=0;x[a+4>>2]=0}e=Hm(a,b);d=hb-16|0;hb=d;if(lD(a)>>>0<e>>>0){Xc();p()}kD(d+8|0,yb(a),e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;g=x[d+12>>2];j=yb(a),k=e+(g<<5)|0,x[j>>2]=k;mr(a,0);hb=d+16|0;rz(a,b,c)}hb=f+16|0}function lK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);b=hb-32|0;hb=b;d=x[a+20>>2];a:{if(!d){break a}if(xc(d+4|0)>>>0<4){break a}d=b+8|0;nj(d,x[a+20>>2]+4|0);e=hb-16|0;hb=e;c=e+8|0;XK(c,ac(e,d));d=b+16|0;Gv(d,c);x[d+12>>2]=0;x[d+8>>2]=0;hb=e+16|0;x[114409]=0;e=S(413,d|0)|0;c=x[114409];x[114409]=0;b:{if((c|0)!=1){if(e){break b}c=x[x[a>>2]+40>>2];x[114409]=0;f=S(c|0,a|0)|0;c=x[114409];x[114409]=0;c:{if((c|0)==1){break c}if(xc(x[a+20>>2]+4|0)-4>>>0<f<<2>>>0){break b}c=x[x[a>>2]+168>>2];e=0;x[114409]=0;P(c|0,a|0,-1);c=x[114409];x[114409]=0;if((c|0)==1){break c}if(f){while(1){x[114409]=0;g=E(wa(712,d|0));c=x[114409];x[114409]=0;if((c|0)==1){break c}c=x[x[a>>2]+44>>2];x[114409]=0;va(c|0,a|0,e|0,E(g));c=x[114409];x[114409]=0;if((c|0)==1){break c}e=e+1|0;if((f|0)!=(e|0)){continue}break}}c=x[x[a>>2]+172>>2];x[114409]=0;V(c|0,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}}a=N()|0;Ab(d);Q(a|0);p()}Ab(d)}hb=b+32|0}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=4;w[e+12>>1]=0;x[e+8>>2]=0;if(d){k=D(c,d);m=(k|0)<=0;c=0;while(1){if(!m){h=b+j|0;n=k+h|0;while(1){o=c;v[e+7|0]=0;JR(a,e+14|0,e+12|0,e+7|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Ue(a,e+6|0)){break b}c=y[e+6|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=y[e+7|0]<<1|f;v[e+7|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=y[e+7|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;l=c&255;if(l>>>0<2){break c}f=c-1|0;if(!(g&1<<l)){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;f=c-1^(i&254)>>>1;c=f+y[e+8|0]|0;v[e+7|0]=c;v[h|0]=c;x[e+8>>2]=((f>>1)-(o<<24>>24)|0)+(c<<24>>24<<1);ce(e+8|0,-128,127);h=d+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function Koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-80|0;hb=e;Xe(b);a:{b:{if(Qb(a,1)){c:{d:{e:{f:{g:{h:{while(1){x[114409]=0;d=U(603,a|0,e+16|0,64)|0;f=x[114409];x[114409]=0;if((f|0)==1){break e}x[e+12>>2]=d;d=Cb(b);x[114409]=0;x[e+8>>2]=c-d;d=O(36,e+12|0,e+8|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break h}d=x[d>>2];if(!d){break c}v[e+12|0]=0;f=e+16|0;h=f+d|0;g=e+12|0;d=Ll(f,h,g);i=e,j=nf(b),x[i+12>>2]=j;g=x[rd(e+4|0,g)>>2];x[114409]=0;Z(604,b|0,g|0,f|0,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}x[114409]=0;O(313,a|0,d-(e+16|0)|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}if(d>>>0>=h>>>0){continue}break}x[114409]=0;O(313,a|0,1)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break c}a=R(74984)|0;break d}a=R(74984)|0;break d}a=R(74984)|0;break d}a=R(74984)|0;break d}a=R(74984)|0}if((ib|0)!=(ca(74984)|0)){break b}Y(a|0)|0;_()}d=(Cb(b)|0)!=0}hb=e+80|0;break a}Q(a|0);p()}return d|0}function bY(){var a=0,b=0,c=0,d=0;c=hb-32|0;hb=c;a:{b=Vb(c+20|0,10518);if(!Cb(b)){break a}b:{if((bg(b,10181)|0)!=-1){a=bg(b,10181);x[114409]=0;W(205,c+8|0,b|0,a+1|0,-1);a=x[114409];x[114409]=0;if((a|0)==1){break b}a=c+8|0;Eb(b,a);xb(a)}if((bg(b,12738)|0)!=-1){a=bg(b,12738);x[114409]=0;W(205,c+8|0,b|0,a+1|0,-1);a=x[114409];x[114409]=0;if((a|0)==1){break b}a=c+8|0;Eb(b,a);xb(a)}if((bg(b,9659)|0)!=-1){a=bg(b,9659);x[114409]=0;W(205,c+8|0,b|0,0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}a=c+8|0;Eb(b,a);xb(a)}if((bg(b,9547)|0)!=-1){a=bg(b,9547);x[114409]=0;W(205,c+8|0,b|0,0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}a=c+8|0;Eb(b,a);xb(a)}if((bg(b,9590)|0)!=-1){a=bg(b,9590);x[114409]=0;W(205,c+8|0,b|0,0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}a=c+8|0;Eb(b,a);xb(a)}x[114409]=0;a=S(206,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break a}}c=N()|0;xb(b);Q(c|0);p()}xb(b);hb=c+32|0;return a|0}function yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];g=x[a+4>>2];h=x[a>>2];x[e+24>>2]=h;x[e+28>>2]=g;i=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=i;i=a;if(d){m=b+24|0;while(1){a=x[e+24>>2];f=(((x[e+28>>2]&2147483647)<<1|a>>>31)&-2)+l|0;a=(((a>>>16|0)+4&131064)<<1)+m|0;n=w[a+14>>1];o=w[a+12>>1];p=w[a+10>>1];q=w[a+8>>1];r=w[a+6>>1];s=w[a+4>>1];t=w[a+2>>1];g=w[a>>1];b=0;a=1;while(1){x[(e+8|0)+(b<<2)>>2]=((((D(v[(b|4)+f|0],p)+D(v[(b|2)+f|0],q)|0)+D(v[(b|6)+f|0],o)|0)+D(v[(b|8)+f|0],n)<<8>>1)+(((D(v[(b|-4)+f|0],t)+D(v[(b|-6)+f|0],g)|0)+D(v[(b|-2)+f|0],s)|0)+D(v[b+f|0],r)<<8>>1)|0)/16384;h=a;a=0;b=1;if(h){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}h=x[e+24>>2];g=x[e+28>>2]}x[i>>2]=h;x[i+4>>2]=g;hb=e+32|0}function LH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=x[a+32>>2];b=x[a+1380>>2];a:{b:{if((b|0)==-1){f=1;b=-1;break b}d=x[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=y[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(A[a+40>>2]<c>>>0){gc(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){gc(a,1);break a}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(y[83456]|y[83457]<<8|(y[83458]<<16|y[83459]<<24))){gc(a,21);break a}if(y[c+4|0]){gc(a,21);break a}e:{if(f){if(!x[a+992>>2]|!(v[c+5|0]&1)){break e}gc(a,21);break a}if(v[c+5|0]&1){break e}gc(a,21);break a}g=c+27|0;d=y[c+26|0];c=g+d|0;if(e>>>0<c>>>0){break d}f=0;b=0;f:{if(!d){break f}while(1){h=y[b+g|0];c=h+c|0;if((h|0)!=255){break f}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}b=(b|0)==(d|0)?-1:b;if(c>>>0<=e>>>0){continue}break}gc(a,1);break a}gc(a,1)}return 0}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+27|0;vj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+20|0,a+d|0);d=x[114409];x[114409]=0;d:{e:{f:{if((d|0)!=1){x[114409]=0;d=S(2443,c+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}e=hn(c+16|0,a);f=Zc(c+12|0);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114409]=0;ga(2444,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}Ob(c+20|0);break d}b=R(0)|0;break e}b=R(0)|0;Ob(c+20|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;uj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];d=x[114409];x[114409]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Mg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}R(0)|0;zb()}p()}return a|0}function v2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+27|0;vj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+20|0,a+d|0);d=x[114409];x[114409]=0;d:{e:{f:{if((d|0)!=1){x[114409]=0;d=S(2443,c+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}e=hn(c+16|0,a);f=Zc(c+12|0);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114409]=0;ga(2447,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}Ob(c+20|0);break d}b=R(0)|0;break e}b=R(0)|0;Ob(c+20|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;uj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];d=x[114409];x[114409]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Mg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}R(0)|0;zb()}p()}return a|0}function t2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+27|0;vj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+20|0,a+d|0);d=x[114409];x[114409]=0;d:{e:{f:{if((d|0)!=1){x[114409]=0;d=S(2443,c+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}e=hn(c+16|0,a);f=Zc(c+12|0);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114409]=0;ga(2448,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}Ob(c+20|0);break d}b=R(0)|0;break e}b=R(0)|0;Ob(c+20|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;uj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];d=x[114409];x[114409]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Mg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}R(0)|0;zb()}p()}return a|0}function s2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+27|0;vj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114409]=0;Fc(c+20|0,a+d|0);d=x[114409];x[114409]=0;d:{e:{f:{if((d|0)!=1){x[114409]=0;d=S(2443,c+20|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}e=hn(c+16|0,a);f=Zc(c+12|0);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114409]=0;ga(2449,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break f}Ob(c+20|0);break d}b=R(0)|0;break e}b=R(0)|0;Ob(c+20|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;uj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];d=x[114409];x[114409]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Mg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}R(0)|0;zb()}p()}return a|0}function Bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;j=hb-112|0;hb=j;a:{b:{if(!He(a)){break b}if(Ac(b)>>>0<2){break b}f=Hz(j+8|0,a);x[f+20>>2]=0;x[f>>2]=0;c:{d=Ac(b);if(d){d:{while(1){c=ud(b,g);e=x[a>>2];i=x[c>>2];if(e>>>0<=i>>>0){break d}c=x[c+4>>2];if(c>>>0>e-i>>>0){break d}e=x[f>>2];if(e>>>0>268435456-c>>>0){break d}x[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!eq(f)){break b}if(!g){break c}i=f+68|0;d=0;c=0;while(1){e=ud(b,d);k=x[f+20>>2];x[114409]=0;k=S(439,k|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}h=x[a+20>>2];x[114409]=0;h=S(439,h|0)|0;l=x[114409];x[114409]=0;if((l|0)==1){break a}sc(c+k|0,h+x[e>>2]|0,x[e+4>>2]);x[e>>2]=c;if(!(!d|d>>>0>9)){x[(i+(d<<2)|0)-4>>2]=c}c=x[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(eq(f)){break c}break b}On(a);Hz(a,f);x[a+4>>2]=0;x[a+8>>2]=x[a>>2];w[a+34>>1]=z[a+34>>1]|2}hb=j+112|0;return}R(0)|0;zb();p()}function m9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{e=hb-16|0;hb=e;f=gd(a);b:{if(Cb(b)){while(1){c=x[yj(b,i)>>2];c:{if(c>>>0>=2097152){x[114409]=0;P(119,f|0,63);a=x[114409];x[114409]=0;if((a|0)!=1){break c}break b}d=0;d:{e:{while(1){h=c&63;v[(e+10|0)+d|0]=h;if(c>>>0<64){break e}c=c>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}a=7;d=6;break d}if(d){a=d+1|0;if((a|0)!=2){break d}d=1;a=2;if((h|0)!=1){break d}a=y[e+10|0]|64}else{a=y[e+10|0]}x[114409]=0;P(119,f|0,a<<24>>24);a=x[114409];x[114409]=0;if((a|0)!=1){break c}break b}d=(2<<d)+255<<7-d;h=a+e|0;c=a;while(1){f:{if((a|0)==(c|0)){g=y[h+9|0];x[114409]=0;P(119,f|0,(d|g)<<24>>24);g=x[114409];x[114409]=0;if((g|0)==1){break b}c=c-1|0;break f}x[114409]=0;c=c-1|0;P(119,f|0,v[c+(e+10|0)|0]|-128);g=x[114409];x[114409]=0;if((g|0)==1){break b}}if(c){continue}break}}i=i+1|0;if(Cb(b)>>>0>i>>>0){continue}break}}hb=e+16|0;break a}a=N()|0;xb(f);Q(a|0);p()}}function UE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break b}b=y[a|0];f=a+1|0;c:{if(b<<24>>24>=0){break c}if(b>>>0<194){break b}if(b>>>0<=223){if((y[a+1|0]&192)!=128|(d-a|0)<2){break b}f=a+2|0;break c}if(b>>>0<=239){if((d-a|0)<3){break b}h=y[a+2|0];f=y[a+1|0];d:{e:{if((b|0)!=237){if((b|0)!=224){break e}if((f&224)==160){break d}break b}if((f&224)!=128){break b}break d}if((f&192)!=128){break b}}if((h&192)!=128){break b}f=a+3|0;break c}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break b}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];f:{g:{switch(b-240|0){case 0:if((f+112&255)>>>0>=48){break b}break f;case 4:if((f&240)!=128){break b}break f;default:break g}}if((f&192)!=128){break b}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}g=g+1|0;f=a+4|0}a=f;g=g+1|0;continue}break}return a-c|0}function o9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=E(0),r=E(0),s=E(0),t=0,u=0,v=0,w=0,z=0,A=E(0);f=hb-16|0;hb=f;a:{if(!x[a+4240>>2]){break a}g=a+44|0;if(!Eh(g)){break a}s=B[a+4220>>2];w=f,z=Qd(g,0),x[w+8>>2]=z;w=f,z=Qd(g,1),x[w+12>>2]=z;w=f,z=ld(g,0),x[w>>2]=z;w=f,z=ld(g,1),x[w+4>>2]=z;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(y[a+4264|0]?1-k|0:h)&255;t=x[((n<<2)+a|0)+4248>>2];u=x[a+4240>>2];v=x[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=x[p>>2];x[p>>2]=e+4;l=B[e>>2];e=v-t|0;q=B[Pb(m,n+((e>>31&u)+e<<1)|0)>>2];r=E(E(B[a+4224>>2]*q)+E(l*B[a+4260>>2]));w=Pb(m,x[a+4244>>2]<<1|h),A=E(F(r))<E(10000000195414814e-40)?E(0):r,B[w>>2]=A;h=f+o|0;e=x[h>>2];x[h>>2]=e+4;B[e>>2]=l+E(E(q-l)*s);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=x[a+4244>>2]+1|0;x[a+4244>>2]=(i|0)!=x[a+4240>>2]?i:0;j=j-1|0;if(j){continue}break}}Gi(a,b,c,ld(g,0),ld(g,1),d)}hb=f+16|0}function VU(a,b){var c=0,d=0;d=y[a|0];if(d>>>0>=36){v[a|0]=0;return}c=y[d+23424|0];v[a|0]=c;a:{b:{c:{d:{e:{f:{g:{if(c>>>0<=22){switch(c-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break b;case 13:break c;case 0:case 1:case 5:break e;case 8:break f;default:break g}}if((c|0)==23){break d}if((c|0)!=31){break a}v[b|0]=(d<<5|y[b|0]>>>3)^128;return}if(y[b|0]|(c|0)!=1){break a}v[a|0]=0;return}a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return}c=y[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}v[b|0]=a;return}a=y[b|0];if(a>>>0<=64){v[b|0]=a<<1;return}v[b|0]=128;return}h:{i:{j:{k:{c=y[b|0];switch((c&240)-48>>>4|0){case 4:break h;case 2:break i;case 1:break j;case 0:break k;default:break a}}v[a|0]=20;v[b|0]=159;return}v[a|0]=20;v[b|0]=192;return}if(c&14){break a}v[a|0]=21;v[b|0]=(y[b|0]!=80)<<6;return}v[a|0]=20;v[b|0]=y[b|0]&15|160;return}if(y[b|0]>31){break a}v[a|0]=16}}function ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+8>>2]=c;x[e+12>>2]=b;if(Hb(e+12|0,e+8|0)){while(1){g=hb-16|0;hb=g;h=e+12|0;b=x[h>>2];if(!(y[b+3|0]!=4|y[b+5|0])){c=g+8|0;se(c,d,z[d+14>>1]);le(c,0);v[b+3|0]=0}c=y[b+2|0];if(!(y[b+4|0]|(c|0)!=11)){f=g+8|0;se(f,d,z[d+14>>1]);le(f,0);v[b+2|0]=0;c=0}a:{b:{c:{if(!y[b|0]){c=g+8|0;se(c,d,z[d+14>>1]);if(Ib(c)){break c}c=y[b+2|0]}f=y[b+3|0];i=g+8|0;se(i,d,z[d+14>>1]);le(i,(f|0)==4|(c|0)==11);c=y[b+3|0];break b}c=y[b+3|0];f=y[b+2|0];if(!(c|(f|0)==11)){v[b+5|0]=0;v[b+3|0]=4;break a}if(f|(c|0)==4){break b}v[b+4|0]=0;v[b+2|0]=11}d:{if(!(!y[d+16|0]|c)){v[b+5|0]=125;v[b+3|0]=17;break d}e:{switch(c-16|0){case 1:break d;case 0:break e;default:break a}}if(y[b+5|0]){break a}v[b+5|0]=6;v[d+16|0]=1;break a}v[d+16|0]=0}w[d+14>>1]=(z[d+14>>1]+1>>>0)%z[d+12>>1];hb=g+16|0;Sj(h);if(Hb(h,e+8|0)){continue}break}}DP(a,d);hb=e+16|0}function Oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=0,w=E(0);if(x[a+4220>>2]){f=a+44|0;i=Qd(f,0);j=Qd(f,1);k=ld(f,0);l=ld(f,1);if(d){h=a+4208|0;e=x[a+4224>>2];m=d;while(1){n=B[j>>2];o=B[i>>2];e=e-x[a+4228>>2]|0;e=(x[a+4220>>2]&e>>31)+e<<1;p=B[Pb(h,e)>>2];e=Pb(h,e|1);r=B[a+4248>>2];s=B[a+4256>>2];t=B[a+4252>>2];u=B[a+4244>>2];q=B[e>>2];g=E(E(E(E(n*r)+E(o*s))+E(p*t))+E(u*q));v=Pb(h,x[a+4224>>2]<<1),w=E(F(g))<E(10000000195414814e-40)?E(0):g,B[v>>2]=w;g=E(E(E(E(r*o)+E(s*n))+E(t*q))+E(u*p));v=Pb(h,x[a+4224>>2]<<1|1),w=E(F(g))<E(10000000195414814e-40)?E(0):g,B[v>>2]=w;e=x[a+4224>>2]+1|0;e=(e|0)!=x[a+4220>>2]?e:0;x[a+4224>>2]=e;B[k>>2]=E(p*B[a+4236>>2])+E(o*B[a+4240>>2]);B[l>>2]=E(q*B[a+4236>>2])+E(n*B[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}Gi(a,b,c,ld(f,0),ld(f,1),d)}}function OL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=hb-16|0;hb=k;v[k+15|0]=c;v[k+14|0]=12;Qg(b,y[tc(k+15|0,k+14|0)|0]);if(Lb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=y[j|0]|y[j+1|0]<<8;m=Pb(b,c),n=j,w[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=y[j|0]|y[j+1|0]<<8;m=Pb(b,c),n=j,w[m>>1]=n;i=i+146|0}i=y[i|0];m=Pb(b,c),n=i,v[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(z[Pb(b,c)>>1]>=z[Pb(b,i)>>1]){break d}if(z[Pb(b,c)>>1]>255){break d}j=y[Pb(b,i)+1|0];l=Pb(b,c);w[l>>1]=z[l>>1]|j<<8;if(z[Pb(b,c)>>1]>=z[Pb(b,i)>>1]){break d}i=Pb(b,c);w[i>>1]=z[i>>1]+256}c=c+1|0;if(Lb(b)>>>0>c>>>0){continue}break}}v[b+12|0]=0;e:{if(!(d&1)){break e}if(kd(b)){break e}v[b+12|0]=y[b+12|0]|1}if(e>>>0<=11){if(d&2){v[b+12|0]=y[b+12|0]|4}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=y[b+12|0]|2}v[b+14|0]=g;v[b+13|0]=f}hb=k+16|0}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;Gm(a);yb(a);c=Bb(h+8|0,x[a+4>>2]);d=Bb(h+4|0,x[a>>2]);e=x[Bb(h,x[b+4>>2])>>2];i=hb-16|0;hb=i;f=hb-32|0;hb=f;Ae(f+24|0,x[c>>2],x[d>>2]);d=x[f+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[f+28>>2];x[c+12>>2]=d;x[c+4>>2]=e;if(qc(c+12|0,c+8|0)){while(1){j=c+12|0;d=Fm(j);k=c+4|0;e=Fm(k);g=y[d+23|0]|y[d+24|0]<<8|(y[d+25|0]<<16|y[d+26|0]<<24);v[e+23|0]=g;v[e+24|0]=g>>>8;v[e+25|0]=g>>>16;v[e+26|0]=g>>>24;g=x[d+20>>2];x[e+16>>2]=x[d+16>>2];x[e+20>>2]=g;g=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=g;g=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=g;Em(j);Em(k);if(qc(j,c+8|0)){continue}break}}Dc(f+16|0,c+12|0,c+4|0);hb=c+16|0;x[f+12>>2]=x[f+16>>2];x[f+8>>2]=x[f+20>>2];Dc(i+8|0,f+12|0,f+8|0);hb=f+32|0;hb=i+16|0;x[h+12>>2]=x[i+12>>2];x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];mr(a,ze(a));hb=h+16|0}function E5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb+-64|0;hb=e;d=x[b+12>>2];x[e+24>>2]=x[b+8>>2];x[e+28>>2]=d;d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;j=wQ(e+16|0);a:{if(j){i=hb-16|0;hb=i;h=e+40|0;g=hb-16|0;hb=g;f=hb-16|0;hb=f;d=g+4|0;x[d+4>>2]=1;k=d,l=_d(324,4),x[k+8>>2]=l;hb=f+16|0;f=x[d+8>>2];x[114409]=0;O(2325,f|0,b|0)|0;b=x[114409];x[114409]=0;b:{if((b|0)!=1){b=So(d);Ro(h,hc(b),b);JI(d);hb=g+16|0;break b}a=N()|0;JI(d);Q(a|0);p()}break a}i=hb-16|0;hb=i;h=e+32|0;g=hb-16|0;hb=g;f=hb-16|0;hb=f;d=g+4|0;x[d+4>>2]=1;k=d,l=oQ(1),x[k+8>>2]=l;hb=f+16|0;f=x[d+8>>2];x[114409]=0;O(2326,f|0,b|0)|0;b=x[114409];x[114409]=0;c:{if((b|0)!=1){b=So(d);Ro(h,hc(b),b);GI(d);hb=g+16|0;break c}a=N()|0;GI(d);Q(a|0);p()}}hb=i+16|0;b=e+48|0;ZC(b,h);d=Im(e+56|0,b);h=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=h;_C(a,e+8|0,c);Ab(b);d:{if(!j){Ab(e+32|0);break d}Ab(e+40|0)}hb=e- -64|0}function oG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Yf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=Yr(x[a+32>>2]);if((g|0)==-1){break b}v[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}i=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];h=c+24|0;g=h+e|0;e:{switch(AG(x[a+36>>2],f,h,g,c+16|0,c+23|0,i,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=Yr(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((Zr(Qh(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Qh(v[c+23|0]),x[k+48>>2]=l}d=Qh(v[c+23|0]);break a}d=-1}hb=c+32|0;return d}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;i=x[a+40>>2];j=x[a+36>>2];k=x[a+16>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){b=i>>12;h=j>>12;break a}while(1){b=x[e+24>>2];g=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(b>>>21&2040)+32976|0;l=w[b+6>>1];m=w[b+4>>1];n=w[b+2>>1];o=w[b>>1];h=0;b=1;while(1){f=h<<1;x[(e+8|0)+(h<<2)>>2]=(((D(w[f+g>>1],n)+D(w[(f|-4)+g>>1],o)|0)+D(w[(f|4)+g>>1],m)|0)+D(w[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(h,x[e+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];g=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+32|0}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=hb-16|0;hb=h;e=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];g=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];i=b;f=x[a>>2];x[h+8>>2]=f;x[h+12>>2]=b;b=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=w[(x[h+12>>2]<<1)+n>>1];f=x[a+60>>2];b=g;g=Yb(g,-16777216,16776704);i=x[a+64>>2];k=Yb(e,-16777216,16776704);o=x[a+72>>2];p=x[c>>2];j=j<<8;e=j;e=sqa(f,f>>31,e,e>>31);q=lb;g=sqa(i,i>>31,g,g>>31);f=g+e|0;e=lb+q|0;e=f>>>0<g>>>0?e+1|0:e;i=f;f=x[a+68>>2];g=sqa(f,f>>31,k,k>>31);f=i+g|0;e=lb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;f=(e|0)/256|0;x[c>>2]=D(f,m)+p;x[c+4>>2]=x[c+4>>2]+D(f,l);g=e-(j&o)|0;c=c+8|0;Tb(h+8|0,h);e=b;d=d-1|0;if(d){continue}break}f=x[h+8>>2];i=x[h+12>>2]}x[a>>2]=f;x[a+4>>2]=i;x[a+48>>2]=b;x[a+44>>2]=g;hb=h+16|0}function tj(a,b){var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;bo(d,e);vj(c+63|0,a,1);a:{b:{if(y[c+63|0]){d=x[x[a>>2]-12>>2];x[114409]=0;d=x[(a+d|0)+24>>2];f=x[114409];x[114409]=0;c:{d:{if((f|0)==1){break d}x[114409]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;W(2453,c+40|0,d|0,c+8|0,8);b=x[114409];x[114409]=0;if((b|0)==1){break d}b=_g(c+24|0,-1,-1);x[114409]=0;b=iT(c+40|0,b);d=x[114409];x[114409]=0;if((d|0)==1){break d}b=b?e|4:e;break c}Y(R(0)|0)|0;b=e|1;uj(x[x[a>>2]-12>>2]+a|0,b);e=x[x[a>>2]-12>>2];x[114409]=0;e=x[(a+e|0)+20>>2];d=x[114409];x[114409]=0;e:{if((d|0)!=1){if(!(e&1)){break e}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break a}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}_()}Mg(x[x[a>>2]-12>>2]+a|0,b)}hb=c- -64|0;return}R(0)|0;zb()}p()}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=hb-16|0;hb=h;e=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];g=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];i=b;f=x[a>>2];x[h+8>>2]=f;x[h+12>>2]=b;b=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=v[x[h+12>>2]+n|0];f=x[a+60>>2];b=g;g=Yb(g,-16777216,16776704);i=x[a+64>>2];k=Yb(e,-16777216,16776704);o=x[a+72>>2];p=x[c>>2];j=j<<16;e=j;e=sqa(f,f>>31,e,e>>31);q=lb;g=sqa(i,i>>31,g,g>>31);f=g+e|0;e=lb+q|0;e=f>>>0<g>>>0?e+1|0:e;i=f;f=x[a+68>>2];g=sqa(f,f>>31,k,k>>31);f=i+g|0;e=lb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;f=(e|0)/256|0;x[c>>2]=D(f,m)+p;x[c+4>>2]=x[c+4>>2]+D(f,l);g=e-(j&o)|0;c=c+8|0;Tb(h+8|0,h);e=b;d=d-1|0;if(d){continue}break}f=x[h+8>>2];i=x[h+12>>2]}x[a>>2]=f;x[a+4>>2]=i;x[a+48>>2]=b;x[a+44>>2]=g;hb=h+16|0}function W$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=hb-416|0;hb=h;d=h+416|0;x[h+12>>2]=d;c=hb-144|0;hb=c;x[c+28>>2]=c+132;i=c+32|0;DF(a+8|0,i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;i=_R(e,x[h+12>>2]);f=hb-16|0;hb=f;x[f+12>>2]=x[a+8>>2];g=Nh(f+8|0,f+12|0);x[114409]=0;a=ww(e,c+12|0,i,c+16|0);i=x[114409];x[114409]=0;a:{if((i|0)!=1){Te(g);hb=f+16|0;break a}a=N()|0;Te(g);Q(a|0);p()}if((a|0)==-1){Mr(8393);p()}x[h+12>>2]=e+(a<<2);hb=c+144|0;g=hb-16|0;hb=g;i=g+8|0;a=hb-32|0;hb=a;Iw(a+24|0,e,x[h+12>>2]);h=a+16|0;j=a+12|0;k=x[a+28>>2];c=hb-16|0;hb=c;f=x[a+24>>2];x[c+8>>2]=f;x[c+12>>2]=b;while(1){if((f|0)!=(k|0)){BG(c+12|0,x[f>>2]);f=f+4|0;x[c+8>>2]=f;continue}break}Dc(h,c+8|0,c+12|0);hb=c+16|0;l=a,m=Hw(e,x[a+16>>2]),x[l+12>>2]=m;x[a+8>>2]=x[a+20>>2];Dc(i,j,a+8|0);hb=a+32|0;hb=g+16|0;hb=d;return x[g+12>>2]}function jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;vQ(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1029,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1032,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=Kz(c+60|0);x[114409]=0;T(1030,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}nQ(c+60|0);nQ(c+52|0);continue}break}a=N()|0;mQ(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];mQ(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Rk(a);Un(a);Un(a);hb=f+16|0}function J6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[114409]=0;V(2211,a|0);e=x[114409];x[114409]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[114409]=0;V(2164,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break e}e=0;x[114409]=0;V(2212,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}a=Sb(c,0,d);if(!y[b|0]){break b}if(xj(b,3490)|(d|0)!=8){break d}x[a+4>>2]=2213;x[a>>2]=2214;break c}Y(R(0)|0)|0;x[114409]=0;W(2113,8100,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();return 0}if(xj(b,7131)|(d|0)!=64){break b}x[a+60>>2]=2215;x[a+56>>2]=2216;x[a+52>>2]=2217;x[a+48>>2]=2218;x[a+44>>2]=2219;x[a+40>>2]=2220;x[a+36>>2]=2221;x[a+32>>2]=2222;x[a+28>>2]=2223;x[a+24>>2]=2224;x[a+20>>2]=2225;x[a+16>>2]=2226;x[a+12>>2]=2227;x[a+8>>2]=2228;x[a+4>>2]=2229;x[a>>2]=2230}e=1}return e|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function lG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Yf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=Yr(x[a+32>>2]);if((g|0)==-1){break b}v[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}i=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];h=c+24|0;g=h+e|0;e:{switch(AG(x[a+36>>2],f,h,g,c+16|0,c+20|0,i,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=Yr(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((Zr(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break b}}x[a+48>>2]=x[c+20>>2]}d=x[c+20>>2];break a}d=-1}hb=c+32|0;return d}function dG(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;lf(g+16|0,a,b,c,e,f-16129|0);Fl(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}hb=g+32|0;return l(2,d&-2147483648|e),r()}function ZW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-48|0;hb=b;c=-1;a:{if(!SC(a,b+12|0)){break a}c=0;if(!PL(b+12|0)){break a}g=Bf(8966);if(g){l=x[a+12>>2];c=b+12|0;if(Tk(a,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))){b:{if(!(y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))){break b}while(1){if(!Hh(a,4)){break b}c:{if((y[c+4|0]|y[c+5|0]<<8)>>>0>=64){d=Uu(a);f=d&63;h=d<<24>>24;d:{if(!(d&64)){break d}e=6;while(1){d=Uu(a);f=(d&127)<<e|f;if(d<<24>>24>=0){break d}d=e>>>0<25;e=e+7|0;if(d){continue}break}}if((((h|0)<0?0-f|0:f)|0)<=0){break c}}e=0;f=1;while(1){d=Uu(a);if(d){h=vn(d<<24>>24);j=e>>>0>=g>>>0;d=j&f;f=!(f&1)|j?d:y[e+8966|0]==(h&255);e=e+1|0;continue}break}ad(a,4);i=(e|0)==(g|0)?f?1:i:i}k=k+1|0;if(k>>>0<(y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0){continue}break}}e=i&1}Tk(a,l)}c=e}a=c;hb=b+48|0;return a|0}function uja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;ri(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1070,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1074,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=ek(c+60|0);x[114409]=0;T(1071,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Kh(c+60|0);Kh(c+52|0);continue}break}a=N()|0;IP(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];IP(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wm(a,Ac(a));hb=f+16|0}function nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;og(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1017,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1019,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=cj(c+60|0);x[114409]=0;T(1015,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Jg(c+60|0);Jg(c+52|0);continue}break}a=N()|0;xQ(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];xQ(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;Gm(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1254,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1256,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=Fm(c+60|0);x[114409]=0;T(1233,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Em(c+60|0);Em(c+52|0);continue}break}a=N()|0;JO(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];JO(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];mr(a,ze(a));hb=f+16|0}function gca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;og(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1661,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1663,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=cj(c+60|0);x[114409]=0;T(1659,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Jg(c+60|0);Jg(c+52|0);continue}break}a=N()|0;FL(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];FL(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;Ge(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1754,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1756,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=Yg(c+60|0);x[114409]=0;T(1752,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}hg(c+60|0);hg(c+52|0);continue}break}a=N()|0;RK(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];RK(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=f+16|0}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;ri(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1303,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1306,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=ek(c+60|0);x[114409]=0;T(1304,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Kh(c+60|0);Kh(c+52|0);continue}break}a=N()|0;ZN(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];ZN(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wm(a,Ac(a));hb=f+16|0}function Fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;uM(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1700,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(1703,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=$x(c+60|0);x[114409]=0;T(1701,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}gL(c+60|0);gL(c+52|0);continue}break}a=N()|0;fL(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];fL(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];iL(a,Lg(a));hb=f+16|0}function pea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Qe(a)),x[l+12>>2]=m;zc(g+12|0,c>>>2|0);c=Db(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Db(y[c|0]);h=e|Db(y[c+1|0])<<8|Db(y[c+2|0])<<16|Db(y[c+3|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+4|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Db(y[b|0]);a=a|Db(y[b+1|0])<<8|Db(y[b+2|0])<<16|Db(y[b+3|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=vqa(k,a,f,0);i=lb;break e}i=vqa(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Ec(a,i)>>>16|0,w[l>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return x[g+12>>2]<<2}function oea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Qe(a)),x[l+12>>2]=m;zc(g+12|0,c>>>2|0);c=Db(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Db(y[c+3|0]);h=e|Db(y[c+2|0])<<8|Db(y[c+1|0])<<16|Db(y[c|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+4|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Db(y[b+3|0]);a=a|Db(y[b+2|0])<<8|Db(y[b+1|0])<<16|Db(y[b|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=vqa(k,a,f,0);i=lb;break e}i=vqa(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Ec(a,i)>>>16|0,w[l>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return x[g+12>>2]<<2}function _I(a,b,c,d){var e=0,f=0,g=0,h=0,i=E(0),j=0;e=hb-80|0;hb=e;h=a+24|0;Gp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;c=Oc(e+40|0,d,c,b);f=x[a+32>>2];i=B[a+48>>2];x[e+16>>2]=x[c+8>>2];d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;c=hb-16|0;hb=c;x[c+8>>2]=x[e+16>>2];d=x[e+12>>2];x[c>>2]=x[e+8>>2];x[c+4>>2]=d;d=Ds(e+52|0);x[d+8>>2]=f;x[d+4>>2]=0;x[d>>2]=83032;f=x[c+4>>2];x[d+12>>2]=x[c>>2];x[d+16>>2]=f;x[d+20>>2]=x[c+8>>2];B[d+24>>2]=i;x[d>>2]=82984;hb=c+16|0;c=0;a:{while(1){if(b){f=x[h>>2];x[e+32>>2]=b;x[e+36>>2]=0;x[114409]=0;x[e+24>>2]=134217727;x[e+28>>2]=0;g=O(2278,e+32|0,e+24|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}g=x[g>>2];x[114409]=0;f=U(2279,f|0,g|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}c=c+f|0;b=b-f|0;if(f){continue}}break}if(!(x[a+52>>2]!=1|c)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=e+80|0;return c}Q(N()|0);p()}function ZI(a,b,c,d){var e=0,f=0,g=0,h=0,i=E(0),j=0;e=hb-80|0;hb=e;h=a+24|0;Gp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;c=Oc(e+40|0,d,c,b);f=x[a+32>>2];i=B[a+48>>2];x[e+16>>2]=x[c+8>>2];d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;c=hb-16|0;hb=c;x[c+8>>2]=x[e+16>>2];d=x[e+12>>2];x[c>>2]=x[e+8>>2];x[c+4>>2]=d;d=Ds(e+52|0);x[d+8>>2]=f;x[d+4>>2]=0;x[d>>2]=83104;f=x[c+4>>2];x[d+12>>2]=x[c>>2];x[d+16>>2]=f;x[d+20>>2]=x[c+8>>2];B[d+24>>2]=i;x[d>>2]=83056;hb=c+16|0;c=0;a:{while(1){if(b){f=x[h>>2];x[e+32>>2]=b;x[e+36>>2]=0;x[114409]=0;x[e+24>>2]=134217727;x[e+28>>2]=0;g=O(2278,e+32|0,e+24|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break a}g=x[g>>2];x[114409]=0;f=U(2279,f|0,g|0,d|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}c=c+f|0;b=b-f|0;if(f){continue}}break}if(!(x[a+52>>2]!=1|c)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=e+80|0;return c}Q(N()|0);p()}function Il(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;wk(a);a:{b:{c:{g=x[b+32>>2];d:{if(!g){e=x[b+2084>>2];if(e){break d}break b}f=x[b+4>>2];if((f|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Hl(h);d=x[b+2092>>2];if((d|0)>=2){while(1){f=d>>>1|0;i=f+c|0;g=j>>>0<A[(i<<2)+e>>2];c=g?c:i;d=g?f:d-f|0;if((d|0)>1){continue}break}}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}if((f|0)>0){e=x[b+8>>2];while(1){f:{d=y[c+e|0];if((d|0)==255){break f}h=x[a+1392>>2];if(x[g+(c<<2)>>2]!=(h&(-1<<d^-1))){break f}e=x[a+1396>>2];if((e|0)>=(d|0)){x[a+1392>>2]=h>>>d;x[a+1396>>2]=e-y[x[b+8>>2]+c|0];return c}x[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}gc(a,21);x[a+1396>>2]=0}return-1}ea(7258,9049,1705,1931);p()}function $la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;v[e+15|0]=8;v[e+14|0]=0;w[e+12>>1]=0;if(d){l=D(c,d);while(1){if((l|0)>0){h=(j<<1)+b|0;n=h+(l<<1)|0;while(1){w[e+10>>1]=0;KR(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Ue(a,e+9|0)){break b}c=y[e+9|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=z[e+10>>1]<<1|f;w[e+10>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=z[e+10>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;m=c&255;if(m>>>0<2){break c}f=c-1|0;if(!(g&1<<m)){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;k=(c-1^(i&65534)>>>1)+k|0;w[e+10>>1]=k;w[h>>1]=k;h=(d<<1)+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function _oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;og(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(568,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(571,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=cj(c+60|0);x[114409]=0;T(569,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Jg(c+60|0);Jg(c+52|0);continue}break}a=N()|0;cU(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];cU(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function Nma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;og(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(787,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(789,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=cj(c+60|0);x[114409]=0;T(785,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Jg(c+60|0);Jg(c+52|0);continue}break}a=N()|0;vS(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];vS(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function Lpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;og(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(516,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(518,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=cj(c+60|0);x[114409]=0;T(514,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Jg(c+60|0);Jg(c+52|0);continue}break}a=N()|0;MU(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];MU(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function Goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;og(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(609,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(611,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=cj(c+60|0);x[114409]=0;T(607,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Jg(c+60|0);Jg(c+52|0);continue}break}a=N()|0;VT(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];VT(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;rl(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(615,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(618,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=Pm(c+60|0);x[114409]=0;T(616,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}ql(c+60|0);ql(c+52|0);continue}break}a=N()|0;UT(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];UT(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Xo(a,qd(a));hb=f+16|0}function uX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;Gm(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(250,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(253,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=Fm(c+60|0);x[114409]=0;T(251,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Em(c+60|0);Em(c+52|0);continue}break}a=N()|0;iD(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];iD(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];mr(a,ze(a));hb=f+16|0}function H0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;ri(a);g=yb(a);d=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);c=Bb(f,x[b+4>>2]);h=x[d>>2];d=x[c>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[e>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(176,c+60|0,c+56|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}if(!d){break a}x[114409]=0;d=S(178,c+52|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}e=ek(c+60|0);x[114409]=0;T(174,g|0,d|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Kh(c+60|0);Kh(c+52|0);continue}break}a=N()|0;nF(c+32|0);Q(a|0);p()}d=c+32|0;Nd(d);g=x[c+52>>2];nF(d);hb=c- -64|0;x[f+12>>2]=g;x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wm(a,Ac(a));hb=f+16|0}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;i=x[a+40>>2];j=x[a+36>>2];k=x[a+16>>2];b=x[a+4>>2];g=b;h=x[a>>2];x[e+24>>2]=h;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){f=i>>12;b=j>>12;break a}while(1){b=x[e+24>>2];g=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(b>>>21&2040)+32976|0;l=w[b+6>>1];m=w[b+4>>1];n=w[b+2>>1];o=w[b>>1];f=0;b=1;while(1){x[(e+8|0)+(f<<2)>>2]=(((D(v[f+g|0],n)+D(v[(f|-2)+g|0],o)|0)+D(v[(f|2)+g|0],m)|0)+D(v[(f|4)+g|0],l)<<8)/16384;h=b;b=0;f=1;if(h){continue}break}h=x[a+32>>2];j=x[a+28>>2]+j|0;b=j>>12;x[c>>2]=x[c>>2]+D(b,x[e+8>>2]);i=h+i|0;f=i>>12;x[c+4>>2]=x[c+4>>2]+D(f,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}h=x[e+24>>2];g=x[e+28>>2]}x[a>>2]=h;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=b;x[a+36>>2]=j;x[a+24>>2]=f;hb=e+32|0}function Wy(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=D(d,896)+a|0;c=e+1075060|0;b:{if(x[c>>2]){break b}if(!Ej(e+1074984|0)){break a}if(x[c>>2]){break b}if(y[e+1075073|0]&24){break a}}if(y[e+1075073|0]&2){if(!yd(f)){break a}if(!zN(x[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=D(b,896)+a|0;if(!x[b+1075680>>2]){d=65535;if(x[b+1075060>>2]){break a}}g=x[b+1075672>>2]|x[b+1075664>>2]<<9}d=65535;b=z[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=D(b,896)+a|0;if(!(x[c+1075680>>2]?0:x[c+1075060>>2])){f=(x[c+1075672>>2]|x[c+1075664>>2]<<9)>>>(x[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=x[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=x[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;jr(a);yb(a);c=Bb(g+8|0,x[a+4>>2]);d=Bb(g+4|0,x[a>>2]);f=x[Bb(g,x[b+4>>2])>>2];h=hb-16|0;hb=h;e=hb-32|0;hb=e;Ae(e+24|0,x[c>>2],x[d>>2]);c=x[e+24>>2];d=hb-16|0;hb=d;x[d+8>>2]=x[e+28>>2];x[d+12>>2]=c;x[d+4>>2]=f;if(qc(d+12|0,d+8|0)){while(1){j=d+12|0;c=Uz(j);k=d+4|0;f=Uz(k);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);v[f|0]=i;v[f+1|0]=i>>>8;v[f+2|0]=i>>>16;v[f+3|0]=i>>>24;v[f+4|0]=c;v[f+5|0]=c>>>8;v[f+6|0]=c>>>16;v[f+7|0]=c>>>24;Tz(j);Tz(k);if(qc(j,d+8|0)){continue}break}}Dc(e+16|0,d+12|0,d+4|0);hb=d+16|0;x[e+12>>2]=x[e+16>>2];x[e+8>>2]=x[e+20>>2];Dc(h+8|0,e+12|0,e+8|0);hb=e+32|0;hb=h+16|0;x[g+12>>2]=x[h+12>>2];x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Cv(a,Tg(a));hb=g+16|0}function rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-32|0;hb=f;x[f+28>>2]=d;j=_j(a,c);Af(f,x[a+28>>2]);d=x[f+12>>2];x[f+16>>2]=x[f+8>>2];x[f+20>>2]=d;a:{if(!j){if(Bd(a,5)){break a}}l=x[f+28>>2];d=hb-48|0;hb=d;h=x[a+28>>2];$j(h,d+40|0);e=x[d+44>>2];if(!e&A[d+40>>2]>256|e){x[d+40>>2]=256;x[d+44>>2]=0}b:{c:{d:{e:{f:{if(x[d+40>>2]|x[d+44>>2]){while(1){Ef(h,d+38|0);g=Xb(d+24|0);x[114409]=0;U(736,h|0,g|0,255)|0;e=x[114409];x[114409]=0;if((e|0)==1){break f}x[114409]=0;T(13,d+12|0,l|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break e}x[114409]=0;e=O(1733,b|0,d+38|0)|0;i=x[114409];x[114409]=0;if((i|0)==1){break d}i=e;e=d+12|0;Eb(i,e);xb(e);xb(g);e=x[d+44>>2];k=k+1|0;if(!e&k>>>0<A[d+40>>2]|e){continue}break}}hb=d+48|0;break b}a=N()|0;break c}a=N()|0;break c}a=N()|0;xb(d+12|0)}xb(g);Q(a|0);p()}}qj(a,j,c,f+16|0);hb=f+32|0}function Aw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}d=x[b>>2];b:{if((d^-1)&d-16843009&-2139062144){break b}while(1){c=d^1027423549;if((c^-1)&c-16843009&-2139062144){break b}d=x[b+4>>2];b=b+4|0;if(!(d-16843009&(d^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if(e){b=c+1|0;if((e|0)!=61){continue}}break}b=c}if((a|0)==(b|0)){return 0}e=b-a|0;c:{if(y[e+a|0]){break c}f=x[115191];if(!f){break c}d=x[f>>2];if(!d){break c}while(1){d:{b=a;h=0;g=e;c=0;e:{if(!e){break e}c=y[b|0];f:{if(!c){break f}while(1){g:{i=y[d|0];if((i|0)!=(c|0)|!i){break g}g=g-1|0;if(!g){break g}d=d+1|0;c=y[b+1|0];b=b+1|0;if(c){continue}break f}break}h=c}c=(h&255)-y[d|0]|0}if(!c){b=x[f>>2]+e|0;if(y[b|0]==61){break d}}d=x[f+4>>2];f=f+4|0;if(d){continue}break c}break}j=b+1|0}return j}function rea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Qe(a)),x[l+12>>2]=m;zc(g+12|0,(c>>>0)/3|0);c=Db(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Db(y[c|0]);h=Db(y[c+1|0])<<16|e<<8|Db(y[c+2|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+3|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Db(y[b|0]);a=Db(y[b+1|0])<<16|a<<8|Db(y[b+2|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=vqa(k,a,f,0);i=lb;break e}i=vqa(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Ec(a,i)>>>16|0,w[l>>1]=m;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return D(x[g+12>>2],3)|0}function qea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Qe(a)),x[l+12>>2]=m;zc(g+12|0,(c>>>0)/3|0);c=Db(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Db(y[c+2|0]);h=Db(y[c+1|0])<<16|e<<8|Db(y[c|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+3|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Db(y[b+2|0]);a=Db(y[b+1|0])<<16|a<<8|Db(y[b|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=vqa(k,a,f,0);i=lb;break e}i=vqa(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Ec(a,i)>>>16|0,w[l>>1]=m;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return D(x[g+12>>2],3)|0}function _la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=4;v[e+14|0]=0;w[e+12>>1]=0;if(d){l=D(c,d);n=(l|0)<=0;while(1){if(!n){h=b+j|0;o=l+h|0;while(1){v[e+11|0]=0;JR(a,e+14|0,e+12|0,e+11|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Ue(a,e+10|0)){break b}c=y[e+10|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=y[e+11|0]<<1|f;v[e+11|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=y[e+11|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;m=c&255;if(m>>>0<2){break c}f=c-1|0;if(!(g&1<<m)){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;k=(c-1^(i&254)>>>1)+k|0;v[e+11|0]=k;v[h|0]=k;h=d+h|0;if(o>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function Hp(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{b:{switch(x[a+480224>>2]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;d=sqa(b,d,5e4,0);e=lb;b=x[$c(c+8|0,c)>>2];b=Ec(tqa(d,e,b,b>>31),lb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=sqa(x[a+1074420>>2],0,sqa(x[a+1074408>>2],0,x[a+1074416>>2],0),lb),x[g>>2]=h;x[c+4>>2]=lb;d=hb-16|0;hb=d;e=c+8|0;f=lv(e,c);hb=d+16|0;d=sqa(b,0,6e5,0);b=f?c:e;b=vqa(d,lb,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];d=sqa(b,d,1e4,0);e=lb;b=x[$c(c+8|0,c)>>2];b=Ec(tqa(d,e,b,b>>31),lb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=sqa(a,a>>31,b,b>>31);a=lb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Ec(tqa(b,a,65536,0),lb);x[d>>2]=a>>>0<=1?1:a;hb=c+16|0}function W6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){d=Xb(c+20|0);b=x[a+24>>2];x[114409]=0;P(2198,c+8|0,b|0);b=x[114409];x[114409]=0;d:{if((b|0)!=1){b=c+8|0;e=c,f=bc(b),x[e+4>>2]=f;e=c,f=dc(b),x[e>>2]=f;if(!Hb(c+4|0,c)){break b}while(1){e:{b=x[c+4>>2];x[114409]=0;O(1328,d|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}b=c+4|0;dk(b);e=c,f=dc(c+8|0),x[e>>2]=f;if(!Hb(b,c)){break b}x[114409]=0;O(2119,d|0,10156)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}b=R(0)|0;pd(c+8|0);break d}b=R(0)|0}xb(d);break c}b=R(0)|0}Y(b|0)|0;b=0;x[114409]=0;W(2113,3360,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();break a}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}b=Ld(Rb(d));pd(c+8|0);xb(d)}hb=c+32|0;return b|0}function C7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{c:{if((b|0)!=1){d=Xb(c+20|0);b=x[a+24>>2];x[114409]=0;P(2163,c+8|0,b|0);b=x[114409];x[114409]=0;d:{if((b|0)!=1){b=c+8|0;e=c,f=bc(b),x[e+4>>2]=f;e=c,f=dc(b),x[e>>2]=f;if(!Hb(c+4|0,c)){break b}while(1){e:{b=x[c+4>>2];x[114409]=0;O(1328,d|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}b=c+4|0;dk(b);e=c,f=dc(c+8|0),x[e>>2]=f;if(!Hb(b,c)){break b}x[114409]=0;O(2119,d|0,10156)|0;b=x[114409];x[114409]=0;if((b|0)!=1){continue}}break}b=R(0)|0;pd(c+8|0);break d}b=R(0)|0}xb(d);break c}b=R(0)|0}Y(b|0)|0;b=0;x[114409]=0;W(2113,2920,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();break a}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}b=Ld(Rb(d));pd(c+8|0);xb(d)}hb=c+32|0;return b|0}function PH(a,b,c,d){var e=0,f=0,g=0,h=E(0),i=0,j=E(0),k=0,l=E(0),m=E(0),n=E(0),o=0;e=hb-96|0;hb=e;if((d|0)>0){while(1){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];f=0;while(1){g=(e+48|0)+(f<<3)|0;i=(f<<4)+a|0;j=B[i+8>>2];h=B[i+4>>2];B[g+4>>2]=j+h;k=f<<1;B[(8-k<<2)+e>>2]=h-j;j=B[i+16>>2];h=B[i+12>>2];B[(7-k<<2)+e>>2]=j-h;B[g+8>>2]=-E(h+j);f=f+1|0;if((f|0)!=4){continue}break}OH(e+48|0);OH(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=B[g>>2];k=g;h=B[f+45840>>2];l=B[f+(e+48|0)>>2];m=B[e+f>>2];g=f+36|0;n=B[g+45840>>2];B[k>>2]=E(h*l)-E(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=E(E(h*m)+E(n*l));B[k>>2]=E(j*B[f>>2])-E(B[g>>2]*h);B[(17-i<<2)+a>>2]=E(B[f>>2]*h)+E(j*B[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}hb=e+96|0}function vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];i=x[a+4>>2];e=x[a>>2];x[f+8>>2]=e;x[f+12>>2]=i;j=x[a+12>>2];x[f>>2]=x[a+8>>2];x[f+4>>2]=j;a:{if(!d){b=g>>12;j=h>>12;break a}i=b+24|0;while(1){l=x[a+32>>2];b=x[f+8>>2];h=x[a+28>>2]+h|0;j=h>>12;e=(x[f+12>>2]<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+i|0;e=(((((D(w[e+4>>1],w[b+10>>1])+D(w[e+2>>1],w[b+8>>1])|0)+D(w[e+6>>1],w[b+12>>1])|0)+D(w[e+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[e-4>>1],w[b+2>>1])+D(w[e-6>>1],w[b>>1])|0)+D(w[e-2>>1],w[b+4>>1])|0)+D(w[e>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(j,e);g=g+l|0;b=g>>12;x[c+4>>2]=x[c+4>>2]+D(e,b);c=c+8|0;Tb(f+8|0,f);d=d-1|0;if(d){continue}break}e=x[f+8>>2];i=x[f+12>>2]}x[a>>2]=e;x[a+4>>2]=i;x[a+40>>2]=g;x[a+20>>2]=j;x[a+36>>2]=h;x[a+24>>2]=b;hb=f+16|0}function h7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;P(2184,c+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}if(Ac(c+4|0)>>>0<2147483647){break h}d=ec(8);x[114409]=0;b=O(2185,d|0,3641)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(2132,b|0,75324,238);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=R(0)|0;break f}b=R(0)|0;break e}b=R(0)|0;break e}j:{k:{if((b|0)>=0){if((Ac(c+4|0)|0)>(b|0)){break k}}b=Ld(17381);break j}b=Ld(Rb(ud(c+4|0,b)))}pd(c+4|0);break d}b=R(0)|0;ic(d)}pd(c+4|0)}Y(b|0)|0;b=0;x[114409]=0;W(2113,7755,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break a}R(0)|0;zb()}p()}Q(a|0);p()}function g7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;P(2186,c+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}if(Ac(c+4|0)>>>0<2147483647){break h}d=ec(8);x[114409]=0;b=O(2185,d|0,3641)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(2132,b|0,75324,238);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=R(0)|0;break f}b=R(0)|0;break e}b=R(0)|0;break e}j:{k:{if((b|0)>=0){if((Ac(c+4|0)|0)>(b|0)){break k}}b=Ld(17381);break j}b=Ld(Rb(ud(c+4|0,b)))}pd(c+4|0);break d}b=R(0)|0;ic(d)}pd(c+4|0)}Y(b|0)|0;b=0;x[114409]=0;W(2113,7723,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break a}R(0)|0;zb()}p()}Q(a|0);p()}function f7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;P(2187,c+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}if(Ac(c+4|0)>>>0<2147483647){break h}d=ec(8);x[114409]=0;b=O(2185,d|0,3641)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(2132,b|0,75324,238);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=R(0)|0;break f}b=R(0)|0;break e}b=R(0)|0;break e}j:{k:{if((b|0)>=0){if((Ac(c+4|0)|0)>(b|0)){break k}}b=Ld(17381);break j}b=Ld(Rb(ud(c+4|0,b)))}pd(c+4|0);break d}b=R(0)|0;ic(d)}pd(c+4|0)}Y(b|0)|0;b=0;x[114409]=0;W(2113,7661,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break a}R(0)|0;zb()}p()}Q(a|0);p()}function e7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;P(2188,c+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}if(Ac(c+4|0)>>>0<2147483647){break h}d=ec(8);x[114409]=0;b=O(2185,d|0,3641)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(2132,b|0,75324,238);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=R(0)|0;break f}b=R(0)|0;break e}b=R(0)|0;break e}j:{k:{if((b|0)>=0){if((Ac(c+4|0)|0)>(b|0)){break k}}b=Ld(17381);break j}b=Ld(Rb(ud(c+4|0,b)))}pd(c+4|0);break d}b=R(0)|0;ic(d)}pd(c+4|0)}Y(b|0)|0;b=0;x[114409]=0;W(2113,7691,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break a}R(0)|0;zb()}p()}Q(a|0);p()}function d7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;P(2189,c+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}if(Ac(c+4|0)>>>0<2147483647){break h}d=ec(8);x[114409]=0;b=O(2185,d|0,3641)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(2132,b|0,75324,238);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=R(0)|0;break f}b=R(0)|0;break e}b=R(0)|0;break e}j:{k:{if((b|0)>=0){if((Ac(c+4|0)|0)>(b|0)){break k}}b=Ld(17381);break j}b=Ld(Rb(ud(c+4|0,b)))}pd(c+4|0);break d}b=R(0)|0;ic(d)}pd(c+4|0)}Y(b|0)|0;b=0;x[114409]=0;W(2113,7626,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break a}R(0)|0;zb()}p()}Q(a|0);p()}function c7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;P(2190,c+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break i}if(Ac(c+4|0)>>>0<2147483647){break h}d=ec(8);x[114409]=0;b=O(2185,d|0,3641)|0;e=x[114409];x[114409]=0;if((e|0)==1){break g}x[114409]=0;T(2132,b|0,75324,238);b=x[114409];x[114409]=0;if((b|0)!=1){break b}b=R(0)|0;break f}b=R(0)|0;break e}b=R(0)|0;break e}j:{k:{if((b|0)>=0){if((Ac(c+4|0)|0)>(b|0)){break k}}b=Ld(17381);break j}b=Ld(Rb(ud(c+4|0,b)))}pd(c+4|0);break d}b=R(0)|0;ic(d)}pd(c+4|0)}Y(b|0)|0;b=0;x[114409]=0;W(2113,7787,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){break a}R(0)|0;zb()}p()}Q(a|0);p()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb-4112|0;hb=c;i=mb[x[x[a>>2]+112>>2]](a)|0;if(!i){mb[x[x[a>>2]+116>>2]](a)}x[c+12>>2]=0;f=hb-16|0;hb=f;h=a+44|0;if(xf(h)){while(1){e=Am(h,d);g=Am(h,d);x[f+12>>2]=0;g=(g+2048|0)-e>>2;if((g|0)>0){while(1){B[e>>2]=B[f+12>>2];e=e+4|0;j=g>>>0>1;g=g-1|0;if(j){continue}break}}d=d+1|0;if(xf(h)>>>0>d>>>0){continue}break}}hb=f+16|0;if(b){f=c+2064|0;while(1){x[c+8>>2]=b;zc(c+8|0,512);d=c+16|0;jq(d);mb[x[x[a>>2]+60>>2]](a,d,f,x[c+8>>2]);e=0;d=0;if(x[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;B[c+4>>2]=F(B[e>>2]);k=c,l=B[Qx(c+12|0,c+4|0)>>2],B[k+12>>2]=l;B[c+4>>2]=F(B[e+2048>>2]);k=c,l=B[Qx(c+12|0,c+4|0)>>2],B[k+12>>2]=l;e=x[c+8>>2];d=d+1|0;if(e>>>0>d>>>0){continue}break}}b=b-e|0;if(b){continue}break}}if(!i){mb[x[x[a>>2]+120>>2]](a)}hb=c+4112|0;return E(B[c+12>>2])}function JM(a,b){var c=0;c=hb-16|0;hb=c;a=gr(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(a,7,1);Nb(a,9,1);Nb(a,10,1);Nb(a,13,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,20,1);Nb(a,21,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,28,1);Nb(a,30,1);Nb(a,31,1);Nb(a,33,1);Nb(a,34,1);Nb(a,39,1);Nb(a,41,1);Nb(a,44,1);Nb(a,46,1);Nb(a,45,1);Nb(a,47,1);Nb(a,48,1);Nb(a,50,1);Nb(a,99,1);Nb(a,102,1);Nb(a,104,1);Nb(a,105,1);break a;case 1:Iy(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Kg(a,107);break a;case 3:Iy(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Kg(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}Iy(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}hb=c+16|0}function jK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;e=Dg(a);g=c,h=td(b),x[g+12>>2]=h;g=c,h=nf(b),x[g+8>>2]=h;a:{b:{if(!Hb(c+12|0,c+8|0)){break b}a=0;while(1){b=y[x[c+12>>2]];c:{d:{if(!a){if(b<<24>>24>=0){a=0;x[114409]=0;P(113,e|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break c}break a}if((b&224)==192){d=b&31;a=1;break c}if((b&240)==224){d=b&15;a=2;break c}f=65533;if((b&248)!=240){break d}d=b&7;a=3;break c}if((b&192)!=128){x[114409]=0;P(113,e|0,65533);a=x[114409];x[114409]=0;if((a|0)==1){break a}d=b&63;a=-1;break c}f=b&63|d<<6;d=f;a=a-1|0;if(a){break c}}d=0;x[114409]=0;P(113,e|0,f|0);b=x[114409];x[114409]=0;a=0;if((b|0)==1){break a}}b=c+12|0;gg(b);if(Hb(b,c+8|0)){continue}break}if(!a){break b}x[114409]=0;P(113,e|0,65533);a=x[114409];x[114409]=0;if((a|0)!=1){break b}break a}hb=c+16|0;return}a=N()|0;Pc(e);Q(a|0);p()}function gs(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+24>>2];d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{if((d|0)!=1){if(!b){break b}x[114409]=0;O(15,c+8|0,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}if(!y[c+8|0]){break e}b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+24>>2];d=x[114409];x[114409]=0;f:{if((d|0)==1){break f}x[114409]=0;b=S(2441,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break f}if((b|0)!=-1){break e}b=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+b|0,1);b=x[114409];x[114409]=0;if((b|0)!=1){break e}}b=R(0)|0;Of(c+8|0);break c}b=R(0)|0;break c}Of(c+8|0);break b}b=R(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}_()}hb=c+16|0;return a|0}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function I8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0);i=hb-16|0;hb=i;j=a+44|0;if(Eh(j)){h=Qd(j,0);x[i+8>>2]=h;k=Qd(j,1);x[i+12>>2]=k;e=ld(j,0);x[i>>2]=e;f=ld(j,1);x[i+4>>2]=f;a:{if(B[a+4216>>2]!=E(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=x[e>>2];x[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=B[m>>2];l=B[g>>2];q=B[a+4228>>2];r=B[a+4224>>2];s=B[a+4220>>2];t=B[a+4236>>2];u=B[a+4232>>2];g=e+4240|0;n=B[g>>2];B[m>>2]=n;B[g>>2]=l;g=e+4264|0;v=B[g>>2];e=e+4256|0;o=B[e>>2];B[g>>2]=o;l=E(E(E(E(n*r)+E(s*l))+E(p*q))-E(E(v*t)+E(o*u)));B[e>>2]=l;f=f+i|0;e=x[f>>2];x[f>>2]=e+4;B[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;sc(e,g,h);sc(f,k,h)}Gi(a,b,c,ld(j,0),ld(j,1),d)}hb=i+16|0}function R6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[114409]=0;V(2164,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}x[114409]=0;V(2164,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}d=x[a+24>>2];x[114409]=0;b=O(122,e+20|0,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break g}x[114409]=0;c=O(122,e+8|0,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break f}x[114409]=0;W(2204,d|0,b|0,c|0,1);d=x[114409];x[114409]=0;if((d|0)==1){break e}xb(c);xb(b);b=1;break b}d=R(0)|0;break c}d=R(0)|0;break d}d=R(0)|0;xb(c)}xb(b)}Y(d|0)|0;b=0;x[114409]=0;W(2113,2763,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=e+32|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function _na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-48|0;hb=e;i=e+24|0;g=hb-144|0;hb=g;f=qh(g+8|0);h=x[x[f>>2]-12>>2];x[114409]=0;j=$(125)|0;k=x[114409];x[114409]=0;a:{b:{if((k|0)==1){break b}x[114409]=0;T(126,g+4|0,f+h|0,j|0);h=x[114409];x[114409]=0;if((h|0)==1){break b}Ob(g+4|0);x[114409]=0;P(137,f|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(128,i|0,f|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}ae(f);hb=g+144|0;break a}a=N()|0;ae(f);Q(a|0);p()}x[114409]=0;T(677,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;c:{d:{if((c|0)!=1){x[114409]=0;P(678,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}x[114409]=0;T(502,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break c}c=N()|0;pf(e+24|0)}Q(c|0);p()}function A5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb+-64|0;hb=e;x[e+60>>2]=c;c=wp(a,e+60|0);h=XI(c+4|0);i=WI(c+24|0);j=VI(c+32|0);k=Fx(c+36|0);x[c+56>>2]=3;l=sh(c+68|0);x[114409]=0;P(2289,c|0,d|0);a=x[114409];x[114409]=0;a:{b:{c:{d:{if((a|0)!=1){a=x[b>>2];f=x[b+4>>2];g=x[b+12>>2];b=x[b+8>>2];x[e+16>>2]=b;x[e+20>>2]=g;x[114409]=0;x[e+36>>2]=b;x[e+40>>2]=g;x[e+28>>2]=a;x[e+32>>2]=f;x[e+8>>2]=a;x[e+12>>2]=f;T(2286,e+44|0,e+8|0,0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;T(2290,c|0,e+44|0,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Ab(e+44|0);x[114409]=0;V(2291,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}od(e+60|0);hb=e- -64|0;return c|0}a=N()|0;break a}a=N()|0;break a}a=N()|0;Ab(e+44|0);break a}a=N()|0}pd(l);Qf(k);kg(j);Ai(i);od(h);od(c);od(e+60|0);Q(a|0);p()}function xR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){f=c;c=v[a+b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((b|0)!=20){continue}break}a:{if(c>>>0>5){break a}while(1){d=D(g,30)+a|0;j=d+20|0;b=0;e=0;while(1){f=b;b=v[e+j|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((e|0)!=22){continue}break}c=b+c|0;if(y[d+44|0]|(c>>>0>48|y[d+45|0]>64)){break a}b=y[d+42|0]|y[d+43|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>32768){break a}b=y[d+42|0]|y[d+43|0]<<8;h=((b<<8|b>>>8)&65535)+h|0;i=y[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|y[a+470|0]>128|y[a+471|0]>220){break a}e=hb-16|0;hb=e;c=a+472|0;d=c+128|0;b:{if((c|0)==(d|0)){break b}b=c+1|0;if((d|0)==(b|0)){break b}while(1){c=y[c|0]<y[b|0]?b:c;b=b+1|0;if((d|0)!=(b|0)){continue}break}}hb=e+16|0;c=y[c|0];if(c>>>0>63|!(y[a+471|0]|(c|y[a+470|0]))){break a}k=1}return k}function R0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[114232];x[114232]=0;g=hb-16|0;hb=g;me();e=hb-16|0;hb=e;f=hb-16|0;hb=f;uw(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;hb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;hb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;hb=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[114232];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[114232]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;hb=h+32|0}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;zd(c,2);v[d+20|0]=y[b+13|0];v[d+8|0]=64;e=d+20|0;f=d+8|0;h=c,i=y[tc(e,f)|0]<<2,w[h+30>>1]=i;g=b+14|0;x[c+24>>2]=(y[g|0]|y[g+1|0]<<8)<<1;$k(f,2,b+1|0);Kc(e,f);x[114409]=0;O(350,c+43|0,e|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){xb(d+20|0);e=cd(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}a=b+22|0;x[c>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a=b+26|0;x[c+4>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a=b+30|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[c+8>>2]=a;if(a>>>0>A[c+4>>2]){x[c+8>>2]=a-1}if(y[b|0]&4){w[c+34>>1]=z[c+34>>1]|2}if(y[b|0]&8){w[c+34>>1]=z[c+34>>1]|4}if(!(y[b|0]&16)){break a}XA(e);vm(e,9);x[c>>2]=x[c>>2]>>>1;x[c+4>>2]=x[c+4>>2]>>>1;x[c+8>>2]=x[c+8>>2]>>>1}hb=d+32|0;return}a=N()|0;xb(d+20|0);Q(a|0);p()}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((xf(a)|0)==(b|0)){if((xf(a+12|0)|0)==(c|0)){break b}}x[114409]=0;P(1762,a|0,b|0);d=x[114409];x[114409]=0;c:{d:{if((d|0)==1){break d}x[114409]=0;e=a+12|0;P(1762,e|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;f=a+24|0;P(1763,f|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;g=a+36|0;P(1763,g|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Am(a,d);i=Pb(f,d),j=h,x[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=R(74984)|0;if((ib|0)!=(ca(74984)|0)){break a}Y(b|0)|0;PK(a);OK(a);b=a+12|0;PK(b);OK(b);b=a+24|0;NK(b);MK(b);a=a+36|0;NK(a);MK(a);_();return 0}a=0;while(1){b=Am(e,a);i=Pb(g,a),j=b,x[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}Q(b|0);p()}function Opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Xb(a);h=Cb(b);x[114409]=0;P(508,f|0,h|0);a=x[114409];x[114409]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=y[pc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=y[pc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=x[c+4>>2];e=x[c>>2];x[114409]=0;d=O(526,e|0,d|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}if(d>>>0<=g>>>0){d=a;break b}x[114409]=0;d=O(509,c|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;O(510,f|0,d|0)|0;e=x[114409];x[114409]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}x[114409]=0;U(511,f|0,1,37)|0;g=x[114409];x[114409]=0;d=a;if((g|0)==1){break a}}x[114409]=0;U(511,f|0,1,e<<24>>24)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=N()|0;xb(f);Q(a|0);p()}function zK(a,b,c){var d=0;a:{b:{switch(b|0){case 0:jK(a,c);return;case 1:b=0;a=Dg(a);d=Cb(c);x[114409]=0;P(114,a|0,d|0);d=x[114409];x[114409]=0;c:{if((d|0)!=1){d:{if(Cb(c)){while(1){d=y[pc(c,b)|0];x[114409]=0;P(113,a|0,(d<<24>>24<0?65533:d)|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}b=b+1|0;if(Cb(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=Dg(a);d=Cb(c);x[114409]=0;P(114,a|0,d|0);d=x[114409];x[114409]=0;e:{if((d|0)!=1){f:{if(Cb(c)){while(1){d=y[pc(c,b)|0];x[114409]=0;P(113,a|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break f}b=b+1|0;if(Cb(c)>>>0>b>>>0){continue}break}}break e}}break a}return;case 3:yp(a,c,17600);return;case 4:yp(a,c,18624);return;case 5:yp(a,c,19648);return;case 6:yp(a,c,20672);return;case 7:yp(a,c,21696);return;default:break b}}Dg(a);return}b=N()|0;Pc(a);Q(b|0);p()}function wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];i=x[a+4>>2];e=x[a>>2];x[f+8>>2]=e;x[f+12>>2]=i;j=x[a+12>>2];x[f>>2]=x[a+8>>2];x[f+4>>2]=j;a:{if(!d){b=g>>12;j=h>>12;break a}i=b+24|0;while(1){l=x[a+32>>2];b=x[f+8>>2];h=x[a+28>>2]+h|0;j=h>>12;e=x[f+12>>2]+k|0;b=(((b>>>16|0)+4&131064)<<1)+i|0;e=((((D(v[e+2|0],w[b+10>>1])+D(v[e+1|0],w[b+8>>1])|0)+D(v[e+3|0],w[b+12>>1])|0)+D(v[e+4|0],w[b+14>>1])<<8>>1)+(((D(v[e-2|0],w[b+2>>1])+D(v[e-3|0],w[b>>1])|0)+D(v[e-1|0],w[b+4>>1])|0)+D(v[e|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(j,e);g=g+l|0;b=g>>12;x[c+4>>2]=x[c+4>>2]+D(e,b);c=c+8|0;Tb(f+8|0,f);d=d-1|0;if(d){continue}break}e=x[f+8>>2];i=x[f+12>>2]}x[a>>2]=e;x[a+4>>2]=i;x[a+40>>2]=g;x[a+20>>2]=j;x[a+36>>2]=h;x[a+24>>2]=b;hb=f+16|0}function xx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Th(c- -64|0,c+32|0,f);d=Oc(c+52|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){i=c+16|0;j=b+4|0;while(1){a=0;if(e){while(1){h=C[ph(c,a,g)>>3];fc(b,a);h=Td(Gg(+(Kj(Td(h*134217728))-1024+((Bs(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(F(h)<2147483648){d=~~h;break a}d=-2147483648}d=Wc(d);k=rn(i,a,g),l=d,w[k>>1]=l;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gd(a);h=Cb(b);x[114409]=0;P(77,f|0,h|0);a=x[114409];x[114409]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=y[pc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=y[pc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=x[c+4>>2];e=x[c>>2];x[114409]=0;d=O(83,e|0,d|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}if(d>>>0<=g>>>0){d=a;break b}x[114409]=0;d=O(78,c|0,g|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;O(79,f|0,d|0)|0;e=x[114409];x[114409]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}x[114409]=0;U(80,f|0,1,37)|0;g=x[114409];x[114409]=0;d=a;if((g|0)==1){break a}}x[114409]=0;U(80,f|0,1,e<<24>>24)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=N()|0;xb(f);Q(a|0);p()}function G_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Lb(a);if(c>>>0<b>>>0){h=hb-32|0;hb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){lF(a,f);break c}g=ul(a);e=h+12|0;d=Lb(a)+f|0;b=hb-16|0;hb=b;x[b+12>>2]=d;d:{c=IE(a);if(d>>>0<=c>>>0){d=sd(a);if(d>>>0<c>>>1>>>0){x[b+8>>2]=d<<1;c=x[$c(b+8|0,b+12|0)>>2]}hb=b+16|0;b=c;break d}Xc();p()}i=Lb(a);c=0;d=hb-16|0;hb=d;x[d+12>>2]=0;We(e+12|0,g);if(b){HE(d+4|0,x[e+16>>2],b);c=x[d+4>>2];b=x[d+8>>2]}else{b=0}x[e>>2]=c;g=(i<<2)+c|0;x[e+8>>2]=g;x[e+4>>2]=g;j=hc(e),k=(b<<2)+c|0,x[j>>2]=k;hb=d+16|0;x[114409]=0;P(2713,e|0,f|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;EE(a,e);a=x[114409];x[114409]=0;if((a|0)==1){break b}CE(e)}hb=h+32|0;break a}a=N()|0;CE(e);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+(b<<2)|0;Lb(a);FE(a,b);sg(a)}}function pqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;zd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Lq(a+4|0,a);x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=Lq(a+8|0,a);x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+15|0;x[b+24>>2]=(y[c|0]|y[c+1|0]<<8)<<1;if(!(y[c|0]|y[c+1|0]<<8)){x[b+24>>2]=16726}c=a+14|0;e=b,f=(D(Mt(v[a+17|0],y[c|0]<<28>>24),x[b+24>>2])>>>0)/8363|0,x[e+24>>2]=f;v[d+15|0]=y[a+18|0];v[d+14|0]=127;e=b,f=(((y[tc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[e+30>>1]=f;if(y[c|0]>=16){c=y[c|0];w[b+34>>1]=32;w[b+28>>1]=c&240}a=a+19|0;if(y[a|0]&4){w[b+34>>1]=z[b+34>>1]|1}a:{if(!(y[a|0]&8)|A[b+4>>2]>=A[b+8>>2]){break a}w[b+34>>1]=z[b+34>>1]|2;if(y[a|0]&16){w[b+34>>1]=z[b+34>>1]|4}if(!(y[a|0]&64)){break a}w[b+34>>1]=z[b+34>>1]|128}hb=d+16|0}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;e=hb-32|0;hb=e;i=c;f=b;d=Ve(b);c=mc(b);a:{if(d){while(1){b=d;d=b+16|0;if(fz(yb(f),i,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!fz(yb(f),d,i)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break a}}b=mc(f);c=b}x[e+28>>2]=b;b=x[c>>2];v[e+27|0]=0;if(!b){j=hb-16|0;hb=j;l=mc(f);b=_d(28,4);k=Xk(j+8|0,l);d=hb-16|0;hb=d;x[114409]=0;x[d+12>>2]=b;g=e+12|0;b=U(1625,g|0,d+12|0,k|0)|0;k=x[114409];x[114409]=0;b:{if((k|0)!=1){hb=d+16|0;break b}R(0)|0;zb();p()}d=x[b>>2]+16|0;x[114409]=0;T(1624,l|0,d|0,i|0);d=x[114409];x[114409]=0;c:{if((d|0)!=1){m=mc(b),n=1,v[m+4|0]=n;hb=j+16|0;break c}a=N()|0;RL(b);Q(a|0);p()}Yk(f,x[e+28>>2],c,x[g>>2]);b=oe(g);v[e+27|0]=1;RL(g)}c=h+8|0;Wi(c,Bb(e+12|0,b),e+27|0);hb=e+32|0;$O(a,c);hb=h+16|0}function zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=rc(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>1>>>0){h=hb-16|0;hb=h;e:{d=bh(h+4|0,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114409]=0;P(851,i|0,e|0);i=x[114409];x[114409]=0;if((i|0)==1){break e}e=e+2|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=Mq(g+12|0,hj(b,rc(b)+e|0),rc(b),d);x[114409]=0;P(849,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(850,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}XR(d)}hb=g+32|0;break b}a=N()|0;XR(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<1)|0;rc(b);YR(b,d);uo(b)}}c=Qb(a,c<<1);if(c){d=f+8|0;HB(d,b);Cd(a,d)}hb=f+16|0;return c|0}function goa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>2>>>0){h=hb-16|0;hb=h;e:{d=ne(h+4|0,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114409]=0;P(751,i|0,e|0);i=x[114409];x[114409]=0;if((i|0)==1){break e}e=e+4|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=tu(g+12|0,Fe(b,Lb(b)+e|0),Lb(b),d);x[114409]=0;P(749,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(750,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}VS(d)}hb=g+32|0;break b}a=N()|0;VS(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<2)|0;Lb(b);WS(b,d);sg(b)}}c=Qb(a,c<<2);if(c){d=f+8|0;CA(d,b);Cd(a,d)}hb=f+16|0;return c|0}function Gma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>2>>>0){h=hb-16|0;hb=h;e:{d=ne(h+4|0,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114409]=0;P(845,i|0,e|0);i=x[114409];x[114409]=0;if((i|0)==1){break e}e=e+4|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=tu(g+12|0,Fe(b,Lb(b)+e|0),Lb(b),d);x[114409]=0;P(843,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(844,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}cS(d)}hb=g+32|0;break b}a=N()|0;cS(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<2)|0;Lb(b);dS(b,d);sg(b)}}c=Qb(a,c<<2);if(c){d=f+8|0;CA(d,b);Cd(a,d)}hb=f+16|0;return c|0}function eN(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;x[f+12>>2]=b;e=0;a:{if(!b){break a}if(x[a+480180>>2]&20){c=a+1074312|0;b=$b(c,73)?b&65535:b;if(y[a+480208|0]&16){a=$b(c,73)?14-((9983-b>>>0)/768|0)&31:((b>>>0)/768|0)+2|0;e=x[((b>>>0)%768<<2)+27200>>2]<<6>>>a|0;break a}e=229079296/((b>>>0<=1?1:b)>>>0)|0;break a}e=227001280/(b>>>0)|0;if(Bq(a)){break a}e=(b+c<<4)-133808|0;if(x[a+480180>>2]==64){break a}b=x[a+480180>>2];zc(f+12|0,16777215);if(b&17408){e=id(vqa(sqa(c?c:8363,0,3506176,0),lb,(x[f+12>>2]<<8)+d|0,0),lb);break a}if(y[a+480208|0]&16){if($b(a+1074312|0,7)){c=d>>31;b=d;a=x[f+12>>2];d=a>>>24|0;e=a<<8;b=b+e|0;a=c+d|0;e=((b>>>0<e>>>0?a+1|0:a)&15)<<28|b>>>4;break a}e=id(vqa(sqa(c?c:8363,0,7012352,0),lb,(x[f+12>>2]<<8)+d|0,0),lb);break a}e=id(vqa(-1485242368,13,(x[f+12>>2]<<8)+d|0,0),lb)}hb=f+16|0;return e}function ZV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=rc(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>1>>>0){h=hb-16|0;hb=h;e:{d=bh(h+4|0,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114409]=0;P(396,i|0,e|0);i=x[114409];x[114409]=0;if((i|0)==1){break e}e=e+2|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=Mq(g+12|0,hj(b,rc(b)+e|0),rc(b),d);x[114409]=0;P(394,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(395,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}FB(d)}hb=g+32|0;break b}a=N()|0;FB(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<1)|0;rc(b);IB(b,d);uo(b)}}c=Qb(a,c<<1);if(c){d=f+8|0;HB(d,b);Cd(a,d)}hb=f+16|0;return c|0}function D$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=uF(c);b:{if(b){b=k+4|0;hk(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gk(b,a);break b}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jh(b,a)}oi(i,b);Pc(b);l=e,m=ti(a),x[l>>2]=m;l=f,m=si(a),x[l>>2]=m;b=k+4|0;zg(b,a);Eb(g,b);xb(b);kh(b,a);oi(h,b);Pc(b);a=fk(a);break a}a=tF(c);c:{if(b){b=k+4|0;hk(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gk(b,a);break c}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jh(b,a)}oi(i,b);Pc(b);l=e,m=ti(a),x[l>>2]=m;l=f,m=si(a),x[l>>2]=m;b=k+4|0;zg(b,a);Eb(g,b);xb(b);kh(b,a);oi(h,b);Pc(b);a=fk(a)}x[j>>2]=a;hb=k+16|0}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;e=hb-32|0;hb=e;i=c;f=b;d=Ve(b);c=mc(b);a:{if(d){while(1){b=d;d=b+14|0;if(Ho(yb(f),i,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!Ho(yb(f),d,i)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break a}}b=mc(f);c=b}x[e+28>>2]=b;b=x[c>>2];v[e+27|0]=0;if(!b){j=hb-16|0;hb=j;k=mc(f);d=TD(1);g=Xk(j+8|0,k);b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=d;d=e+12|0;g=U(1221,d|0,b+12|0,g|0)|0;l=x[114409];x[114409]=0;b:{if((l|0)!=1){hb=b+16|0;break b}R(0)|0;zb();p()}b=x[g>>2]+14|0;x[114409]=0;T(1220,k|0,b|0,i|0);b=x[114409];x[114409]=0;c:{if((b|0)!=1){m=mc(g),n=1,v[m+4|0]=n;hb=j+16|0;break c}a=N()|0;ZO(g);Q(a|0);p()}Yk(f,x[e+28>>2],c,x[d>>2]);b=oe(d);v[e+27|0]=1;ZO(d)}c=h+8|0;Wi(c,Bb(e+12|0,b),e+27|0);hb=e+32|0;$O(a,c);hb=h+16|0}function F4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=sh(a);a=b+24|0;c=x[a>>2];x[114409]=0;c=S(2318,c+484344|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{if((f|0)==1){break c}x[114409]=0;P(1629,e|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}d:{e:{f:{g:{while(1){c=x[a>>2];x[114409]=0;c=S(2318,c+484344|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(c>>>0<=g>>>0){break d}c=Zb(x[a>>2]+484344|0,g);x[114409]=0;P(2315,d+8|0,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){x[114409]=0;T(2309,d+20|0,b|0,d+8|0);c=x[114409];x[114409]=0;if((c|0)==1){break g}x[114409]=0;P(1631,e|0,d+20|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}g=g+1|0;xb(d+20|0);xb(d+8|0);continue}break}a=N()|0;break a}a=N()|0;break e}a=N()|0;xb(d+20|0)}xb(d+8|0);break a}hb=d+32|0;return}a=N()|0;break a}a=N()|0}pd(e);Q(a|0);p()}function x5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-32|0;hb=f;x[f+28>>2]=d;d=wp(a,f+28|0);g=XI(d+4|0);h=WI(d+24|0);i=VI(d+32|0);j=Fx(d+36|0);x[d+56>>2]=3;k=sh(d+68|0);x[114409]=0;P(2289,d|0,e|0);a=x[114409];x[114409]=0;a:{b:{c:{d:{if((a|0)!=1){x[114409]=0;a=S(2295,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;T(2296,f+4|0,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;T(2297,f+12|0,f+4|0,0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;T(2290,d|0,f+12|0,e|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Ab(f+12|0);x[114409]=0;V(2291,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}}a=N()|0;break b}a=N()|0;break b}a=N()|0;Ab(f+12|0)}pd(k);Qf(j);kg(i);Ai(h);od(g);od(d);od(f+28|0);Q(a|0);p()}od(f+28|0);hb=f+32|0;return d|0}function wJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=hb-48|0;hb=j;x[j+44>>2]=e;e=x[a+4>>2];k=x[a>>2];a=x[a+8>>2];x[114409]=0;x[j+28>>2]=b;x[j+40>>2]=a;x[j+32>>2]=k;x[j+36>>2]=e;x[j+16>>2]=d?d:2121;a=O(2122,j+16|0,j+44|0)|0;b=x[114409];x[114409]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+20>>2]=a;a=x[xp(j+24|0,j+20|0)>>2];x[114409]=0;b=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=b;b=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=b;c=+ua(2123,j|0,+c,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}od(j+20|0);break b}a=R(0)|0;break c}a=R(0)|0;od(j+20|0)}Y(a|0)|0;x[114409]=0;fa(2124,10698,d|0,x[j+44>>2],f|0,g|0,h|0,i|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}hb=j+48|0;return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function i5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb+-64|0;hb=d;a:{b:{if((b|0)>=0){e=a+24|0;if(Jj(Wb(x[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}g=z[vc(Wb(x[e>>2]+484360|0),b)>>1];c:{if(!so(x[e>>2]+484344|0,g)){break c}if((c|0)>=0){f=c;if((f|0)<x[Zb(x[e>>2]+484344|0,g)+12>>2]){break c}}a=a+16|0;break a}w[x[e>>2]+1074438>>1]=b;b=b&65535;DM(x[e>>2],b);x[x[e>>2]+1074428>>2]=f;x[x[e>>2]+1074392>>2]=-2;c=x[e>>2];e=y[a+64|0];v[d+30|0]=255;x[d+40>>2]=0;w[d+28>>1]=0;x[d+24>>2]=0;if(!((b|0)==65535|(f|0)==-1)){w[d+36>>1]=b;x[d+32>>2]=f;x[d+40>>2]=2}b=x[d+44>>2];x[d+16>>2]=x[d+40>>2];x[d+20>>2]=b;b=x[d+36>>2];x[d+8>>2]=x[d+32>>2];x[d+12>>2]=b;b=x[d+28>>2];x[d>>2]=x[d+24>>2];x[d+4>>2]=b;b=d+52|0;st(b,c,e?7:1,d);h=a,i=C[eh(b)>>3],C[h+16>>3]=i;em(b);a=a+16|0}hb=d- -64|0;return+C[a>>3]}function XG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;x[114409]=0;g=O(15,d+8|0,a|0)|0;e=x[114409];x[114409]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!y[g|0]){break e}e=jl(d,a);f=x[x[a>>2]-12>>2];h=x[(f+a|0)+4>>2];x[114409]=0;f=a+f|0;i=S(16,f|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break d}e=x[e>>2];x[114409]=0;c=b+c|0;b=ga(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break d}x[d+4>>2]=b;if(!hl(d+4|0)){break e}b=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+b|0,5);b=x[114409];x[114409]=0;if((b|0)!=1){break e}break d}Of(g);break b}b=R(0)|0;Of(g);break c}b=R(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}_()}hb=d+16|0;return a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){R(0)|0;zb();p()}Q(a|0);p()}function H$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=yF(c);b:{if(b){b=k+4|0;hk(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gk(b,a);break b}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jh(b,a)}Eb(i,b);xb(b);l=e,m=ti(a),v[l|0]=m;l=f,m=si(a),v[l|0]=m;b=k+4|0;zg(b,a);Eb(g,b);xb(b);kh(b,a);Eb(h,b);xb(b);a=fk(a);break a}a=xF(c);c:{if(b){b=k+4|0;hk(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gk(b,a);break c}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jh(b,a)}Eb(i,b);xb(b);l=e,m=ti(a),v[l|0]=m;l=f,m=si(a),v[l|0]=m;b=k+4|0;zg(b,a);Eb(g,b);xb(b);kh(b,a);Eb(h,b);xb(b);a=fk(a)}x[j>>2]=a;hb=k+16|0}function Zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=No(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1458,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+32;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}h=hb-32|0;hb=h;i=yb(a);e=Hm(a,ze(a)+1|0);g=ze(a);d=hb-16|0;hb=d;x[d+12>>2]=0;c=h+12|0;We(c+12|0,i);if(e){f=YM(x[c+16>>2],e);x[d+8>>2]=e;x[d+4>>2]=f;f=x[d+4>>2];e=x[d+8>>2]}else{e=0}x[c>>2]=f;g=(g<<5)+f|0;x[c+8>>2]=g;x[c+4>>2]=g;j=hc(c),k=(e<<5)+f|0,x[j>>2]=k;hb=d+16|0;d=x[c+8>>2];x[114409]=0;T(1458,i|0,d|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+32;x[114409]=0;P(1459,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}ZM(c);hb=h+32|0;break b}a=N()|0;ZM(c);Q(a|0);p()}}function Cca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;zd(b,4);w[b+30>>1]=y[a+12|0]<<2;dg(b+30|0,256);c=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=c;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=a+4|0;e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=e;c=a+8|0;x[b+8>>2]=e+(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));a=a+14|0;if(y[a|0]&16){x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}if(y[a|0]&32){x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}a:{if(!(y[a|0]&3)|A[b+8>>2]<=A[b+4>>2]){break a}w[b+34>>1]=z[b+34>>1]|2;if(!(y[a|0]&2)){break a}w[b+34>>1]=z[b+34>>1]|4}a=Vb(d+4|0,17381);x[114409]=0;O(350,b+43|0,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){xb(a);hb=d+16|0;return}b=N()|0;xb(a);Q(b|0);p()}function kY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;rl(a);yb(a);e=Bb(g+8|0,x[a+4>>2]);c=Bb(g+4|0,x[a>>2]);f=x[Bb(g,x[b+4>>2])>>2];h=hb-16|0;hb=h;d=hb-32|0;hb=d;Ae(d+24|0,x[e>>2],x[c>>2]);e=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=e;x[c+4>>2]=f;if(qc(c+12|0,c+8|0)){while(1){j=c+12|0;e=Pm(j);k=c+4|0;f=Pm(k);i=z[e+10>>1]|z[e+12>>1]<<16;l=z[e+6>>1]|z[e+8>>1]<<16;w[f+6>>1]=l;w[f+8>>1]=l>>>16;w[f+10>>1]=i;w[f+12>>1]=i>>>16;i=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=i;ql(j);ql(k);if(qc(j,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(h+8|0,d+12|0,d+8|0);hb=d+32|0;hb=h+16|0;x[g+12>>2]=x[h+12>>2];x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Xo(a,qd(a));hb=g+16|0}function $ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;c=Fk(a);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((ng(a)|0)!=(c|0)){break b}c=hb-16|0;hb=c;d=bc(a);f=dc(a);di(c+10|0);a=hb-16|0;hb=a;x[a+8>>2]=f;x[a+12>>2]=d;f=bt(a+8|0,a+12|0);h=hb-16|0;hb=h;x[h+12>>2]=d;if((f|0)>0){while(1){i=h+12|0;d=x[i>>2];e=y[c+10|0]|y[c+11|0]<<8|(y[c+12|0]<<16|y[c+13|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;e=y[c+14|0]|y[c+15|0]<<8;v[d+4|0]=e;v[d+5|0]=e>>>8;d=f>>>0>1;Sj(i);f=f-1|0;if(d){continue}break}}hb=h+16|0;hb=a+16|0;hb=c+16|0;break a}d=g+14|0;di(d);c=vT(g+20|0,c,d);sL(a);$l(a,c);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];d=x[yb(c)>>2];j=yb(a),k=d,x[j>>2]=k;j=yb(c),k=0,x[j>>2]=k;x[c>>2]=0;x[c+4>>2]=0;hm(c);x[a+12>>2]=b}hb=g+32|0;return(b|0)!=0|0}function GV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c;c=0;if(ag(a,e+11|0)){x[e+4>>2]=y[e+11|0];g=x[Mb(e+4|0,e+12|0)>>2];c=hb+-64|0;hb=c;d=c+44|0;uf(d,a,g);a=x[d>>2];x[114409]=0;d=S(445,d|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;d=S(446,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,c+20|0,3,d|0,a|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;P(370,c+32|0,c+20|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;P(449,c+12|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;O(450,c+12|0,c+32|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(c+32|0);Jc(c+44|0);hb=c- -64|0;c=!g|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(c+32|0)}Jc(c+44|0);Q(a|0);p()}}hb=e+16|0;return c|0}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;ri(a);g=yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);d=Bb(e,x[b+4>>2]);h=x[c>>2];d=x[d>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[f>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];f=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=f;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(1337,c+60|0,c+56|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!d){break a}d=SN(c+52|0);f=ek(c+60|0);x[114409]=0;T(1333,g|0,d|0,f|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Kh(c+60|0);Kh(c+52|0);continue}break}a=N()|0;RN(c+32|0);Q(a|0);p()}g=c+32|0;Nd(g);d=x[c+52>>2];RN(g);hb=c- -64|0;x[e+12>>2]=d;x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wm(a,Ac(a));hb=e+16|0}function kN(a,b,c){var d=0,e=0;a:{if(x[a+480180>>2]==4){d=y[b+833|0];if(c){v[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(y[a+480208|0]&16)){break c}d=x[b+700>>2];if(x[a+480180>>2]==4){break c}c=Py(a,c&15);e=sqa(c,c>>31,d,d>>31);c=lb;e=e+32768|0;c=e>>>0<32768?c+1|0:c;c=Ec(tqa(e,c,65536,0),lb);x[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074312|0;if(!(!$b(a,7)|x[b+700>>2]==2147483647)){x[b+700>>2]=x[b+700>>2]+1;return}if($b(a,7)){break b}a=x[b+700>>2];if((a|0)<2){break b}x[b+700>>2]=a-1;return}c=d-((c&255)<<2)|0;x[b+700>>2]=c;if((c|0)>0){break b}x[b+700>>2]=1;if(x[a+480180>>2]!=2){break b}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}}function U3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;rl(a);g=yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);d=Bb(e,x[b+4>>2]);h=x[c>>2];d=x[d>>2];c=hb+-64|0;hb=c;x[c+56>>2]=x[f>>2];x[c+60>>2]=h;x[c+52>>2]=d;x[c+48>>2]=d;d=Oc(c+20|0,g,c+48|0,c+52|0);x[c+16>>2]=x[d+8>>2];f=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=f;Od(c+32|0,c+8|0);a:{while(1){b:{x[114409]=0;d=O(2333,c+60|0,c+56|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!d){break a}d=DI(c+52|0);f=Pm(c+60|0);x[114409]=0;T(2250,g|0,d|0,f|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}ql(c+60|0);ql(c+52|0);continue}break}a=N()|0;BI(c+32|0);Q(a|0);p()}g=c+32|0;Nd(g);d=x[c+52>>2];BI(g);hb=c- -64|0;x[e+12>>2]=d;x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Xo(a,qd(a));hb=e+16|0}function TK(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{if(Lb(a)>>>0>511){break a}if(!Nf(x[x[b>>2]-12>>2]+b|0)){break a}g=hb-16|0;hb=g;f=Re(64);x[114409]=0;h=S(1523,f|0)|0;e=x[114409];x[114409]=0;b:{c:{if((e|0)!=1){f=Fy(g+8|0,h);e=x[f>>2];x[114409]=0;h=U(1750,e|0,b|0,c|0)|0;e=x[114409];x[114409]=0;d:{e:{if((e|0)!=1){if((h|0)==1){break e}Ey(g+12|0);break d}a=N()|0;Xf(f);break c}yq(g+12|0,f)}Xf(f);hb=g+16|0;e=x[g+12>>2];break b}a=N()|0;_b(f)}Q(a|0);p()}x[d+12>>2]=e;f:{g:{if(!yd(d+12|0)){x[114409]=0;c=O(1748,b|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break g}x[d+8>>2]=c;b=d+8|0;jT(d+12|0,oe(b));Xf(b)}e=0;if(!yd(d+12|0)){break f}b=d+12|0;e=x[b>>2];x[114409]=0;P(1749,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)!=1){break f}}a=N()|0;Xf(d+12|0);Q(a|0);p()}Xf(d+12|0)}hb=d+16|0;return e}function me(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(y[460996]){return x[115248]}c=hb-32|0;hb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=aG(a,d?9986:17381)}else{d=x[a<<2>>2]}x[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!$F(0)){b=61672;if(!dd(c+8|0,61672,24)){break a}b=61696;if(!dd(c+8|0,61696,24)){break a}a=0;if(!y[460824]){while(1){f=(a<<2)+460776|0,g=aG(a,17381),x[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}v[460824]=1;x[115200]=x[115194]}b=460776;if(!dd(c+8|0,460776,24)){break a}b=460800;if(!dd(c+8|0,460800,24)){break a}b=xd(24);if(!b){break b}}a=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+16>>2]=x[c+24>>2];x[b+20>>2]=a;a=x[c+20>>2];x[b+8>>2]=x[c+16>>2];x[b+12>>2]=a;break a}b=0}hb=c+32|0;v[460996]=1;x[115248]=b;return b|0}function W5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=cl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(2256,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}h=hb-32|0;hb=h;i=yb(a);f=bl(a,vd(a)+1|0);g=vd(a);d=hb-16|0;hb=d;x[d+12>>2]=0;c=h+12|0;We(c+12|0,i);if(f){_M(d+4|0,x[c+16>>2],f);e=x[d+4>>2];f=x[d+8>>2]}else{f=0}x[c>>2]=e;g=D(g,24)+e|0;x[c+8>>2]=g;x[c+4>>2]=g;j=hc(c),k=D(f,24)+e|0,x[j>>2]=k;hb=d+16|0;d=x[c+8>>2];x[114409]=0;T(2256,i|0,d|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114409]=0;P(2257,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}zI(c);hb=h+32|0;break b}a=N()|0;zI(c);Q(a|0);p()}}function Is(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-176|0;hb=d;e=qh(d+40|0);f=x[x[e>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}x[114409]=0;T(126,d+36|0,e+f|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}Ob(d+36|0);x[114409]=0;P(145,e|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}x[114409]=0;P(136,e|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;P(128,d+12|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;T(143,d+24|0,d+12|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;T(144,a|0,d+24|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}xb(d+24|0);xb(d+12|0);ae(e);hb=d+176|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;xb(d+24|0)}xb(d+12|0)}ae(e);Q(c|0);p()}function Ci(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;d=a+24|0;g=x[x[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|x[x[d>>2]+24624>>2]!=(c|0))){if(y[a+29|0]){break a}mM(x[d>>2],1);break a}e=f+8|0;sc(e,x[d>>2]+24604|0,40);h=x[e+32>>2];i=x[e+36>>2];x[f+28>>2]=c;x[f+24>>2]=b;Sl(e,h);Kn(e,i);Ay(x[d>>2],e);if((b|0)==(g|0)){break a}b=x[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=x[c>>2];b:{if(!b){break b}if(!(mb[x[x[b>>2]+112>>2]](b)|0)){break b}mb[x[x[b>>2]+104>>2]](b,0);mb[x[x[b>>2]+92>>2]](b);mb[x[x[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=x[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=x[c>>2];c:{if(!b){break c}if(mb[x[x[b>>2]+112>>2]](b)|0){break c}mb[x[x[b>>2]+104>>2]](b,1);mb[x[x[b>>2]+116>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}v[a+29|0]=1;hb=f+48|0}function $fa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;b=C[a+8>>3];d=hb-32|0;hb=d;o(+C[a>>3]);a=j(1)|0;i=j(0)|0;o(+b);c=j(1)|0;f=j(0)|0;h=c&2147483647;c=a&2147483647;e=(h|0)==(c|0)&f>>>0>i>>>0|c>>>0<h>>>0;a=e?i:f;e=e?c:h;m=e;l(0,a|0);l(1,e|0);b=+n();e=e>>>20|0;a:{if((e|0)==2047){break a}p=f;f=(c|0)==(h|0)&f>>>0<i>>>0|c>>>0>h>>>0;l(0,(f?i:p)|0);c=f?c:h;l(1,c|0);g=+n();b:{if(!(a|m)){break b}a=c>>>20|0;if((a|0)==2047){break b}if((a-e|0)>=65){b=g+b;break a}c:{if(a>>>0>=1534){b=b*190109156629516e-225;g=g*190109156629516e-225;k=5.260135901548374e210;break c}k=1;if(e>>>0>572){break c}b=b*5.260135901548374e210;g=g*5.260135901548374e210;k=190109156629516e-225}oH(d+24|0,d+16|0,g);oH(d+8|0,d,b);b=k*M(C[d>>3]+C[d+16>>3]+C[d+8>>3]+C[d+24>>3]);break a}b=g}hb=d+32|0;return+b}function tr(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a=gd(a);a:{b:{c:{switch(b|0){case 0:x[114409]=0;b=O(2,d+4|0,11851)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}Eb(a,b);xb(b);break b;case 1:x[114409]=0;b=O(2,d+4|0,11876)|0;c=x[114409];x[114409]=0;if((c|0)!=1){Eb(a,b);xb(b);break b}break a;case 2:x[114409]=0;b=O(2,d+4|0,11824)|0;c=x[114409];x[114409]=0;if((c|0)!=1){Eb(a,b);xb(b);break b}break a;case 3:x[114409]=0;b=O(2,d+4|0,11798)|0;c=x[114409];x[114409]=0;if((c|0)!=1){Eb(a,b);xb(b);break b}break a;case 4:x[114409]=0;b=O(2,d+4|0,8842)|0;c=x[114409];x[114409]=0;if((c|0)!=1){Eb(a,b);xb(b);break b}break a;case 5:break c;default:break b}}x[114409]=0;b=O(2,d+4|0,3460)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}Eb(a,b);xb(b)}hb=d+16|0;return}b=N()|0;xb(a);Q(b|0);p()}function _c(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=Fw(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function ux(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+48>>2]=x[d+20>>2];f=x[d+16>>2];x[c+40>>2]=x[d+12>>2];x[c+44>>2]=f;qn(c+68|0,c+40|0,e);d=Oc(c+56|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+32>>2]=x[c+76>>2];a=x[c+72>>2];x[c+24>>2]=x[c+68>>2];x[c+28>>2]=a;x[c+16>>2]=x[d+8>>2];a=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=a;if(e){i=c+24|0;j=c+8|0;k=b+4|0;while(1){a=0;if(f){while(1){h=C[ph(j,a,g)>>3];fc(b,a);h=Td(Gg(+(Kj(Td(h*134217728))-1024+((Bs(k)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(F(h)<2147483648){d=~~h;break a}d=-2147483648}d=Wc(d);l=pn(i,a,g),m=d,w[l>>1]=m;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-32|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];l=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){g=h>>12;b=i>>12;break a}while(1){b=x[e+24>>2];m=b>>>18|0;j=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){k=g<<1;f=w[k+j>>1];x[(e+8|0)+(g<<2)>>2]=f+((D(w[(k|4)+j>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}f=x[a+32>>2];i=x[a+28>>2]+i|0;b=i>>12;x[c>>2]=x[c>>2]+D(b,x[e+8>>2]);h=f+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(g,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];j=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+40>>2]=h;x[a+20>>2]=b;x[a+36>>2]=i;x[a+24>>2]=g;hb=e+32|0}function Hv(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;x[e+44>>2]=d;a:{f=x[b>>2];b:{if(!(mb[x[x[f>>2]+40>>2]](f,c,d)|0)){ii(a);break b}nl(e+28|0,b);x[114409]=0;b=S(244,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[x[b>>2]+24>>2];x[114409]=0;b=S(d|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;x[e+24>>2]=b-c;b=O(36,e+44|0,e+24|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}g=x[b>>2];b=x[e+32>>2];x[e+16>>2]=x[e+28>>2];x[e+20>>2]=b;b=hb-16|0;hb=b;d=e+16|0;f=nl(b+8|0,d);x[114409]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;W(258,e+36|0,b|0,c|0,g|0);c=x[114409];x[114409]=0;c:{if((c|0)!=1){Ab(d);hb=b+16|0;break c}a=N()|0;Ab(d);Q(a|0);p()}b=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=b;_C(a,e+8|0,0)}hb=e+48|0;return}a=N()|0;Ab(e+28|0);Q(a|0);p()}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=hb-48|0;hb=c;Ef(a,c+46|0);a:{b:{c:{d:{e:{f:{g:{e=x[19555];if(z[c+46>>1]>z[e+12>>1]){f=x[b+12>>2];d=c+8|0;lB(d,12606);x[114409]=0;W(1235,c+20|0,d|0,c+46|0,e+12|0);d=x[114409];x[114409]=0;if((d|0)==1){break g}x[114409]=0;d=O(658,c+32|0,c+20|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break f}x[114409]=0;P(634,f|0,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}xb(d);xb(c+20|0);Gb(c+8|0);w[c+46>>1]=z[e+12>>1]}Og(Ti(b,0),z[c+46>>1]);b=Ti(b,0);h=c,i=bc(b),x[h+8>>2]=i;h=c,i=dc(b),x[h+4>>2]=i;if(Hb(c+8|0,c+4|0)){break b}break a}b=N()|0;break c}b=N()|0;break d}b=N()|0;xb(d)}xb(c+20|0)}Gb(c+8|0);Q(b|0);p()}while(1){b=c+8|0;d=x[b>>2];Ef(a,c+2|0);w[d>>1]=z[c+2>>1];ke(b);if(Hb(b,c+4|0)){continue}break}}hb=c+48|0}function pk(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;v[k+15|0]=a;a:{b:{c:{if(x[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=y[j+24|0]){l=45;if(y[j+25|0]!=(m|0)){break c}}x[d>>2]=c+1;v[c|0]=l;break b}if(!(!Cb(g)|(a|0)!=(f|0))){a=0;b=x[i>>2];if((b-h|0)>159){break a}a=x[e>>2];x[i>>2]=b+4;x[b>>2]=a;break b}a=-1;f=Ll(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=x[d>>2];if((b|0)==(c|0)|(b-c|0)>2|y[b-1|0]!=48){break a}a=0;x[e>>2]=0;x[d>>2]=b+1;v[b|0]=y[f+64896|0];break a}a=x[d>>2];x[d>>2]=a+1;v[a|0]=y[f+64896|0];x[e>>2]=x[e>>2]+1;a=0;break a}a=0;x[e>>2]=0}hb=k+16|0;return a|0}function nk(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=hb-16|0;hb=k;x[k+12>>2]=a;a:{b:{c:{if(x[d>>2]!=(c|0)){break c}l=43;if(x[j+96>>2]!=(a|0)){l=45;if(x[j+100>>2]!=(a|0)){break c}}x[d>>2]=c+1;v[c|0]=l;break b}if(!(!Cb(g)|(a|0)!=(f|0))){a=0;b=x[i>>2];if((b-h|0)>159){break a}a=x[e>>2];x[i>>2]=b+4;x[b>>2]=a;break b}a=-1;g=ow(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=x[d>>2];if((b|0)==(c|0)|(b-c|0)>2|y[b-1|0]!=48){break a}a=0;x[e>>2]=0;x[d>>2]=b+1;v[b|0]=y[f+64896|0];break a}a=x[d>>2];x[d>>2]=a+1;v[a|0]=y[f+64896|0];x[e>>2]=x[e>>2]+1;a=0;break a}a=0;x[e>>2]=0}hb=k+16|0;return a|0}function jN(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if(!x[b+700>>2]){break a}c=x[a+480180>>2]==64?D(c,-20):c;b:{if(!(!(y[a+480208|0]&16)|x[a+480180>>2]==4)){g=x[b+700>>2];d=c>>31;x[f+12>>2]=(d^c)-d>>>2;zc(f+12|0,255);d=x[f+12>>2];c:{if(!d){break c}e=x[b+700>>2];h=e>>31;d:{if((c|0)<0){d=Py(a,d);break d}d=Oy(a,d)}e=sqa(e,h,d,d>>31);d=lb;e=e+32768|0;d=e>>>0<32768?d+1|0:d;d=Ec(tqa(e,d,65536,0),lb);x[b+700>>2]=d;if((d|0)!=(g|0)){break c}g=$b(a+1074312|0,7);d=x[b+700>>2];e:{if((g|0)==(c>>>31|0)){if((d|0)==2147483647){break c}c=x[b+700>>2]+1|0;break e}if((d|0)<2){break c}c=d-1|0}x[b+700>>2]=c}c=x[b+700>>2];break b}c=c+x[b+700>>2]|0;x[b+700>>2]=c}if((c|0)>0){break a}x[b+700>>2]=1;if(x[a+480180>>2]!=2){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}hb=f+16|0}function Ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);v[e+15|0]=y[a+4|0];v[e+14|0]=64;f=b,g=y[tc(e+15|0,e+14|0)|0]<<2,w[f+30>>1]=g;c=a+6|0;d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);a=a+10|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);d=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);a=d+(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))|0;x[b+8>>2]=a;d=x[b+4>>2];c=x[b>>2];if(d>>>0>=c>>>0){d=c-1|0;x[b+4>>2]=d}if(a>>>0>c>>>0){x[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}x[b+68>>2]=d;w[b+34>>1]=z[b+34>>1]|2}hb=e+16|0}function np(a){var b=E(0),c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Sh(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Sh(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Rh(f+1.5707963267948966);break a}b=Rh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Sh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Rh(-4.71238898038469-+a);break a}b=Rh(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch($w(a,c+8|0)&3){case 0:b=Sh(C[c+8>>3]);break a;case 1:b=Rh(-C[c+8>>3]);break a;case 2:b=E(-Sh(C[c+8>>3]));break a;default:break b}}b=Rh(C[c+8>>3])}a=b;hb=c+16|0;return a}function LI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-176|0;hb=d;e=qh(d+40|0);f=x[x[e>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}x[114409]=0;T(126,d+36|0,e+f|0,g|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}Ob(d+36|0);x[114409]=0;P(150,e|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break e}x[114409]=0;P(133,e|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;P(128,d+12|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;T(143,d+24|0,d+12|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}x[114409]=0;T(144,a|0,d+24|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}xb(d+24|0);xb(d+12|0);ae(e);hb=d+176|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;xb(d+24|0)}xb(d+12|0)}ae(e);Q(c|0);p()}function v9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;g=hb-16|0;hb=g;j=a+44|0;if(Eh(j)){r=g,s=Qd(j,0),x[r+8>>2]=s;r=g,s=Qd(j,1),x[r+12>>2]=s;r=g,s=ld(j,0),x[r>>2]=s;r=g,s=ld(j,1),x[r+4>>2]=s;if(d){p=y[a+4273|0];q=y[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=x[f>>2];x[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=E(E(B[a+4236>>2]*B[m>>2])+E(B[a+4240>>2]*B[e>>2]));B[m>>2]=i;i=E(B[a+4260>>2]*XJ(E(i*E(1073741824)),q,p));e=f+4244|0;n=B[a+4264>>2];f=f+4252|0;o=B[f>>2];i=E(i-E(E(B[a+4268>>2]*B[e>>2])+E(n*o)));B[f>>2]=i;B[e>>2]=o+E(i*n);e=g+h|0;h=x[e>>2];x[e>>2]=h+4;B[h>>2]=i*E(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}Gi(a,b,c,ld(j,0),ld(j,1),d)}hb=g+16|0}function mea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=E(0),h=0,i=E(0),j=E(0),k=0,m=0;f=hb-16|0;hb=f;k=f,m=D(x[a>>2],Qe(a)),x[k+12>>2]=m;zc(f+12|0,c>>>2|0);c=Db(b);g=B[e+4>>2];e=x[f+12>>2];if(e){while(1){h=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);i=E(F((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r())));g=g<i?i:g;c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==E(0);a:{if(c){break a}e=x[f+12>>2];if(!e){break a}i=c?E(1):E(E(1)/g);c=x[a+20>>2];while(1){a=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);j=he(E(rf(E((l(2,a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)),r())*i),E(-1))*E(32768)));b:{if(E(F(j))<E(2147483648)){a=~~j;break b}a=-2147483648}k=c,m=Wc(a),w[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){B[d>>2]=g}hb=f+16|0;return x[f+12>>2]<<2}function _ma(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;if((d-1&255)>>>0<=5){v[g+14|0]=d+15}JS(g+15|0,g+13|0);JS(g+14|0,g+12|0);a:{if(y[g+15|0]==10){v[g+13|0]=y[g+13|0]&15?-1:y[g+12|0];if(y[g+14|0]!=10){break a}v[g+14|0]=0;break a}if(y[g+14|0]!=10){break a}v[g+12|0]=y[g+12|0]&15?-1:0}if(b){v[a+2|0]=1;v[a+4|0]=b+2>>>2}jy(g+15|0,g+13|0,g+14|0,g+12|0);c=y[g+15|0];b:{if(!c){break b}d=y[g+14|0];if(!d){v[g+14|0]=c;v[g+12|0]=y[g+13|0];break b}if((c|0)==(d|0)&(c|0)!=20){break b}if(!b){iy(g+10|0,g+15|0,g+13|0,g+14|0,g+12|0);v[a+2|0]=y[g+15|0];v[a+4|0]=y[g+13|0];break b}if(Bn(c)>>>0<=Bn(y[g+14|0])>>>0){break b}zh(g+15|0,g+14|0);zh(g+13|0,g+12|0)}v[a+3|0]=y[g+14|0];v[a+5|0]=y[g+12|0];hb=g+16|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-32|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){g=h>>12;b=i>>12;break a}while(1){b=x[e+24>>2];l=b>>>10&4194048;j=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+k|0;g=0;b=1;while(1){f=v[g+j|0];x[(e+8|0)+(g<<2)>>2]=((D(v[(g|2)+j|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=x[a+32>>2];i=x[a+28>>2]+i|0;b=i>>12;x[c>>2]=x[c>>2]+D(b,x[e+8>>2]);h=f+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(g,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];j=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+40>>2]=h;x[a+20>>2]=b;x[a+36>>2]=i;x[a+24>>2]=g;hb=e+32|0}function kea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0;f=hb-16|0;hb=f;k=f,m=D(x[a>>2],Qe(a)),x[k+12>>2]=m;zc(f+12|0,c>>>3|0);c=Db(b);g=C[e+8>>3];e=x[f+12>>2];if(e){while(1){i=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l(1,i|0);h=F(+n());g=g<h?h:g;c=c+8|0;e=e-1|0;if(e){continue}break}}c=g==0;a:{if(c){break a}e=x[f+12>>2];if(!e){break a}h=c?1:1/g;c=x[a+20>>2];while(1){a=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);i=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);l(0,i|0);l(1,a|0);j=Td(Gg(+n()*h)*32768);b:{if(F(j)<2147483648){a=~~j;break b}a=-2147483648}k=c,m=Wc(a),w[k>>1]=m;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){C[d>>3]=g}hb=f+16|0;return x[f+12>>2]<<3}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;d=yb(c);x[114409]=0;U(1704,b+8|0,a+12|0,d|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];d=x[yb(c)>>2];g=yb(b),h=d,x[g>>2]=h;g=yb(c),h=0,x[g>>2]=h;x[c>>2]=0;x[c+4>>2]=0;hb=a+16|0;break a}R(0)|0;zb();p()}x[b+20>>2]=x[c+20>>2];a=x[c+16>>2];x[b+12>>2]=x[c+12>>2];x[b+16>>2]=a;f=hb-16|0;hb=f;d=b+24|0;x[d>>2]=0;x[d+4>>2]=0;x[f+12>>2]=0;a=c+24|0;e=yb(a);x[114409]=0;U(1705,d+8|0,f+12|0,e|0)|0;e=x[114409];x[114409]=0;b:{if((e|0)!=1){x[d>>2]=x[a>>2];x[d+4>>2]=x[a+4>>2];e=x[yb(a)>>2];g=yb(d),h=e,x[g>>2]=h;g=yb(a),h=0,x[g>>2]=h;x[a>>2]=0;x[a+4>>2]=0;hb=f+16|0;break b}R(0)|0;zb();p()}Jd(b+36|0,c+36|0);x[b+48>>2]=x[c+48>>2]}function yx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Th(c- -64|0,c+32|0,f);d=Oc(c+52|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){h=c+16|0;i=b+4|0;while(1){a=0;if(e){while(1){d=x[Vf(c,a,g)>>2];fc(b,a);d=(d+((Bs(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0<=491520?491520:d;j=rn(h,a,g),k=(d|0)>=557055?557055:d,w[j>>1]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function dH(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Rh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Sh(d+1.5707963267948966));break a}a=Sh(d+-1.5707963267948966);break a}a=Rh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Sh(d+4.71238898038469);break a}a=E(-Sh(d+-4.71238898038469));break a}a=Rh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch($w(a,b+8|0)&3){case 0:a=Rh(C[b+8>>3]);break a;case 1:a=Sh(C[b+8>>3]);break a;case 2:a=Rh(-C[b+8>>3]);break a;default:break b}}a=E(-Sh(C[b+8>>3]))}hb=b+16|0;return a}function XF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-1040|0;hb=f;g=x[b>>2];x[f+12>>2]=g;j=a?a:f+16|0;d=a?d:256;a:{b:{c:{if(!g|!d){break c}while(1){h=c>>>2|0;if(h>>>0<d>>>0&c>>>0<=131){break b}h=ww(j,f+12|0,d>>>0>h>>>0?h:d,e);if((h|0)==-1){i=-1;d=0;g=x[f+12>>2];break c}k=(f+16|0)!=(j|0)?h:0;d=d-k|0;j=(k<<2)+j|0;c=c+g|0;g=x[f+12>>2];c=g?c-g|0:0;i=h+i|0;if(!g){break c}if(d){continue}break}}if(!g){break a}}if(!d|!c){break a}h=i;while(1){d:{i=jp(j,g,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:x[f+12>>2]=0;break e;case 0:break a;default:break f}}x[e>>2]=0;break e}g=x[f+12>>2]+i|0;x[f+12>>2]=g;h=h+1|0;d=d-1|0;if(d){break d}}i=h;break a}j=j+4|0;c=c-i|0;i=h;if(c){continue}break}}if(a){x[b>>2]=x[f+12>>2]}hb=f+1040|0;return i|0}function Sz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-80|0;hb=d;a:{b:{e=x[a+4>>2];if(e>>>0<b>>>0){h=Po(d+72|0);f=b-e|0;b=$t(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){b=d+60|0;lq(b,a);Dd(h,b);x[a+4>>2]=x[a+4>>2]+f;break b}Rz(a);b=Qz(d+60|0);e=x[a+4>>2];x[114409]=0;e=O(958,a|0,e+f|0)|0;g=x[114409];x[114409]=0;c:{if((g|0)==1){break c}x[114409]=0;P(959,b|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[b+4>>2]=x[a+4>>2]+f;cm(d+44|0,a);lq(d+36|0,a);e=d+28|0;cm(e,b);x[114409]=0;g=x[d+48>>2];x[d+8>>2]=x[d+44>>2];x[d+12>>2]=g;g=x[d+40>>2];x[d>>2]=x[d+36>>2];x[d+4>>2]=g;W(960,d+52|0,d+8|0,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}Dd(h,d+52|0);Oz(a,b);ge(b);break b}a=N()|0;ge(b);Q(a|0);p()}x[a+4>>2]=b;break a}Tq(Dd(d+20|0,h),f,c)}hb=d+80|0}function OH(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);b=B[a+32>>2];c=B[a+8>>2];e=B[a+16>>2];f=E(E(b-c)+e);i=B[a>>2];j=B[a+24>>2];k=E(i-j);B[a+16>>2]=f+k;d=B[a+4>>2];g=B[a+20>>2];h=B[a+28>>2];l=E(E(d-E(g+h))*E(.8660253882408142));k=E(k-E(f*E(.5)));B[a+4>>2]=l+k;m=E(E(g+d)*E(.9848077297210693));f=E(B[a+12>>2]*E(.8660253882408142));n=E(E(h+d)*E(-.6427876353263855));o=E(E(m-f)+n);d=E(i+E(j*E(.5)));i=E(E(b+c)*E(.7660444378852844));b=E(E(e-b)*E(.1736481785774231));j=E(E(d-i)+b);B[a+12>>2]=o+j;B[a+20>>2]=j-o;B[a+28>>2]=k-l;g=E(E(g-h)*E(.3420201539993286));h=E(g-E(f+m));c=E(E(e+c)*E(.9396926164627075));b=E(E(d+c)-b);B[a+32>>2]=h+b;e=E(E(g+f)+n);c=E(E(d-c)+i);B[a+24>>2]=e+c;B[a+8>>2]=c-e;B[a>>2]=b-h}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;i=Xb(a);c=Xb(e+20|0);a:{b:{c:{d:{g=b+24|0;if(!z[x[g>>2]+480190>>1]){break d}a=0;f=1;while(1){b=x[g>>2];x[114409]=0;b=O(2308,b|0,f&65535)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;b=O(122,e+8|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}d=Yc(b);x[114409]=0;O(1328,c|0,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}x[114409]=0;O(2119,c|0,17358)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}a=d^1|a;xb(b);f=f+1|0;if(z[x[g>>2]+480190>>1]>=(f&65535)>>>0){continue}break}if(!(a&1)){break d}x[114409]=0;O(420,i|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break d}a=N()|0;break a}xb(c);hb=e+32|0;return}a=N()|0;break a}a=N()|0;xb(b)}xb(c);xb(i);Q(a|0);p()}function $4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;i=Xb(a);c=Xb(e+20|0);a:{b:{c:{d:{g=b+24|0;if(!z[x[g>>2]+480192>>1]){break d}a=0;f=1;while(1){b=x[g>>2];x[114409]=0;b=O(2307,b|0,f&65535)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;b=O(122,e+8|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break c}d=Yc(b);x[114409]=0;O(1328,c|0,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}x[114409]=0;O(2119,c|0,17358)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}a=d^1|a;xb(b);f=f+1|0;if(z[x[g>>2]+480192>>1]>=(f&65535)>>>0){continue}break}if(!(a&1)){break d}x[114409]=0;O(420,i|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break d}a=N()|0;break a}xb(c);hb=e+32|0;return}a=N()|0;break a}a=N()|0;xb(b)}xb(c);xb(i);Q(a|0);p()}function sv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;g=a+1|0;d=f+15|0;Qg(b,y[tc(g,d)|0]);e=y[tc(a+2|0,d)|0];v[b+13|0]=e;j=b,k=Md(y[a+3|0],e,y[f+15|0]),v[j+14|0]=k;d=y[tc(a+4|0,d)|0];v[b+15|0]=d;j=b,k=Md(y[a+5|0],d,y[f+15|0]),v[j+16|0]=k;v[f+14|0]=25;if(y[tc(f+14|0,g)|0]){d=0;while(1){e=D(d,3)+a|0;h=Yb(y[e+6|0]+c<<24>>24,0,64);j=Pb(b,d),k=h,v[j+2|0]=k;e=e+7|0;e=y[e|0]|y[e+1|0]<<8;j=Pb(b,d),k=e,w[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(z[Pb(b,d)>>1]>=z[Pb(b,e)>>1]){break a}if(z[Pb(b,d)>>1]>255){break a}h=y[Pb(b,e)+1|0];i=Pb(b,d);w[i>>1]=z[i>>1]|h<<8;if(z[Pb(b,d)>>1]>=z[Pb(b,e)>>1]){break a}e=Pb(b,d);w[e>>1]=z[e>>1]+256}v[f+14|0]=25;d=d+1|0;if(d>>>0<y[tc(f+14|0,g)|0]){continue}break}}hb=f+16|0}function Fn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;e=x[b+656>>2];if(!(!e|v[b+724|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}f=z[c+34>>1];if(f&2){x[b+88>>2]=(f&4?d|4:d&-135)|2;d=x[c>>2];x[b+76>>2]=d;f=x[c+4>>2];x[b+80>>2]=f;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<d>>>0){x[b+76>>2]=c;g=c}else{g=d}d=x[b+4>>2];if(g>>>0>=d>>>0){break b}x[b>>2]=0;x[b+4>>2]=((d-f>>>0)%(c-f>>>0)|0)+f;break b}x[b+88>>2]=d&-135;x[b+76>>2]=x[c>>2]}if(!e){break a}if(!(!(y[e+60|0]&2|x[a+480180>>2]&1064964)|!x[e>>2])){x[b+88>>2]=x[b+88>>2]|4096}if(y[e+65|0]==255|x[b+732>>2]!=-1){break a}a=e+48|0;h=b,i=gq(a,x[b+728>>2],256,64),x[h+732>>2]=i;h=b,i=z[Pb(a,y[e+65|0])>>1],x[h+728>>2]=i}}function Of(a){var b=0,c=0;b=x[a+4>>2];c=x[x[b>>2]-12>>2];x[114409]=0;b=x[(b+c|0)+24>>2];c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=x[a+4>>2];c=x[x[b>>2]-12>>2];x[114409]=0;b=Nf(b+c|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}if(!b){break b}b=x[a+4>>2];if(!(x[(x[x[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(TG()){break b}b=x[a+4>>2];c=x[x[b>>2]-12>>2];x[114409]=0;b=x[(b+c|0)+24>>2];c=x[114409];x[114409]=0;c:{if((c|0)==1){break c}x[114409]=0;b=S(2441,b|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+b|0,1);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;f=-1;a:{if(!fA(a,80)){break a}b:{c:{if(!Tk(a,60)){break c}if(!bQ(a,b+140|0)){break c}e=15;if(Wt(b+140|0,15)){break b}}if(!fA(a,144)){break a}f=0;if(!Tk(a,124)){break a}if(!bQ(a,b+140|0)){break a}e=31;if(!Wt(b+140|0,31)){break a}}x[a+12>>2]=0;f=0;while(1){c=0;d=hb-16|0;hb=d;if(_P(a,d+12|0)){c=d+12|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24)}hb=d+16|0;if(c>>>0>131072){break a}g=g+1|0;if((g|0)!=(e|0)){continue}break}f=-1;if(!ad(a,D(e,30)|20)){break a}e=hb-16|0;hb=e;d=e+8|0;c=b+10|0;oR(d,c);g=Fb(d);d=nd(a,ac(e,d));if((g|0)==(d|0)){ad(a,Fb(e+8|0))}hb=e+16|0;a=(d|0)==(g|0);if(!a){pR(c)}if(!a){break a}f=aQ(b+10|0)}hb=b+160|0;return f|0}function Pca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-80|0;hb=c;e=qO(a,1<<b-1);x[e+12>>2]=b;a=1<<b;g=a>>>2|0;a:{if(b>>>0>=2){h=1/+(a>>>0);b=g;a=1;while(1){x[114409]=0;C[c+40>>3]=+(b>>>0)*-6.283185307179586*h;T(1626,c+48|0,35024,c+40|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;P(1279,c- -64|0,c+48|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=wc(e,a);f=x[c+76>>2];x[d+8>>2]=x[c+72>>2];x[d+12>>2]=f;f=x[c+68>>2];x[d>>2]=x[c+64>>2];x[d+4>>2]=f;a=a<<1;d=b>>>0<2;b=b>>>1|0;if(!d){continue}break}}a=_l(c+24|0,1,0);x[114409]=0;b=x[a+12>>2];x[c+16>>2]=x[a+8>>2];x[c+20>>2]=b;b=x[a+4>>2];x[c+8>>2]=x[a>>2];x[c+12>>2]=b;W(1627,e|0,0,g|0,c+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}hb=c+80|0;return e|0}a=N()|0;_p(e);Q(a|0);p()}function rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;zd(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;d=a+40|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+44|0;x[c+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+48|0;x[c+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+52|0;x[c+24>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=b+151|0;if(y[d|0]<5){v[c+38|0]=y[y[d|0]+35850|0]}v[c+39|0]=y[b+152|0];d=b+156|0;v[c+41|0]=(y[d|0]|y[d+1|0]<<8)>>>4;b=b+154|0;b=(y[b|0]|y[b+1|0]<<8)>>>2|0;v[c+40|0]=b;if(y[c+41|0]|b&255){v[c+39|0]=y[c+39|0]^-1}a=a+38|0;if(y[a|0]&4){w[c+34>>1]=z[c+34>>1]|1}if(y[a|0]&8){w[c+34>>1]=z[c+34>>1]|2}if(y[a|0]&16){w[c+34>>1]=z[c+34>>1]|4}if(y[a|0]&32){w[c+34>>1]=z[c+34>>1]|32}}function S3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;og(a);yb(a);c=Bb(f+8|0,x[a+4>>2]);e=Bb(f+4|0,x[a>>2]);g=x[Bb(f,x[b+4>>2])>>2];h=hb-16|0;hb=h;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[e>>2]);e=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=e;x[c+4>>2]=g;if(qc(c+12|0,c+8|0)){while(1){i=c+12|0;e=cj(i);k=c+4|0;g=cj(k);x[g+16>>2]=x[e+16>>2];j=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=j;j=x[e+4>>2];x[g>>2]=x[e>>2];x[g+4>>2]=j;Jg(i);Jg(k);if(qc(i,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(h+8|0,d+12|0,d+8|0);hb=d+32|0;hb=h+16|0;x[f+12>>2]=x[h+12>>2];x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];al(a,vd(a));hb=f+16|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;g=a;if(d){while(1){a=x[e+24>>2];h=((((x[e+28>>2]&2147483647)<<1|a>>>31)&2147483646)<<1)+l|0;a=(a>>>21&2040)+32976|0;m=w[a+6>>1];n=w[a+4>>1];o=w[a+2>>1];f=w[a>>1];i=0;b=1;while(1){a=i<<1;x[(e+8|0)+(i<<2)>>2]=(((D(w[a+h>>1],o)+D(w[(a|-4)+h>>1],f)|0)+D(w[(a|4)+h>>1],n)|0)+D(w[(a|8)+h>>1],m)|0)/16384;a=b;b=0;i=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];f=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+32|0}function IJ(a){var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=cf(x[a+16>>2]);g=E(E(B[a+4220>>2]*E(.9980000257492065))+E(.0010000000474974513));d=-9965.784284662086/+E(E(E(B[a+4216>>2]*E(2999.9990234375))+E(.0010000000474974513))*E(c>>>0));m=a,n=E(oh(d*+A[a+4288>>2])),B[m+4232>>2]=n;m=a+4236|0,n=E(oh(d*+A[a+4292>>2])),B[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=x[(c<<2)+h>>2];e=c<<1&-4;f=oh(l*+(j+x[(e+h|0)+16>>2]>>>0));b=oh(d*+(j>>>0));g=B[e+i>>2];e=(c<<3)+i|0;f=f*.5;B[e+12>>2]=b*(.5-f);B[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=oh(+HJ(B[a+4208>>2])*.16609640474436813);b=oh(+HJ(B[a+4212>>2])*.33219280948873625);B[a+4228>>2]=d*4*M(b)/M(k);B[a+4224>>2]=d*M(1-b)}function zL(a){a=a|0;var b=0;a:{b:{c:{if(y[a+3|0]!=19){break c}v[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=y[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}v[a+3|0]=2;break a}v[a+3|0]=3;break a}v[a+5|0]=b&15|16;return}v[a+5|0]=b&3|48;return}v[a+5|0]=b&223^120;return}v[a+5|0]=b&15|176;return}v[a+5|0]=b&3|64;return}v[a+3|0]=15;v[a+5|0]=b&15;return}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;return}break b}if(b&15){v[a+3|0]=11;break a}break b}if((b|0)!=192){break c}v[a|0]=254;break b}if((b|0)!=208){break c}v[a+3|0]=0}return}v[a+3|0]=0;return}v[a+5|0]=b|240}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;zd(b,0);c=d+8|0;Bh(c,1,a);e=d+20|0;Kc(e,c);x[114409]=0;O(350,b+43|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){e=d+20|0;xb(e);c=a+48|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+52|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+56|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+62|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8;Lt(b,+((y[a+60|0]^8)-120|0)*.005208333333333333);v[d+20|0]=y[a+61|0];v[d+8|0]=64;f=b,g=y[tc(e,d+8|0)|0]<<2,w[f+30>>1]=g;w[b+34>>1]=0;a=a+47|0;if(y[a|0]&4){w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}if(y[a|0]&32){w[b+34>>1]=z[b+34>>1]|4}if(v[a|0]<0){w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0;return}a=N()|0;xb(d+20|0);Q(a|0);p()}function sS(a){var b=0,c=0,d=0;a:{if(dd(a,9970,3)){break a}b=a+3|0;if(y[b|0]<48|y[b|0]>51){break a}b=a+8|0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))>>>0<52){break a}b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);d=(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))>>>0<4294967216}return d}function su(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;Ge(a);yb(a);d=Bb(f+8|0,x[a+4>>2]);c=Bb(f+4|0,x[a>>2]);g=x[Bb(f,x[b+4>>2])>>2];h=hb-16|0;hb=h;e=hb-32|0;hb=e;Ae(e+24|0,x[d>>2],x[c>>2]);d=x[e+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[e+28>>2];x[c+12>>2]=d;x[c+4>>2]=g;if(qc(c+12|0,c+8|0)){while(1){i=c+12|0;d=Yg(i);j=c+4|0;g=Yg(j);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;hg(i);hg(j);if(qc(i,c+8|0)){continue}break}}Dc(e+16|0,c+12|0,c+4|0);hb=c+16|0;x[e+12>>2]=x[e+16>>2];x[e+8>>2]=x[e+20>>2];Dc(h+8|0,e+12|0,e+8|0);hb=e+32|0;hb=h+16|0;x[f+12>>2]=x[h+12>>2];x[b+4>>2]=x[f+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=f+16|0}function T8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a+4260>>2]=0;x[a>>2]=80416;c=a+4960|0;b=a+4504|0;d=b;while(1){d=Ck(d)+24|0;if((d|0)!=(c|0)){continue}break}v[a+5046|0]=1;w[a+5044>>1]=0;x[a+4208>>2]=1063675494;x[a+4212>>2]=1065185444;x[a+4256>>2]=1059760811;d=a+4248|0;x[d>>2]=1065353216;x[d+4>>2]=1048525618;d=a+4240|0;x[d>>2]=1038174126;x[d+4>>2]=1065353216;d=a+4232|0;x[d>>2]=1047457519;x[d+4>>2]=1062836634;d=a+4224|0;x[d>>2]=1053079357;x[d+4>>2]=1059859440;d=a+4216|0;x[d>>2]=0;x[d+4>>2]=1032805417;x[114409]=0;U(1760,a+44|0,2,2)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){x[114409]=0;V(1761,a|0);d=x[114409];x[114409]=0;if((d|0)!=1){break a}}d=N()|0;while(1){c=lg(c-24|0);if((b|0)!=(c|0)){continue}break}Cf(a);Q(d|0);p()}return a|0}function s8(){var a=0,b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;c=Xb(b+20|0);x[114409]=0;V(2118,b+8|0);a=x[114409];x[114409]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+8|0;d=b,e=bc(a),x[d+4>>2]=e;d=b,e=dc(a),x[d>>2]=e;if(!Hb(b+4|0,b)){break c}while(1){e:{a=x[b+4>>2];x[114409]=0;O(1328,c|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break e}a=b+4|0;dk(a);d=b,e=dc(b+8|0),x[d>>2]=e;if(!Hb(a,b)){break c}x[114409]=0;O(2119,c|0,10156)|0;a=x[114409];x[114409]=0;if((a|0)!=1){continue}}break}a=R(0)|0;pd(b+8|0);break d}a=R(0)|0}xb(c);Y(a|0)|0;a=0;x[114409]=0;W(2113,3291,0,0,0);c=x[114409];x[114409]=0;if((c|0)==1){break a}_();break b}a=Ld(Rb(c));pd(b+8|0);xb(c)}hb=b+32|0;return a|0}b=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(b|0);p()}R(0)|0;zb();p()}function Af(a,b){var c=0,d=0,e=0;d=hb-32|0;hb=d;a=_g(a,-1,-1);vj(d+31|0,b,1);a:{b:{if(y[d+31|0]){c=x[x[b>>2]-12>>2];x[114409]=0;c=x[(b+c|0)+24>>2];e=x[114409];x[114409]=0;c:{d:{if((e|0)==1){break d}x[114409]=0;Ka(2452,d+8|0,c|0,0,0,1,8);c=x[114409];x[114409]=0;if((c|0)==1){break d}c=x[d+12>>2];x[a>>2]=x[d+8>>2];x[a+4>>2]=c;c=x[d+20>>2];x[a+8>>2]=x[d+16>>2];x[a+12>>2]=c;a=0;break c}Y(R(0)|0)|0;uj(x[x[b>>2]-12>>2]+b|0,1);a=x[x[b>>2]-12>>2];x[114409]=0;a=x[(a+b|0)+20>>2];c=x[114409];x[114409]=0;e:{if((c|0)!=1){if(!(a&1)){break e}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break a}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}_();a=1}Mg(x[x[b>>2]-12>>2]+b|0,a)}hb=d+32|0;return}R(0)|0;zb()}p()}function Aoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;x[e+12>>2]=b;k=e,l=td(a),x[k>>2]=l;f=zm(e+12|0,e);a:{b=dj(c,d);b:{if(!b){k=e,l=td(a),x[k>>2]=l;a=Le(e,f);break b}if(!Kx(a,c)){i=hb-16|0;hb=i;g=Cb(a);h=Hc(a);c:{if(b>>>0<=h-g>>>0){h=Rb(a);if((f|0)==(g|0)){break c}j=f+h|0;kl(b+j|0,j,g-f|0);break c}dl(a,h,(b+g|0)-h|0,g,f,0,b);h=x[a>>2]}b=b+g|0;ch(a,b);v[i+15|0]=0;$d(b+h|0,i+15|0);if((c|0)!=(d|0)){b=f+h|0;while(1){$d(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=i,l=td(a),x[k+8>>2]=l;a=Le(i+8|0,f);hb=i+16|0;break b}c=Fi(e,c,d);d=td(c);g=nf(c);x[114409]=0;a=aa(620,a|0,b|0,f|0,d|0,g|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}xb(c)}hb=e+16|0;return a|0}a=N()|0;xb(c);Q(a|0);p()}function vk(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return sc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}v[d|0]=y[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;v[d|0]=y[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;x[c+a>>2]=x[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;v[c+a|0]=y[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){x[d>>2]=x[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function EE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;Ge(a);ul(a);h=Bb(e+8|0,x[a+4>>2]);d=Bb(e+4|0,x[a>>2]);c=Bb(e,x[b+4>>2]);i=x[d>>2];f=x[c>>2];g=hb-16|0;hb=g;l=g+8|0;d=hb-32|0;hb=d;c=hb-16|0;hb=c;x[c+12>>2]=x[h>>2];x[c+8>>2]=i;qr(d+24|0,c+12|0,c+8|0);hb=c+16|0;h=d+16|0;i=d+12|0;j=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=j;x[c+4>>2]=f;while(1){if(qc(c+12|0,c+8|0)){f=c+12|0;j=x[Yg(f)>>2];k=c+4|0;m=Yg(k),n=j,x[m>>2]=n;hg(f);hg(k);continue}break}Dc(h,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(l,i,d+8|0);hb=d+32|0;hb=g+16|0;x[e+12>>2]=x[g+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=e+16|0}function D4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;g=sh(a);f=b+24|0;a=z[x[f>>2]+480192>>1];x[114409]=0;P(1629,g|0,a|0);c=x[114409];x[114409]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(z[x[f>>2]+480192>>1]){while(1){c=x[f>>2];x[114409]=0;c=O(2307,c|0,a&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}x[114409]=0;c=O(122,d+8|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}x[114409]=0;T(2309,d+20|0,b|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(1631,g|0,d+20|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}xb(d+20|0);xb(c);a=a+1|0;if(z[x[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}hb=d+32|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;xb(d+20|0)}xb(c);break a}a=N()|0}pd(g);Q(a|0);p()}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;g=sh(a);f=b+24|0;a=z[x[f>>2]+480190>>1];x[114409]=0;P(1629,g|0,a|0);c=x[114409];x[114409]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(z[x[f>>2]+480190>>1]){while(1){c=x[f>>2];x[114409]=0;c=O(2308,c|0,a&65535)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}x[114409]=0;c=O(122,d+8|0,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break e}x[114409]=0;T(2309,d+20|0,b|0,c|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(1631,g|0,d+20|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}xb(d+20|0);xb(c);a=a+1|0;if(z[x[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}hb=d+32|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;xb(d+20|0)}xb(c);break a}a=N()|0}pd(g);Q(a|0);p()}function ZL(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Fp(a,E(1));Ep(a,E(3.725290298461914e-9));Dp(a,E(268435456));Cp(a,0);break b;case 1:Fp(a,E(32));Ep(a,E(4.656612873077393e-10));Dp(a,E(2147483648));Cp(a,0);break b;case 2:Fp(a,E(2));Ep(a,E(7.450580596923828e-9));Dp(a,E(134217728));Cp(a,1);break b;default:Fp(a,E(1));Ep(a,E(7.450580596923828e-9));Dp(a,E(134217728));Cp(a,1);uy(a,0);Sl(a,1);ty(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Fp(a,E(.75));Ep(a,E(7.450580596923828e-9));Dp(a,E(134217728));Cp(a,1);uy(a,0);b=(b|0)==4;Sl(a,b?2:3);ty(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}uy(a,1);Sl(a,0);ty(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function ZG(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:mb[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];g=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=g;h=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=h;h=a;if(d){while(1){a=x[e+24>>2];i=(((x[e+28>>2]&2147483647)<<1|a>>>31)&-2)+l|0;a=(a>>>21&2040)+32976|0;m=w[a+6>>1];n=w[a+4>>1];o=w[a+2>>1];g=w[a>>1];f=0;b=1;while(1){x[(e+8|0)+(f<<2)>>2]=(((D(v[f+i|0],o)+D(v[(f|-2)+i|0],g)|0)+D(v[(f|2)+i|0],n)|0)+D(v[(f|4)+i|0],m)<<8)/16384;a=b;b=0;f=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];g=x[e+28>>2]}x[h>>2]=b;x[h+4>>2]=g;hb=e+32|0}function gA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;if(v[a|0]&1){v[b+12|0]=y[b+12|0]|1}if(y[a|0]&2){v[b+12|0]=y[b+12|0]|4}if(y[a|0]&4){v[b+12|0]=y[b+12|0]|2}if(y[a|0]&16){v[b+12|0]=y[b+12|0]|16}if(y[a|0]&32){v[b+12|0]=y[b+12|0]|8}v[g+15|0]=y[a+1|0];v[g+14|0]=25;Qg(b,y[tc(g+15|0,g+14|0)|0]);e=a+2|0;v[b+15|0]=y[e|0];v[b+16|0]=y[((d|0)==4?e:a+3|0)|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];if(Lb(b)){d=0;while(1){e=(d<<2)+a|0;f=e+6|0;f=y[f|0]|y[f+1|0]<<8;h=Pb(b,d),i=f,w[h>>1]=i;a:{if(!d){break a}f=d-1|0;if(z[Pb(b,d)>>1]>=z[Pb(b,f)>>1]){break a}f=z[Pb(b,f)>>1];h=Pb(b,d),i=f+1|0,w[h>>1]=i}e=e+8|0;e=Yb((y[e|0]|y[e+1|0]<<8)<<16>>16>>c,0,64);h=Pb(b,d),i=e,v[h+2|0]=i;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}hb=g+16|0}function K2(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb+-64|0;hb=c;if(uH(0,c+40|0)){Cr(x[114232],8514);p()}e=Li(c+24|0,c+40|0);x[c+12>>2]=x[c+48>>2]/1e3;f=UG(c+16|0,c+12|0);b=hb-32|0;hb=b;d=hb-16|0;hb=d;g=hb-16|0;hb=g;a=hb-16|0;hb=a;i=a,j=sqa(x[e>>2],x[e+4>>2],1e6,0),x[i>>2]=j;x[a+4>>2]=lb;e=Li(a+8|0,a);h=x[e>>2];e=x[e+4>>2];hb=a+16|0;hb=g+16|0;a=d;x[a+8>>2]=h;x[a+12>>2]=e;d=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=d;hb=a+16|0;a=x[b+8>>2];e=x[b+12>>2];d=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=d;f=x[b>>2];d=a+f|0;a=x[b+4>>2]+e|0;x[b+16>>2]=d;x[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=Li(b+24|0,b+16|0);d=x[a>>2];a=x[a+4>>2];hb=b+32|0;x[c+32>>2]=d;x[c+36>>2]=a;b=Li(c+56|0,c+32|0);a=x[b>>2];hb=c- -64|0;lb=x[b+4>>2];return a|0}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Ac(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/12>>>0){e=hb-16|0;hb=e;d:{b=xl(e+4|0,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;P(1069,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}c=c+12|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=ok(d+12|0,an(a,Ac(a)+c|0),Ac(a),b);x[114409]=0;P(1063,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1064,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}KP(b)}hb=d+32|0;break a}a=N()|0;KP(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+D(b,12)|0;Ac(a);MP(a,b);Vt(a)}}function Gn(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){v[b+829|0]=c;break a}c=y[b+829|0]}d=x[a+480180>>2]&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(x[a+480180>>2]&69206029){break b}e=d&255;f=d&15;if((f|0)==15){if(e>>>0>=16){Sp(a,b,(d&240)>>>4|0,0);return}if(!(v[b+872|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((e&240)!=240){break b}if(f){Rp(a,b,f,0);return}if(!(v[b+872|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+872|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|x[a+480180>>2]!=524288)){break c}e=d&15;d:{if(e){if((d&255)>>>0>15?x[a+480180>>2]&16777248:0){break d}c=c-(e<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if(x[a+480180>>2]!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}g=b,h=Yb(c,0,256),x[g+688>>2]=h}function vx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+48>>2]=x[d+20>>2];f=x[d+16>>2];x[c+40>>2]=x[d+12>>2];x[c+44>>2]=f;qn(c+68|0,c+40|0,e);d=Oc(c+56|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+32>>2]=x[c+76>>2];a=x[c+72>>2];x[c+24>>2]=x[c+68>>2];x[c+28>>2]=a;x[c+16>>2]=x[d+8>>2];a=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=a;if(e){h=c+24|0;i=c+8|0;j=b+4|0;while(1){a=0;if(f){while(1){d=x[Vf(i,a,g)>>2];fc(b,a);d=(d+((Bs(j)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0<=491520?491520:d;k=pn(h,a,g),l=(d|0)>=557055?557055:d,w[k>>1]=l;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=aj(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/48>>>0){e=hb-16|0;hb=e;d:{b=lU(e+4|0,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;P(752,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}c=c+48|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=jU(d+12|0,kU(a,aj(a)+c|0),aj(a),b);x[114409]=0;P(708,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(552,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Fu(b)}hb=d+32|0;break a}a=N()|0;Fu(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+D(b,48)|0;aj(a);mU(a,b);yU(a)}}function T2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;a:{b:{b=d+16|0;c:{d:{if(ns(ta(x[a+60>>2],b|0,2,d+12|0)|0)){e=b;break d}while(1){g=x[d+12>>2];if((g|0)==(f|0)){break c}if((g|0)<0){e=b;break b}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;b=e;i=i-j|0;if(!ns(ta(x[a+60>>2],b|0,i|0,d+12|0)|0)){continue}break}}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[e+4>>2]|0}hb=d+32|0;return a|0}function iG(a,b,c,d,e,f){var g=0;g=hb-80|0;hb=g;a:{if((f|0)>=16384){wd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}wd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}wd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}wd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}wd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;hb=g+80|0}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){e=hb-16|0;hb=e;d:{b=ne(e+4|0,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;P(1773,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=Rf(d+12|0,Fe(a,Lb(a)+c|0),Lb(a),b);x[114409]=0;P(1770,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1767,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Us(b)}hb=d+32|0;break a}a=N()|0;Us(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+(b<<2)|0;Lb(a);AK(a,b);sg(a)}}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb+-64|0;hb=d;a=x[a+4>>2];wv(d+16|0,b);x[114409]=0;b=O(2,d+4|0,13619)|0;e=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[114409]=0;T(3,d+28|0,d+16|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break h}x[114409]=0;T(732,d+40|0,d+28|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break g}x[114409]=0;T(9,d+52|0,0,d+40|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[114409]=0;P(c|0,a|0,d+52|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}xb(d+52|0);xb(d+40|0);xb(d+28|0);xb(b);xb(d+16|0);hb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;xb(d+52|0)}xb(d+40|0)}xb(d+28|0)}xb(b)}xb(d+16|0);Q(a|0);p()}function gM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;h=-1;a:{if(!wy(a,b,2)){break a}d=x[b+656>>2];f=a+1074312|0;g=$b(f,31);i=x[b+752>>2];if(i?0:g){break a}g=d+88|0;f=i-$b(f,31)|0;d=x[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=gq(g,f,d,x[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(y[b+748|0]&16){h=Wp(a,b,!(x[b+88>>2]&32768),d);break a}if(Lj(b)){if((d|0)==x[b+768>>2]){break a}x[b+768>>2]=d;v[b+872|0]=y[b+872|0]|16;break a}a=Op(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Fh(e+12|0,255);a=(x[e+12>>2]<<2)+(a?31424:30400)|0;break b}Fh(e+12|0,255);a=(x[e+12>>2]<<2)+(a?30400:31424)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];j=c,k=Ec(tqa(sqa(b,d,a,a>>31),lb,65536,0),lb),x[j>>2]=k}hb=e+16|0;return h}function Z1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(A[b+24>>2]>A[b+44>>2]){x[b+44>>2]=x[b+24>>2]}l=-1;m=-1;h=f&24;a:{if(!h|(e|0)==1&(h|0)==24){break a}h=x[b+44>>2];if(h){i=h-Rb(b+32|0)|0;j=i>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;k=g>>31;break b}g=x[b+24>>2]-x[b+20>>2]|0;k=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=i;k=j}d=d+k|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>i>>>0&(d|0)>=(j|0)|(d|0)>(j|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!x[b+24>>2]){break a}}if(e){fn(b,x[b+8>>2],c+x[b+8>>2]|0,x[b+44>>2])}if(f&16){Kw(b,x[b+20>>2],x[b+28>>2]);ds(b,c)}l=c;m=d}_g(a,l,m)}function aI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;a:{b:{c:{d:{if((b|0)>=0){if((up(a+8|0)|0)>(b|0)){break d}}b=ec(8);x[114409]=0;c=O(122,f+4|0,6687)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=a+32|0;a=(x[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;x[a>>2]=c|x[a>>2]&-134218753;a=(x[d>>2]+D(b,896)|0)+1075072|0;x[a>>2]=c|x[a>>2]&-134218753;a=z[x[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=D(a,896);if((b|0)==z[(e+x[d>>2]|0)+1075792>>1]){e=(e+x[d>>2]|0)+1075072|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}hb=f+16|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function aw(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;f=x[a>>2];e=x[f-4>>2];f=x[f-8>>2];x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;v[d+55|0]=0;v[d+56|0]=0;v[d+57|0]=0;v[d+58|0]=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+20>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+f|0;b=0;a:{if(vg(e,c,0)){x[d+56>>2]=1;mb[x[x[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=x[d+32>>2]==1?a:0;break a}mb[x[x[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:b=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}b=x[d+24>>2]}hb=d- -64|0;return b}function $w(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=yH(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}hb=e+16|0;return c}function Sb(a,b,c){var d=0,e=0,f=0,g=0;a:{if(!c){break a}v[a|0]=b;d=a+c|0;v[d-1|0]=b;if(c>>>0<3){break a}v[a+2|0]=b;v[a+1|0]=b;v[d-3|0]=b;v[d-2|0]=b;if(c>>>0<7){break a}v[a+3|0]=b;v[d-4|0]=b;if(c>>>0<9){break a}d=0-a&3;e=d+a|0;b=D(b&255,16843009);x[e>>2]=b;d=c-d&-4;c=d+e|0;x[c-4>>2]=b;if(d>>>0<9){break a}x[e+8>>2]=b;x[e+4>>2]=b;x[c-8>>2]=b;x[c-12>>2]=b;if(d>>>0<25){break a}x[e+24>>2]=b;x[e+20>>2]=b;x[e+16>>2]=b;x[e+12>>2]=b;x[c-16>>2]=b;x[c-20>>2]=b;x[c-24>>2]=b;x[c-28>>2]=b;g=e&4|24;c=d-g|0;if(c>>>0<32){break a}d=sqa(b,0,1,1);f=lb;b=e+g|0;while(1){x[b+24>>2]=d;x[b+28>>2]=f;x[b+16>>2]=d;x[b+20>>2]=f;x[b+8>>2]=d;x[b+12>>2]=f;x[b>>2]=d;x[b+4>>2]=f;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function HL(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-16|0;hb=h;v[h+15|0]=b;v[h+14|0]=10;Qg(g,y[tc(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;if(Lb(g)){c=0;while(1){b=D(c,3)+f|0;d=y[b|0]|y[b+1|0]<<8;i=Pb(g,c),j=d>>>4|0,w[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(z[Pb(g,c)>>1]>=z[Pb(g,d)>>1]){break a}e=c;d=z[Pb(g,d)>>1]+1|0}i=Pb(g,e),j=d,w[i>>1]=j}b=Md(y[b+2|0],0,64);i=Pb(g,c),j=b,v[i+2|0]=j;c=c+1|0;if(Lb(g)>>>0>c>>>0){continue}break}}b=y[g+12|0]&-2|a&1;v[g+12|0]=b;if(a&2){b=y[g+15|0];b=(Lb(g)>>>0>=b>>>0)<<2|y[g+12|0]&-5}else{b=b&251}v[g+12|0]=b;c:{d:{if(a&4){a=y[g+13|0];if(a>>>0<=y[g+14|0]){break d}}a=b&253;break c}b=Lb(g);a=y[g+12|0]&-3|(a>>>0<=b>>>0)<<1}v[g+12|0]=a;hb=h+16|0}function O6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{c:{if((e|0)==1){break c}x[114409]=0;V(2164,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;V(2164,c|0);f=x[114409];x[114409]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=uc(d+24|0,b);c=uc(d+16|0,c);x[114409]=0;g=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=g;b=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=b;W(2208,f|0,d+8|0,d|0,1);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,1993,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}hb=d+32|0;return e|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;ri(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);g=x[Bb(e,x[b+4>>2])>>2];h=hb-16|0;hb=h;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=g;if(qc(c+12|0,c+8|0)){while(1){g=c+12|0;f=ek(g);j=c+4|0;i=ek(j);x[i+8>>2]=x[f+8>>2];k=x[f+4>>2];x[i>>2]=x[f>>2];x[i+4>>2]=k;Kh(g);Kh(j);if(qc(g,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(h+8|0,d+12|0,d+8|0);hb=d+32|0;hb=h+16|0;x[e+12>>2]=x[h+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wm(a,Ac(a));hb=e+16|0}function wx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Th(c- -64|0,c+32|0,f);d=Oc(c+52|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){d=c+16|0;while(1){a=0;if(e){while(1){h=C[ph(c,a,g)>>3];fc(b,a);i=Kj(Td(h*134217728));j=Rn(d,a,g),k=E(+(i|0)*7.450580596923828e-9),B[j>>2]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function Tv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=xc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>>0){e=hb-16|0;hb=e;d:{b=xh(e+4|0,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;P(191,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}c=c+1|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=ci(d+12|0,bi(a,xc(a)+c|0),xc(a),b);x[114409]=0;P(187,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(183,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Tm(b)}hb=d+32|0;break a}a=N()|0;Tm(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+b|0;xc(a);SD(a,b);iq(a)}}function Iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+4>>2]=0;yb(c);Zc(b+8|0);Yd(a+4|0,x[Bb(a,b)>>2]);b:{d=ng(c);if(!d){break b}x[114409]=0;P(690,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[c+4>>2];f=x[c>>2];x[114409]=0;W(1698,b|0,f|0,e|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){break b}}b=N()|0;co(a+4|0);Q(b|0);p()}d=a+4|0;Xd(d);co(d);hb=a+16|0;x[b+20>>2]=x[c+20>>2];a=x[c+16>>2];x[b+12>>2]=x[c+12>>2];x[b+16>>2]=a;x[114409]=0;d=O(1697,b+24|0,c+24|0)|0;a=x[114409];x[114409]=0;c:{d:{if((a|0)!=1){x[114409]=0;O(121,b+36|0,c+36|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break d}x[b+48>>2]=x[c+48>>2];break a}a=N()|0;break c}a=N()|0;Me(d)}hm(b);Q(a|0);p()}}function $V(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;zd(b,0);d=e+8|0;Bh(d,1,a+33|0);f=e+20|0;Kc(f,d);x[114409]=0;O(350,b+43|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){f=e+20|0;xb(f);d=a+50|0;x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+54|0;x[b+24>>2]=y[d|0]|y[d+1|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;g=b,h=y[tc(f,e+8|0)|0]<<2,w[g+30>>1]=h;d=a+57|0;x[b+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+61|0;x[b+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(!(!c|!x[b+4>>2])){x[b+8>>2]=x[b>>2]}a:{if(!y[a|0]){break a}a=x[b+8>>2];if(a>>>0<=x[b+4>>2]+2>>>0|a>>>0>A[b>>2]){break a}w[b+34>>1]=z[b+34>>1]|2}hb=e+32|0;return}a=N()|0;xb(e+20|0);Q(a|0);p()}function Dna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;x[d+28>>2]=0;Xi(a,d+28|0);a:{b:{e=x[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Xb(d+16|0);x[114409]=0;w[d+14>>1]=0;f=U(734,a|0,e|0,255)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}if(!f){break d}x[114409]=0;O(724,a|0,d+14|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;T(13,d|0,c|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break f}x[114409]=0;f=O(735,b|0,d+14|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}Eb(f,d);xb(d);xb(e);h=h+1|0;if(h>>>0<A[d+28>>2]){continue}break}}Nf(x[x[a>>2]-12>>2]+a|0);break c}a=N()|0;break a}a=N()|0;xb(d);break a}xb(e)}hb=d+32|0;return}a=N()|0}xb(e);Q(a|0);p()}function Cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;w[d+30>>1]=0;Ef(a,d+30|0);a:{b:{e=z[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Xb(d+16|0);x[114409]=0;w[d+14>>1]=0;f=U(736,a|0,e|0,255)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}if(!f){break d}x[114409]=0;O(724,a|0,d+14|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}x[114409]=0;T(13,d|0,c|0,e|0);f=x[114409];x[114409]=0;if((f|0)==1){break f}x[114409]=0;f=O(735,b|0,d+14|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break e}Eb(f,d);xb(d);xb(e);h=h+1|0;if(h>>>0<z[d+30>>1]){continue}break}}Nf(x[x[a>>2]-12>>2]+a|0);break c}a=N()|0;break a}a=N()|0;xb(d);break a}xb(e)}hb=d+32|0;return}a=N()|0}xb(e);Q(a|0);p()}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=h;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){f=b+24|0;while(1){a=x[e+8>>2];b=(x[e+12>>2]<<1)+k|0;a=(((a>>>16|0)+4&131064)<<1)+f|0;a=(((((D(w[b+4>>1],w[a+10>>1])+D(w[b+2>>1],w[a+8>>1])|0)+D(w[b+6>>1],w[a+12>>1])|0)+D(w[b+8>>1],w[a+14>>1])|0)/2|0)+((((D(w[b-4>>1],w[a+2>>1])+D(w[b-6>>1],w[a>>1])|0)+D(w[b-2>>1],w[a+4>>1])|0)+D(w[b>>1],w[a+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];h=x[e+12>>2]}x[g>>2]=f;x[g+4>>2]=h;hb=e+16|0}function aG(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=Aw(9661);if(y[b|0]?b:0){break a}b=Aw(D(a,12)+61728|0);if(y[b|0]?b:0){break a}b=Aw(9908);if(y[b|0]?b:0){break a}b=10289}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=10289;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!xj(e,10289)){break e}if(xj(e,9361)){break d}}if(!a){c=61636;if(y[e+1|0]==46){break c}}return 0}c=x[115193];if(c){while(1){if(!xj(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=xd(36);if(c){b=x[15410];x[c>>2]=x[15409];x[c+4>>2]=b;b=c+8|0;sc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[115193];x[115193]=c}c=a|c?c:61636}return c}function Dt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[b+40>>2]=0;x[b+44>>2]=0;d=b- -64|0;x[d>>2]=0;x[d+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){nO(b,C[ol(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=e,h=bc(c),x[g+12>>2]=h;g=e,h=dc(c),x[g+8>>2]=h;if(Hb(e+12|0,e+8|0)){while(1){d=e+12|0;f=x[d>>2];g=f,i=nO(b,C[f>>3]),C[g>>3]=i;jz(d);if(Hb(d,e+8|0)){continue}break}}b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[b+12>>2]=0;d=yb(c);x[114409]=0;U(1287,a+8|0,b+12|0,d|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];d=x[yb(c)>>2];g=yb(a),h=d,x[g>>2]=h;g=yb(c),h=0,x[g>>2]=h;x[c>>2]=0;x[c+4>>2]=0;hb=b+16|0;break a}R(0)|0;zb();p()}hb=e+16|0}function J5(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;c=x[a+4>>2];a=x[a>>2];x[d>>2]=a;x[d+4>>2]=c;x[d+8>>2]=a;x[d+12>>2]=c;a=hb+-64|0;hb=a;a:{if(!x[d+4>>2]){break a}c=77184;b:{while(1){b=x[d+4>>2];x[a+56>>2]=x[d>>2];x[a+60>>2]=b;b=uc(a+48|0,x[c+8>>2]);e=x[a+60>>2];x[a+24>>2]=x[a+56>>2];x[a+28>>2]=e;e=x[b+4>>2];x[a+16>>2]=x[b>>2];x[a+20>>2]=e;if(XL(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=77700){continue}break}c=77712;while(1){b=x[d+4>>2];x[a+40>>2]=x[d>>2];x[a+44>>2]=b;b=uc(a+32|0,x[c+8>>2]);e=x[a+44>>2];x[a+8>>2]=x[a+40>>2];x[a+12>>2]=e;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;b=XL(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=77760){continue}break}break a}b=1}hb=a- -64|0;hb=d+16|0;return b|0}function dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];g=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Db(b);if(g){a=x[a+20>>2];b=g;while(1){d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);f=he(E(rf(E((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r())*h),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){d=~~f;break a}d=-2147483648}i=a,j=Wc(d),w[i>>1]=j;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=he(E(rf(E((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r())*h),E(-1))*E(32768)));b:{if(E(F(f))<E(2147483648)){d=~~f;break b}d=-2147483648}i=a,j=Wc(d),w[i+2>>1]=j;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return g<<3}function wK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=hb-48|0;hb=c;x[c+12>>2]=542066252;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;v[c+19|0]=0;d=x[b+4220>>2];v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=x[b+4224>>2];v[c+24|0]=d;v[c+25|0]=d>>>8;v[c+26|0]=d>>>16;v[c+27|0]=d>>>24;d=x[b+4228>>2];v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=x[b+4232>>2];v[c+32|0]=d;v[c+33|0]=d>>>8;v[c+34|0]=d>>>16;v[c+35|0]=d>>>24;d=x[b+4236>>2];v[c+36|0]=d;v[c+37|0]=d>>>8;v[c+38|0]=d>>>16;v[c+39|0]=d>>>24;v[c+40|0]=y[b+4240|0];v[c+41|0]=y[b+4241|0];v[c+42|0]=y[b+4242|0];v[c+43|0]=y[b+4243|0];v[c+44|0]=y[b+4244|0];b=b+4208|0;Uk(b,33);sc(x[b>>2],c+12|0,33);d=c+4|0;nj(d,b);Dd(a,d);hb=c+48|0}function Qg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){e=hb-16|0;hb=e;d:{b=ne(e+4|0,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;P(351,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=Ao(d+12|0,Fe(a,Lb(a)+c|0),Lb(a),b);x[114409]=0;P(346,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(347,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}fj(b)}hb=d+32|0;break a}a=N()|0;fj(b);Q(a|0);p()}return}if(b>>>0<c>>>0){rv(a,x[a>>2]+(b<<2)|0)}}function p8(a){a=a|0;var b=0;b=4221;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=13326;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=17381;break a}b=4254;break a}b=1518;break a}b=4277;break a}b=4291;break a}b=1874;break a}b=1894;break a}b=4303;break a}b=4235;break a}b=8670;break a}b=7987;break a}b=2446;break a}if((a|0)!=357){break a}b=4188}return Ld(b)|0}function eO(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c;if(z[a+28>>1]!=(b|0)){Bt(a+12|0);w[a+28>>1]=b}c=a+12|0;if(kd(c)){gO(c,iz(a,z[vc(Yp(a),b)>>1]))}b=e+12|0;a:{if(x[c+4>>2]!=x[yb(c)>>2]){d=hb-16|0;hb=d;a=ne(d+4|0,c,1);c=yb(c);f=x[a+4>>2];x[114409]=0;T(390,c|0,f|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+4;Jb(a);hb=d+16|0;break a}b=N()|0;Jb(a);Q(b|0);p()}d=hb-32|0;hb=d;f=yb(c);a=Rf(d+12|0,Fe(c,Lb(c)+1|0),Lb(c),f);g=x[a+8>>2];x[114409]=0;T(390,f|0,g|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[a+8>>2]=x[a+8>>2]+4;x[114409]=0;P(102,c|0,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}Ek(a);hb=d+32|0;break b}b=N()|0;Ek(a);Q(b|0);p()}}hb=e+16|0}function aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;g=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=x[a+32>>2];e=x[b+8>>2];i=x[a+28>>2]+i|0;j=i>>12;f=(x[b+12>>2]<<1)+k|0;e=(e>>>21&2040)+32976|0;e=(((D(w[f>>1],w[e+2>>1])+D(w[f-2>>1],w[e>>1])|0)+D(w[f+2>>1],w[e+4>>1])|0)+D(w[f+4>>1],w[e+6>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(j,e);h=g+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=g;hb=b+16|0}function KV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;zd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Lq(a+4|0,a);x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=Lq(a+8|0,a);x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d+15|0]=127;v[d+14|0]=y[a+15|0];f=b,g=(((y[tc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[f+30>>1]=g;e=a+12|0;if(y[e|0]>=16){c=y[e|0];w[b+34>>1]=32;w[b+28>>1]=c&240}c=a+13|0;x[b+24>>2]=(y[c|0]|y[c+1|0]<<8)<<1;if(!(y[c|0]|y[c+1|0]<<8)){x[b+24>>2]=16726}f=b,g=(D(Mt(0,y[e|0]<<28>>24),x[b+24>>2])>>>0)/8363|0,x[f+24>>2]=g;if(A[b+4>>2]<A[b+8>>2]){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}hb=d+16|0}function iN(a,b,c){var d=0,e=0;a:{if(x[a+480180>>2]==4){d=y[b+833|0];if(c){v[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{d:{if(!(y[a+480208|0]&16)){break d}d=x[b+700>>2];if(x[a+480180>>2]==4){break d}c=Oy(a,c&15);e=sqa(c,c>>31,d,d>>31);c=lb;e=e+32768|0;c=e>>>0<32768?c+1|0:c;c=Ec(tqa(e,c,65536,0),lb);x[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074312|0;if(!($b(a,7)|x[b+700>>2]==2147483647)){a=x[b+700>>2]+1|0;break c}if(!$b(a,7)){break b}a=x[b+700>>2];if((a|0)<2){break b}a=a-1|0;break c}a=((c&255)<<2)+d|0;a=(a|0)>=65535?65535:a}x[b+700>>2]=a}}function DR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){j=z[vc(b,i)>>1];m=j+1|0;n=j>>>0<(h&65535)>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=j>>>0<(l&65535)>>>0?l:m;h=n?h:m;i=i+1|0;if((i|0)!=128){continue}break}Og(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(oj(a)&-2)){break c}Tc(a,c+(f<<10)|0);if(!bA(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((oj(a)|0)!=(d+D(f,i)|0)){break a}}Tc(a,c+D(f,z[e>>1])|0);h=bA(a,64,1)?h:k}Tc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(oj(a)|0)){break d}}if(c>>>0>=255){aA(b,254,65534);aA(b,255,65535)}l=h}return l&65535}function sk(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;x[a+4>>2]=0;vj(e+15|0,a,1);a:{b:{d=4;c:{if(!y[e+15|0]){break c}d=x[x[a>>2]-12>>2];x[114409]=0;d=x[(a+d|0)+24>>2];f=x[114409];x[114409]=0;d:{if((f|0)==1){break d}x[114409]=0;b=U(2451,d|0,b|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break d}x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(R(0)|0)|0;uj(x[x[a>>2]-12>>2]+a|0,1);b=x[x[a>>2]-12>>2];x[114409]=0;b=x[(a+b|0)+20>>2];c=x[114409];x[114409]=0;e:{if((c|0)!=1){if(!(b&1)){break e}x[114409]=0;X(86);a=x[114409];x[114409]=0;if((a|0)!=1){break a}}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)==1){break b}Q(a|0);p()}_();d=1}Mg(x[x[a>>2]-12>>2]+a|0,d);hb=e+16|0;return}R(0)|0;zb()}p()}function dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+44|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+20|0,2,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+32|0,d+20|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(504,d+12|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;O(450,d+12|0,d+32|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+32|0);Jc(d+44|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+32|0)}Jc(d+44|0);Q(a|0);p()}return a|0}function Zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+44|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+20|0,3,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+32|0,d+20|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(777,d+12|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;O(450,d+12|0,d+32|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+32|0);Jc(d+44|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+32|0)}Jc(d+44|0);Q(a|0);p()}return a|0}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>4;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);h=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);l(0,h|0);l(1,e|0);g=Td(Gg(+n())*32768);a:{if(F(g)<2147483648){e=~~g;break a}e=-2147483648}i=a,j=Wc(e),w[i>>1]=j;e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);h=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);l(0,h|0);l(1,e|0);g=Td(Gg(+n())*32768);b:{if(F(g)<2147483648){e=~~g;break b}e=-2147483648}i=a,j=Wc(e),w[i+2>>1]=j;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=f+16|0;return d<<4}function pT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+44|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+20|0,2,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+32|0,d+20|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(492,d+12|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;O(450,d+12|0,d+32|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+32|0);Jc(d+44|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+32|0)}Jc(d+44|0);Q(a|0);p()}return a|0}function _1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;a:{b:{if(!re(b,-1)){f=x[a+12>>2];g=x[a+8>>2];if(x[a+24>>2]==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}h=x[a+24>>2];i=x[a+20>>2];j=x[a+44>>2];k=x[a+20>>2];x[114409]=0;c=a+32|0;P(111,c|0,0);d=x[114409];x[114409]=0;if((d|0)==1){break b}d=Hc(c);x[114409]=0;P(1736,c|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}d=Rb(c);Kw(a,d,Cb(c)+d|0);ds(a,h-i|0);x[a+44>>2]=x[a+20>>2]+(j-k|0)}x[e+12>>2]=x[a+24>>2]+1;l=a,m=x[$c(e+12|0,a+44|0)>>2],x[l+44>>2]=m;if(y[a+48|0]&8){c=Rb(a+32|0);fn(a,c,c+(f-g|0)|0,x[a+44>>2])}c=KG(a,b<<24>>24);break a}c=bs(b);break a}Y(R(0)|0)|0;_();c=-1}a=c;hb=e+16|0;return a|0}function Nl(a,b){var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){e=hb-16|0;hb=e;d:{b=ne(e+4|0,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;P(1738,f|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=Rf(d+12|0,Fe(a,Lb(a)+c|0),Lb(a),b);x[114409]=0;P(1713,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1712,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}yn(b)}hb=d+32|0;break a}a=N()|0;yn(b);Q(a|0);p()}return}if(b>>>0<c>>>0){_x(a,x[a>>2]+(b<<2)|0)}}function J2(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-48|0;hb=c;if(uH(1,c+24|0)){Cr(x[114232],8551);p()}e=Li(c+8|0,c+24|0);f=UG(c,c+32|0);b=hb-32|0;hb=b;d=hb-16|0;hb=d;g=hb-16|0;hb=g;a=hb-16|0;hb=a;i=a,j=sqa(x[e>>2],x[e+4>>2],1e9,0),x[i>>2]=j;x[a+4>>2]=lb;e=Li(a+8|0,a);h=x[e>>2];e=x[e+4>>2];hb=a+16|0;hb=g+16|0;a=d;x[a+8>>2]=h;x[a+12>>2]=e;d=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=d;hb=a+16|0;a=x[b+8>>2];e=x[b+12>>2];d=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=d;f=x[b>>2];d=a+f|0;a=x[b+4>>2]+e|0;x[b+16>>2]=d;x[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=Li(b+24|0,b+16|0);d=x[a>>2];a=x[a+4>>2];hb=b+32|0;x[c+16>>2]=d;x[c+20>>2]=a;b=Li(c+40|0,c+16|0);a=x[b>>2];hb=c+48|0;lb=x[b+4>>2];return a|0}function Aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=h;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){f=b+24|0;while(1){a=x[e+8>>2];b=x[e+12>>2]+k|0;a=(((a>>>16|0)+4&131064)<<1)+f|0;a=((((D(v[b+2|0],w[a+10>>1])+D(v[b+1|0],w[a+8>>1])|0)+D(v[b+3|0],w[a+12>>1])|0)+D(v[b+4|0],w[a+14>>1])<<8>>1)+(((D(v[b-2|0],w[a+2>>1])+D(v[b-3|0],w[a>>1])|0)+D(v[b-1|0],w[a+4>>1])|0)+D(v[b|0],w[a+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];h=x[e+12>>2]}x[g>>2]=f;x[g+4>>2]=h;hb=e+16|0}function GB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;ij(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);g=x[Bb(e,x[b+4>>2])>>2];h=hb-16|0;hb=h;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=g;if(qc(c+12|0,c+8|0)){while(1){f=c+12|0;g=Wj(f);i=c+4|0;j=Wj(i);g=y[g|0]|y[g+1|0]<<8;v[j|0]=g;v[j+1|0]=g>>>8;Ch(f);Ch(i);if(qc(f,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(h+8|0,d+12|0,d+8|0);hb=d+32|0;hb=h+16|0;x[e+12>>2]=x[h+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Do(a,rc(a));hb=e+16|0}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=x[a+32>>2];b=x[e+8>>2];i=x[a+28>>2]+i|0;j=i>>12;f=x[e+12>>2]+k|0;b=(b>>>21&2040)+32976|0;b=(((D(v[f|0],w[b+2>>1])+D(v[f-1|0],w[b>>1])|0)+D(v[f+1|0],w[b+4>>1])|0)+D(v[f+2|0],w[b+6>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(j,b);h=g+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(b,g);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=g;hb=e+16|0}function YK(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-48|0;hb=f;d=Xb(f+36|0);x[114409]=0;O(1735,a|0,f+24|0)|0;g=x[114409];x[114409]=0;a:{b:{if((g|0)!=1){g=x[f+28>>2];e=x[f+24>>2];Xe(d);x[114409]=0;g=!g&e>>>0>=255|g?255:e;P(1736,d|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}if(g){e=0;while(1){h=pc(d,e);x[114409]=0;O(1737,a|0,h|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}e=e+1|0;if((g|0)!=(e|0)){continue}break}}if((wE(d)|0)!=-1){a=wE(d);x[114409]=0;P(1736,d|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}x[114409]=0;T(13,f+12|0,c|0,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){break b}break a}break a}a=f+12|0;Eb(b,a);xb(a);xb(d);hb=f+48|0;return}a=N()|0;xb(d);Q(a|0);p()}function zs(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Th(c- -64|0,c+32|0,f);d=Oc(c+52|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){d=c+16|0;while(1){a=0;if(e){while(1){h=x[Vf(c,a,g)>>2];fc(b,a);i=Rn(d,a,g),j=E(E(h|0)*E(7.450580596923828e-9)),B[i>>2]=j;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function V6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[114409]=0;V(2164,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}e=x[a+24>>2];x[114409]=0;c=O(122,d+8|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;W(2199,d+20|0,e|0,c|0,1);b=x[114409];x[114409]=0;if((b|0)==1){break d}a=d+20|0;b=Ld(Rb(a));xb(a);xb(c);break b}b=R(0)|0;break c}b=R(0)|0;break c}b=R(0)|0;xb(c)}Y(b|0)|0;b=0;x[114409]=0;W(2113,2786,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=d+32|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function yK(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;B[d+12>>2]=c;Tx(a);Vh(d+12|0);a:{b:{switch(b|0){case 0:B[a+4220>>2]=B[d+12>>2];break a;case 1:B[a+4224>>2]=B[d+12>>2];break a;case 2:B[a+4228>>2]=B[d+12>>2];Ts(a);break a;case 3:v[a+4240|0]=B[d+12>>2]>=E(.5);Ts(a);break a;case 4:b=hb-16|0;hb=b;f=b,g=_h(E(B[d+12>>2]*E(32))),x[f+12>>2]=g;x[b+8>>2]=0;x[b+4>>2]=5;e=x[gl(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;x[a+4232>>2]=e;break a;case 5:v[a+4241|0]=B[d+12>>2]>=E(.5);break a;case 6:v[a+4242|0]=B[d+12>>2]>=E(.5);break a;case 7:v[a+4244|0]=B[d+12>>2]>=E(.5);break a;case 8:break b;default:break a}}c=B[d+12>>2];if(c==E(0)){Sx(a);c=B[d+12>>2]}C[a+4256>>3]=c}hb=d+16|0}function Xg(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0);d=B[a+4268>>2];f=NJ(a);c=E(E(B[a+4224>>2]*E(1.899999976158142))+E(.10000000149011612));e=pe(E(10),E(E(E(x[((b<<2)+a|0)+4292>>2])*E(-3))/E(B[a+4268>>2]*E(E(B[a+4220>>2]*E(19.899999618530273))+E(.10000000149011612)))));c=E(E(pe(e,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-np(c>E(1)?E(3.1415927410125732):E(E(f*E(6.2831854820251465))/d))));a:{if(c==E(0)){break a}d=E(0);g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(!(c<=E(0))){d=E(M(c))}h=E(E(d-f)/g);if(E(F(h))<=E(1)){break a}h=E(E(-E(d+f))/g)}b=(b<<3)+a|0;B[b+4404>>2]=h;B[b+4400>>2]=e;c=B[a+4272>>2];c=E(c*c);d=E(E(1)-c);e=E(e*e);return E(E(E(E(d*d)*e)/E(E(1)-E(c*e)))+c)}function B7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[114409]=0;V(2164,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break f}e=x[a+24>>2];x[114409]=0;c=O(122,d+8|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break e}x[114409]=0;T(2165,d+20|0,e|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}a=d+20|0;b=Ld(Rb(a));xb(a);xb(c);break b}b=R(0)|0;break c}b=R(0)|0;break c}b=R(0)|0;xb(c)}Y(b|0)|0;b=0;x[114409]=0;W(2113,9158,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=d+32|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function nea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=E(0),h=E(0),i=E(0),j=0,k=0;f=hb-16|0;hb=f;j=f,k=D(x[a>>2],Qe(a)),x[j+12>>2]=k;zc(f+12|0,c>>>2|0);c=Db(b);g=B[e+4>>2];e=x[f+12>>2];if(e){while(1){h=E(F((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r())));g=g<h?h:g;c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==E(0);a:{if(c){break a}e=x[f+12>>2];if(!e){break a}h=c?E(1):E(E(1)/g);c=x[a+20>>2];while(1){i=he(E(rf(E((l(2,y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)),r())*h),E(-1))*E(32768)));b:{if(E(F(i))<E(2147483648)){a=~~i;break b}a=-2147483648}j=c,k=Wc(a),w[j>>1]=k;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){B[d>>2]=g}hb=f+16|0;return x[f+12>>2]<<2}function mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{b:{c:{d:{e:{if(Dj(b)){break e}w[d>>1]=z[a+480190>>1];w[d+14>>1]=x[b+4>>2]-1;c=z[Gf(d,d+14|0)>>1];if(!c){break e}g=c;while(1){if(!Mz(b,c)){x[114409]=0;e=O(1521,a|0,c&65535)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(e){x[114409]=0;e=O(122,d|0,17381)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;O(348,((c<<5)+a|0)+946304|0,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}xb(e);h=h+1|0}if(!(z[a+480190>>1]!=(c|0)|c>>>0<2)){w[a+480190>>1]=z[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}hb=d+16|0;return h&65535}c=N()|0;break a}c=N()|0;xb(e);break a}c=N()|0}Q(c|0);p()}function FG(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[114409]=0;O(2462,c+8|0,a|0)|0;b=x[114409];x[114409]=0;c:{if((b|0)!=1){d:{if(!y[c+8|0]){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[114409]=0;b=S(2463,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[114409]=0;P(2464,a+b|0,1);b=x[114409];x[114409]=0;if((b|0)!=1){break d}}b=R(0)|0;CG(c+8|0);break c}CG(c+8|0);break b}b=R(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}_()}hb=c+16|0;return a|0}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function cL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=E(0),i=E(0),j=0,k=E(0);f=hb-16|0;hb=f;if(!(!z[b>>1]|w[d>>1]>w[d+2>>1]|(!(B[c>>2]>E(0))|(w[d+2>>1]-w[d>>1]|0)>32766))){w[a>>1]=3;g=a+4|0;Ki(g);w[a+28>>1]=65472;x[f+12>>2]=1065353216;eL(g,128,f+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Ki(a+16|0);w[a+28>>1]=z[d>>1];e=hb-16|0;hb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Gf(e+14|0,e+12|0)>>1];hb=e+16|0;w[a+30>>1]=b;h=E(F(B[c>>2]));B[a+32>>2]=h;h=pe(h,E(E(1)/E(w[a+30>>1])));e=1;Nl(g,(w[d+2>>1]-w[d>>1]|0)+1|0);b=w[d>>1];if((b|0)<=w[d+2>>1]){while(1){i=pe(h,E(b|0));j=Pb(g,b-w[a+28>>1]|0),k=i,B[j>>2]=k;c=w[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}Bp(a)}hb=f+16|0;return e|0}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=Lg(a);if(d>>>0<b>>>0){h=hb-32|0;hb=h;a:{b:{f=b-d|0;c:{if(f>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/52>>>0){cy(a,f,c);break c}g=yb(a);e=oL(a,Lg(a)+f|0);j=Lg(a);d=hb-16|0;hb=d;x[d+12>>2]=0;b=h+12|0;We(b+12|0,g);if(e){jL(d+4|0,x[b+16>>2],e);i=x[d+4>>2];e=x[d+8>>2]}else{e=0}x[b>>2]=i;g=D(j,52)+i|0;x[b+8>>2]=g;x[b+4>>2]=g;k=hc(b),l=D(e,52)+i|0,x[k>>2]=l;hb=d+16|0;x[114409]=0;T(1693,b|0,f|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1694,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}hL(b)}hb=h+32|0;break a}a=N()|0;hL(b);Q(a|0);p()}return}if(b>>>0<d>>>0){pL(a,x[a>>2]+D(b,52)|0)}}function Ty(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{if(!d){break a}if(c){v[b+835|0]=c;break a}c=y[b+835|0]}d=x[a+480180>>2]&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{e:{if(!d){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(y[a+480209|0]&16)){break b}a=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(y[a+480209|0]&16)){break b}c=c<<2;break c}if(y[a+480209|0]&16){break b}d=e+8|0;Kb(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Ib(d)){break d}a=a>>2;break d}if(y[a+480209|0]&16){break b}if(!f){c=c<<2;if(!d|!(x[a+480180>>2]&16777248)){break c}break b}a=0-(d>>>2|0)|0}c=a;if(!c){break b}}a=Yb(x[b+692>>2]+c|0,0,256);w[b+796>>1]=0;x[b+692>>2]=a}hb=e+16|0}function yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=E(0);e=hb-16|0;hb=e;Ge(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);g=x[Bb(e,x[b+4>>2])>>2];h=hb-16|0;hb=h;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=g;if(qc(c+12|0,c+8|0)){while(1){f=c+12|0;i=B[Yg(f)>>2];g=c+4|0;j=Yg(g),k=i,B[j>>2]=k;hg(f);hg(g);if(qc(f,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(h+8|0,d+12|0,d+8|0);hb=d+32|0;hb=h+16|0;x[e+12>>2]=x[h+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=e+16|0}function wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>3;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=he(E(rf((l(2,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24)),r()),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){e=~~g;break a}e=-2147483648}h=a,i=Wc(e),w[h>>1]=i;e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=he(E(rf((l(2,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24)),r()),E(-1))*E(32768)));b:{if(E(F(g))<E(2147483648)){e=~~g;break b}e=-2147483648}h=a,i=Wc(e),w[h+2>>1]=i;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=f+16|0;return d<<3}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;c=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=c;c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=rQ(d);a=vq(a);v[a+8|0]=0;x[a+4>>2]=c;x[a>>2]=75520;c=Pj(a+12|0);v[a+24|0]=0;x[114409]=0;O(39,a+28|0,0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){f=a+40|0;c=0;while(1){e=f+D(c,12)|0;x[e>>2]=0;x[e+4>>2]=0;v[e+8|0]=0;c=c+1|0;if((c|0)!=16){continue}break}if(y[a+24|0]){e=a+232|0;c=0;while(1){g=ef(e,c),h=c,x[g>>2]=h;c=c+1|0;if((c|0)!=16){continue}break}}break a}a=N()|0;yh(c);Q(a|0);p()}x[a>>2]=75636;c=x[b+4>>2];x[a+296>>2]=x[b>>2];x[a+300>>2]=c;c=x[b+12>>2];x[a+304>>2]=x[b+8>>2];x[a+308>>2]=c;hb=d+16|0;return a|0}function zp(a,b,c){var d=0,e=0,f=0;d=Xb(a);a=Cb(b);x[114409]=0;P(112,d|0,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){a:{if(Cb(b)){while(1){f=x[yj(b,e)>>2];a=32;b:{c:{while(1){if(x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}x[114409]=0;P(111,d|0,a<<24>>24);a=x[114409];x[114409]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(x[(a<<2)+c>>2]==(f|0)){x[114409]=0;P(111,d|0,a<<24>>24);a=x[114409];x[114409]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}x[114409]=0;P(111,d|0,63);a=x[114409];x[114409]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Cb(b)>>>0>e>>>0){continue}break}}return}}a=N()|0;xb(d);Q(a|0);p()}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-48|0;hb=c;d=c+28|0;f=Pj(d+8|0);x[114409]=0;e=S(305,b|0)|0;g=x[114409];x[114409]=0;a:{b:{if((g|0)==1){break b}x[114409]=0;T(448,d|0,b|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}e=x[d>>2];x[114409]=0;O(313,b|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;yh(f);Q(a|0);p()}x[114409]=0;P(715,c+12|0,d|0);b=x[114409];x[114409]=0;c:{if((b|0)==1){break c}x[114409]=0;P(716,c+20|0,c+12|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}b=x[c+20>>2];d=x[c+24>>2];x[114409]=0;U(717,a|0,b|0,d|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}Jc(c+28|0);hb=c+48|0;return}a=N()|0;Jc(c+28|0);Q(a|0);p()}function tx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+48>>2]=x[d+20>>2];f=x[d+16>>2];x[c+40>>2]=x[d+12>>2];x[c+44>>2]=f;tp(c+68|0,c+40|0,e);d=Oc(c+56|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+32>>2]=x[c+76>>2];a=x[c+72>>2];x[c+24>>2]=x[c+68>>2];x[c+28>>2]=a;x[c+16>>2]=x[d+8>>2];a=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=a;if(e){d=c+24|0;h=c+8|0;while(1){a=0;if(f){while(1){i=C[ph(h,a,g)>>3];fc(b,a);j=Kj(Td(i*134217728));k=Vf(d,a,g),l=E(+(j|0)*7.450580596923828e-9),B[k>>2]=l;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function t4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=hb-32|0;hb=b;e=sh(a);Gd(b+24|0);a=0;x[114409]=0;c=O(2324,x[b+24>>2],x[b+28>>2])|0;d=x[114409];x[114409]=0;a:{b:{if((d|0)==1){break b}x[114409]=0;P(1629,e|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}c:{while(1){x[114409]=0;c=O(2324,x[b+24>>2],x[b+28>>2])|0;d=x[114409];x[114409]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}hb=b+32|0;return}a=N()|0;break a}c=x[x[b+24>>2]+(a<<3)>>2];x[114409]=0;c=O(122,b+12|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(1631,e|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}xb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;xb(c);break a}a=N()|0}pd(e);Q(a|0);p()}function zn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;Ge(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);h=x[Bb(e,x[b+4>>2])>>2];g=hb-16|0;hb=g;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=h;if(qc(c+12|0,c+8|0)){while(1){f=c+12|0;h=x[Yg(f)>>2];i=c+4|0;j=Yg(i),k=h,x[j>>2]=k;hg(f);hg(i);if(qc(f,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(g+8|0,d+12|0,d+8|0);hb=d+32|0;hb=g+16|0;x[e+12>>2]=x[g+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=e+16|0}function vR(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Qb(a,1024)){d=c+24|0;Yz(d,b);Cd(a,d);break a}x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;a=64;while(1){d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}hb=c+32|0}function uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>3;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);e=g&16711680;h=e>>>8|0;i=e<<24;e=g&-16777216;k=e>>>24|0;i=i|e<<8;e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,i|(((e&255)<<24|g>>>8)&-16777216|((e&16777215)<<8|g>>>24)&16711680|(e>>>8&65280|e>>>24)));e=h|k|(g<<24|(g&65280)<<8);h=0;l(1,e|(h|h));j=Td(Gg(+n())*32768);a:{if(F(j)<2147483648){e=~~j;break a}e=-2147483648}m=a,o=Wc(e),w[m>>1]=o;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=f+16|0;return d<<3}function sO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=dt(b);c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);x[114409]=0;P(1280,a|0,2048);e=x[114409];x[114409]=0;a:{if((e|0)!=1){x[114409]=0;P(1283,a|0,2048);e=x[114409];x[114409]=0;if((e|0)!=1){break a}}a=N()|0;Ct(c+4|0);Q(a|0);p()}e=c+4|0;Xd(e);Ct(e);hb=c+16|0;c=a;a=0;b:{while(1){d=1;if((a|0)!=1024){x[114409]=0;d=+(a-1024|0);g=+fb(1274,+(M(d*d*-9.5367431640625e-7+1)*b));e=x[114409];x[114409]=0;if((e|0)==1){break b}d=d*.0372006759294457;d=g*vi(d)/(d*f)}h=ol(c,a),i=d*.011841342921061943,C[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=N()|0;Tf(c);Q(a|0);p()}function Yk(a,b,c,d){var e=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;if(x[x[a>>2]>>2]){x[a>>2]=x[x[a>>2]>>2]}d=x[mc(a)>>2];b=x[c>>2];c=(d|0)==(b|0);v[b+12|0]=c;a:{if(c){break a}while(1){if(y[x[b+8>>2]+12|0]){break a}e=Hg(x[b+8>>2]);c=x[b+8>>2];b:{if(e){c=x[x[c+8>>2]+4>>2];if(!(!c|y[c+12|0])){break b}if(!Hg(b)){b=x[b+8>>2];xq(b)}b=x[b+8>>2];v[b+12|0]=1;b=x[b+8>>2];v[b+12|0]=0;wq(b);break a}c=x[x[c+8>>2]>>2];if(!(!c|y[c+12|0])){break b}if(Hg(b)){b=x[b+8>>2];wq(b)}b=x[b+8>>2];v[b+12|0]=1;b=x[b+8>>2];v[b+12|0]=0;xq(b);break a}b=x[b+8>>2];v[b+12|0]=1;b=x[b+8>>2];v[b+12|0]=(b|0)==(d|0);v[c+12|0]=1;if((b|0)!=(d|0)){continue}break}}a=yb(a);x[a>>2]=x[a>>2]+1}function yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb+-64|0;hb=e;Xe(b);f=e+44|0;uf(f,a,d);a=x[f>>2];x[114409]=0;f=S(445,f|0)|0;g=x[114409];x[114409]=0;a:{b:{c:{d:{if((g|0)==1){break d}x[114409]=0;f=S(446,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;W(447,e+8|0,2,f|0,a|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;P(370,e+20|0,e+8|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;T(13,e+32|0,c|0,e+20|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}c=b;b=e+32|0;Eb(c,b);xb(b);xb(e+20|0);Jc(e+44|0);hb=e- -64|0;a=!d|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(e+20|0)}Jc(e+44|0);Q(a|0);p()}return a|0}function eY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb+-64|0;hb=g;Qi(g+16|0,g+15|0,c);x[114409]=0;c=g+28|0;T(197,c|0,g+14|0,d|0);d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){c:{x[114409]=0;c=g+40|0;T(197,c|0,g+13|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;c=g+52|0;T(197,c|0,g+12|0,f|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;P(198,g+4|0,g+16|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,g+4|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}PD(g+16|0);hb=g- -64|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break a}a=N()|0;PD(g+16|0)}Q(a|0);p()}function Vha(a){a=a|0;var b=0,c=0,d=0;d=YF(x[x[a>>2]-12>>2]+a|0,10);c=hb-16|0;hb=c;x[114409]=0;O(15,c+8|0,a|0)|0;b=x[114409];x[114409]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!y[c+8|0]){break e}b=jl(c+4|0,a);x[114409]=0;O(2460,b|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){if(!hl(b)){break e}b=x[x[a>>2]-12>>2];x[114409]=0;P(18,a+b|0,1);b=x[114409];x[114409]=0;if((b|0)!=1){break e}}b=R(0)|0;Of(c+8|0);break d}Of(c+8|0);break c}b=R(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114409]=0;V(19,a+b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}_()}hb=c+16|0;break a}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}gs(a);return a|0}function Tla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb+-64|0;hb=e;Xe(b);f=e+44|0;uf(f,a,d);a=x[f>>2];x[114409]=0;f=S(445,f|0)|0;g=x[114409];x[114409]=0;a:{b:{c:{d:{if((g|0)==1){break d}x[114409]=0;f=S(446,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break d}x[114409]=0;W(447,e+8|0,3,f|0,a|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;P(370,e+20|0,e+8|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;T(13,e+32|0,c|0,e+20|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}c=b;b=e+32|0;Eb(c,b);xb(b);xb(e+20|0);Jc(e+44|0);hb=e- -64|0;a=!d|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(e+20|0)}Jc(e+44|0);Q(a|0);p()}return a|0}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;zd(b,0);c=d+8|0;BQ(c,a+1|0);e=d+20|0;Kc(e,c);x[114409]=0;O(350,b+43|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(d+20|0);c=a+73|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+54|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+58|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+62|0;if(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)){x[b+8>>2]=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;zc(b+8|0,x[b>>2]);zc(b+4|0,x[b+8>>2]);hb=d+32|0;return}a=N()|0;xb(d+20|0);Q(a|0);p()}function Dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-528|0;hb=b;c=-1;a:{if(!Hh(a,1468)){break a}Tk(a,1464);c=b+524|0;HR(a,c);if(!Wd(c,23938)){c=0;if(!Wd(b+524|0,11604)){break a}}Tk(a,20);c=1;b:{while(1){if(!ER(a,b)){break b}d=eA(b)+d|0;e=c&65535;c=c+1|0;if(e>>>0<=30){continue}break}c=0;if(d>>>0>40){break a}d=b+522|0;e=hb-16|0;hb=e;c:{if(Hh(a,2)){f=e+8|0;xm(f,d);Xz(a,f);break c}v[e+7|0]=0;MB(d,e+7|0)}hb=e+16|0;e=ed(d);if(y[d|0]>128){break a}c=hb-16|0;hb=c;d:{if(Hh(a,512)){d=c+8|0;qB(d,b);Xz(a,d);break d}kR(b)}hb=c+16|0;a=y[e|0];d=0;while(1){if(a>>>0>=y[b+d|0]){c=1;d=d+1|0;if((d|0)!=512){continue}break a}break}c=0;break a}c=-1}hb=b+528|0;return c|0}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;a:{b:{if(x[a+8>>2]!=x[hc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=x[a+4>>2];d=x[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=ue(f,x[g>>2],f+c|0),x[i>>2]=j;x[h>>2]=c+x[h>>2];break b}i=e,j=x[hc(a)>>2]-x[a>>2]>>1,x[i+8>>2]=j;x[e+28>>2]=1;d=e+8|0;c=x[$c(d,e+28|0)>>2];c=Ao(d,c,c>>>2|0,x[a+16>>2]);d=Bb(e+4|0,x[a+4>>2]);f=x[Bb(e,x[a+8>>2])>>2];d=x[d>>2];x[114409]=0;T(1214,c|0,d|0,f|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}Ub(a,c);Ub(h,c+4|0);Ub(g,c+8|0);Ub(hc(a),hc(c));fj(c)}xS(x[a+16>>2],x[a+8>>2],b);x[a+8>>2]=x[a+8>>2]+4;hb=e+32|0;return}a=N()|0;fj(c);Q(a|0);p()}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;EK(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);h=x[Bb(e,x[b+4>>2])>>2];g=hb-16|0;hb=g;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=h;if(qc(c+12|0,c+8|0)){while(1){f=c+12|0;h=CK(f);i=c+4|0;sc(CK(i),h,2048);BK(f);BK(i);if(qc(f,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(g+8|0,d+12|0,d+8|0);hb=d+32|0;hb=g+16|0;x[e+12>>2]=x[g+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];xf(a);Bk(a);Bk(a);hb=e+16|0}function vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a>>2]=78452;b=Pj(a+4208|0);c=a+4288|0;x[c>>2]=0;x[c+4>>2]=0;x[a+4280>>2]=0;x[a+4284>>2]=0;x[114409]=0;c=$(1477)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}x[114409]=0;c=S(1478,c|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[a+4296>>2]=c;v[a+4244|0]=0;x[a+4236>>2]=2147483647;x[a+4240>>2]=0;Ts(a);Ss(a);x[114409]=0;U(1760,a+44|0,2,2)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;V(1761,a|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}return a|0}c=N()|0;yh(b);Cf(a);Q(c|0);p()}function apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;iU(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);h=x[Bb(e,x[b+4>>2])>>2];g=hb-16|0;hb=g;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=h;if(qc(c+12|0,c+8|0)){while(1){f=c+12|0;h=gU(f);i=c+4|0;sc(gU(i),h,48);fU(f);fU(i);if(qc(f,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(g+8|0,d+12|0,d+8|0);hb=d+32|0;hb=g+16|0;x[e+12>>2]=x[g+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];aj(a);im(a);im(a);hb=e+16|0}function Qma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;GS(a);yb(a);c=Bb(e+8|0,x[a+4>>2]);f=Bb(e+4|0,x[a>>2]);h=x[Bb(e,x[b+4>>2])>>2];g=hb-16|0;hb=g;d=hb-32|0;hb=d;Ae(d+24|0,x[c>>2],x[f>>2]);f=x[d+24>>2];c=hb-16|0;hb=c;x[c+8>>2]=x[d+28>>2];x[c+12>>2]=f;x[c+4>>2]=h;if(qc(c+12|0,c+8|0)){while(1){f=c+12|0;h=DS(f);i=c+4|0;sc(DS(i),h,33);CS(f);CS(i);if(qc(f,c+8|0)){continue}break}}Dc(d+16|0,c+12|0,c+4|0);hb=c+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(g+8|0,d+12|0,d+8|0);hb=d+32|0;hb=g+16|0;x[e+12>>2]=x[g+12>>2];x[b+4>>2]=x[e+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Vk(a);gm(a);gm(a);hb=e+16|0}function jp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=d?d:460760;d=x[f>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];e=d<<24>>24;if((e|0)>=0){if(a){x[a>>2]=d}return(e|0)!=0|0}if(!x[x[114276]>>2]){e=1;if(!a){break b}x[a>>2]=v[b|0]&57343;return 1}d=y[b|0]-194|0;if(d>>>0>50){break c}d=x[(d<<2)+61408>>2];e=c-1|0;if(!e){break a}b=b+1|0}g=y[b|0];h=g>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=g-128|d<<6;if((d|0)>=0){x[f>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;g=y[b|0];if((g&192)==128){continue}break}}x[f>>2]=0;x[114232]=25;e=-1}return e|0}x[f>>2]=d;return-2}function CQ(a,b){var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+44|0;uf(d,a,4);a=x[d>>2];x[114409]=0;d=S(445,d|0)|0;e=x[114409];x[114409]=0;b:{c:{d:{if((e|0)==1){break d}x[114409]=0;d=S(446,d|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;W(447,c+20|0,3,d|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(370,c+32|0,c+20|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(1014,c+12|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}x[114409]=0;O(450,c+12|0,c+32|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}xb(c+32|0);Jc(c+44|0);hb=c- -64|0;break a}a=N()|0;break b}a=N()|0;xb(c+32|0)}Jc(c+44|0);Q(a|0);p()}}function Aba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-16|0;hb=d;w[a>>1]=0;e=Ck(a+4|0);h=Ck(a+16|0);x[a+36>>2]=0;i=gd(a+40|0);f=hb-16|0;hb=f;g=f+15|0;b=hb-16|0;hb=b;x[114409]=0;c=a+52|0;S(1709,c+4|0)|0;j=x[114409];x[114409]=0;a:{b:{if((j|0)==1){break b}x[114409]=0;x[b+12>>2]=0;U(1710,c+8|0,b+12|0,g|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}k=c,l=mc(c),x[k>>2]=l;hb=b+16|0;break a}R(0)|0;zb();p()}hb=f+16|0;Ki(e);w[a+28>>1]=65472;x[114409]=0;x[d+12>>2]=1065353216;T(1707,e|0,128,d+12|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Ki(h);hb=d+16|0;return a|0}a=N()|0;dT(c);xb(i);lg(h);lg(e);Q(a|0);p()}function ws(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+48>>2]=x[d+20>>2];f=x[d+16>>2];x[c+40>>2]=x[d+12>>2];x[c+44>>2]=f;tp(c+68|0,c+40|0,e);d=Oc(c+56|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+32>>2]=x[c+76>>2];a=x[c+72>>2];x[c+24>>2]=x[c+68>>2];x[c+28>>2]=a;x[c+16>>2]=x[d+8>>2];a=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=a;if(e){d=c+24|0;h=c+8|0;while(1){a=0;if(f){while(1){i=x[Vf(h,a,g)>>2];fc(b,a);j=Vf(d,a,g),k=E(E(i|0)*E(7.450580596923828e-9)),B[j>>2]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<=2147483631){b:{if(Hc(a)>>>0>=b>>>0){break b}k=c,l=Cb(a),x[k+8>>2]=l;b=mj(x[$c(c+12|0,c+8|0)>>2]);if((Hc(a)|0)==(b|0)){break b}d=hb-16|0;hb=d;f=Hc(a);g=Cb(a);c:{d:{h=ml(b);e:{if(h){i=1;j=b+1|0;b=a;e=x[a>>2];break e}e=b+1|0;f:{if(b>>>0>f>>>0){Mh(d+8|0,a,e);break f}x[114409]=0;T(33,d+8|0,a|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break d}}b=x[d+8>>2];j=x[d+12>>2];i=we(a);e=Rb(a)}Se(b,e,Cb(a)+1|0);if(i){fg(a,e,f+1|0)}g:{if(!h){Jf(a,j);ee(a,g);_e(a,b);break g}Ie(a,g)}break c}Y(R(0)|0)|0;_()}hb=d+16|0}hb=c+16|0;break a}If();p()}}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-32|0;hb=e;k=x[a+24>>2];l=x[a+20>>2];m=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;g=a;if(d){while(1){b=x[e+24>>2];f=b>>>18|0;i=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;h=0;b=1;while(1){a=h<<1;j=w[a+i>>1];x[(e+8|0)+(h<<2)>>2]=j+((D(w[(a|4)+i>>1]-j|0,f)|0)/16384|0);a=b;b=0;h=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],k);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];f=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+32|0}function bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;d=x[a+28>>2];bo(x[x[d>>2]-12>>2]+d|0,0);if(x[x[b>>2]+4>>2]){h=x[a+28>>2];d=x[a+12>>2];g=x[x[b>>2]+4>>2];f=g+x[a+8>>2]|0;d=_g(e+48|0,f,f>>>0<g>>>0?d+1|0:d);f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;tj(h,e+8|0)}d=e+24|0;Af(d,x[a+28>>2]);f=x[d+12>>2];x[e+40>>2]=x[d+8>>2];x[e+44>>2]=f;qz(x[a+28>>2],c,x[x[b>>2]+8>>2]);c=x[b>>2];b=Sm(d,Cc(a+32|0,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);x[114409]=0;a=Z(1747,a|0,c|0,b|0,e+40|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){Gb(b);hb=e- -64|0;break a}a=N()|0;Gb(b);Q(a|0);p()}return a|0}
function fP(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+820|0]=0;return}v[a+820|0]=1;return}v[a+820|0]=2;return}v[a+820|0]=3;return}v[a+724|0]=y[a+724|0]&254;return}v[a+724|0]=y[a+724|0]|1;return}v[a+736|0]=y[a+736|0]&254;return}v[a+736|0]=y[a+736|0]|1;return}v[a+748|0]=y[a+748|0]&254;return}v[a+748|0]=y[a+748|0]|1;return}if(x[c+480180>>2]!=16777216){break a}c=a;a=y[a+748|0];v[c+748|0]=(b|0)==13?a&238|1:a|17}}function cI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=hb-16|0;hb=d;a:{b:{c:{d:{if((b|0)>=0){if((up(a+8|0)|0)>(b|0)){break d}}a=ec(8);x[114409]=0;d=O(122,d+4|0,6687)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,d);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(d);break b}if(!(!(c<0)&c<=1)){a=ec(8);x[114409]=0;d=O(122,d+4|0,7596)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=oc(a,d);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(d);break b}b=N()|0;ic(a);break b}e=Mn(c*64);x[(x[a+32>>2]+D(b,896)|0)+1075744>>2]=e;hb=d+16|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function T$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=hb-16|0;hb=k;l=j;a:{if(a){a=k+4|0;b=yF(b);hk(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;gk(a,b);Eb(i,a);xb(a);jh(a,b);Eb(h,a);xb(a);m=d,n=ti(b),v[m|0]=n;m=e,n=si(b),v[m|0]=n;zg(a,b);Eb(f,a);xb(k+4|0);kh(a,b);Eb(g,a);xb(k+4|0);a=fk(b);break a}a=k+4|0;b=xF(b);hk(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;gk(a,b);Eb(i,a);xb(a);jh(a,b);Eb(h,a);xb(a);m=d,n=ti(b),v[m|0]=n;m=e,n=si(b),v[m|0]=n;zg(a,b);Eb(f,a);xb(k+4|0);kh(a,b);Eb(g,a);xb(k+4|0);a=fk(b)}x[l>>2]=a;hb=k+16|0}function XL(a,b){var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;if(x[a+4>>2]==x[b+4>>2]){d=x[a+4>>2];a=x[a>>2];x[c+24>>2]=a;x[c+28>>2]=d;e=x[b+4>>2];b=x[b>>2];x[c+16>>2]=b;x[c+20>>2]=e;x[c+8>>2]=a;x[c+12>>2]=d;x[c>>2]=b;x[c+4>>2]=e;b=0;a=hb-16|0;hb=a;d=c+8|0;x[a+12>>2]=x[d+4>>2];x[a+8>>2]=x[c+4>>2];a:{b:{if(!x[Mb(a+12|0,a+8|0)>>2]){break b}while(1){e=vn(v[Cc(d,b)|0]);f=vn(v[Cc(c,b)|0]);if((e|0)!=(f|0)){b=e>>>0<f>>>0?-1:1;break a}if(e){x[a+12>>2]=x[d+4>>2];x[a+8>>2]=x[c+4>>2];b=b+1|0;if(b>>>0>=A[Mb(a+12|0,a+8|0)>>2]){break b}continue}break}b=0;break a}b=0;if(x[d+4>>2]==x[c+4>>2]){break a}b=A[d+4>>2]<A[c+4>>2]?-1:1}hb=a+16|0;d=!b}hb=c+32|0;return d}function WF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!b){return 0}a:{b:{if(!c){break b}d=y[b|0];e=d<<24>>24;if((e|0)>=0){if(a){x[a>>2]=d}return(e|0)!=0|0}if(!x[x[114276]>>2]){c=1;if(!a){break a}x[a>>2]=v[b|0]&57343;return 1}d=y[b|0]-194|0;if(d>>>0>50){break b}d=x[(d<<2)+61408>>2];if(d<<D(c,6)-6<0&c>>>0<=3){break b}c=y[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}d=c-128|d<<6;if((d|0)>=0){c=2;if(!a){break a}x[a>>2]=d;return 2}c=y[b+2|0]-128|0;if(c>>>0>63){break b}d=c|d<<6;if((d|0)>=0){c=3;if(!a){break a}x[a>>2]=d;return 3}b=y[b+3|0]-128|0;if(b>>>0>63){break b}c=4;if(!a){break a}x[a>>2]=b|d<<6;return 4}x[114232]=25;c=-1}return c|0}function M$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=hb-16|0;hb=k;l=j;a:{if(a){a=k+4|0;b=uF(b);hk(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;gk(a,b);oi(i,a);Pc(a);jh(a,b);oi(h,a);Pc(a);m=d,n=ti(b),x[m>>2]=n;m=e,n=si(b),x[m>>2]=n;zg(a,b);Eb(f,a);xb(a);kh(a,b);oi(g,a);Pc(k+4|0);a=fk(b);break a}a=k+4|0;b=tF(b);hk(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;gk(a,b);oi(i,a);Pc(a);jh(a,b);oi(h,a);Pc(a);m=d,n=ti(b),x[m>>2]=n;m=e,n=si(b),x[m>>2]=n;zg(a,b);Eb(f,a);xb(a);kh(a,b);oi(g,a);Pc(k+4|0);a=fk(b)}x[l>>2]=a;hb=k+16|0}
function iZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<=1073741807){a:{if(Vm(a)>>>0>=b>>>0){break a}k=c,l=Cb(a),x[k+8>>2]=l;b=wl(x[$c(c+12|0,c+8|0)>>2]);if((Vm(a)|0)==(b|0)){break a}d=hb-16|0;hb=d;f=Vm(a);g=Cb(a);b:{c:{h=bp(b);d:{if(h){i=1;j=b+1|0;b=a;e=x[a>>2];break d}e=b+1|0;e:{if(b>>>0>f>>>0){ck(d+8|0,a,e);break e}x[114409]=0;T(2995,d+8|0,a|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}}b=x[d+8>>2];j=x[d+12>>2];i=we(a);e=Rb(a)}Ph(b,e,Cb(a)+1|0);if(i){ap(e,f+1|0)}f:{if(!h){Jf(a,j);ee(a,g);_e(a,b);break f}Ie(a,g)}break b}Y(R(0)|0)|0;_()}hb=d+16|0}hb=c+16|0;return}If();p()}function Gy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;if(!kd(a)){k=b,l=bc(a),x[k+12>>2]=l;k=b,l=dc(a),x[k+8>>2]=l;if(Hb(b+12|0,b+8|0)){while(1){d=b+12|0;e=x[d>>2];Jo(e,4194304,67108864);e=x[e>>2];f=e+f|0;c=e>>>0>f>>>0?c+1|0:c;je(d);if(Hb(d,b+8|0)){continue}break}}d=Lb(a);e=Lb(a);k=b,l=bc(a),x[k+12>>2]=l;k=b,l=dc(a),x[k+8>>2]=l;e=e<<24;if(Hb(b+12|0,b+8|0)){f=vqa(f,c,d,0);d=f;h=((lb&1)<<31|d>>>1)&2147483647;while(1){g=b+12|0;c=x[g>>2];i=c;d=x[c>>2];c=d>>>8|0;d=h+(d<<24)|0;c=c+j|0;c=id(vqa(d,d>>>0<h>>>0?c+1|0:c,f,j),lb);x[i>>2]=c;e=e-c|0;je(g);if(Hb(g,b+8|0)){continue}break}}a=Gc(a,0);x[a>>2]=x[a>>2]+e}hb=b+16|0}function Dr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<=2147483631){a:{if(Hc(a)>>>0>=b>>>0){break a}k=c,l=Cb(a),x[k+8>>2]=l;b=mj(x[$c(c+12|0,c+8|0)>>2]);if((Hc(a)|0)==(b|0)){break a}d=hb-16|0;hb=d;f=Hc(a);g=Cb(a);b:{c:{h=ml(b);d:{if(h){i=1;j=b+1|0;b=a;e=x[a>>2];break d}e=b+1|0;e:{if(b>>>0>f>>>0){Mh(d+8|0,a,e);break e}x[114409]=0;T(33,d+8|0,a|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}}b=x[d+8>>2];j=x[d+12>>2];i=we(a);e=Rb(a)}Se(b,e,Cb(a)+1|0);if(i){fg(a,e,f+1|0)}f:{if(!h){Jf(a,j);ee(a,g);_e(a,b);break f}Ie(a,g)}break b}Y(R(0)|0)|0;_()}hb=d+16|0}hb=c+16|0;return}If();p()}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;zd(b,0);c=d+8|0;Bh(c,1,a);e=d+20|0;Kc(e,c);x[114409]=0;O(350,b+43|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){e=d+20|0;xb(e);c=a+32|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+13|0;w[b+34>>1]=z[b+34>>1]&65533|(y[c|0]|y[c+1|0]<<8)<<1&2;c=a+16|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+20|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+24|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d+20|0]=y[a+15|0];v[d+8|0]=64;f=b,g=y[tc(e,d+8|0)|0]<<2,w[f+30>>1]=g;hb=d+32|0;return}a=N()|0;xb(d+20|0);Q(a|0);p()}function gq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;if(!kd(a)){g=Lb(a)-1|0;a:{if((Lb(a)|0)==1){break a}while(1){if(z[Gc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Lb(a)-1>>>0){continue}break}}h=z[Gc(a,g)>>1];x[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(y[Gc(a,g)+2|0]<<16)/(d|0)|0,x[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(y[Gc(a,e)+2|0]<<16)/(d|0)|0;x[f+12>>2]=i;e=z[Gc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((y[Gc(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=sqa(d,g,a,a>>31);a=h-e|0;j=f,k=Ec(tqa(b,lb,a,a>>31),lb)+i|0,x[j+12>>2]=k}ce(f+12|0,0,65536);e=(D(x[f+12>>2],c)+32768|0)/65536|0}hb=f+16|0;return e}function Vp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;if(e){v[e|0]=0}i=a+484344|0;a:{if(!pg(i,b)){break a}d=Hf(Zb(i,b),c,d);g=y[d+5|0];b:{c:{d:{h=y[d+3|0];switch(h-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}x[f+12>>2]=2;j=0;break b}x[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=x[a+480180>>2]==4}l=f,m=x[Zb(i,b)+12>>2]+(c^-1)|0,x[l+8>>2]=m;c=x[Mb(f+8|0,f+12|0)>>2];if(!c){break a}while(1){k=D(Fk(Zb(i,b)),6);a=k+d|0;if(y[a+3|0]!=34){break a}h=g<<8;g=j?g>>>0<256?h+-8192|0:h:h;d=y[(d+k|0)+5|0];if(e){v[e|0]=1}g=d|g;d=a;c=c-1|0;if(c){continue}break}}hb=f+16|0;return g|0}function bW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;zd(b,0);c=d+8|0;Bh(c,1,a+33|0);e=d+20|0;Kc(e,c);x[114409]=0;O(350,b+43|0,e|0)|0;c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=d+20|0;xb(c);e=a+50|0;x[b>>2]=y[e|0]|y[e+1|0]<<8;e=a+52|0;x[b+24>>2]=y[e|0]|y[e+1|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;f=b,g=y[tc(c,d+8|0)|0]<<2,w[f+30>>1]=g;c=a+55|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8;c=a+57|0;c=y[c|0]|y[c+1|0]<<8;x[b+8>>2]=c;if((c|0)!=65535){break b}x[b+4>>2]=0;x[b+8>>2]=0;break a}a=N()|0;xb(d+20|0);Q(a|0);p()}if(!y[a|0]){break a}a=x[b+8>>2];if(a>>>0<=x[b+4>>2]+2>>>0|a>>>0>A[b>>2]){break a}w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0}function _L(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=d;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}h=e+1|0;g=(h<<1)+a|0;x[f+8>>2]=g;b:{c:{e=e+2|0;if((e|0)>=(c|0)){break c}if(!Hk(b,z[g>>1],z[g+2>>1])){break c}g=g+2|0;x[f+8>>2]=g;break b}e=h}if(Hk(b,z[g>>1],z[d>>1])){break a}g=z[x[f+12>>2]>>1];while(1){d:{w[x[f+12>>2]>>1]=z[x[f+8>>2]>>1];j=x[f+8>>2];x[f+12>>2]=j;if((e|0)>(i|0)){break d}e=e<<1;h=e|1;d=(h<<1)+a|0;x[f+8>>2]=d;e:{f:{e=e+2|0;if((e|0)>=(c|0)){break f}if(!Hk(b,z[d>>1],z[d+2>>1])){break f}d=d+2|0;x[f+8>>2]=d;break e}e=h}if(!Hk(b,z[d>>1],g)){continue}}break}w[j>>1]=g}hb=f+16|0}function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;x[e+60>>2]=d;d=x[a+28>>2];bo(x[x[d>>2]-12>>2]+d|0,0);if(x[x[b>>2]+4>>2]){h=x[a+28>>2];d=x[a+12>>2];g=x[x[b>>2]+4>>2];f=g+x[a+8>>2]|0;d=_g(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;tj(h,e)}d=e+16|0;Af(d,x[a+28>>2]);f=x[d+12>>2];x[e+32>>2]=x[d+8>>2];x[e+36>>2]=f;YK(x[a+28>>2],c,x[e+60>>2]);c=x[b>>2];b=Sm(d,Cc(a+32|0,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);x[114409]=0;Z(1747,a|0,c|0,b|0,e+32|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){Gb(b);hb=e- -64|0;return}a=N()|0;Gb(b);Q(a|0);p()}function aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;x[e+60>>2]=d;d=x[a+28>>2];bo(x[x[d>>2]-12>>2]+d|0,0);if(x[x[b>>2]+4>>2]){h=x[a+28>>2];d=x[a+12>>2];g=x[x[b>>2]+4>>2];f=g+x[a+8>>2]|0;d=_g(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;tj(h,e)}d=e+16|0;Af(d,x[a+28>>2]);f=x[d+12>>2];x[e+32>>2]=x[d+8>>2];x[e+36>>2]=f;TK(c,x[a+28>>2],x[e+60>>2]);c=x[b>>2];b=Sm(d,Cc(a+32|0,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);x[114409]=0;Z(1747,a|0,c|0,b|0,e+32|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){Gb(b);hb=e- -64|0;return}a=N()|0;Gb(b);Q(a|0);p()}function Tca(a,b){a=a|0;b=b|0;var c=0,d=0;b=77184;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[c+12>>2]=0;U(1616,a+8|0,c+12|0,c+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=c+16|0;break a}R(0)|0;zb();p()}b:{while(1){c:{if(!kd(a)){if(!xj(x[b+8>>2],x[Fj(a)>>2])){break c}}x[114409]=0;P(1615,a|0,b+8|0);c=x[114409];x[114409]=0;if((c|0)!=1){break c}break b}b=b+12|0;if((b|0)!=77700){continue}break}b=77712;while(1){d:{if(!kd(a)){if(!xj(x[b+8>>2],x[Fj(a)>>2])){break d}}x[114409]=0;P(1615,a|0,b+8|0);c=x[114409];x[114409]=0;if((c|0)!=1){break d}break b}b=b+12|0;if((b|0)!=77760){continue}break}return}b=N()|0;sy(a);Q(b|0);p()}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;g=a;if(d){while(1){b=x[e+24>>2];f=b>>>10&4194048;i=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+l|0;h=0;b=1;while(1){a=v[h+i|0];x[(e+8|0)+(h<<2)>>2]=((D(v[(h|2)+i|0]-a|0,f)|0)/16384|0)+(a<<8);a=b;b=0;h=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];f=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+32|0}function yz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{b:{c:{if(!kd(a)){w[x[a>>2]>>1]=0;df(x[a>>2]+2|0,b);g=c,h=bc(a),x[g+8>>2]=h;d=c+8|0;g=c,h=Pn(d,1),x[g+12>>2]=h;g=c,h=dc(a),x[g+8>>2]=h;if(Hb(c+12|0,d)){break c}break b}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;break a}while(1){d=c+12|0;e=x[d>>2];g=c,h=eP(d,1),x[g+8>>2]=h;f=e;e=c+8|0;f=jj(f,x[e>>2]);w[x[d>>2]>>1]=z[f>>1];df(x[c+12>>2]+2|0,b);je(d);g=c,h=dc(a),x[g+8>>2]=h;if(Hb(d,e)){continue}break}}df(a+14|0,Lb(a)-1&255);df(a+13|0,y[a+14|0]);df(a+16|0,Lb(a)-1&255);df(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}df(a+17|0,Lb(a)-1&255)}hb=c+16|0}function Zg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb+-64|0;hb=e;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}if(pg(a,b)){break b}c:{d:{if(Lg(a)>>>0<=b>>>0){d=ey(e+12|0,a);x[114409]=0;T(1690,a|0,b+1|0,d|0);f=x[114409];x[114409]=0;if((f|0)==1){break d}Ik(d)}d=Ye(a,b);x[114409]=0;O(1691,d|0,c|0)|0;c=x[114409];x[114409]=0;e:{if((c|0)!=1){c=Ye(a,b);x[c+16>>2]=0;x[c+20>>2]=0;c=Ye(a,b);x[114409]=0;O(1692,c|0,17381)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break e}}b=R(74984)|0;a=ib;break c}g=Ah(Ye(a,b));break b}b=R(74984)|0;a=ib;Ik(d)}if((ca(74984)|0)!=(a|0)){break a}Y(b|0)|0;_()}hb=e- -64|0;return g|0}Q(b|0);p()}function Hi(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=78656;b=a+24|0;x[b>>2]=0;x[b+4>>2]=0;x[b+16>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;c=rK(a+44|0);d=rK(c+12|0);e=qK(c+24|0);f=qK(c+36|0);x[114409]=0;U(1760,c|0,2,0)|0;g=x[114409];x[114409]=0;if((g|0)==1){a=N()|0;Rs(f);Rs(e);Qs(d);Qs(c);Q(a|0);p()}d=0;w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;c=x[a+16>>2];x[c+946300>>2]=x[c+946300>>2]+1;x[b>>2]=a+99&-8;e=x[a+20>>2];if((e|0)!=(c+906300|0)){f=a+4200|0;while(1){a:{b=d+1|0;if(d>>>0>247){break a}d=b;if((e|0)!=((c+D(b,160)|0)+906300|0)){continue}}break}v[f|0]=b}return a}function OX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-32|0;hb=e;f=Rb(b);g=Cb(b);i=Rb(c);j=Cb(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(Bo(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=td(b),x[k+24>>2]=l;c=rd(e+28|0,e+24|0);k=e,l=td(b),x[k+12>>2]=l;k=e,l=Le(e+12|0,h),x[k+16>>2]=l;d=rd(e+20|0,e+16|0);Rx(b,x[c>>2],x[d>>2]);break c}if(!Cb(b)){break c}f=Rb(b);h=Cb(b);g=Rb(c);d=-1;i=Cb(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!Bo(g,i,c)){continue}break}d=c-f|0}}if((Cb(b)-1|0)!=(d|0)){break c}gd(a);break b}Jd(a,b)}hb=e+32|0}function OA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Qg(b,Md(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;if(Lb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){h=a+(d<<2)|0;g=h+160|0;w[e+12>>1]=y[g|0]|y[g+1|0]<<8;g=z[jj(e+14|0,e+12|0)>>1];w[e+14>>1]=g;i=Pb(b,d),j=g,w[i>>1]=j;w[e+14>>1]=z[e+14>>1]+1;v[e+11|0]=(c^y[h+162|0])>>>f;v[e+10|0]=64;h=y[tc(e+11|0,e+10|0)|0];i=Pb(b,d),j=h,v[i+2|0]=j;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}zz(b,4,32);hb=e+16|0}function bO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{b:{i=Yp(a);h=Jj(i);if(h){j=1;while(1){k=z[vc(i,f)>>1];c:{if(!pg(x[a+24>>2]+484344|0,k)){break c}if(Ac(a)>>>0<=f>>>0){break b}e=0;g=ud(a,f);d:{if(!x[g+4>>2]){break d}while(1){if((Mz(g,e)|0)==(d|0)){break d}e=e+1|0;if(e>>>0<A[g+4>>2]){continue}break}}l=x[g+4>>2];if(d){if((e|0)==(l|0)){break b}break c}if(e>>>0<l>>>0){w[b>>1]=f;break a}if(A[g+4>>2]>=A[Zb(x[a+24>>2]+484344|0,k)+12>>2]){break c}w[b>>1]=f;e=x[g+4>>2];break a}f=f+1|0;j=h>>>0>f>>>0;if((f|0)!=(h|0)){continue}break}}w[b>>1]=65535;e=-1;break a}w[b>>1]=f;e=0}x[c>>2]=e;return j|0}function pN(a,b,c){var d=0;a:{if(x[a+480180>>2]==4){d=y[b+834|0];if(c){v[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(y[a+480208|0]&16)){break c}d=x[b+700>>2];if(x[a+480180>>2]==4){break c}a=hN(a,c&15);c=sqa(a,a>>31,d,d>>31);a=lb;c=c+32768|0;a=c>>>0<32768?a+1|0:a;a=Ec(tqa(c,a,65536,0),lb);x[b+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;x[b+700>>2]=c;if((c|0)>0){break b}x[b+700>>2]=1;if(x[a+480180>>2]!=2){break b}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}}function aH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-208|0;hb=f;x[f+204>>2]=c;c=f+160|0;Sb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if(($G(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(cH(a)){break b}}c=$G(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){mb[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}hb=f+208|0;return e}function Ln(a){var b=0,c=0;b=z[a+24>>1];c=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;x[a+40>>2]=((c&3)<<4)+24368;b=b+(c>>>2|0)|0;w[a+36>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+32>>1]=b;w[a+34>>1]=-1<<b^-1;if(z[a+24>>1]==15){w[a+36>>1]=4095}b=z[a+26>>1];c=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;x[a+52>>2]=((c&3)<<4)+24368;b=b+(c>>>2|0)|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+44>>1]=b;w[a+46>>1]=-1<<b^-1;b=z[a+30>>1];c=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;x[a+64>>2]=((c&3)<<4)+24368;b=b+(c>>>2|0)|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+58>>1]=-1<<b^-1}function mO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b=hb-16|0;hb=b;g=b+4|0;e=hb-144|0;hb=e;d=qh(e+8|0);f=x[x[d>>2]-12>>2];x[114409]=0;h=$(125)|0;i=x[114409];x[114409]=0;b:{c:{if((i|0)==1){break c}x[114409]=0;T(126,e+4|0,d+f|0,h|0);f=x[114409];x[114409]=0;if((f|0)==1){break c}Ob(e+4|0);x[114409]=0;P(136,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}x[114409]=0;P(128,g|0,d|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}ae(d);hb=e+144|0;break b}a=N()|0;ae(d);Q(a|0);p()}x[114409]=0;T(13,a|0,0,g|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break a}a=N()|0;xb(b+4|0);Q(a|0);p()}}function eda(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;a:{if(z[a+480192>>1]<b>>>0){break a}h=x[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+20|0;aP(b,h);i=g,j=hS(b),x[i+16>>2]=j;i=g,j=Oj(b),x[i+12>>2]=j;while(1){b:{x[114409]=0;b=O(805,g+16|0,g+12|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}if(!b){sq(g+20|0);break a}x[114409]=0;b=S(806,g+16|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break b}b=z[b>>1];if(b>>>0<=z[a+480190>>1]){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}ou(g+16|0);continue}break}a=N()|0;sq(g+20|0);Q(a|0);p()}hb=g+32|0}function _H(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=hb-16|0;hb=e;a:{b:{c:{d=a+8|0;d:{if(!Kl(d)){if((b|0)<0|(Gs(d)|0)<=(b|0)){break d}a=mq(x[a+32>>2],b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}d=Kl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ec(8);x[114409]=0;c=O(122,e+4|0,2427)|0;b=x[114409];x[114409]=0;e:{if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break e}b=N()|0;ic(a)}Q(b|0);p()}b=b+1<<2;a=a+32|0;if(!x[(b+x[a>>2]|0)+900380>>2]){break b}a=x[(b+x[a>>2]|0)+900380>>2];v[a+15|0]=y[a+15|0]&253|(c?2:0)}hb=e+16|0;return}p()}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){f=x[a+32>>2];e=x[b+12>>2]+k|0;g=v[e|0];i=x[a+28>>2]+i|0;j=i>>12;e=((D(v[e+1|0]-g|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(g<<8)|0;x[c>>2]=x[c>>2]+D(j,e);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,f);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function r0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+28>>2]=b;a:{if(!(x[c+4>>2]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;Fc(a,c);x[114409]=0;a=S(2607,a|0)|0;b=x[114409];x[114409]=0;b:{if((b|0)!=1){Ob(f+16|0);c:{if(e){kh(f+16|0,a);break c}jh(f+16|0,a)}g=f,h=td(f+16|0),x[g+12>>2]=h;while(1){g=f,h=lk(f+16|0),x[g+8>>2]=h;if(!Hb(f+12|0,f+8|0)){c=x[f+28>>2];Pc(f+16|0);break a}a=x[x[f+12>>2]>>2];x[114409]=0;O(2629,f+28|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){je(f+12|0);continue}break}c=N()|0;Pc(f+16|0);break b}c=N()|0;Ob(f+16|0)}Q(c|0);p()}hb=f+32|0;return c|0}function eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];g=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Db(b);if(g){a=x[a+20>>2];d=g;while(1){f=he(E(rf(E((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r())*h),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){b=~~f;break a}b=-2147483648}i=a,j=Wc(b),w[i>>1]=j;f=he(E(rf(E((l(2,y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24)),r())*h),E(-1))*E(32768)));b:{if(E(F(f))<E(2147483648)){b=~~f;break b}b=-2147483648}i=a,j=Wc(b),w[i+2>>1]=j;a=a+4|0;c=c+8|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g<<3}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];g=x[a>>2];x[b+8>>2]=g;x[b+12>>2]=e;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){e=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=w[g+2>>1];f=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+D(j,w[g>>1]);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,f);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}g=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=g;x[a+4>>2]=e;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function Dda(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}dy(a+484344|0);Xe(a+1304400|0);Xe(a+1304412|0);Xe(a+1304424|0);bB(a+1304500|0);b=a+900380|0;c=a+484380|0;while(1){On(c);c=c+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;while(1){d=x[b>>2];if(d){_b(nu(d))}x[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){kK(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0;return 1}function C0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+28>>2]=b;a:{if(!(x[c+4>>2]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;Fc(a,c);x[114409]=0;a=S(2576,a|0)|0;b=x[114409];x[114409]=0;b:{if((b|0)!=1){Ob(f+16|0);c:{if(e){kh(f+16|0,a);break c}jh(f+16|0,a)}g=f,h=td(f+16|0),x[g+12>>2]=h;while(1){g=f,h=nf(f+16|0),x[g+8>>2]=h;if(!Hb(f+12|0,f+8|0)){c=x[f+28>>2];xb(f+16|0);break a}a=v[x[f+12>>2]];x[114409]=0;O(2460,f+28|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){gg(f+12|0);continue}break}c=N()|0;xb(f+16|0);break b}c=N()|0;Ob(f+16|0)}Q(c|0);p()}hb=f+32|0;return c|0}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){f=x[a+32>>2];e=(x[b+12>>2]<<1)+k|0;g=w[e>>1];i=x[a+28>>2]+i|0;j=i>>12;e=g+((D(w[e+2>>1]-g|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(j,e);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,f);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;zc(a,65536);zc(a+4|0,64);zc(a+8|0,256);dg(a+28|0,16384);df(a+30|0,128);df(a+31|0,17);if(y[a+16|0]>=4){v[a+16|0]=0}if(y[a+17|0]>=5){v[a+17|0]=0}if(y[a+18|0]>=3){v[a+18|0]=0}df(a+19|0,64);df(a+20|0,100);c=-32;d=v[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<=32){break a}}v[a+26|0]=c}df(a+23|0,64);df(a+24|0,64);yz(a+48|0,64);yz(a+68|0,64);yz(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(y[fc(c,b)|0]){if(y[fc(c,b)|0]<121){break b}}e=fc(c,b),f=b+1|0,v[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!xo(y[a+14|0])){v[a+14|0]=5}if(y[a+34|0]>=251){v[a+34|0]=0}}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];g=x[a>>2];x[b+8>>2]=g;x[b+12>>2]=e;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){e=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=v[g+1|0];f=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+(D(j,v[g|0])<<8);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+(D(e,f)<<8);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}g=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=g;x[a+4>>2]=e;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function vj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;v[a|0]=0;f=Nf(x[x[b>>2]-12>>2]+b|0);e=x[x[b>>2]-12>>2]+b|0;a:{b:{if(f){if(x[e+72>>2]){gs(x[(x[x[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(x[(x[x[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=d+12|0;Fc(c,x[x[b>>2]-12>>2]+b|0);x[114409]=0;f=S(21,c|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}Ob(d+12|0);c=hn(d+8|0,b);e=Zc(d+4|0);while(1){d:{if(Cg(c,e)){break d}if(!Bg(f,1,tk(c))){break d}Dl(c);continue}break}if(!Cg(c,e)){break c}Mg(x[x[b>>2]-12>>2]+b|0,6)}g=a,h=Nf(x[x[b>>2]-12>>2]+b|0),v[g|0]=h;break b}Mg(e,4)}hb=d+16|0;return}a=N()|0;Ob(d+12|0);Q(a|0);p()}function npa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-48|0;hb=d;e=d+28|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+4|0,3,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+16|0,d+4|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;O(350,b|0,d+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+16|0);Jc(d+28|0);hb=d+48|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+16|0)}Jc(d+28|0);Q(a|0);p()}return a|0}function doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-48|0;hb=d;e=d+28|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+4|0,2,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+16|0,d+4|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;O(358,b|0,d+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+16|0);Jc(d+28|0);hb=d+48|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+16|0)}Jc(d+28|0);Q(a|0);p()}return a|0}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-48|0;hb=d;e=d+28|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+4|0,2,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+16|0,d+4|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;O(350,b|0,d+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+16|0);Jc(d+28|0);hb=d+48|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+16|0)}Jc(d+28|0);Q(a|0);p()}return a|0}function Oba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=b;a:{if(Bj(a)>>>0>=b>>>0){h=e,i=Lg(a),x[h+8>>2]=i;b=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];if(d){while(1){wL(b,c);b=b+52|0;d=d-1|0;if(d){continue}break}}b=x[e+12>>2];d=x[e+8>>2];if(b>>>0>d>>>0){cy(a,b-d|0,c);break a}pL(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){dy(a);By(yb(a),x[a>>2],Bj(a));h=yb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}f=oL(a,b);d=hb-16|0;hb=d;if(kL(a)>>>0<f>>>0){Xc();p()}jL(d+8|0,yb(a),f);f=x[d+8>>2];x[a+4>>2]=f;x[a>>2]=f;g=x[d+12>>2];h=yb(a),i=f+D(g,52)|0,x[h>>2]=i;iL(a,0);hb=d+16|0;cy(a,b,c)}hb=e+16|0}function GU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-48|0;hb=d;e=d+28|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break d}x[114409]=0;W(447,d+4|0,2,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;P(370,d+16|0,d+4|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}x[114409]=0;O(348,b|0,d+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}xb(d+16|0);Jc(d+28|0);hb=d+48|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+16|0)}Jc(d+28|0);Q(a|0);p()}return a|0}function BY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=hb-32|0;hb=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[114409]=0;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Ea(2131,a|0,b|0,c|0)|0;b=x[114409];x[114409]=0;a:{b:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;fa(2124,6396,e|0,f|0,g|0,h|0,i|0,j|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_();a=-255}hb=k+32|0;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}return a|0}function zY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[114409]=0;V(2164,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break d}e=x[a+24>>2];b=uc(c+8|0,b);x[114409]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Ca(2206,e|0,c|0,f|0,d|0,1);d=x[114409];x[114409]=0;b=1;if((d|0)!=1){break c}}Y(R(0)|0)|0;x[114409]=0;W(2113,4834,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_();b=0}hb=c+16|0;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}return b|0}function pw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+12|0;Fc(g,b);x[114409]=0;b=S(2606,g|0)|0;g=x[114409];x[114409]=0;a:{if((g|0)==1){break a}x[114409]=0;Z(2619,b|0,64896,64928,c|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;b=S(2607,f+12|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;c=S(2620,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}x[d>>2]=c;x[114409]=0;c=S(2616,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[e>>2]=c;x[114409]=0;P(2617,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ob(f+12|0);hb=f+16|0;return}a=N()|0;Ob(f+12|0);Q(a|0);p()}function vs(a,b,c){var d=0,e=0;d=a,e=zi(E(E(E(E(E(E(E(E(E(B[c+3328>>2]+B[c+256>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))+E(E(B[c+3072>>2]-B[c+512>>2])*E(459)))+E(E(B[c+2816>>2]+B[c+768>>2])*E(2037)))+E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153)))+E(E(B[c+2304>>2]+B[c+1280>>2])*E(6574)))+E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489)))+E(B[c+1792>>2]*E(75038)))),w[d>>1]=e;d=(b<<5)+a|0,e=zi(E(E(E(E(E(E(E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))+E(B[c+2568>>2]*E(9727)))+E(B[c+2056>>2]*E(64019)))+E(B[c+1544>>2]*E(-9975)))+E(B[c+1032>>2]*E(-45)))+E(B[c+520>>2]*E(146)))+E(B[c+8>>2]*E(-5)))),w[d>>1]=e}function hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(784,a+8|0,d+12|0,d+11|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){hb=d+16|0;break a}R(0)|0;zb();p()}d=a;b:{c:{d:{e:{while(1){x[114409]=0;a=O(231,b|0,6)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}if(!a){break d}x[114409]=0;T(769,e+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;P(770,d|0,e+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}qe(e+8|0);continue}break}a=N()|0;break b}a=N()|0;qe(e+8|0);break b}hb=e+32|0;return}a=N()|0}uA(d);Q(a|0);p()}function fqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(513,a+8|0,d+12|0,d+11|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){hb=d+16|0;break a}R(0)|0;zb();p()}d=a;b:{c:{d:{e:{while(1){x[114409]=0;a=O(231,b|0,8)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}if(!a){break d}x[114409]=0;T(493,e+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;P(494,d|0,e+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}qe(e+8|0);continue}break}a=N()|0;break b}a=N()|0;qe(e+8|0);break b}hb=e+32|0;return}a=N()|0}kB(d);Q(a|0);p()}function S6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{if((d|0)==1){break c}x[114409]=0;V(2164,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}d=x[a+24>>2];b=uc(c+12|0,b);x[114409]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;W(2203,c+20|0,d|0,c|0,1);b=x[114409];x[114409]=0;if((b|0)==1){break c}a=c+20|0;b=Ld(Rb(a));xb(a);break b}Y(R(0)|0)|0;b=0;x[114409]=0;W(2113,2021,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=c+32|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(606,a+8|0,d+12|0,d+11|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){hb=d+16|0;break a}R(0)|0;zb();p()}d=a;b:{c:{d:{e:{while(1){x[114409]=0;a=O(231,b|0,8)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}if(!a){break d}x[114409]=0;T(598,e+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;P(599,d|0,e+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break e}qe(e+8|0);continue}break}a=N()|0;break b}a=N()|0;qe(e+8|0);break b}hb=e+32|0;return}a=N()|0}VA(d);Q(a|0);p()}function vpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(A[a+4>>2]<A[yb(a)>>2]){e=hb-16|0;hb=e;d=cl(e+4|0,a,1);f=yb(a);g=x[d+4>>2];x[114409]=0;W(554,f|0,g|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=x[d+4>>2]+24;Jb(d);hb=e+16|0;break a}a=N()|0;Jb(d);Q(a|0);p()}e=hb-32|0;hb=e;f=yb(a);d=qo(e+12|0,bl(a,vd(a)+1|0),vd(a),f);g=x[d+8>>2];x[114409]=0;W(554,f|0,g|0,b|0,c|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[d+8>>2]=x[d+8>>2]+24;x[114409]=0;P(555,a|0,d|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}dU(d);hb=e+32|0;break b}a=N()|0;dU(d);Q(a|0);p()}}return Mu(a)|0}function rw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+12|0;Fc(g,b);x[114409]=0;b=S(21,g|0)|0;g=x[114409];x[114409]=0;a:{if((g|0)==1){break a}x[114409]=0;Z(2599,b|0,64896,64928,c|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;b=S(2576,f+12|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;c=S(2600,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}v[d|0]=c;x[114409]=0;c=S(2590,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}v[e|0]=c;x[114409]=0;P(2591,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ob(f+12|0);hb=f+16|0;return}a=N()|0;Ob(f+12|0);Q(a|0);p()}function aP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;c=hb-16|0;hb=c;f=c+15|0;d=hb-16|0;hb=d;x[114409]=0;S(1218,a+4|0)|0;g=x[114409];x[114409]=0;a:{b:{if((g|0)==1){break b}x[114409]=0;x[d+12>>2]=0;U(1219,a+8|0,d+12|0,f|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}h=a,i=mc(a),x[h>>2]=i;hb=d+16|0;break a}R(0)|0;zb();p()}hb=c+16|0;b=b+236|0;d=St(b);c:{if((b|0)!=(d|0)){while(1){c=z[b>>1];w[e+14>>1]=c;if(c){x[114409]=0;T(1217,e+4|0,a|0,e+14|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}}b=b+2|0;if((d|0)!=(b|0)){continue}break}}hb=e+16|0;return}b=N()|0;sq(a);Q(b|0);p()}function TI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;g=d+4|0;e=hb-144|0;hb=e;c=qh(e+8|0);f=x[x[c>>2]-12>>2];x[114409]=0;h=$(125)|0;i=x[114409];x[114409]=0;a:{b:{if((i|0)==1){break b}x[114409]=0;T(126,e+4|0,c+f|0,h|0);f=x[114409];x[114409]=0;if((f|0)==1){break b}Ob(e+4|0);x[114409]=0;P(133,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(128,g|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}ae(c);hb=e+144|0;break a}a=N()|0;ae(c);Q(a|0);p()}x[114409]=0;T(13,a|0,0,g|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(d+4|0);hb=d+16|0;return}a=N()|0;xb(d+4|0);Q(a|0);p()}function mK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;d=i+8|0;Ih(d,b);h=hb-16|0;hb=h;f=h+8|0;Yo(f,mi(h,d));d=hb-16|0;hb=d;b=x[a+8>>2];c=x[a+12>>2];g=c;a:{if((c|0)<0){break a}if(!g&Fb(a)>>>0<b>>>0|g){break a}g=Fb(a);b=x[a+8>>2];c=g-b|0;b=0-(x[a+12>>2]+(b>>>0>g>>>0)|0)|0;x[d+8>>2]=c;x[d+12>>2]=b;j=d,k=$g(f),x[j>>2]=k;x[d+4>>2]=0;c=Zz(d+8|0,d);c=wR(x[c>>2],x[c+4>>2]);if((c|0)!=($g(f)|0)){break a}ue(x[f>>2],x[f>>2]+c|0,Db(x[a>>2]+x[a+8>>2]|0));e=x[a+12>>2];b=c+x[a+8>>2]|0;e=b>>>0<c>>>0?e+1|0:e;x[a+8>>2]=b;x[a+12>>2]=e;e=1}hb=d+16|0;hb=h+16|0;hb=i+16|0;return e|0}function vU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i|!b){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){c=a+g|0;f=y[c+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(a+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=a+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=a+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}e:{if(!f){break e}a=y[(a+g|0)+5|0];if(a?(a|0)!=(i|0):0){break a}if((a|0)!=(i|0)){break e}v[e|0]=0;return}a=c;b=b-1|0;if(b){continue}break}}}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;c=hb-16|0;hb=c;d=Ve(a);f=mc(a);g=hb-16|0;hb=g;if(d){while(1){h=yt(yb(a),d+16|0,b);f=h?f:d;d=x[(h?d+4|0:d)>>2];if(d){continue}break}}d=x[Bb(g+12|0,f)>>2];hb=g+16|0;x[c+12>>2]=d;i=c,j=Oj(a),x[i+8>>2]=j;a:{b:{if(!Hb(c+12|0,c+8|0)){break b}if(yt(yb(a),b,vh(c+12|0))){break b}b=x[c+12>>2];break a}b=Oj(a)}hb=c+16|0;x[e+12>>2]=b;i=e,j=Oj(a),x[i+8>>2]=j;b=0;if(!Zs(e+12|0,e+8|0)){c=x[Bb(e+4|0,x[e+12>>2])>>2];b=hb-16|0;hb=b;x[b+12>>2]=c;c=b+12|0;d=x[c>>2];UK(a,d);mc(a);Zl(vh(c));dz(d);hb=b+16|0;b=1}hb=e+16|0;return b|0}function FH(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Ee(a)){gc(a,31);return 0}f=a,g=Ee(a),v[f+1375|0]=g;d=yi(a);b=yi(a);yi(a);f=a,g=yi(a),x[f+1112>>2]=g;yi(a);c=Ee(a);x[a+1116>>2]=c;if(!hx(a,a+1120|0,c)){gc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){e=x[a+1116>>2];if((e|0)<=0){b=27}else{c=0;b=0;while(1){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}x[a- -64>>2]=d;x[a+60>>2]=x[a+56>>2]+(b+e|0)}x[a+1380>>2]=0;return 1}function sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-32|0;hb=f;d=f+8|0;Du(d,2,a+2|0);e=f+20|0;Kc(e,d);x[114409]=0;O(348,b+492|0,e|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){xb(f+20|0);d=b+236|0;e=c+1|0;c=0;while(1){g=y[(a+c|0)+31|0];h=fd(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;if(c>>>0<120){continue}break}x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;d=a+2|0;e=a+3|0;g=a+4|0;HL(y[a|0]&15,y[c|0]&15,y[d|0]&15,y[e|0]&15,y[g|0]&15,a+5|0,b+48|0);HL(y[a|0]>>>4|0,y[c|0]>>>4|0,y[d|0]>>>4|0,y[e|0]>>>4|0,y[g|0]>>>4|0,a+35|0,b+68|0);hb=f+32|0;return}a=N()|0;xb(f+20|0);Q(a|0);p()}function OY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(vg(a,x[b+8>>2],f)){Zv(b,c,d,e);return}g=y[b+53|0];j=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;Xv(m,b,c,d,e,f);k=y[b+53|0];g=g|k;l=y[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){if(y[b+54|0]){break a}b:{if(l){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Xv(i,b,c,d,e,f);k=y[b+53|0];g=k|g;l=y[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}v[b+53|0]=(g&255)!=0;v[b+52|0]=(h&255)!=0}function qP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=d;a:{if(!d){break a}Xe(a);Dr(a,c);if(!c){break a}e=0;while(1){j=c-g|0;x[f+4>>2]=j;h=x[Mb(f+12|0,f+4|0)>>2];ir(a,Db(b)+g|0,h);Xp(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=v[vE(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=vE(a,e),m=32,v[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}x[f+4>>2]=j-h;e=i+1|0;g=x[Mb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}hb=f+16|0;return(d|0)!=0|0}function zl(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){f=he(E(rf((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r()),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Wc(g),w[h>>1]=i;f=he(E(rf((l(2,y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24)),r()),E(-1))*E(32768)));b:{if(E(F(f))<E(2147483648)){g=~~f;break b}g=-2147483648}h=a,i=Wc(g),w[h+2>>1]=i;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function u1(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-160|0;hb=d;a=mn(d+20|0,a,8);c=x[x[a>>2]-12>>2];x[114409]=0;b=$(125)|0;e=x[114409];x[114409]=0;a:{b:{if((e|0)==1){break b}x[114409]=0;T(126,d+16|0,a+c|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}Ob(d+16|0);x[114409]=0;c=O(159,a|0,147)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;c=O(160,c|0,d+12|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[x[c>>2]-12>>2];x[114409]=0;c=S(153,b+c|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}b=x[d+12>>2];Pf(a);hb=d+160|0;a=c?0:b;break a}d=N()|0;Pf(a);Q(d|0);p()}return a|0}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=0;RE(a,c+12|0,1);d=x[c+12>>2];e=d>>>2&3;v[c+11|0]=e;if(e){v[c+4|0]=3;d=y[tc(c+4|0,c+11|0)|0];v[c+4|0]=0;v[c|0]=0;v[c+10|0]=0;a:{if(!d){break a}Jh(a,c+4|0);if((d|0)==1){break a}Jh(a,c);if(d>>>0<3){break a}Jh(a,c+10|0);f=y[c+10|0]<<24}d=y[c+12|0]|(y[c+4|0]<<8|y[c|0]<<16|f);x[c+12>>2]=d}x[c+4>>2]=d>>>4;x[c>>2]=1e6;kw(b,x[Mb(c+4|0,c)>>2]);if(Cb(b)){d=0;while(1){sk(a,pc(b,d),1);d=d+1|0;if(Cb(b)>>>0>d>>>0){continue}break}}d=x[c+12>>2]>>>4|0;b=Cb(b);e=d-b|0;x[c+12>>2]=e;if((b|0)!=(d|0)){Cl(a,e,-1)}hb=c+16|0}function ZH(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a:{b:{c:{c=a+8|0;d:{if(!Kl(c)){if((b|0)<0|(Gs(c)|0)<=(b|0)){break d}c=(y[mq(x[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=Kl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ec(8);x[114409]=0;c=O(122,d+4|0,2427)|0;b=x[114409];x[114409]=0;e:{if((b|0)!=1){a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break e}b=N()|0;ic(a)}Q(b|0);p()}b=b+1<<2;a=a+32|0;c=1;if(!x[(b+x[a>>2]|0)+900380>>2]){break b}c=(y[x[(b+x[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}hb=d+16|0;return c|0}p()}function Q6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{c:{if((e|0)==1){break c}x[114409]=0;V(2164,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}e=x[a+24>>2];b=uc(d+8|0,b);x[114409]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;W(2205,e|0,d|0,(c|0)!=0|0,1);c=x[114409];x[114409]=0;b=1;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5991,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}hb=d+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function AY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[114409]=0;V(2164,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break d}c=x[a+24>>2];b=uc(d+8|0,b);x[114409]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=eE(c,d,1);e=x[114409];x[114409]=0;c=lb;if((e|0)!=1){break c}}Y(R(0)|0)|0;x[114409]=0;W(2113,4865,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_();b=0;c=0}hb=d+16|0;a=c;break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}ib=a;return b|0}function Fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=xl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1065,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ok(d+12|0,an(a,Ac(a)+1|0),Ac(a),e);f=x[c+8>>2];x[114409]=0;T(1065,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114409]=0;P(1060,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Ut(c);hb=d+32|0;break b}a=N()|0;Ut(c);Q(a|0);p()}}function zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=cl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1015,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=qo(d+12|0,bl(a,vd(a)+1|0),vd(a),e);f=x[c+8>>2];x[114409]=0;T(1015,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114409]=0;P(1016,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}yQ(c);hb=d+32|0;break b}a=N()|0;yQ(c);Q(a|0);p()}}function kca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=cl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1659,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=qo(d+12|0,bl(a,vd(a)+1|0),vd(a),e);f=x[c+8>>2];x[114409]=0;T(1659,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114409]=0;P(1660,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}GL(c);hb=d+32|0;break b}a=N()|0;GL(c);Q(a|0);p()}}function Ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=No(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1233,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+32;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=or(d+12|0,Hm(a,ze(a)+1|0),ze(a),e);f=x[c+8>>2];x[114409]=0;T(1233,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+32;x[114409]=0;P(1234,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Ht(c);hb=d+32|0;break b}a=N()|0;Ht(c);Q(a|0);p()}}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1719,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(1719,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(1712,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}yn(c);hb=d+32|0;break b}a=N()|0;yn(c);Q(a|0);p()}}function a6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=Qm(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(2250,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+16;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=wr(d+12|0,xr(a,qd(a)+1|0),qd(a),e);f=x[c+8>>2];x[114409]=0;T(2250,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+16;x[114409]=0;P(2251,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}CI(c);hb=d+32|0;break b}a=N()|0;CI(c);Q(a|0);p()}}function WN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=xl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1333,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ok(d+12|0,an(a,Ac(a)+1|0),Ac(a),e);f=x[c+8>>2];x[114409]=0;T(1333,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114409]=0;P(1334,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}xt(c);hb=d+32|0;break b}a=N()|0;xt(c);Q(a|0);p()}}function Sca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1618,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(1618,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(1619,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}TL(c);hb=d+32|0;break b}a=N()|0;TL(c);Q(a|0);p()}}function vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1517,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(1517,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(1518,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}nM(c);hb=d+32|0;break b}a=N()|0;nM(c);Q(a|0);p()}}function aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1108,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=tu(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(1108,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(1109,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}vP(c);hb=d+32|0;break b}a=N()|0;vP(c);Q(a|0);p()}}function _aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1752,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(1752,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(1753,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}SK(c);hb=d+32|0;break b}a=N()|0;SK(c);Q(a|0);p()}}function R9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(1886,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(1886,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(1883,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Ps(c);hb=d+32|0;break b}a=N()|0;Ps(c);Q(a|0);p()}}function Ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=Qm(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(613,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+16;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=wr(d+12|0,xr(a,qd(a)+1|0),qd(a),e);f=x[c+8>>2];x[114409]=0;T(613,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+16;x[114409]=0;P(614,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Bu(c);hb=d+32|0;break b}a=N()|0;Bu(c);Q(a|0);p()}}function Ana(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=xl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(740,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ok(d+12|0,an(a,Ac(a)+1|0),Ac(a),e);f=x[c+8>>2];x[114409]=0;T(740,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114409]=0;P(175,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Pr(c);hb=d+32|0;break b}a=N()|0;Pr(c);Q(a|0);p()}}function uH(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[456932]){f=456933,g=Va()|0,v[f|0]=g;v[456932]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[456933]){break c}d=+Ua();break a}x[114232]=28;return-1}d=+Wa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(sqa(e,a,1e3,0)>>>0)+ +(lb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function opa(a,b){a=a|0;b=b|0;var c=0,d=0;zd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=a+4|0;x[b+12>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+8|0;x[b+16>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+12|0;c=y[c|0]|y[c+1|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=a+14|0;if(y[c|0]){d=y[c|0]+1|0}else{d=256}w[b+30>>1]=d;w[b+34>>1]=z[b+34>>1]&32767|!y[c|0]<<15;a=a+15|0;if(!(!(v[a|0]&1)|A[b+16>>2]<=A[b+12>>2])){w[b+34>>1]=z[b+34>>1]|8}if(y[a|0]&2){w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;x[b+12>>2]=x[b+12>>2]>>>1;x[b+16>>2]=x[b+16>>2]>>>1}}function Wma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=cl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(785,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=qo(d+12|0,bl(a,vd(a)+1|0),vd(a),e);f=x[c+8>>2];x[114409]=0;T(785,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114409]=0;P(786,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}wS(c);hb=d+32|0;break b}a=N()|0;wS(c);Q(a|0);p()}}function Tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=cl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(514,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=qo(d+12|0,bl(a,vd(a)+1|0),vd(a),e);f=x[c+8>>2];x[114409]=0;T(514,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114409]=0;P(515,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}OU(c);hb=d+32|0;break b}a=N()|0;OU(c);Q(a|0);p()}}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=cl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(607,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=qo(d+12|0,bl(a,vd(a)+1|0),vd(a),e);f=x[c+8>>2];x[114409]=0;T(607,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114409]=0;P(608,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}WT(c);hb=d+32|0;break b}a=N()|0;WT(c);Q(a|0);p()}}function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=lU(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(551,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+48;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=jU(d+12|0,kU(a,aj(a)+1|0),aj(a),e);f=x[c+8>>2];x[114409]=0;T(551,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+48;x[114409]=0;P(552,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Fu(c);hb=d+32|0;break b}a=N()|0;Fu(c);Q(a|0);p()}}function UW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=No(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(251,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+32;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=or(d+12|0,Hm(a,ze(a)+1|0),ze(a),e);f=x[c+8>>2];x[114409]=0;T(251,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+32;x[114409]=0;P(241,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}nr(c);hb=d+32|0;break b}a=N()|0;nr(c);Q(a|0);p()}}function Bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;zd(b,0);c=d+8|0;BQ(c,a+1|0);e=d+20|0;Kc(e,c);x[114409]=0;O(350,b+43|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(d+20|0);c=a+78|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8;c=a+58|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+62|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+66|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;zc(b+8|0,x[b>>2]);zc(b+4|0,x[b+8>>2]);hb=d+32|0;return}a=N()|0;xb(d+20|0);Q(a|0);p()}function A1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=xl(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(174,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ok(d+12|0,an(a,Ac(a)+1|0),Ac(a),e);f=x[c+8>>2];x[114409]=0;T(174,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114409]=0;P(175,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Pr(c);hb=d+32|0;break b}a=N()|0;Pr(c);Q(a|0);p()}}function uV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=bh(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(361,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+2;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Eo(d+12|0,hj(a,rc(a)+1|0),rc(a),e);f=x[c+8>>2];x[114409]=0;T(361,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+2;x[114409]=0;P(360,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Tj(c);hb=d+32|0;break b}a=N()|0;Tj(c);Q(a|0);p()}}function WW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(323,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(323,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(319,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}er(c);hb=d+32|0;break b}a=N()|0;er(c);Q(a|0);p()}}function P6(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{if((d|0)==1){break c}x[114409]=0;V(2164,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}d=x[a+24>>2];b=uc(e+8|0,b);x[114409]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;bb(2207,d|0,e|0,+c,1);d=x[114409];x[114409]=0;b=1;if((d|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2353,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}hb=e+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function K5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;d=hb-32|0;hb=d;Qt(d+24|0,a,b);h=d+16|0;i=d+12|0;g=x[d+28>>2];b=hb-32|0;hb=b;e=x[d+24>>2];x[b+24>>2]=e;x[b+28>>2]=c;a:{b:{if((e|0)!=(g|0)){while(1){c=Vb(b+12|0,x[e>>2]);x[114409]=0;O(2337,b+28|0,c|0)|0;j=x[114409];x[114409]=0;if((j|0)==1){break b}xb(c);e=e+4|0;x[b+24>>2]=e;if((e|0)!=(g|0)){continue}break}}Dc(h,b+24|0,b+28|0);hb=b+32|0;break a}a=N()|0;xb(c);Q(a|0);p()}k=d,l=Xx(a,x[d+16>>2]),x[k+12>>2]=l;x[d+8>>2]=x[d+20>>2];Dc(f+8|0,i,d+8|0);hb=d+32|0;hb=f+16|0;return x[f+12>>2]}function G1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=re(b,-1);d=y[a+52|0];a:{if(e){if(d){break a}b=x[a+48>>2];f=a,g=re(b,-1)^1,v[f+52|0]=g;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(as(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Zr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function iV(a,b,c){var d=0,e=0,f=0;d=hb-48|0;hb=d;e=d+28|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{if((f|0)==1){break c}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}x[114409]=0;W(447,d+4|0,3,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(370,d+16|0,d+4|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;O(348,b|0,d+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}xb(d+16|0);Jc(d+28|0);hb=d+48|0;return!c|(a|0)!=0}a=N()|0;break a}a=N()|0;xb(d+16|0)}Jc(d+28|0);Q(a|0);p()}function hV(a,b,c){var d=0,e=0,f=0;d=hb-48|0;hb=d;e=d+28|0;uf(e,a,c);a=x[e>>2];x[114409]=0;e=S(445,e|0)|0;f=x[114409];x[114409]=0;a:{b:{c:{if((f|0)==1){break c}x[114409]=0;e=S(446,e|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break c}x[114409]=0;W(447,d+4|0,3,e|0,a|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(370,d+16|0,d+4|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;O(358,b|0,d+16|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}xb(d+16|0);Jc(d+28|0);hb=d+48|0;return!c|(a|0)!=0}a=N()|0;break a}a=N()|0;xb(d+16|0)}Jc(d+28|0);Q(a|0);p()}function du(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;aR(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function Ry(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(101,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Rf(d+12|0,Fe(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114409]=0;T(101,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114409]=0;P(102,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Ek(c);hb=d+32|0;break b}a=N()|0;Ek(c);Q(a|0);p()}}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Db(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=(Db(y[c|0])|Db(y[c+1|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Db(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=(Db(y[c|0])|Db(y[c+1|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;x[f+8>>2]=x[a>>2]<<1;c=f+8|0;e=x[Mb(c,f+12|0)>>2];x[f+8>>2]=x[a>>2]<<1;x[f+4>>2]=x[f+12>>2]-e;i=e>>>1|0;j=x[Mb(c,f+4|0)>>2];c=Db(b);if(e>>>0>=2){g=x[a+20>>2];e=i;h=d;while(1){h=(Db(y[c|0])+h|0)+(Db(y[c+1|0])<<8)|0;w[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Db(b);if(j>>>0>=2){g=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;e=h;while(1){d=(Db(y[c|0])+d|0)+(Db(y[c+1|0])<<8)|0;w[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}hb=f+16|0;return h+i<<1}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Db(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=(Db(y[c+1|0])|Db(y[c|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Db(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=(Db(y[c+1|0])|Db(y[c|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;x[f+8>>2]=x[a>>2]<<1;c=f+8|0;e=x[Mb(c,f+12|0)>>2];x[f+8>>2]=x[a>>2]<<1;x[f+4>>2]=x[f+12>>2]-e;i=e>>>1|0;j=x[Mb(c,f+4|0)>>2];c=Db(b);if(e>>>0>=2){g=x[a+20>>2];e=i;h=d;while(1){h=(Db(y[c+1|0])+h|0)+(Db(y[c|0])<<8)|0;w[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Db(b);if(j>>>0>=2){g=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;e=h;while(1){d=(Db(y[c+1|0])+d|0)+(Db(y[c|0])<<8)|0;w[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}hb=f+16|0;return h+i<<1}function jJ(a,b){var c=0,d=0;c=x[a>>2];x[a>>2]=b;if(c){x[114409]=0;S(1490,c|0)|0;a=x[114409];x[114409]=0;a:{if((a|0)!=1){a=x[c+4>>2];if(a){b=hb-16|0;hb=b;d=Bb(b+12|0,a);x[114409]=0;V(1491,d|0);d=x[114409];x[114409]=0;b:{if((d|0)!=1){hb=b+16|0;break b}R(0)|0;zb();p()}_b(a)}x[c+4>>2]=0;QM(c+1304500|0);My(c+1304436|0);xb(c+1304424|0);xb(c+1304412|0);xb(c+1304400|0);Ly(c+1304396|0);Ky(c+1304392|0);pt(c+1304360|0);b=c+946300|0;a=c+906300|0;while(1){b=Kp(b-160|0);if((a|0)!=(b|0)){continue}break}sz(c+484360|0);LM(c+484344|0);Me(c+480248|0);break a}R(0)|0;zb();p()}_b(c)}}function OC(a,b){var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=c;a:{if(!c){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){c=x[c>>2]}else{x[e+12>>2]=d-16;c=x[$c(c,e+12|0)>>2]}x[a+8>>2]=c;if(!(y[b+88|0]&2)|!y[b+816|0]){break a}b:{c:{d:{if(!((y[x[b+104>>2]+34|0]&8)>>>3&(x[b+88>>2]&2050)==2)){c=x[b+104>>2];break d}c=x[b+104>>2];if(x[b+80>>2]!=x[c+12>>2]){break d}d=x[b+84>>2];if((d|0)==x[c+16>>2]){break c}}b=x[b+84>>2];if((b|0)!=x[c+8>>2]){break a}b=(x[c>>2]-b|0)+48|0;break b}b=(x[c>>2]-d|0)+112|0}f=a,g=x[a>>2]+D(Ko(c),b)|0,x[f+4>>2]=g}hb=e+16|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;Zc(a+8|0);Yd(d+8|0,x[Bb(d+4|0,a)>>2]);a:{if(b){x[114409]=0;P(1061,a|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}f=hb-16|0;hb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];if((b|0)!=(e|0)){while(1){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}Jb(c);hb=f+16|0}b=d+8|0;Xd(b);RP(b);hb=d+16|0;return a|0}a=N()|0;RP(d+8|0);Q(a|0);p()}function y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=re(b,-1);d=y[a+52|0];a:{if(e){if(d){break a}b=x[a+48>>2];f=a,g=re(b,-1)^1,v[f+52|0]=g;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(as(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Zr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;f=sh(a);a:{b:{c:{d:{e:{e=b+24|0;if(z[x[e>>2]+480188>>1]){a=0;while(1){d=x[e>>2];x[114409]=0;P(2316,c+8|0,(d+(a<<5)|0)+480289|0);d=x[114409];x[114409]=0;if((d|0)==1){break e}x[114409]=0;T(2309,c+20|0,b|0,c+8|0);d=x[114409];x[114409]=0;if((d|0)==1){break d}x[114409]=0;P(1631,f|0,c+20|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}xb(c+20|0);xb(c+8|0);a=a+1|0;if(a>>>0<z[x[e>>2]+480188>>1]){continue}break}}hb=c+32|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;xb(c+20|0)}xb(c+8|0)}pd(f);Q(a|0);p()}function T6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{c:{if((d|0)==1){break c}x[114409]=0;V(2164,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}d=x[a+24>>2];b=uc(c+8|0,b);x[114409]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+ka(2202,d|0,c|0,1);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2390,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}hb=c+16|0;return+e}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Zj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=x[a+28>>2];if((c|0)>=(b|0)){f=x[a+24>>2];break a}i=a+32|0;g=x[a+20>>2];d=x[a+16>>2];e=c;while(1){b:{if(d>>>0>=g>>>0){g=Lv(a,i,1024);x[a+16>>2]=0;x[a+20>>2]=g;if(!g){break b}d=0;e=x[a+28>>2]}h=d+1|0;x[a+16>>2]=h;d=y[(a+d|0)+32|0];c=e+8|0;x[a+28>>2]=c;f=x[a+24>>2]|d<<e;x[a+24>>2]=f;d=h;e=c;if((c|0)<(b|0)){continue}break a}break}e=ec(8);x[114409]=0;b=S(237,e|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){a=N()|0;ic(e);Q(a|0);p()}da(b|0,75852,238);p()}x[a+28>>2]=c-b;x[a+24>>2]=f>>>b;return(-1<<b^-1)&f}function U6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{c:{if((c|0)==1){break c}x[114409]=0;V(2164,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}c=x[a+24>>2];b=uc(d+8|0,b);x[114409]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(2200,c|0,d|0,1)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,6022,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}hb=d+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function EV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=xc(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>>0){GC(b,e);break d}d=yb(b);d=ci(g+12|0,bi(b,xc(b)+e|0),xc(b),d);x[114409]=0;P(341,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(342,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}Dh(d)}hb=g+32|0;break b}a=N()|0;Dh(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){uv(b,x[b>>2]+c|0)}}c=Qb(a,c);if(c){d=hb-16|0;hb=d;e=f+8|0;jc(e,x[b>>2],xc(b));hb=d+16|0;Cd(a,e)}hb=f+16|0;return c|0}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){a=x[b+8>>2];e=(x[b+12>>2]<<1)+j|0;a=(a>>>21&2040)+32976|0;a=(((D(w[e>>1],w[a+2>>1])+D(w[e-2>>1],w[a>>1])|0)+D(w[e+2>>1],w[a+4>>1])|0)+D(w[e+4>>1],w[a+6>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function _o(a,b){var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=xh(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(184,a|0,e|0,b|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+1;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ci(d+12|0,bi(a,xc(a)+1|0),xc(a),e);f=x[c+8>>2];x[114409]=0;T(184,e|0,f|0,b|0);b=x[114409];x[114409]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+1;x[114409]=0;P(183,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Tm(c);hb=d+32|0;break b}a=N()|0;Tm(c);Q(a|0);p()}}function PS(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ae(d+24|0,a,b);b=x[d+24>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d+28>>2];x[a+12>>2]=b;x[a+4>>2]=c;if(qc(a+12|0,a+8|0)){while(1){f=a+12|0;b=xA(f);g=a+4|0;c=xA(g);h=y[b+4|0]|y[b+5|0]<<8;v[c+4|0]=h;v[c+5|0]=h>>>8;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;wA(f);wA(g);if(qc(f,a+8|0)){continue}break}}Dc(d+16|0,a+12|0,a+4|0);hb=a+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(e+8|0,d+12|0,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(re(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){if((wj(c+23|0,1,1,x[a+32>>2])|0)!=1){break b}break c}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=as(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((wj(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((wj(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}a=bs(b);break a}a=-1}hb=c+32|0;return a|0}function CG(a){var b=0,c=0;a:{b=x[a+4>>2];b:{if(!x[(x[x[b>>2]-12>>2]+b|0)+24>>2]){break b}b=x[a+4>>2];if(!Nf(x[x[b>>2]-12>>2]+b|0)){break b}b=x[a+4>>2];if(!(x[(x[x[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(TG()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[114409]=0;b=S(2463,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[114409]=0;P(2464,a+b|0,1);a=x[114409];x[114409]=0;if((a|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function ooa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-48|0;hb=f;Qi(f+12|0,f+11|0,c);x[114409]=0;c=f+24|0;T(197,c|0,f+10|0,d|0);d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){c:{x[114409]=0;c=f+36|0;T(197,c|0,f+9|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;P(214,f|0,f+12|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Nm(f+12|0);hb=f+48|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break a}a=N()|0;Nm(f+12|0)}Q(a|0);p()}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Db(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=Db(y[c|0])|Db(y[c+1|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Db(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=Db(y[c|0])|Db(y[c+1|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Uja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-48|0;hb=f;Qi(f+12|0,f+11|0,c);x[114409]=0;c=f+24|0;T(213,c|0,f+10|0,d|0);d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){c:{x[114409]=0;c=f+36|0;T(197,c|0,f+9|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;P(214,f|0,f+12|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Nm(f+12|0);hb=f+48|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break a}a=N()|0;Nm(f+12|0)}Q(a|0);p()}function Uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Db(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=Db(y[c+1|0])|Db(y[c|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Db(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=Db(y[c+1|0])|Db(y[c|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>2>>>0){NQ(b,e);break d}d=yb(b);d=tu(g+12|0,Fe(b,Lb(b)+e|0),Lb(b),d);x[114409]=0;P(977,d|0,e|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}x[114409]=0;P(978,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)==1){break c}IQ(d)}hb=g+32|0;break b}a=N()|0;IQ(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<2)|0;Lb(b);JQ(b,d);sg(b)}}c=Qb(a,c<<2);if(c){d=f+8|0;CA(d,b);Cd(a,d)}hb=f+16|0;return c|0}function VX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-48|0;hb=f;Om(f+12|0,f+11|0,c);x[114409]=0;c=f+24|0;T(213,c|0,f+10|0,d|0);d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){c:{x[114409]=0;c=f+36|0;T(213,c|0,f+9|0,e|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;P(214,f|0,f+12|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Nm(f+12|0);hb=f+48|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break a}a=N()|0;Nm(f+12|0)}Q(a|0);p()}function kx(a,b,c){var d=0,e=E(0),f=0,g=0,h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=0;d=hb-32|0;hb=d;h=B[a+12>>2];e=B[a+24>>2];i=B[a+36>>2];j=B[a+48>>2];NH(E(-B[a>>2]),E(h+e),E(i+j),d+20|0);NH(B[a+60>>2],E(j-i),E(e-h),d+8|0);B[d+12>>2]=-B[d+12>>2];a=0;while(1){f=a<<2;g=f+c|0;h=B[g>>2];n=g;g=f+45920|0;e=B[g>>2];i=B[f+(d+20|0)>>2];j=B[f+(d+8|0)>>2];k=B[g+12>>2];B[n>>2]=E(e*i)-E(j*k);g=b+f|0;l=B[(0-a<<2)+45928>>2];f=5-a<<2;m=B[f+45920>>2];e=E(E(e*j)+E(k*i));B[g>>2]=E(h*l)-E(m*e);B[b+f>>2]=E(m*h)+E(e*l);a=a+1|0;if((a|0)!=3){continue}break}hb=d+32|0}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){a=x[b+8>>2];e=x[b+12>>2]+j|0;a=(a>>>21&2040)+32976|0;a=(((D(v[e|0],w[a+2>>1])+D(v[e-1|0],w[a>>1])|0)+D(v[e+1|0],w[a+4>>1])|0)+D(v[e+2|0],w[a+6>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];h=x[a>>2];x[b+8>>2]=h;x[b+12>>2]=e;i=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=i;a:{if(!d){i=f>>12;j=g>>12;break a}while(1){h=x[a+32>>2];g=x[a+28>>2]+g|0;j=g>>12;e=w[(x[b+12>>2]<<1)+k>>1];x[c>>2]=x[c>>2]+D(j,e);f=f+h|0;i=f>>12;x[c+4>>2]=x[c+4>>2]+D(e,i);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}h=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=f;x[a+20>>2]=j;x[a+36>>2]=g;x[a+24>>2]=i;hb=b+16|0}function Ov(a){var b=0,c=0,d=0,e=0;a:{if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;b=No(d+4|0,a,1);c=yb(a);e=x[b+4>>2];x[114409]=0;P(240,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)!=1){x[b+4>>2]=x[b+4>>2]+32;Jb(b);hb=d+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}d=hb-32|0;hb=d;c=yb(a);b=or(d+12|0,Hm(a,ze(a)+1|0),ze(a),c);e=x[b+8>>2];x[114409]=0;P(240,c|0,e|0);c=x[114409];x[114409]=0;b:{c:{if((c|0)==1){break c}x[b+8>>2]=x[b+8>>2]+32;x[114409]=0;P(241,a|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}nr(b);hb=d+32|0;break b}a=N()|0;nr(b);Q(a|0);p()}}eh(a)}function v1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(re(b,-1)){break c}x[c+20>>2]=b;if(y[a+44|0]){if((wj(c+20|0,4,1,x[a+32>>2])|0)!=1){break b}break c}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=as(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((wj(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((wj(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}a=bs(b);break a}a=-1}hb=c+32|0;return a|0}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];h=x[a>>2];x[b+8>>2]=h;x[b+12>>2]=e;i=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=i;a:{if(!d){i=f>>12;j=g>>12;break a}while(1){h=x[a+32>>2];g=x[a+28>>2]+g|0;j=g>>12;e=v[x[b+12>>2]+k|0]<<8;x[c>>2]=x[c>>2]+D(j,e);f=f+h|0;i=f>>12;x[c+4>>2]=x[c+4>>2]+D(e,i);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}h=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=f;x[a+20>>2]=j;x[a+36>>2]=g;x[a+24>>2]=i;hb=b+16|0}function qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+4>>2]=0;yb(c);Zc(b+8|0);Yd(a+4|0,x[Bb(a,b)>>2]);b:{d=rc(c);if(!d){break b}x[114409]=0;P(944,b|0,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[c+4>>2];f=x[c>>2];x[114409]=0;W(1250,b|0,f|0,e|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){break b}}b=N()|0;Vn(a+4|0);Q(b|0);p()}d=a+4|0;Xd(d);Vn(d);hb=a+16|0;x[114409]=0;O(4,b+12|0,c+12|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){x[b+24>>2]=x[c+24>>2];w[b+28>>1]=z[c+28>>1];break a}a=N()|0;vf(b);Q(a|0);p()}}function j5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;f=e+12|0;c=Re(12);b=hb-16|0;hb=b;x[c>>2]=0;x[c+4>>2]=0;x[b+12>>2]=0;d=yb(a);x[114409]=0;U(2300,c+8|0,b+12|0,d|0)|0;d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];d=x[yb(a)>>2];g=yb(c),h=d,x[g>>2]=h;g=yb(a),h=0,x[g>>2]=h;x[a>>2]=0;x[a+4>>2]=0;hb=b+16|0;break b}break a}b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=c;a=U(2301,f|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;c:{if((c|0)!=1){hb=b+16|0;break c}break a}hb=e+16|0;return x[a>>2]}R(0)|0;zb();p()}function dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;x[114409]=0;c=O(231,a|0,1)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}x[114409]=0;P(772,b|0,64);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;c=S(425,a|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}if(!c){break c}while(1){x[114409]=0;d=O(773,a|0,e+15|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}f=d;d=y[e+15|0];if(f&d>>>0<64){sc(KS(b,d),e+15|0,33)}c=c-1|0;if(c&255){continue}break}}Ab(a);hb=e+48|0;return}}b=N()|0;Ab(a);Q(b|0);p()}function Og(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Gf(23296,d+14|0)>>1];c=rc(a);a:{if(b>>>0>c>>>0){e=hb-32|0;hb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>1>>>0){Rq(a,c,f);break d}b=yb(a);b=Eo(e+12|0,hj(a,rc(a)+c|0),rc(a),b);x[114409]=0;T(359,b|0,c|0,f|0);c=x[114409];x[114409]=0;if((c|0)==1){break c}x[114409]=0;P(360,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}Tj(b)}hb=e+32|0;break b}a=N()|0;Tj(b);Q(a|0);p()}break a}if(b>>>0<c>>>0){vo(a,x[a>>2]+(b<<1)|0)}}hb=d+16|0}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;f=z[il(a,b)>>1];a:{b:{if(!dq(a,b)){break b}c=x[a+24>>2]+484360|0;i=d,j=bc(c),x[i+12>>2]=j;i=d,j=dc(c),x[i+8>>2]=j;if(!Hb(d+12|0,d+8|0)){break b}while(1){g=x[d+12>>2];h=Nu(g);if(h){e=0;while(1){c:{if(!((a|0)!=(g|0)|(b|0)!=(e|0))|z[vc(g,e)>>1]!=(f|0)){break c}c=mL(x[a+24>>2]+484344|0,f,0);if((c|0)==65535){break c}i=il(a,b),j=c,w[i>>1]=j;break a}e=e+1|0;if((h|0)!=(e|0)){continue}break}}c=d+12|0;Mo(c);if(Hb(c,d+8|0)){continue}break}}c=f}hb=d+16|0;return c&65535}function J$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;d=Cb(a);e=Vm(a);g=ju(b,c);a:{if(!g){break a}b:{if(Rb(a)>>>0<=b>>>0){h=Rb(a)+(Cb(a)<<2)>>>0>=b>>>0}else{h=0}if(!h){if(e-d>>>0<g>>>0){tE(a,e,(d+g|0)-e|0,d,d)}e=Rb(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}wg(e,b);b=b+4|0;e=e+4|0;continue}}e=hb-16|0;hb=e;d=f+4|0;RF(d,b,c);hb=e+16|0;b=Rb(d);c=Cb(d);x[114409]=0;U(2657,a|0,b|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){Pc(d);break a}a=N()|0;Pc(d);Q(a|0);p()}x[f+4>>2]=0;wg(e,f+4|0);ch(a,d+g|0)}hb=f+16|0;return a|0}function BC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=y[a+8|0];g=x[a>>2];a=x[a+4>>2];d=Rb(b);b=Cb(b);c=hb-16|0;hb=c;x[c+8>>2]=b;x[c+12>>2]=a;e=x[Mb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=g;break b}b=e;a=g;while(1){h=y[d|0];v[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{if((f-1&255)>>>0<=1){d=x[c+12>>2];v[c+7|0]=0;Ms(a,((a+d|0)-e|0)+b|0,c+7|0);break c}if((f-3&255)>>>0>1){break c}d=x[c+12>>2];v[c+6|0]=32;Ms(a,((a+d|0)-e|0)+b|0,c+6|0)}d:{switch(f-1|0){case 0:case 3:v[(x[c+12>>2]+g|0)-1|0]=0;break;default:break d}}hb=c+16|0}function JW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=x[x[a+1056>>2]>>2]-x[a+1060>>2];x[d+8>>2]=16384;e=x[Mb(d+12|0,d+8|0)>>2];x[a+1068>>2]=e;c=17;x[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Zj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}_q(d+4|0,Zj(a,4));break b}if(c>>>0>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}_q(d+4|0,e-c|0);break b}KC(a,e,f,b);break b}c=e&(f^-1);if(e&f){x[d+4>>2]=c+1;break b}KC(a,c,0,b)}if(!x[a+1068>>2]){break a}c=x[d+4>>2];if((c|0)<18){continue}break}}hb=d+16|0}function jC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((y[a|0]|y[a+1|0]<<8)!=26217){if((y[a|0]|y[a+1|0]<<8)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}d=a+110|0;b=a+2|0;while(1){c:{if((y[b|0]-1&255)>>>0>30){break c}c=c+1|0;if((c&255)>>>0<=40){break c}return 0}b=b+1|0;if((d|0)!=(b|0)){continue}break}c=0;while(1){b=0;d=a+c|0;e=v[d+113|0];if((e|0)<-2){break a}f=y[d+241|0];if(!f&(e|0)>=0|f>>>0>15|y[d+369|0]>=64){break a}b=1;c=c+1|0;if(c>>>0<128){continue}break}}return b}function X$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;c=hb-128|0;hb=c;x[c+12>>2]=c+116;d=c+16|0;DF(a+8|0,d,c+12|0,e,f,g);g=hb-16|0;hb=g;h=g+8|0;a=hb-32|0;hb=a;Iw(a+24|0,d,x[c+12>>2]);i=a+16|0;j=a+12|0;k=x[a+28>>2];e=hb-16|0;hb=e;f=x[a+24>>2];x[e+8>>2]=f;x[e+12>>2]=b;while(1){if((f|0)!=(k|0)){HG(e+12|0,v[f|0]);f=f+1|0;x[e+8>>2]=f;continue}break}Dc(i,e+8|0,e+12|0);hb=e+16|0;l=a,m=Hw(d,x[a+16>>2]),x[l+12>>2]=m;x[a+8>>2]=x[a+20>>2];Dc(h,j,a+8|0);hb=a+32|0;hb=g+16|0;hb=c+128|0;return x[g+12>>2]}function IW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=x[x[a+1056>>2]>>2]-x[a+1060>>2];x[d+8>>2]=32768;e=x[Mb(d+12|0,d+8|0)>>2];x[a+1068>>2]=e;c=9;x[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Zj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}_q(d+4|0,Zj(a,3));break b}if(c>>>0>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}_q(d+4|0,e-c|0);break b}JC(a,e,f,b);break b}c=e&(f^-1);if(e&f){x[d+4>>2]=c+1;break b}JC(a,c,0,b)}if(!x[a+1068>>2]){break a}c=x[d+4>>2];if((c|0)<10){continue}break}}hb=d+16|0}function oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;d=e+8|0;Ng(d,2,a+6|0);f=e+20|0;Kc(f,d);x[114409]=0;O(348,b+492|0,f|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){xb(e+20|0);f=b+236|0;g=c+1|0;c=0;d=0;while(1){h=y[(a+c|0)+38|0];i=fd(f,c),j=g+h|0,w[i>>1]=j;d=d+1|0;c=d&255;if(c>>>0<128){continue}break}c=a+226|0;x[b>>2]=(y[c|0]|y[c+1|0]<<8)<<5;ly(a+180|0,b+48|0,0);ly(a+228|0,b+88|0,2);ly(a+276|0,b+68|0,1);a=a+324|0;if(!(y[a|0]|y[a+1|0]<<8)){Sb(b+236|0,0,256)}hb=e+32|0;return}a=N()|0;xb(e+20|0);Q(a|0);p()}function sN(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}c=x[a+480180>>2]&1048580?(b&240?-16:15)&b:b;b=c&15;c=c&255;b:{c:{d:{if(!((b|0)!=15|c>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=c>>>3&30;break d}e=x[a+480208>>2]&4096;f=c&240;if(!(!b|(f|0)!=240)){if(!e){break b}b=0-(b<<1)|0;break c}if(e){break b}if(f){if(x[a+480180>>2]&59314208?b:0){break b}b=c>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074444|0;x[d+12>>2]=x[c>>2]+(b<<!(x[a+480180>>2]&59314208));ce(d+12|0,0,256);x[c>>2]=x[d+12>>2]}hb=d+16|0}function wV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-208|0;hb=d;Tu(c,a);sV(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}v[d+12|0]=64;Qg(b,y[tc(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;if(!Lb(b)){break a}a=0;while(1){if(a){c=z[Pb(b,a-1|0)>>1];x[d+12>>2]=1;e=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[e+1|0]&1)<<8|y[e|0];e=z[Yf(d+12|0,d+8|0)>>1];f=Pb(b,a),g=c+e|0,w[f>>1]=g}c=y[((d+16|0)+D(a,3)|0)+2|0];f=Pb(b,a),g=c,v[f+2|0]=g;a=a+1|0;if(Lb(b)>>>0>a>>>0){continue}break}}hb=d+208|0}function ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,26);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function WY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=a>>>0<=1?1:a;a=zE(16,b);if(!a){a:{b=(b+3>>>2|0)+1|0;a=x[115724];if(!a){x[115724]=462924;w[231463]=125;f=462924,g=bw(463424),w[f>>1]=g;a=x[115724]}while(1){b:{if(!a|(a|0)==463424){a=0}else{c=z[a+2>>1];e=b+(b>>>0<c>>>0?c-b&3:0)|0;if(c>>>0>e>>>0){d=c-e|0;w[a+2>>1]=d;a=((d&65535)<<2)+a|0;w[a+2>>1]=e;w[a>>1]=0;a=a+4|0;break a}if(b>>>0>c>>>0){break b}b=z[a>>1];c:{if(!d){f=462896,g=cw(b),x[f>>2]=g;break c}w[d>>1]=b}w[a>>1]=0;a=a+4|0}break a}d=a;a=cw(z[a>>1]);continue}}}return a|0}function LZ(a){a=a|0;if(y[461136]){return x[115283]}if(!y[462240]){v[462240]=1}bd(461952,71160);bd(461964,71192);bd(461976,71228);bd(461988,71252);bd(462e3,71276);bd(462012,71292);bd(462024,71312);bd(462036,71332);bd(462048,71360);bd(462060,71400);bd(462072,71432);bd(462084,71468);bd(462096,71504);bd(462108,71520);bd(462120,71536);bd(462132,71552);bd(462144,71276);bd(462156,71568);bd(462168,71584);bd(462180,71600);bd(462192,71616);bd(462204,71632);bd(462216,71648);bd(462228,71664);v[461136]=1;x[115283]=461952;return 461952}function aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if(AA(a)){x[b>>2]=0;a=0;break a}g=qg(a,f,16);d=Db(y[f|0]);c=d&127;x[b>>2]=c;if(c){while(1){h=h+1|0;e=c>>>0>1;c=c>>>1|0;if(e){continue}break}}e=d<<24>>24;d=(e|0)<0;c=1;b:{if(g>>>0<2|(e|0)>=0){break b}while(1){d=Db(y[c+f|0]);x[b>>2]=d&127|x[b>>2]<<7;h=h+7|0;e=d<<24>>24;d=(e|0)<0;c=c+1|0;if((g|0)==(c|0)){cc(a,g);g=qg(a,f,16);c=0}if(c>>>0>=g>>>0){break b}if((e|0)<0){continue}break}}cc(a,c);if(h>>>0>=33){x[b>>2]=-1;a=0;break a}a=!d}hb=f+16|0;return a|0}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb+-64|0;hb=e;x[e+56>>2]=c;x[e+60>>2]=b;x[e+52>>2]=d;x[e+48>>2]=d;b=Oc(e+20|0,a,e+48|0,e+52|0);x[e+16>>2]=x[b+8>>2];c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;Od(e+32|0,e+8|0);a:{if(Hb(e+60|0,e+56|0)){while(1){b=x[e+52>>2];c=x[e+60>>2];x[114409]=0;T(361,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=e+60|0;ke(b);x[e+52>>2]=x[e+52>>2]+2;if(Hb(b,e+56|0)){continue}break}}a=e+32|0;Nd(a);b=x[e+52>>2];It(a);hb=e- -64|0;return b|0}a=N()|0;It(e+32|0);Q(a|0);p()}function ui(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;lf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;hb=f+16|0}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;tO(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function qN(a,b,c){var d=0;a:{if(x[a+480180>>2]==4){d=y[b+834|0];if(c){v[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{d:{if(!(y[a+480208|0]&16)){break d}d=x[b+700>>2];if(x[a+480180>>2]==4){break d}a=gN(a,c&15);c=sqa(a,a>>31,d,d>>31);a=lb;c=c+32768|0;a=c>>>0<32768?a+1|0:a;a=Ec(tqa(c,a,65536,0),lb);a=a-((a|0)==(d|0))|0;break c}a=(c&255)+d|0;a=(a|0)>=65535?65535:a}x[b+700>>2]=a}}function pka(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-160|0;hb=b;a=mn(b+20|0,a,8);d=x[x[a>>2]-12>>2];x[114409]=0;c=$(125)|0;e=x[114409];x[114409]=0;a:{b:{if((e|0)==1){break b}x[114409]=0;T(126,b+16|0,a+d|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break b}Ob(b+16|0);x[114409]=0;d=O(156,a|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}c=x[x[d>>2]-12>>2];x[114409]=0;d=S(153,c+d|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}c=z[b+14>>1];Pf(a);hb=b+160|0;a=(d?0:c)&65535;break a}b=N()|0;Pf(a);Q(b|0);p()}return a|0}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=hb-16|0;hb=e;c=y[c|0]|y[c+1|0]<<8;w[e+14>>1]=c<<8|c>>>8;c=hb-16|0;hb=c;f=c+4|0;eJ(f,e+14|0);x[114409]=0;g=d+20|0;T(13,g|0,0,f|0);f=x[114409];x[114409]=0;a:{if((f|0)!=1){xb(c+4|0);hb=c+16|0;break a}a=N()|0;xb(c+4|0);Q(a|0);p()}hb=e+16|0;x[114409]=0;P(75,d+8|0,g|0);c=x[114409];x[114409]=0;b:{if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}function ps(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=hb-240|0;hb=h;g=x[c>>2];x[h+232>>2]=g;c=x[c+4>>2];x[h>>2]=a;x[h+236>>2]=c;j=1;a:{b:{c:{if(!(c|(g|0)!=1)){c=a;break c}g=a;while(1){i=(d<<2)+f|0;c=g-x[i>>2]|0;if((Gl(c,a,b)|0)<=0){c=g;break c}d:{if(!((d|0)<2|e)){e=x[i-8>>2];i=g-4|0;if((Gl(i,c,b)|0)>=0){break d}if((Gl(i-e|0,c,b)|0)>=0){break d}}x[(j<<2)+h>>2]=c;g=h+232|0;e=hH(g);qs(g,e);j=j+1|0;d=d+e|0;e=0;g=c;if(x[h+236>>2]|x[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}gH(h,j);Yw(c,b,d,f)}hb=h+240|0}function pj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!we(a)){if(!we(b)){x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;return a|0}e=Rb(b);b=Cb(b);d=hb-16|0;hb=d;a:{if(b>>>0<=10){Ie(a,b);Se(a,e,b);v[d+15|0]=0;$d(a+b|0,d+15|0);break a}c=Io(a);Lo(a,10,b-10|0,c,0,c,b,e)}hb=d+16|0;return a|0}e=Rb(b);b=Cb(b);d=hb-16|0;hb=d;c=Di(a);b:{if(c>>>0>b>>>0){c=x[a>>2];ee(a,b);Se(c,e,b);v[d+15|0]=0;$d(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=x[a+4>>2];Lo(a,f,g,c,0,c,b,e)}hb=d+16|0}return a|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=my(a);a:{b:{c:{d:{while(1){x[114409]=0;a=O(231,b|0,8)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}if(a){x[114409]=0;T(1651,e+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(1652,f|0,e+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}qe(e+8|0);a=Mu(f);if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=(d|0)){continue}}break}hb=e+32|0;return}a=N()|0;break a}a=N()|0;qe(e+8|0);break a}a=N()|0}Rl(f);Q(a|0);p()}function k5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;a:{b:{if(Bi(a)){vp(b+28|0);break b}c=b+16|0;tn(c,a);x[114409]=0;c=S(2298,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}x[b+28>>2]=c;Qf(b+16|0)}if(Bi(a)){c=a+36|0}else{c=x[b+28>>2]}a=x[a+8>>2];c:{if((a|0)==-1){f=b,g=bc(c),x[f+16>>2]=g;f=b,g=dc(c),x[f+12>>2]=g;if(!Hb(b+16|0,b+12|0)){break c}while(1){a=b+16|0;d=C[x[a>>2]>>3]+d;bj(a);if(Hb(a,b+12|0)){continue}break}break c}d=C[Vc(c,a)>>3]}zk(b+28|0);hb=b+32|0;return+d}a=N()|0;Qf(b+16|0);Q(a|0);p()}function Y6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[114409]=0;V(2138,a|0);h=x[114409];x[114409]=0;a:{b:{if((h|0)!=1){c:{h=x[a+24>>2];x[114409]=0;fa(2196,g+4|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}a=g+4|0;b=Ld(Rb(a));xb(a);break b}}Y(R(0)|0)|0;b=0;x[114409]=0;W(2113,6645,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=g+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function X6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[114409]=0;V(2138,a|0);h=x[114409];x[114409]=0;a:{b:{if((h|0)!=1){c:{h=x[a+24>>2];x[114409]=0;fa(2197,g+4|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}a=g+4|0;b=Ld(Rb(a));xb(a);break b}}Y(R(0)|0)|0;b=0;x[114409]=0;W(2113,6600,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=g+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function F5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;x[d+60>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];a=x[a+8>>2];x[d+16>>2]=a;x[d+20>>2]=f;x[114409]=0;x[d+36>>2]=a;x[d+40>>2]=f;x[d+28>>2]=c;x[d+32>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;T(2286,d+44|0,d+8|0,0);a=x[114409];x[114409]=0;a:{b:{if((a|0)!=1){a=x[wp(d+24|0,d+60|0)>>2];x[114409]=0;b=+ua(2287,d+44|0,+b,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Ab(d+44|0);od(d+60|0);hb=d- -64|0;return+b}a=N()|0;break a}a=N()|0;Ab(d+44|0)}od(d+60|0);Q(a|0);p()}function Oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=Lz(a);a:{b:{c:{d:{while(1){x[114409]=0;a=O(231,b|0,8)|0;g=x[114409];x[114409]=0;if((g|0)==1){break b}if(a){x[114409]=0;T(999,e+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}x[114409]=0;P(1e3,f|0,e+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break c}qe(e+8|0);a=Mu(f);if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=(d|0)){continue}}break}hb=e+32|0;return}a=N()|0;break a}a=N()|0;qe(e+8|0);break a}a=N()|0}bm(f);Q(a|0);p()}
function yW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;OG(b);a:{if(!(y[a|0]|y[a+1|0]<<8)){c=a+2|0;if(!(y[c|0]|y[c+1|0]<<8)){break a}}x[b+20>>2]=((y[a|0]|y[a+1|0]<<8)>>>9|0)+80;d=b,e=Yb((y[a|0]|y[a+1|0]<<8)>>>5&15,1,12)-1|0,x[d+16>>2]=e;d=b,e=Yb((y[a|0]|y[a+1|0]<<8)&31,1,31),x[d+12>>2]=e;c=a+2|0;d=b,e=Yb((y[c|0]|y[c+1|0]<<8)>>>11|0,0,23),x[d+8>>2]=e;d=b,e=Yb((y[c|0]|y[c+1|0]<<8)>>>5&63,0,59),x[d+4>>2]=e;d=b,e=Yb((y[c|0]|y[c+1|0]<<8)<<1&62,0,59),x[d>>2]=e}a=a+4|0;x[b+44>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}function t8(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{b:{if(!a){a=Ld(17381);break b}x[114409]=0;c=O(122,b+8|0,a|0)|0;a=x[114409];x[114409]=0;c:{d:{if((a|0)!=1){x[114409]=0;P(2117,b+20|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}d=b+20|0;a=Ld(Rb(d));xb(d);xb(c);break b}a=R(0)|0;break c}a=R(0)|0;xb(c)}Y(a|0)|0;a=0;x[114409]=0;W(2113,6955,0,0,0);c=x[114409];x[114409]=0;if((c|0)==1){break a}_()}hb=b+32|0;return a|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function QY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(vg(a,x[b+8>>2],e)){Yv(b,c,d);return}a:{if(vg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];mb[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function vba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;e=w[b>>1];b=w[a+30>>1];a:{if(!b){break a}if((e|0)>=0){e=(e|0)%(b|0)|0;break a}e=b+((e^-1)%(b|0)^-1)|0}w[d+14>>1]=e;b:{if(!Yc(c)){pj(bL(a+52|0,d+14|0),c);break b}f=a+52|0;i=d,j=Zx(f,d+14|0),x[i+8>>2]=j;i=d,j=Zi(f),x[i+4>>2]=j;if(!Yi(d+8|0,d+4|0)){break b}g=hb-16|0;hb=g;a=x[Bb(g+8|0,x[d+8>>2])>>2];h=hb-16|0;hb=h;x[h+12>>2]=a;e=h+12|0;c=x[e>>2];b=UK(f,c);a=mc(f);Vi(vh(e));dh(a,c,1);hb=h+16|0;Bb(g+12|0,b);hb=g+16|0}hb=d+16|0}function Xma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;if(tS(b,e+26|0)){d=e+28|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24)}f=e+8|0;Ad(f,b,g);d=y[e+26|0]|y[e+27|0]<<8|(y[e+28|0]<<16|y[e+29|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[e+30|0]|y[e+31|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;Dm(a+8|0,f);Ab(f);a:{if(!c){break a}d=(g>>>0)%(c>>>0)|0;if(!d){break a}x[114409]=0;O(313,b|0,c-d|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break a}b=N()|0;qe(a);Q(b|0);p()}hb=e+32|0}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0,j=0;e=hb-16|0;hb=e;i=x[a+4>>2];uI(a,b,c,d);g=B[a+28>>2];b=x[a+24>>2];x[e+8>>2]=x[a+20>>2];x[e+12>>2]=b;b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;a=hb-16|0;hb=a;b=x[e+12>>2];x[a+8>>2]=x[e+8>>2];x[a+12>>2]=b;b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;b=0;if(!(!d|g==E(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=Rn(a,f,j);B[h>>2]=B[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}hb=a+16|0;hb=e+16|0}function ZX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{d:{if(h=Yc(b),i=1,j=x[b+12>>2],j?h:i){gd(a);break d}f=hb-16|0;hb=f;d=Cb(b);e=Bf(9998);g=Rb(Mw(c+20|0,d+e|0));Se(g,Rb(b),d);d=d+g|0;Se(d,9998,e);In(d+e|0,1,0);hb=f+16|0;x[114409]=0;P(207,c+8|0,b+12|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}x[114409]=0;T(3,a|0,c+20|0,c+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}xb(c+8|0);xb(c+20|0)}hb=c+32|0;return}b=N()|0;break a}b=N()|0;xb(c+8|0)}xb(c+20|0);Q(b|0);p()}function Xl(a,b,c,d){var e=0;a:{e=a+1074312|0;if($b(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!$b(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+796>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!$b(e,10)){break a}v[b+851|0]=0;w[b+790>>1]=0}}function NZ(a){a=a|0;if(y[461128]){return x[115281]}if(!y[461936]){v[461936]=1}Rc(461648,1541);Rc(461660,1532);Rc(461672,6815);Rc(461684,6571);Rc(461696,1751);Rc(461708,7496);Rc(461720,1608);Rc(461732,2095);Rc(461744,5007);Rc(461756,4990);Rc(461768,4998);Rc(461780,5017);Rc(461792,6059);Rc(461804,9114);Rc(461816,5080);Rc(461828,3946);Rc(461840,1751);Rc(461852,5674);Rc(461864,6459);Rc(461876,6827);Rc(461888,5220);Rc(461900,2817);Rc(461912,1978);Rc(461924,9023);v[461128]=1;x[115281]=461648;return 461648}function SO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=x[a+8>>2];c=f-1|0;d=x[a+12>>2];g=x[a>>2]+D(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){v[b+g|0]=y[x[a+4>>2]+(D(c,d)+b|0)|0];b=b+1|0;d=x[a+12>>2];if((b|0)<(d|0)){continue}break}f=x[a+8>>2]}b=D(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!y[a+16|0]){e=1;c=0;break a}e=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>=0|c)){c=y[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function HM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;f=d+12|0;c=Lb(a);a:{if(c>>>0<b>>>0){e=hb-32|0;hb=e;b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){WB(a,c,f);break c}b=yb(a);b=Rf(e+12|0,Fe(a,Lb(a)+c|0),Lb(a),b);x[114409]=0;T(1534,b|0,c|0,f|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(102,a|0,b|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}Ek(b)}hb=e+32|0;break a}a=N()|0;Ek(b);Q(a|0);p()}if(b>>>0<c>>>0){rM(a,x[a>>2]+(b<<2)|0)}}Gy(a);hb=d+16|0}function $j(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;g=gh(a,e+15|0);c=y[e+15|0];x[b>>2]=(c&252)>>>2;x[b+4>>2]=0;c=c&3;if(c){c=-1<<c;j=(c>>>0>=4294967294?-2:c)^-1;while(1){v[e+15|0]=0;k=gh(a,e+15|0);d=x[b>>2];l=x[b+4>>2];h=y[e+15|0];c=i;f=f+1|0;i=f?c:c+1|0;m=d;c=(f<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=h<<d;d=0}else{c=(1<<d)-1&h>>>32-d;d=h<<d}x[b>>2]=m|d;x[b+4>>2]=c|l;g=g&k;if((f|0)!=(j|0)|i){continue}break}}hb=e+16|0;return g|0}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=Xb(a);a:{b:{c:{if(Ac(b)){a=0;while(1){d:{if(!a){break d}x[114409]=0;O(1328,f|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break d}a=N()|0;break a}d=ud(b,a);x[114409]=0;P(1329,e+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;O(1328,f|0,e+4|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}xb(e+4|0);a=a+1|0;if(Ac(b)>>>0>a>>>0){continue}break}}hb=e+16|0;return}a=N()|0;break a}a=N()|0;xb(e+4|0)}xb(f);Q(a|0);p()}function Fl(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Aja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!He(a)){break b}f=x[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}On(b);Hz(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!eq(b)){break b}if(x[a>>2]!=(d|0)){Sb(b+68|0,0,36)}f=x[b+20>>2];x[114409]=0;f=S(439,f|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}a=x[a+20>>2];x[114409]=0;a=S(439,a|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}sc(f,a+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}return}R(0)|0;zb();p()}function TO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=b?33:32;c=y[a+16|0];j=c?-1:1;k=c?1:-1;e=x[a+8>>2]-1|0;l=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;m=c?0:e;f=x[a+12>>2];g=x[a>>2]+D(f,62)|0;n=x[a+4>>2];d=b?1:-1;o=D(f,d)<<1;b=e;while(1){if((f|0)>0){c=D(b,f);a=0;while(1){w[(a<<1)+g>>1]=z[(a+c<<1)+n>>1];a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+o|0;a:{if((b|0)==(e|0)){a=l;c=j;if((d|0)>0){break a}}a=b+d|0;b=!b&(d|0)<0;a=b?m:a;c=b?k:d}d=c;b=a;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function _6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[114409]=0;V(2138,a|0);g=x[114409];x[114409]=0;a:{b:{if((g|0)!=1){c:{g=x[a+24>>2];x[114409]=0;ia(2194,f+4|0,g|0,b|0,c|0,d|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}a=f+4|0;b=Ld(Rb(a));xb(a);break b}}Y(R(0)|0)|0;b=0;x[114409]=0;W(2113,8280,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=f+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Z6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[114409]=0;V(2138,a|0);g=x[114409];x[114409]=0;a:{b:{if((g|0)!=1){c:{g=x[a+24>>2];x[114409]=0;ia(2195,f+4|0,g|0,b|0,c|0,d|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break c}a=f+4|0;b=Ld(Rb(a));xb(a);break b}}Y(R(0)|0)|0;b=0;x[114409]=0;W(2113,8180,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}hb=f+16|0;return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function fq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=z[a+34>>1];if(!b){if(d&512){YO(a);d=z[a+34>>1]}w[a+34>>1]=d&65023;return}x[a>>2]=4;w[a+34>>1]=d&64958|512;eq(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}function QX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=gd(a);a:{b:{c:{if(Ac(b)){a=0;while(1){d:{if(!a){break d}x[114409]=0;O(164,f|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){break d}a=N()|0;break a}d=ud(b,a);x[114409]=0;P(225,e+4|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break c}x[114409]=0;O(164,f|0,e+4|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}xb(e+4|0);a=a+1|0;if(Ac(b)>>>0>a>>>0){continue}break}}hb=e+16|0;return}a=N()|0;break a}a=N()|0;xb(e+4|0)}xb(f);Q(a|0);p()}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>4;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c|0]);Db(y[c+1|0]);Db(y[c+2|0]);Db(y[c+3|0]);Db(y[c+4|0]);Db(y[c+5|0]);f=a,g=Db(y[c+6|0])|Db(y[c+7|0])<<8,w[f>>1]=g;Db(y[c+8|0]);Db(y[c+9|0]);Db(y[c+10|0]);Db(y[c+11|0]);Db(y[c+12|0]);Db(y[c+13|0]);f=a,g=Db(y[c+14|0])|Db(y[c+15|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<4}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>4;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c+7|0]);Db(y[c+6|0]);Db(y[c+5|0]);Db(y[c+4|0]);Db(y[c+3|0]);Db(y[c+2|0]);f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;Db(y[c+15|0]);Db(y[c+14|0]);Db(y[c+13|0]);Db(y[c+12|0]);Db(y[c+11|0]);Db(y[c+10|0]);f=a,g=Db(y[c+9|0])|Db(y[c+8|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<4}function Zm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((om(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=LF(i+4|0,b,f);h=Rb(f);x[114409]=0;h=U(2633,a|0,h|0,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}Pc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((om(a,c,b)|0)!=(b|0)){break b}}JB(e);j=a}hb=i+16|0;return j|0}a=N()|0;Pc(f);Q(a|0);p()}function uE(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=hb-16|0;hb=i;if((b^-1)+1073741807>>>0>=c>>>0){k=Rb(a);j=i+4|0;if(b>>>0<536870887){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=wl(x[$c(i+4|0,i+12|0)>>2])+1|0}else{c=1073741807}ck(j,a,c);c=x[i+4>>2];if(e){Ph(c,k,e)}if(g){Ph(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Ph((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){ap(k,b)}_e(a,c);Jf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;ee(b,a);x[i+12>>2]=0;wg(c+(a<<2)|0,i+12|0);hb=i+16|0;return}If();p()}function oN(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}f=e+8|0;Kb(f,a+1074312|0,3);if(Ib(f)){break c}if(!(v[(D(b,896)+a|0)+1075856|0]&1)){break a}c=D(d&15,c>>31|(c|0)!=0);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,896)+a|0)+1075856|0]&1){d=e+8|0;Kb(d,a+1074312|0,3);if(!Ib(d)){break a}}c=c<<2}if(!c){break a}d=Qy(a,b);if(!d){break a}a=x[(D(b,896)+a|0)+1075640>>2];if(a){a=y[a+33|0]}else{a=13}mb[x[x[d>>2]+80>>2]](d,c,a<<24>>24,b)}hb=e+16|0}function nn(a){var b=0,c=0,d=0;if(!a){if(x[20980]){b=nn(x[20980])}if(x[20904]){b=nn(x[20904])|b}a=x[114235];if(a){while(1){if(x[a+20>>2]!=x[a+28>>2]){b=nn(a)|b}a=x[a+56>>2];if(a){continue}break}}return b}d=x[a+76>>2]>=0;a:{b:{if(x[a+20>>2]==x[a+28>>2]){break b}mb[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break b}b=-1;break a}b=x[a+8>>2];c=x[a+4>>2];if((b|0)!=(c|0)){b=c-b|0;mb[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}return b}function X0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=y[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=x[114232];x[114232]=0;a=hw(a,e+12|0,d,me());d=lb;g=x[114232];f:{if(g){if(x[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}x[114232]=h;if(x[e+12>>2]==(b|0)){break b}}}}x[c>>2]=4;b=0;a=0;break a}x[c>>2]=4;b=-1;a=-1;break a}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d}hb=e+16|0;lb=a;return b|0}function tH(a){var b=0,c=0,d=0,e=0;b=hb-160|0;hb=b;a=mn(b+20|0,a,8);d=x[x[a>>2]-12>>2];x[114409]=0;c=$(125)|0;e=x[114409];x[114409]=0;a:{if((e|0)==1){break a}x[114409]=0;T(126,b+16|0,a+d|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}Ob(b+16|0);x[114409]=0;d=O(152,a|0,b+12|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[x[d>>2]-12>>2];x[114409]=0;d=S(153,c+d|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b+12>>2];Pf(a);hb=b+160|0;return d?0:c}b=N()|0;Pf(a);Q(b|0);p()}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;d=hb-144|0;hb=d;c=qh(d+8|0);e=x[x[c>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;a:{b:{if((h|0)==1){break b}x[114409]=0;T(126,d+4|0,c+e|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}Ob(d+4|0);x[114409]=0;P(138,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(128,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}ae(c);hb=d+144|0;break a}a=N()|0;ae(c);Q(a|0);p()}hb=f+16|0}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;d=hb-144|0;hb=d;c=qh(d+8|0);e=x[x[c>>2]-12>>2];x[114409]=0;g=$(125)|0;h=x[114409];x[114409]=0;a:{b:{if((h|0)==1){break b}x[114409]=0;T(126,d+4|0,c+e|0,g|0);e=x[114409];x[114409]=0;if((e|0)==1){break b}Ob(d+4|0);x[114409]=0;P(139,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break b}x[114409]=0;P(128,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}ae(c);hb=d+144|0;break a}a=N()|0;ae(c);Q(a|0);p()}hb=f+16|0}function $0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=y[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=x[114232];x[114232]=0;a=hw(a,e+12|0,d,me());d=lb;g=x[114232];g:{if(g){if(x[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}x[114232]=h;if(x[e+12>>2]==(b|0)){break d}}}}x[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}x[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a&65535}function lV(a,b,c){var d=0,e=0,f=0;e=hb-48|0;hb=e;Xe(b);d=e+28|0;uf(d,a,c);a=x[d>>2];x[114409]=0;d=S(445,d|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)==1){break a}x[114409]=0;d=S(446,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}x[114409]=0;W(447,e+4|0,3,d|0,a|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;P(370,e+16|0,e+4|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=b;b=e+16|0;Eb(d,b);xb(b);Jc(e+28|0);hb=e+48|0;return!c|(a|0)!=0}a=N()|0;Jc(e+28|0);Q(a|0);p()}function fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Db(b);if(f){d=x[a+20>>2];b=f;while(1){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=he(E(rf(E((l(2,a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)),r())*h),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){a=~~g;break a}a=-2147483648}i=d,j=Wc(a),w[i>>1]=j;d=d+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<2}function dY(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;c=Vb(b+8|0,12710);x[114409]=0;T(199,b+20|0,a|0,c|0);a=x[114409];x[114409]=0;a:{b:{c:{if((a|0)!=1){xb(c);if(Ac(b+20|0)){break c}a=0;break a}d=N()|0;xb(c);break b}a=0;while(1){d:{c=ud(b+20|0,d);x[114409]=0;c=S(200,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Ac(b+20|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=N()|0;Al(b+20|0)}Q(d|0);p()}Al(b+20|0);hb=b+32|0;return a|0}function d1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[114232];x[114232]=0;a=AE(a,e+12|0,d,me());d=lb;f=x[114232];d:{if(f){if(x[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}x[114232]=g;if(x[e+12>>2]==(b|0)){break c}}}x[c>>2]=4;b=0;break a}if((d|0)<0&a>>>0<2147483648|(d|0)<-1|(a>>>0>2147483647&(d|0)>=0|(d|0)>0)){break b}b=a;break a}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}b=-2147483648}hb=e+16|0;return b|0}function QU(a,b,c){var d=0,e=0,f=0;e=hb-48|0;hb=e;Xe(b);d=e+28|0;uf(d,a,c);a=x[d>>2];x[114409]=0;d=S(445,d|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)==1){break a}x[114409]=0;d=S(446,d|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}x[114409]=0;W(447,e+4|0,2,d|0,a|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}x[114409]=0;P(370,e+16|0,e+4|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=b;b=e+16|0;Eb(d,b);xb(b);Jc(e+28|0);hb=e+48|0;return!c|(a|0)!=0}a=N()|0;Jc(e+28|0);Q(a|0);p()}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){e=x[b+12>>2]+j|0;a=v[e|0];a=((D(v[e+1|0]-a|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(a<<8)|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function hoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c;g=Qb(b,c<<2);a:{if(!g){break a}zc(f+12|0,65535);Og(a,z[f+12>>1]);h=f,i=bc(a),x[h+4>>2]=i;h=f,i=dc(a),x[h>>2]=i;if(!Hb(f+4|0,f)){break a}while(1){a=x[f+4>>2];c=f+8|0;yu(b,c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);w[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+4|0;ke(a);if(Hb(a,f)){continue}break}}hb=f+16|0;return g|0}function lf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function TF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;lb=x[d+4>>2];return x[d>>2]}function Hs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=x[b>>2];e=x[b+8>>2];b=x[b+4>>2]?d&24576?d:(e|0)!=-1?d&-12289|8192:d:d;a:{if(b&1){d=146}else{if(!(b&2)){break a}d=147}rx(a,d)}b:{if(b&4096){break b}if(b&8192){f=c,g=qx(4),x[f+12>>2]=g;WH(a,c+12|0);break b}if(!(b&16384)){break b}f=c,g=qx(256),x[f+8>>2]=g;WH(a,c+8|0)}c:{if(b&16){b=148}else{if(!(b&32)){break c}b=149}rx(a,b)}if((e|0)!=-1){f=c,g=qx(e),x[f+4>>2]=g;x[(x[x[a>>2]-12>>2]+a|0)+8>>2]=x[c+4>>2]}hb=c+16|0}function P7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}x[114409]=0;V(2149,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[a+24>>2];x[114409]=0;b=O(2150,d|0,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(R(0)|0)|0;x[114409]=0;W(2113,6334,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();return 0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){e=(x[b+12>>2]<<1)+j|0;a=w[e>>1];a=a+((D(w[e+2>>1]-a|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;f=b-1&65535;a:{if(f>>>0>3998){break a}e=(D(b,104)+a|0)+484380|0;if(!He(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(x[d+104>>2]==(e|0)){x[d+76>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}On(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[c+24>>2]=0;x[c+8>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c>>2]=0;x[c+4>>2]=0;fq(e,0,c)}hb=c+32|0;return f>>>0<3999|0}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];c=d+8|0;g=x[Mb(c,d+12|0)>>2];x[d+8>>2]=x[a>>2];x[d+4>>2]=x[d+12>>2]-g;h=x[Mb(c,d+4|0)>>2];c=Db(b);if(g){e=x[a+20>>2];f=g;while(1){i=e,j=Db(y[c|0])^128,v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){c=b+x[a>>2]|0;e=x[a+20>>2]+1|0;f=h;while(1){i=e,j=Db(y[c|0])^128,v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}hb=d+16|0;return g+h|0}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2];c=e+8|0;h=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2];x[e+4>>2]=x[e+12>>2]-h;i=x[Mb(c,e+4|0)>>2];c=Db(b);if(h){f=x[a+20>>2];g=h;j=d;while(1){j=Db(y[c|0])+j|0;v[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=Db(b);if(i){c=b+x[a>>2]|0;f=x[a+20>>2]+1|0;g=i;while(1){d=Db(y[c|0])+d|0;v[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}hb=e+16|0;return h+i|0}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=x[b+8>>2];f=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+i|0;e=w[f+2>>1];x[c>>2]=x[c>>2]+D(w[f>>1],h);x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function jx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=b;j=e,k=td(a),x[j+8>>2]=k;b=zm(e+12|0,e+8|0);h=hb-16|0;hb=h;a:{g=Cb(a);if(b>>>0<=g>>>0){if(c){f=Hc(a);b:{if(f-g>>>0>=c>>>0){f=Rb(a);if((b|0)==(g|0)){break b}i=b+f|0;kl(i+c|0,i,g-b|0);break b}dl(a,f,(c+g|0)-f|0,g,b,0,c);f=x[a>>2]}In(b+f|0,c,d);c=c+g|0;ch(a,c);v[h+15|0]=0;$d(c+f|0,h+15|0)}hb=h+16|0;break a}wm();p()}j=e,k=td(a),x[j+4>>2]=k;a=Le(e+4|0,b);hb=e+16|0;return a|0}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(2329,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+16|0;x[e+44>>2]=d;b=b+16|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];EI(a);hb=e+48|0;return b|0}a=N()|0;EI(e+24|0);Q(a|0);p()}function G3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(2338,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+12|0;x[e+44>>2]=d;b=b+12|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];oI(a);hb=e+48|0;return b|0}a=N()|0;oI(e+24|0);Q(a|0);p()}function E3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;x[e+44>>2]=c;c=x[b+12>>2];x[e+32>>2]=x[b+8>>2];x[e+36>>2]=c;c=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=c;b=x[wp(e+20|0,e+44|0)>>2];x[114409]=0;c=x[e+36>>2];x[e+8>>2]=x[e+32>>2];x[e+12>>2]=c;c=x[e+28>>2];x[e>>2]=x[e+24>>2];x[e+4>>2]=c;Z(2136,a+8|0,e|0,b|0,d|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=nI(a);b=mI(a+88|0);x[a>>2]=83128;x[b>>2]=83216;od(e+44|0);hb=e+48|0;return a|0}a=N()|0;od(e+44|0);Q(a|0);p()}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1325,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+2|0;x[e+44>>2]=d;b=b+2|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];XN(a);hb=e+48|0;return b|0}a=N()|0;XN(e+24|0);Q(a|0);p()}function oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1252,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+2|0;x[e+44>>2]=d;b=b+2|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];It(a);hb=e+48|0;return b|0}a=N()|0;It(e+24|0);Q(a|0);p()}function iM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+813|0]!=27){a=v[b+851|0];break a}e=a+1074312|0;c=$b(e,21);d=a;a=y[b+841|0];a=xy(d,y[b+848|0],c?a:a+16>>>2|0);b:{if(!(!$b(e,45)|y[b+848|0]!=3)){c=y[b+841|0];c:{if(!(!c|c>>>0>=y[b+849|0])){a=y[b+852|0];d=c+1|0;break c}v[b+852|0]=a;d=1}v[b+841|0]=d;a=a<<24>>24;break b}v[b+841|0]=y[b+841|0]+y[b+849|0]}if(!$b(e,47)){break a}v[b+851|0]=a}if(a){f=b,g=Yb(x[b+684>>2]+((D(y[b+850|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function hka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1026,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+1|0;x[e+44>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];qQ(a);hb=e+48|0;return b|0}a=N()|0;qQ(e+24|0);Q(a|0);p()}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1536,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+1|0;x[e+44>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];oM(a);hb=e+48|0;return b|0}a=N()|0;oM(e+24|0);Q(a|0);p()}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1681,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+4|0;x[e+44>>2]=d;b=b+4|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];uL(a);hb=e+48|0;return b|0}a=N()|0;uL(e+24|0);Q(a|0);p()}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1685,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+6|0;x[e+44>>2]=d;b=b+6|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];qL(a);hb=e+48|0;return b|0}a=N()|0;qL(e+24|0);Q(a|0);p()}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;x[e+44>>2]=d;x[e+40>>2]=d;d=Oc(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[d+8>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Od(e+24|0,e);a:{if((b|0)!=(c|0)){d=x[e+44>>2];while(1){x[114409]=0;T(1293,a|0,d|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[e+44>>2]+8|0;x[e+44>>2]=d;b=b+8|0;if((c|0)!=(b|0)){continue}break}}a=e+24|0;Nd(a);b=x[e+44>>2];iO(a);hb=e+48|0;return b|0}a=N()|0;iO(e+24|0);Q(a|0);p()}function vN(a,b){var c=0,d=0,e=0;a:{b:{if(!y[b+866|0]|x[a+480180>>2]!=1){break b}d=x[b+104>>2];if(!d){break b}if(!He(d)|(z[d+34>>1]&3)!=2){break b}c=y[b+867|0]+y[(y[b+866|0]&15)+26496|0]|0;v[b+867|0]=c;if(c<<24>>24>=0){break b}v[b+867|0]=0;c=x[b+784>>2]+1|0;x[b+784>>2]=c>>>0<x[d+8>>2]-x[d+4>>2]>>>0?c:0;c=x[d+20>>2];x[114409]=0;c=S(439,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}b=Db(c)+(x[b+784>>2]+x[d+4>>2]|0)|0;v[b|0]=y[b|0]^-1;XO(d,a,0)}return}R(0)|0;zb();p()}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=x[b+8>>2];f=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+i|0;e=v[f+1|0];x[c>>2]=x[c>>2]+(D(v[f|0],h)<<8);x[c+4>>2]=x[c+4>>2]+(D(e,g)<<8);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function Dq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;g=Qb(b,c);a:{if(!g){break a}zc(f+12|0,65535);Og(a,z[f+12>>1]);i=f,j=bc(a),x[i+4>>2]=j;i=f,j=dc(a),x[i>>2]=j;if(!Hb(f+4|0,f)){break a}while(1){a=x[f+4>>2];c=f+11|0;if(!ag(b,c)){h=hb-16|0;hb=h;qf(c);hb=h+16|0}c=y[f+11|0];w[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+4|0;ke(a);if(Hb(a,f)){continue}break}}hb=f+16|0;return g|0}function DO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(Ij(a)){e=hb-16|0;hb=e;c=Re(3848);b=x[d+12>>2];x[114409]=0;f=O(1260,c|0,b|0)|0;b=x[114409];x[114409]=0;b:{if((b|0)!=1){c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=f;b=U(1261,e+12|0,c+12|0,c+11|0)|0;f=x[114409];x[114409]=0;c:{if((f|0)!=1){hb=c+16|0;break c}R(0)|0;zb();p()}hb=e+16|0;b=x[b>>2];break b}a=N()|0;_b(c);Q(a|0);p()}x[d+8>>2]=b;b=d+8|0;ht(a,b);kg(b);break a}GO(x[a>>2],b)}CO(a);hb=d+16|0}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=(b-a|0)/160|0;if((b|0)>0){while(1){x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=hb-16|0;hb=e;f=x[c+4>>2];h=x[c+8>>2];g=dj(f,h);a:{if(g>>>0<=tf(d)>>>0){if(xc(d)>>>0<g>>>0){x[e+12>>2]=f;qM(e+12|0,xc(d));ue(f,x[e+12>>2],x[d>>2]);pM(d,x[e+12>>2],h,g-xc(d)|0);break a}oA(d,ue(f,h,x[d>>2]));break a}$y(d);Yn(d,bi(d,g));pM(d,f,h,g)}hb=e+16|0}sc(a+16|0,c+16|0,144);a=a+160|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function sm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((om(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Qj(i+4|0,b,f);g=Rb(f);x[114409]=0;g=U(31,a|0,g|0,b|0)|0;h=x[114409];x[114409]=0;if((h|0)==1){break a}xb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((om(a,c,b)|0)!=(b|0)){break b}}JB(e);j=a}hb=i+16|0;return j|0}a=N()|0;xb(f);Q(a|0);p()}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];c=d+8|0;g=x[Mb(c,d+12|0)>>2];x[d+8>>2]=x[a>>2];x[d+4>>2]=x[d+12>>2]-g;h=x[Mb(c,d+4|0)>>2];c=Db(b);if(g){e=x[a+20>>2];f=g;while(1){i=e,j=lm(y[c|0]),v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){c=b+x[a>>2]|0;e=x[a+20>>2]+1|0;f=h;while(1){i=e,j=lm(y[c|0]),v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}hb=d+16|0;return g+h|0}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=x[b>>2];g=YT(b);b=hb-16|0;hb=b;e=ju(d,g);a:{if(e>>>0<=sd(a)>>>0){if(Lb(a)>>>0<e>>>0){x[b+12>>2]=d;bS(b+12|0,Lb(a));ue(d,x[b+12>>2],x[a>>2]);aS(a,x[b+12>>2],g,e-Lb(a)|0);break a}rv(a,ue(d,g,x[a>>2]));break a}$R(a);c=Fe(a,e);f=hb-16|0;hb=f;if(Dk(a)>>>0<c>>>0){Xc();p()}rC(f+8|0,yb(a),c);c=x[f+8>>2];x[a+4>>2]=c;x[a>>2]=c;h=x[f+12>>2];i=yb(a),j=c+(h<<2)|0,x[i>>2]=j;Wh(a,0);hb=f+16|0;aS(a,d,g,e)}hb=b+16|0}function Fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=hb-608|0;hb=f;b=hb-16|0;hb=b;c=b+8|0;e=f+8|0;lR(c,e);d=Fb(c);c=nd(a,ac(b,c));if((d|0)==(c|0)){ad(a,Fb(b+8|0))}hb=b+16|0;c=(c|0)==(d|0);if(!c){mR(e)}b=-1;a:{if(!c){break a}b=0;if(!xR(f+8|0)){break a}b=-1;if(!Hh(a,1024)){break a}b=0;e=hb-1024|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;Yz(d,e);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;if((d|0)==(g|0)){b=_z(e,0)>>>0<17}hb=e+1024|0}hb=f+608|0;return b|0}function bqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}zc(f+12|0,65535);Og(a,z[f+12>>1]);h=f,i=bc(a),x[h+4>>2]=i;h=f,i=dc(a),x[h>>2]=i;if(!Hb(f+4|0,f)){break a}while(1){a=x[f+4>>2];c=f+10|0;Vu(b,c);c=y[c|0]|y[c+1|0]<<8;c=c<<8|c>>>8;w[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+4|0;ke(a);if(Hb(a,f)){continue}break}}hb=f+16|0;return g|0}function Lo(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=hb-16|0;hb=i;if((b^-1)+2147483631>>>0>=c>>>0){k=Rb(a);j=i+4|0;if(b>>>0<1073741799){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=mj(x[$c(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}Mh(j,a,c);c=x[i+4>>2];if(e){Se(c,k,e)}if(g){Se(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Se((c+e|0)+g|0,(e+k|0)+f|0,h)}b=b+1|0;if((b|0)!=11){fg(a,k,b)}_e(a,c);Jf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;ee(b,a);v[i+12|0]=0;$d(a+c|0,i+12|0);hb=i+16|0;return}If();p()}function JR(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Ue(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Ue(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}hb=f+16|0}function vl(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;x[a+20>>2]=0;w[a+16>>1]=65535;x[a+8>>2]=0;x[a+12>>2]=0;x[a+24>>2]=11;x[a+28>>2]=b;DE(a+32|0);b=hb-16|0;hb=b;c=a+44|0;x[c>>2]=0;x[c+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(182,c+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){hb=b+16|0;break a}R(0)|0;zb();p()}x[a+72>>2]=0;x[a+76>>2]=0;x[a+64>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;x[a+80>>2]=0;x[a+84>>2]=0;x[a+88>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;return a|0}function qJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=Hc(a);a:{b:{c:{f=dj(b,c);if(d>>>0<f>>>0){if(Kx(a,b)){break c}g=d;h=f-d|0;d=Cb(a);dl(a,g,h,d,0,d,0)}d=Rb(a);if((b|0)!=(c|0)){while(1){$d(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}v[e+15|0]=0;$d(d,e+15|0);ch(a,f);break b}b=Fi(e,b,c);c=Rb(b);d=Cb(b);x[114409]=0;U(124,a|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}xb(b)}hb=e+16|0;return a|0}a=N()|0;xb(b);Q(a|0);p()}function OF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=y[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=x[114232];x[114232]=0;a=hw(a,e+12|0,d,me());d=lb;g=x[114232];g:{if(g){if(x[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}x[114232]=h;if(x[e+12>>2]==(b|0)){break d}}}}x[c>>2]=4;a=0;break a}if(!d){break b}}x[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a|0}function ms(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[114276]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[114232]=25;a=-1}else{a=1}return a|0}v[a|0]=b;return 1}function Zw(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>2;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Db(b);if(d){b=x[a+20>>2];a=d;while(1){e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=he(E(rf((l(2,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24)),r()),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){e=~~g;break a}e=-2147483648}h=b,i=Wc(e),w[h>>1]=i;b=b+2|0;c=c+4|0;a=a-1|0;if(a){continue}break}}hb=f+16|0;return d<<2}function p9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a>>2]=79776;b=Ck(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=cf(c);x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[114409]=0;U(1760,a+44|0,2,2)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;V(1761,a|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}return a|0}c=N()|0;lg(b);Cf(a);Q(c|0);p()}function lc(a,b){var c=0,d=0,e=0;a:{b:{c=x[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return lc(a,24)+(lc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){d=us(a);if((d|0)==-1){break b}e=x[a+1396>>2];c=e+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}x[a+1396>>2]=c-b;c=a;a=x[a+1392>>2];x[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}x[a+1396>>2]=-1;return 0}ea(6063,9049,1632,3155);p()}function zoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=d;e=Cb(a);d=Hc(a);a:{if(d-e>>>0>=b>>>0){d=Rb(a);if((c|0)==(e|0)){break a}g=c+d|0;kl(g+b|0,g,e-c|0);break a}dl(a,d,(b+e|0)-d|0,e,c,0,b);d=x[a>>2]}b=b+e|0;ch(a,b);v[f+7|0]=0;$d(b+d|0,f+7|0);if(Hb(f+12|0,f+8|0)){e=c+d|0;while(1){b=f+12|0;$d(e,x[b>>2]);e=e+1|0;gg(b);if(Hb(b,f+8|0)){continue}break}}h=f,i=td(a),x[h>>2]=i;a=Le(f,c);hb=f+16|0;return a|0}function vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l(1,f|0);g=Td(Gg(+n())*32768);a:{if(F(g)<2147483648){f=~~g;break a}f=-2147483648}h=a,i=Wc(f),w[h>>1]=i;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function hQ(a){var b=0,c=0,d=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|y[a+30|0]>2){break a}b=a+40|0;if(y[b|0]|y[b+1|0]<<8){break a}b=a+38|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>32){break a}b=a+32|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>256){break a}b=a+34|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>255){break a}a=a+36|0;if(!(y[a|0]|y[a+1|0]<<8)){break a}d=(y[a|0]|y[a+1|0]<<8)>>>0<129}return d}function xT(a,b){a=a|0;b=b|0;var c=0,d=0;d=y[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!y[a|0]){break a}}c:{d:{e:{switch(y[a+3|0]){case 10:case 17:case 18:c=8;break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=y[a|0];if(!(c&7)){break d}case 11:c=b+1>>>1|0;b=(y[a+3|0]==11)<<4;break c;case 9:break e;default:break d}}c=16}c=D(c>>>3|0,b);b=(y[a+3|0]==11)<<4}c=b+D(rT(a),c)|0}return c|0}function J3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0,j=0;e=hb-16|0;hb=e;i=x[a+4>>2];qI(a,b,c,d);g=B[a+24>>2];x[e+8>>2]=x[a+20>>2];b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;a=hb-16|0;hb=a;x[a+8>>2]=x[e+8>>2];b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;b=0;if(!(!d|g==E(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=Vf(a,f,j);B[h>>2]=B[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}hb=a+16|0;hb=e+16|0}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ng(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/6>>>0){KA(a,d,c);break c}b=yb(a);b=RS(e+12|0,yA(a,ng(a)+d|0),ng(a),b);x[114409]=0;T(719,b|0,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(720,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}qu(b)}hb=e+32|0;break a}a=N()|0;qu(b);Q(a|0);p()}return}if(b>>>0<d>>>0){JA(a,x[a>>2]+D(b,6)|0)}}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ze(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=x[yb(a)>>2]-x[a+4>>2]>>5>>>0){rz(a,d,c);break c}b=yb(a);b=or(e+12|0,Hm(a,ze(a)+d|0),ze(a),b);x[114409]=0;T(1247,b|0,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1234,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Ht(b)}hb=e+32|0;break a}a=N()|0;Ht(b);Q(a|0);p()}return}if(b>>>0<d>>>0){NO(a,x[a>>2]+(b<<5)|0)}}function sU(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a+1060>>2];if((b|0)>255){break a}while(1){f=(D(b,6)+a|0)+1068|0,g=Zj(a,7),v[f|0]=g;d=Zj(a,1);e=Zj(a,1);c=x[a+1056>>2];if((c|0)>255){break a}b=x[a+1060>>2]+1|0;x[a+1056>>2]=b;x[a+1060>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1064>>1]=b;sU(a);b=x[a+1060>>2];break b}w[(D(c,6)+a|0)+1064>>1]=65535}x[a+1056>>2]=b;if(e){w[(D(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}w[(D(c,6)+a|0)+1066>>1]=65535}}function bna(a,b){a=a|0;b=b|0;var c=0,d=0;c=qd(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>4>>>0){UB(a,c);break c}b=yb(a);b=wr(d+12|0,xr(a,qd(a)+c|0),qd(a),b);x[114409]=0;P(776,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(614,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Bu(b)}hb=d+32|0;break a}a=N()|0;Bu(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+(b<<4)|0;qd(a);DB(a,b);WD(a)}}function K7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;x[114409]=0;V(2138,a|0);h=x[114409];x[114409]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[114409]=0;b=qa(2155,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8817,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function H7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;x[114409]=0;V(2138,a|0);h=x[114409];x[114409]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[114409]=0;b=qa(2158,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8749,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function hK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a>>2]=79136;b=Ck(a+4260|0);x[a+4232>>2]=1061997773;c=a+4224|0;x[c>>2]=1061158912;x[c+4>>2]=1059082943;c=a+4216|0;x[c>>2]=1038174126;x[c+4>>2]=1065353216;x[a+4208>>2]=1056964608;x[a+4212>>2]=1036831949;x[114409]=0;U(1760,a+44|0,2,2)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;V(1761,a|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}return a|0}c=N()|0;lg(b);Cf(a);Q(c|0);p()}function eL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Lb(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){Yx(a,d,c);break c}b=yb(a);b=Rf(e+12|0,Fe(a,Lb(a)+d|0),Lb(a),b);x[114409]=0;T(1711,b|0,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(1712,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}yn(b)}hb=e+32|0;break a}a=N()|0;yn(b);Q(a|0);p()}return}if(b>>>0<d>>>0){_x(a,x[a>>2]+(b<<2)|0)}}function P$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=Cb(a);e=Hc(a);g=dj(b,c);a:{if(!g){break a}b:{if(!Kx(a,b)){if(e-d>>>0<g>>>0){dl(a,e,(d+g|0)-e|0,d,d,0,0)}e=Rb(a)+d|0;while(1){if((b|0)==(c|0)){break b}$d(e,b);b=b+1|0;e=e+1|0;continue}}b=Fi(f,b,c);c=Rb(b);d=Cb(b);x[114409]=0;U(2649,a|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(b);break a}a=N()|0;xb(b);Q(a|0);p()}v[f+15|0]=0;$d(e,f+15|0);ch(a,d+g|0)}hb=f+16|0;return a|0}function o0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=37;x[a+252>>2]=0;g=a+248|0;mk(g|1,6568,1,x[c+4>>2]);h=me();x[a>>2]=e;x[a+4>>2]=f;e=a+224|0;f=kf(e,24,h,g,a)+e|0;g=yg(e,f,c);h=a+20|0;Fc(h,c);x[114409]=0;fa(2630,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+20|0);b=Zm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+256|0;break a}b=N()|0;Ob(a+20|0);Q(b|0);p()}return b|0}function m0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=37;x[a+252>>2]=0;g=a+248|0;mk(g|1,6568,0,x[c+4>>2]);h=me();x[a>>2]=e;x[a+4>>2]=f;e=a+224|0;f=kf(e,24,h,g,a)+e|0;g=yg(e,f,c);h=a+20|0;Fc(h,c);x[114409]=0;fa(2630,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+20|0);b=Zm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+256|0;break a}b=N()|0;Ob(a+20|0);Q(b|0);p()}return b|0}function lO(a,b){var c=0,d=0,e=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;d=3546895/+(b>>>0);c=d*.25;a:{if(F(c)<2147483648){b=~~c;break a}b=-2147483648}x[a+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(F(c)<0x8000000000000000){e=~~c>>>0;b=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break b}b=-2147483648}x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=e;x[a+12>>2]=b;return a}function z0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-112|0;hb=a;x[a+104>>2]=37;x[a+108>>2]=0;g=a+104|0;mk(g|1,6568,1,x[c+4>>2]);h=me();x[a>>2]=e;x[a+4>>2]=f;e=a+80|0;f=kf(e,24,h,g,a)+e|0;g=yg(e,f,c);h=a+20|0;Fc(h,c);x[114409]=0;fa(2621,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+20|0);b=sm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+112|0;break a}b=N()|0;Ob(a+20|0);Q(b|0);p()}return b|0}function x0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-112|0;hb=a;x[a+104>>2]=37;x[a+108>>2]=0;g=a+104|0;mk(g|1,6568,0,x[c+4>>2]);h=me();x[a>>2]=e;x[a+4>>2]=f;e=a+80|0;f=kf(e,24,h,g,a)+e|0;g=yg(e,f,c);h=a+20|0;Fc(h,c);x[114409]=0;fa(2621,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+20|0);b=sm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+112|0;break a}b=N()|0;Ob(a+20|0);Q(b|0);p()}return b|0}function aL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(sd(a)>>>0>=b>>>0){f=d,g=Lb(a),x[f+8>>2]=g;b=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];if(e){while(1){B[b>>2]=B[c>>2];b=b+4|0;e=e-1|0;if(e){continue}break}}b=x[d+12>>2];e=x[d+8>>2];if(b>>>0>e>>>0){Yx(a,b-e|0,c);break a}_x(a,x[a>>2]+(b<<2)|0);break a}if(x[a>>2]){Ki(a);bf(yb(a),x[a>>2],sd(a));f=yb(a),g=0,x[f>>2]=g;x[a>>2]=0;x[a+4>>2]=0}_u(a,Fe(a,b));Yx(a,b,c)}hb=d+16|0}function um(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-32|0;hb=d;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+12>>2]=c;a:{if(c){while(1){x[d+8>>2]=16;f=0;e=x[Mb(d+8|0,d+12|0)>>2];h=x[a>>2];if((e|0)!=((j=h,k=Db(d+16|0),l=x[a+8>>2]+g|0,m=e,i=x[x[h>>2]+28>>2],mb[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(dd(d+16|0,b+g|0,e)){break a}f=x[d+12>>2];x[d+12>>2]=f-e;g=e+g|0;if((e|0)!=(f|0)){continue}break}}cc(a,c);f=1}hb=d+32|0;return f}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[d+16>>2]=b;e=x[a+48>>2];x[d+20>>2]=c-((e|0)!=0);g=x[a+44>>2];x[d+28>>2]=e;x[d+24>>2]=g;a:{b:{if(ns(Pa(x[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=x[d+12>>2];if((e|0)>0){break b}b=e?32:16}x[a>>2]=b|x[a>>2];break a}f=e;g=x[d+20>>2];if(g>>>0>=e>>>0){break a}f=x[a+44>>2];x[a+4>>2]=f;x[a+8>>2]=f+(e-g|0);if(x[a+48>>2]){x[a+4>>2]=f+1;v[(b+c|0)-1|0]=y[f|0]}f=c}hb=d+32|0;return f|0}function F6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[114409]=0;V(2211,a|0);f=x[114409];x[114409]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[114409]=0;b=_a(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7178,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function xda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;f=a+1304392|0;if(!yd(f)){d=hb-16|0;hb=d;b=Re(532);a=x[a+24620>>2];x[114409]=0;a=O(1516,b|0,a|0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=a;a=U(1519,d+12|0,b+12|0,b+11|0)|0;e=x[114409];x[114409]=0;b:{if((e|0)!=1){hb=b+16|0;break b}R(0)|0;zb();p()}hb=d+16|0;a=x[a>>2];break a}a=N()|0;_b(b);Q(a|0);p()}x[c+12>>2]=a;a=c+12|0;MM(f,oe(a));Ky(a)}hb=c+16|0}function ET(a){var b=0,c=0,d=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((y[b|0]|y[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(y[a+49|0]<32|(y[b|0]|y[b+1|0]<<8)>>>0>255|y[a+50|0]>64){break a}b=a+51|0;if(y[b|0]<4|v[b|0]<0){break a}d=a+576|0;a=a- -64|0;b=0;while(1){c=0;b:{switch(y[a+15|0]){case 0:case 1:b=1;break;case 2:break b;default:break a}}c=b;a=a+16|0;if((d|0)!=(a|0)){continue}break}}return c&1}function B6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;Fc(a,b);x[114409]=0;T(131,d+12|0,b|0,c|0);e=x[114409];x[114409]=0;a:{if((e|0)==1){break a}Ob(d+12|0);x[114409]=0;e=S(30,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}if(e){x[114409]=0;b=S(30,b|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break a}x[114409]=0;T(132,d+8|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}Ob(d+8|0)}hb=d+16|0;return}b=N()|0;Ob(a);Q(b|0);p()}function zx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Fs(b)){break a}a=a+24|0;if(!pg(x[a>>2]+484344|0,b&65535)){break a}b=Zb(x[a>>2]+484344|0,b);if((d|0)<0|x[b+12>>2]<=(c|0)|(c|0)<0|(z[x[a>>2]+480188>>1]<=d>>>0|e>>>0>5)){break a}b=Hf(b,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}f=y[b|0]}return f|0}function Mc(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;if(x[a+4>>2]==x[b+4>>2]){c=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;b=hb-16|0;hb=b;x[b+12>>2]=x[a+4>>2];c=x[d+4>>2];x[114409]=0;x[b+8>>2]=c;c=O(36,b+12|0,b+8|0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){c=xn(x[a>>2],x[d>>2],x[c>>2]);b:{if(c){break b}c=0;if(x[a+4>>2]==x[d+4>>2]){break b}c=A[a+4>>2]<A[d+4>>2]?-1:1}hb=b+16|0;break a}R(0)|0;zb();p()}c=!c}hb=d+16|0;return c}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xc(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=x[yb(a)>>2]-x[a+4>>2]>>>0){Fq(a,d,c);break c}b=yb(a);b=ci(e+12|0,bi(a,xc(a)+d|0),xc(a),b);x[114409]=0;T(714,b|0,d|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(342,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Dh(b)}hb=e+32|0;break a}a=N()|0;Dh(b);Q(a|0);p()}return}if(b>>>0<d>>>0){uv(a,x[a>>2]+b|0)}}function Ld(a){var b=0,c=0,d=0;d=lp(Bf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=y[a|0];break b}if(a&3){while(1){b=y[a|0];v[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=x[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){x[c>>2]=b;b=x[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}v[c|0]=b;if(!(b&255)){break a}while(1){b=y[a+1|0];v[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function DV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}zc(f+12|0,65535);Og(a,z[f+12>>1]);h=f,i=bc(a),x[h+4>>2]=i;h=f,i=dc(a),x[h>>2]=i;if(!Hb(f+4|0,f)){break a}while(1){a=x[f+4>>2];c=f+10|0;Vu(b,c);c=y[c|0]|y[c+1|0]<<8;w[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+4|0;ke(a);if(Hb(a,f)){continue}break}}hb=f+16|0;return g|0}function hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Db(b);if(f){a=x[a+20>>2];d=f;while(1){g=he(E(rf(E((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r())*h),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){b=~~g;break a}b=-2147483648}i=a,j=Wc(b),w[i>>1]=j;a=a+2|0;c=c+4|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return f<<2}function xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;e=my(a);a:{b:{c:{d:{while(1){x[114409]=0;a=O(231,b|0,8)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!a){break c}x[114409]=0;T(1651,d+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;P(1652,e|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}qe(d+8|0);continue}break}a=N()|0;break a}a=N()|0;qe(d+8|0);break a}hb=d+32|0;return}a=N()|0}Rl(e);Q(a|0);p()}function eJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-144|0;hb=d;c=qh(d+8|0);e=x[x[c>>2]-12>>2];x[114409]=0;f=$(125)|0;g=x[114409];x[114409]=0;a:{if((g|0)==1){break a}x[114409]=0;T(126,d+4|0,c+e|0,f|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}Ob(d+4|0);x[114409]=0;P(135,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;P(128,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}ae(c);hb=d+144|0;return}a=N()|0;ae(c);Q(a|0);p()}function Jx(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-144|0;hb=d;c=qh(d+8|0);e=x[x[c>>2]-12>>2];x[114409]=0;f=$(125)|0;g=x[114409];x[114409]=0;a:{if((g|0)==1){break a}x[114409]=0;T(126,d+4|0,c+e|0,f|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}Ob(d+4|0);x[114409]=0;P(127,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}x[114409]=0;P(128,a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}ae(c);hb=d+144|0;return}a=N()|0;ae(c);Q(a|0);p()}function Rx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+12>>2]=b;k=d,l=td(a),x[k+4>>2]=l;b=d+12|0;h=d+4|0;f=zm(b,h);b=zm(d+8|0,b);a:{if(Cb(a)>>>0>=f>>>0){if((b|0)==-1){zC(a,f);break a}e=hb-16|0;hb=e;x[e+12>>2]=b;if(b){c=Cb(a);i=Rb(a);b=c-f|0;x[e+8>>2]=b;g=x[Mb(e+12|0,e+8|0)>>2];x[e+12>>2]=g;if((b|0)!=(g|0)){j=f+i|0;kl(j,g+j|0,b-g|0);b=x[e+12>>2]}kv(a,i,c-b|0)}hb=e+16|0;break a}wm();p()}Le(h,f);hb=d+16|0}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[114409]=0;V(2211,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[114409]=0;b=Z(f|0,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7323,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function oy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;a:{if(!c){b=wc(a,b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;oy(a,b,f,e+16|0);Yh(e+32|0,d,wc(a,c));d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;oy(a,b|c,f,e)}hb=e+48|0}function Nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;e=Lz(a);a:{b:{c:{d:{while(1){x[114409]=0;a=O(231,b|0,8)|0;f=x[114409];x[114409]=0;if((f|0)==1){break b}if(!a){break c}x[114409]=0;T(999,d+8|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){x[114409]=0;P(1e3,e|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}qe(d+8|0);continue}break}a=N()|0;break a}a=N()|0;qe(d+8|0);break a}hb=d+32|0;return}a=N()|0}bm(e);Q(a|0);p()}function H6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[114409]=0;V(2211,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[114409]=0;b=Z(f|0,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7359,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function wL(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=hb-16|0;hb=c;f=x[b+4>>2];d=x[b>>2];e=(f-d|0)/6|0;a:{if(e>>>0<=$i(a)>>>0){if(ng(a)>>>0<e>>>0){x[c+12>>2]=d;g=ng(a);x[c+12>>2]=x[c+12>>2]+D(g,6);at(d,x[c+12>>2],x[a>>2]);fy(a,x[c+12>>2],f,e-ng(a)|0);break a}JA(a,at(d,f,x[a>>2]));break a}sL(a);_A(a,yA(a,e));fy(a,d,f,e)}hb=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];vL(a+24|0,b+24|0);pj(a+36|0,b+36|0)}function c5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!x[b+4>>2]){break a}d=x[b+4>>2];x[114409]=0;P(2304,a|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){d=x[b>>2];e=x[b>>2];f=D(x[b+4>>2],12);b=x[b+4>>2];x[114409]=0;W(2305,a|0,d|0,e+f|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;SI(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);SI(b);hb=c+16|0;return a|0}function D6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[114409]=0;V(2211,a|0);d=x[114409];x[114409]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[114409]=0;T(f|0,d|0,b|0,(c|0)!=0|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2989,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function A6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[114409]=0;V(2211,a|0);d=x[114409];x[114409]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[114409]=0;T(f|0,d|0,b|0,(c|0)!=0|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3043,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function XB(a,b){a=a|0;b=b|0;var c=0,d=0;c=rc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>1>>>0){KB(a,c);break c}b=yb(a);b=Eo(d+12|0,hj(a,rc(a)+c|0),rc(a),b);x[114409]=0;P(389,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(360,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Tj(b)}hb=d+32|0;break a}a=N()|0;Tj(b);Q(a|0);p()}return}if(b>>>0<c>>>0){vo(a,x[a>>2]+(b<<1)|0)}}function qC(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ae(d+24|0,a,b);b=x[d+24>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d+28>>2];x[a+12>>2]=b;x[a+4>>2]=c;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;c=Yg(b);f=a+4|0;g=Yg(f);v[g+2|0]=y[c+2|0];w[g>>1]=z[c>>1];hg(b);hg(f);if(qc(b,a+8|0)){continue}break}}Dc(d+16|0,a+12|0,a+4|0);hb=a+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(e+8|0,d+12|0,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function oV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-32|0;hb=d;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+12>>2]=c;a:{if(c){while(1){x[d+8>>2]=16;f=0;e=x[Mb(d+8|0,d+12|0)>>2];if((e|0)!=((i=a,j=Db(d+16|0),k=x[a+12>>2]+g|0,l=e,h=x[x[a>>2]+28>>2],mb[h](i|0,j|0,k|0,l|0)|0)|0)){break a}if(dd(d+16|0,b+g|0,e)){break a}f=x[d+12>>2];x[d+12>>2]=f-e;g=e+g|0;if((e|0)!=(f|0)){continue}break}}ad(a,c);f=1}hb=d+32|0;return f}function MX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-32|0;hb=b;c=hb-16|0;hb=c;d=c+8|0;e=b+22|0;tD(d,e);f=Fb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){uD(e)}c=-1;a:{if(!d){break a}c=0;if(!JD(b+22|0)){break a}c=hb-16|0;hb=c;d=c+8|0;e=b+8|0;rD(d,e);f=Fb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(f|0);if(!a){sD(e)}c=-1;if(!a){break a}c=ID(b+8|0)}hb=b+32|0;return c|0}function yy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(!Lj(b)){c=eN(a,c,x[b+704>>2],d);break a}c=x[b+700>>2]}x[e+12>>2]=c;b=x[b+656>>2];b:{if(!b){break b}d=x[b+40>>2];if(!d){break b}b=(d|0)/2|0;f=x[a+1074420>>2];f=sqa(f,f>>31,c,c>>31);c=b+f|0;b=lb+(b>>31)|0;g=e,h=Ec(tqa(c,c>>>0<f>>>0?b+1|0:b,d,d>>31),lb),x[g+12>>2]=h}zc(e+12|0,2147483647);c=x[a+24620>>2]<<4;a=tqa(0,x[e+12>>2],c,0);hb=e+16|0;return a|0}function XX(a,b){a=a|0;b=b|0;var c=0;a=gd(a);a:{if(y[b+16|0]){x[114409]=0;O(208,a|0,1452)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[114409]=0;O(208,a|0,8355)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}}if(Yc(a)){x[114409]=0;O(208,a|0,6053)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[114409]=0;O(208,a|0,7006)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}}return}b=N()|0;xb(a);Q(b|0);p()}function kG(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function gna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;e=bc(b);f=dc(b);c=hb-16|0;hb=c;x[c+8>>2]=f;x[c+12>>2]=e;x[c+4>>2]=d+12;a:{if(!Hb(c+12|0,c+8|0)){break a}while(1){e=x[c+12>>2];if(x[x[c+4>>2]>>2]==(y[e|0]|y[e+1|0]<<8)){break a}e=c+12|0;bj(e);if(Hb(e,c+8|0)){continue}break}}hb=c+16|0;x[d+8>>2]=x[c+12>>2];g=d,h=dc(b),x[g+4>>2]=h;b:{if(Hb(d+8|0,d+4|0)){hf(a,yb(x[d+8>>2]));break b}ii(a)}hb=d+16|0}function ana(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,18);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function a_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=hb-16|0;hb=f;x[f+12>>2]=x[a+8>>2];i=Nh(f+8|0,f+12|0);x[114409]=0;j=UF(c,d-c|0,b);l=x[114409];x[114409]=0;b:{if((l|0)!=1){Te(i);hb=f+16|0;break b}a=N()|0;Te(i);Q(a|0);p()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function DY(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[114409]=0;m=a;a=0;a=fE(2129,m|a,b,c,d,a|e,f);b=x[114409];x[114409]=0;a:{b:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;fa(2124,4964,g|0,h|0,i|0,j|0,k|0,l|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_();a=-255}break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}return a|0}function $e(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=sqa(b,c,h,i);h=lb;e=sqa(d,e,f,g);i=e+i|0;d=lb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=sqa(g,e,c,d);g=c+i|0;i=lb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=sqa(f,0,b,0);h=lb;i=0;d=sqa(f,i,k,d);h=h+d|0;f=lb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=sqa(b,m,j,e)+h|0;e=lb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function Bna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;c=Ve(a);f=mc(a);g=hb-16|0;hb=g;if(c){while(1){h=$n(yb(a),c+16|0,b);f=h?f:c;c=x[(h?c+4|0:c)>>2];if(c){continue}break}}c=x[Bb(g+12|0,f)>>2];hb=g+16|0;x[d+12>>2]=c;i=d,j=Oj(a),x[i+8>>2]=j;a:{b:{if(!Hb(d+12|0,d+8|0)){break b}if($n(yb(a),b,vh(d+12|0))){break b}a=x[d+12>>2];break a}a=Oj(a)}hb=d+16|0;a=x[Bb(e+12|0,a)>>2];hb=e+16|0;return a|0}function Zx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;c=Ve(a);f=mc(a);g=hb-16|0;hb=g;if(c){while(1){h=_s(yb(a),c+16|0,b);f=h?f:c;c=x[(h?c+4|0:c)>>2];if(c){continue}break}}c=x[Bb(g+12|0,f)>>2];hb=g+16|0;x[d+12>>2]=c;i=d,j=Oj(a),x[i+8>>2]=j;a:{b:{if(!Hb(d+12|0,d+8|0)){break b}if(_s(yb(a),b,vh(d+12|0))){break b}a=x[d+12>>2];break a}a=Oj(a)}hb=d+16|0;a=x[Bb(e+12|0,a)>>2];hb=e+16|0;return a|0}function y6(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[114409]=0;V(2211,a|0);d=x[114409];x[114409]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[114409]=0;ab(f|0,d|0,b|0,+c);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7522,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function x4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;f=x[c+12>>2];a:{if(!f){break a}g=v[c+16|0];e=Cb(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(y[pc(b,0)|0]==43){break b}if(y[pc(b,0)|0]==45){break b}}i=d,j=td(b),x[i+4>>2]=j;i=d,j=Le(d+4|0,e-c|0),x[i+8>>2]=j;jx(b,x[rd(d+12|0,d+8|0)>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Jd(a,b);hb=d+16|0}function t5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ec(8);x[114409]=0;c=O(122,h+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,4);c=Dx(a,c,d,e,f,g);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=h+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function q5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ec(8);x[114409]=0;c=O(122,h+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,4);c=Cx(a,c,d,e,f,g);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=h+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function q0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb-144|0;hb=a;x[a+136>>2]=37;x[a+140>>2]=0;f=a+136|0;mk(f|1,6727,1,x[c+4>>2]);g=me();x[a>>2]=e;e=a+123|0;f=kf(e,13,g,f,a)+e|0;g=yg(e,f,c);h=a+4|0;Fc(h,c);x[114409]=0;fa(2630,e|0,g|0,f|0,a+16|0,a+12|0,a+8|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+4|0);b=Zm(b,a+16|0,x[a+12>>2],x[a+8>>2],c,d);hb=a+144|0;break a}b=N()|0;Ob(a+4|0);Q(b|0);p()}return b|0}function n0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb-144|0;hb=a;x[a+136>>2]=37;x[a+140>>2]=0;f=a+136|0;mk(f|1,6727,0,x[c+4>>2]);g=me();x[a>>2]=e;e=a+123|0;f=kf(e,13,g,f,a)+e|0;g=yg(e,f,c);h=a+4|0;Fc(h,c);x[114409]=0;fa(2630,e|0,g|0,f|0,a+16|0,a+12|0,a+8|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+4|0);b=Zm(b,a+16|0,x[a+12>>2],x[a+8>>2],c,d);hb=a+144|0;break a}b=N()|0;Ob(a+4|0);Q(b|0);p()}return b|0}function L7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[114409]=0;V(2138,a|0);f=x[114409];x[114409]=0;a:{b:{if((f|0)!=1){f=x[a+24>>2];x[114409]=0;b=aa(2154,f|0,b|0,c|0,d|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5610,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function I7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[114409]=0;V(2138,a|0);f=x[114409];x[114409]=0;a:{b:{if((f|0)!=1){f=x[a+24>>2];x[114409]=0;b=aa(2157,f|0,b|0,c|0,d|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5538,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function $6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[114409]=0;V(2138,a|0);f=x[114409];x[114409]=0;a:{b:{if((f|0)!=1){f=x[a+24>>2];x[114409]=0;b=aa(2193,f|0,b|0,c|0,d|0,e|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8233,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function y8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;v[a+4202|0]=1;b=Si(E(E(cf(x[a+16>>2])>>>0)*E(.04500000178813934)));c=Si(E(E(b>>>0)*E(1.1892070770263672)));d=Si(E(E(c>>>0)*E(1.1892070770263672)));g=Si(E(E(d>>>0)*E(1.1892070770263672)));e=Si(E(E(b+d>>>0)*E(.11546666920185089)));f=Si(E(E(c+g>>>0)*E(.11546666920185089)));x[a+4292>>2]=f;x[a+4288>>2]=e;x[a+4276>>2]=d-e;x[a+4272>>2]=b-e;x[a+4284>>2]=g-f;x[a+4280>>2]=c-f;IJ(a);GJ(a)}function fu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(y[fc(a,0)|0]&15)<<8|y[fc(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=z[(c<<1)+25936>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(z[(c<<1)+25934>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}v[b|0]=e;c=y[fc(a,2)|0];g=b,h=y[fc(a,0)|0]&16|c>>>4,v[g+1|0]=h;g=b,h=y[fc(a,2)|0]&15,v[g+3|0]=h;g=b,h=y[fc(a,3)|0],v[g+5|0]=h}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=b;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+12>>2]=b;b=mu(d+8|0,d+12|0);hb=d+16|0;a:{b=hi(e,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];d=x[b>>2];f=x[e+12>>2];x[114409]=0;T(782,c|0,d|0,f|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[b>>2]=x[b>>2]+4;je(e+12|0);if(x[b>>2]!=x[b+4>>2]){continue}break}}Bc(b);hb=e+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function E9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a>>2]=79368;b=Ck(a+4256|0);c=a+4224|0;x[c>>2]=1017370378;x[c+4>>2]=1065353216;c=a+4216|0;x[c>>2]=1028670828;x[c+4>>2]=1059760811;x[a+4208>>2]=1056964608;x[a+4212>>2]=1017370378;x[114409]=0;U(1760,a+44|0,2,2)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;V(1761,a|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}return a|0}c=N()|0;lg(b);Cf(a);Q(c|0);p()}function NM(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){a=hb-16|0;hb=a;f=a,g=bc(c),x[f+12>>2]=g;f=a,g=dc(c),x[f+8>>2]=g;if(Hb(a+12|0,a+8|0)){while(1){e=x[a+12>>2];a:{while(1){b=x[e>>2];d=x[b>>2];if(!d){break a}b=x[x[d>>2]+8>>2];x[114409]=0;V(b|0,d|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}Gb(b+20|0);Gb(b+8|0);_b(b);b=a+12|0;je(b);if(Hb(b,a+8|0)){continue}break}}b=iK(c);hb=a+16|0;_b(b)}}function y0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb+-64|0;hb=a;x[a+56>>2]=37;x[a+60>>2]=0;f=a+56|0;mk(f|1,6727,0,x[c+4>>2]);g=me();x[a>>2]=e;e=a+43|0;f=kf(e,13,g,f,a)+e|0;g=yg(e,f,c);h=a+4|0;Fc(h,c);x[114409]=0;fa(2621,e|0,g|0,f|0,a+16|0,a+12|0,a+8|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+4|0);b=sm(b,a+16|0,x[a+12>>2],x[a+8>>2],c,d);hb=a- -64|0;break a}b=N()|0;Ob(a+4|0);Q(b|0);p()}return b|0}function Uk(a,b){a=a|0;b=b|0;var c=0,d=0;c=xc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>>0){BS(a,c);break c}b=yb(a);b=ci(d+12|0,bi(a,xc(a)+c|0),xc(a),b);x[114409]=0;P(45,b|0,c|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;P(44,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Ou(b)}hb=d+32|0;break a}a=N()|0;Ou(b);Q(a|0);p()}return}if(b>>>0<c>>>0){oA(a,x[a>>2]+b|0)}}function B0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb+-64|0;hb=a;x[a+56>>2]=37;x[a+60>>2]=0;f=a+56|0;mk(f|1,6727,1,x[c+4>>2]);g=me();x[a>>2]=e;e=a+43|0;f=kf(e,13,g,f,a)+e|0;g=yg(e,f,c);h=a+4|0;Fc(h,c);x[114409]=0;fa(2621,e|0,g|0,f|0,a+16|0,a+12|0,a+8|0,h|0);e=x[114409];x[114409]=0;a:{if((e|0)!=1){Ob(a+4|0);b=sm(b,a+16|0,x[a+12>>2],x[a+8>>2],c,d);hb=a- -64|0;break a}b=N()|0;Ob(a+4|0);Q(b|0);p()}return b|0}function CC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ae(d+24|0,a,b);b=x[d+24>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d+28>>2];x[a+12>>2]=b;x[a+4>>2]=c;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;c=z[Wj(b)>>1];f=a+4|0;g=Wj(f),h=c,w[g>>1]=h;Ch(b);Ch(f);if(qc(b,a+8|0)){continue}break}}Dc(d+16|0,a+12|0,a+4|0);hb=a+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(e+8|0,d+12|0,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function fz(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;Ei(d+8|0,c);a=hb-16|0;hb=a;c=x[d+12>>2];x[a+8>>2]=x[d+8>>2];x[a+12>>2]=c;g=a,h=Cb(b),x[g+4>>2]=h;x[a>>2]=x[a+12>>2];b=Rb(b);c=x[a+8>>2];x[114409]=0;e=O(36,a+4|0,a|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){b=xn(b,c,x[e>>2]);b:{if(b){break b}b=-1;c=x[a+4>>2];e=x[a>>2];if(c>>>0<e>>>0){break b}b=c>>>0>e>>>0}hb=a+16|0;break a}R(0)|0;zb();p()}hb=d+16|0;return b>>>31|0}function lE(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(a>>>0<463424&a>>>0>=462912){c=a;b=a-4|0;d=x[115724];e=d;a:{while(1){a=e;if(!(!a|(a|0)==463424)){if((kE(a)|0)==(b|0)){w[a+2>>1]=z[c-2>>1]+z[a+2>>1];break a}if((kE(b)|0)==(a|0)){c=c-2|0;w[c>>1]=z[a+2>>1]+z[c>>1];if(!f){x[115724]=b;w[b>>1]=z[a>>1];break a}g=f,h=bw(b),w[g>>1]=h;break a}else{e=cw(z[a>>1]);f=a;continue}}break}g=b,h=bw(d),w[g>>1]=h;x[115724]=b}return}_b(a)}function jja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=hb-48|0;hb=g;a:{b:{if(c>>>0>d>>>0){break b}if(Ne(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(Ah(Ye(b,f))){h=bc(Ye(b,f));i=dc(Ye(b,f));f=EP(g+8|0,e);x[114409]=0;W(1081,g+28|0,h|0,i|0,f|0);h=x[114409];x[114409]=0;if((h|0)==1){break a}ge(g+28|0);ge(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}DP(a,e);hb=g+48|0;return}a=N()|0;ge(f);Q(a|0);p()}function ST(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ae(d+24|0,a,b);b=x[d+24>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d+28>>2];x[a+12>>2]=b;x[a+4>>2]=c;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;c=y[NA(b)|0];f=a+4|0;g=NA(f),h=c,v[g|0]=h;Au(b);Au(f);if(qc(b,a+8|0)){continue}break}}Dc(d+16|0,a+12|0,a+4|0);hb=a+16|0;x[d+12>>2]=x[d+16>>2];x[d+8>>2]=x[d+20>>2];Dc(e+8|0,d+12|0,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function h2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;d=x[fe(e+12|0,fe(e+8|0,e+4|0))>>2];Ph(b,x[a+12>>2],d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}hb=e+16|0;return g|0}function Ys(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function Taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Hi(a,b,c,d);x[a>>2]=78248;b=Ck(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=0;e=a,f=cf(c),x[e+4232>>2]=f;x[114409]=0;V(1759,a+4260|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;U(1760,a+44|0,2,2)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}x[114409]=0;V(1761,a|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}return a|0}c=N()|0;lg(b);Cf(a);Q(c|0);p()}function OK(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{b:{if(Bk(a)>>>0<=xf(a)>>>0){break b}b=yb(a);d=xf(a);e=xf(a);x[114409]=0;b=Z(1764,c+12|0,d|0,e|0,b|0)|0;d=x[114409];x[114409]=0;c:{d:{if((d|0)!=1){x[114409]=0;P(1765,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}Vs(b);break b}a=R(0)|0;break c}a=R(0)|0;Vs(b)}Y(a|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break a}}hb=c+32|0;return}R(0)|0;zb();p()}function MK(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{b:{if(sd(a)>>>0<=Lb(a)>>>0){break b}b=yb(a);d=Lb(a);e=Lb(a);x[114409]=0;b=Z(1766,c+12|0,d|0,e|0,b|0)|0;d=x[114409];x[114409]=0;c:{d:{if((d|0)!=1){x[114409]=0;P(1767,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}Us(b);break b}a=R(0)|0;break c}a=R(0)|0;Us(b)}Y(a|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break a}}hb=c+32|0;return}R(0)|0;zb();p()}function JL(a){var b=0,c=0,d=0,e=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=y[b+1|0]<<8;d=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|c|d)!=-1346458146&(d|(c|y[b|0]))!=-1095062050){break a}b=a+16|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}a=a+8|0;e=((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+24|0)==(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))}return e}function Lka(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+15|0]=128;a=Lu(a,127,b+15|0);x[114409]=0;v[b+14|0]=64;d=U(908,a+12|0,127,b+14|0)|0;c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;v[b+13|0]=0;U(1003,a+24|0,127,b+13|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;hb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;de(d)}de(a);Q(b|0);p()}function BH(a){var b=E(0),c=0,d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;j=a-24|0;b=B[j>>2];c=a-8|0;d=B[c>>2];e=E(b+d);k=a-16|0;f=B[k>>2];l=B[a>>2];g=E(f+l);B[a>>2]=e+g;B[c>>2]=g-e;c=a-28|0;g=B[c>>2];h=a-12|0;m=B[h>>2];e=E(g+m);p=h;h=a-20|0;i=B[h>>2];a=a-4|0;n=B[a>>2];o=E(i+n);B[p>>2]=o-e;i=E(n-i);b=E(d-b);B[c>>2]=i+b;d=E(m-g);f=E(l-f);B[k>>2]=d+f;B[j>>2]=f-d;B[a>>2]=o+e;B[h>>2]=i-b}function zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){f=he(E(rf((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r()),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Wc(g),w[h>>1]=i;a=a+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<2}function zd(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;On(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;c=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?c|32:c;b=Vb(d+4|0,17381);x[114409]=0;O(350,a+43|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(b);YO(a);hb=d+16|0;return}a=N()|0;xb(b);Q(a|0);p()}function of(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;g=Cn(a);a:{if(b){f=x[b+4>>2];h=x[b>>2];break a}h=Cn(a)}x[e+8>>2]=h;x[e+12>>2]=f;f=x[a+12>>2];a=1;b:{if(!b){break b}b=c+f|0;d=c>>>0>b>>>0?d+1|0:d;x[e>>2]=2048;x[e+4>>2]=0;a=mv(e+8|0,e);c=x[a>>2];a=x[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;f=x[e+12>>2];if((d|0)==(f|0)&b>>>0>A[e+8>>2]|d>>>0>f>>>0){break b}}a=1}hb=e+16|0;return a}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;w[e+12>>1]=c;w[e+14>>1]=b;dg(e+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=hb-16|0;hb=b;d=z[e+14>>1];x[b+12>>2]=d;a:{if(_f(a)>>>0>=d>>>0){g=b,h=rc(a),x[g+8>>2]=h;pA(x[a>>2],x[Mb(b+12|0,b+8|0)>>2],c);f=x[b+8>>2];d=x[b+12>>2];if(f>>>0<d>>>0){Rq(a,d-f|0,c);break a}vo(a,x[a>>2]+(d<<1)|0);break a}QO(a);cu(a,hj(a,d));Rq(a,d,c)}hb=b+16|0;hb=e+16|0}function LV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,17);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+16|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function rR(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function r6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[114409]=0;P(e|0,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5269,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function p6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[114409]=0;P(e|0,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8619,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function gS(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{b:{if(tf(a)>>>0<=xc(a)>>>0){break b}b=yb(a);d=xc(a);e=xc(a);x[114409]=0;b=Z(43,c+12|0,d|0,e|0,b|0)|0;d=x[114409];x[114409]=0;c:{d:{if((d|0)!=1){x[114409]=0;P(44,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break d}Ou(b);break b}a=R(0)|0;break c}a=R(0)|0;Ou(b)}Y(a|0)|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)==1){break a}}hb=c+32|0;return}R(0)|0;zb();p()}function Qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;yb(a);x[c+12>>2]=214748364;x[114409]=0;x[c+8>>2]=2147483647;e=O(36,c+12|0,c+8|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){hb=c+16|0;c=x[e>>2];break a}R(0)|0;zb();p()}if(b>>>0>c>>>0){Xc();p()}c=UR(yb(a),b);x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;c=x[d+12>>2];g=yb(a),h=b+D(c,20)|0,x[g>>2]=h;oq(a);oq(a);hb=d+16|0}function G6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[114409]=0;P(e|0,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7188,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function w6(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[114409]=0;ma(e|0,c|0,+b);c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7560,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);d=x[114409];x[114409]=0;if((d|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function u6(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[114409]=0;ma(e|0,c|0,+b);c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,4009,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);d=x[114409];x[114409]=0;if((d|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function s6(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[114409]=0;ma(e|0,c|0,+b);c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3957,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);d=x[114409];x[114409]=0;if((d|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function ZU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;e=bc(b);f=dc(b);c=hb-16|0;hb=c;x[c+8>>2]=f;x[c+12>>2]=e;x[c+4>>2]=d+12;a:{if(!Hb(c+12|0,c+8|0)){break a}while(1){if((Vj(x[c+12>>2])|0)==x[x[c+4>>2]>>2]){break a}e=c+12|0;bj(e);if(Hb(e,c+8|0)){continue}break}}hb=c+16|0;x[d+8>>2]=x[c+12>>2];g=d,h=dc(b),x[g+4>>2]=h;b:{if(Hb(d+8|0,d+4|0)){hf(a,yb(x[d+8>>2]));break b}ii(a)}hb=d+16|0}function z6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[114409]=0;d=+$a(e|0,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7541,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return+d}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function xy(a,b,c){if($b(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+26704|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return cM(En(a))+-64|0}if(x[a+480180>>2]&67633152){return v[(c>>>1&31)+25824|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+26576|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+26640|0]}function eq(a){a=a|0;var b=0,c=0,d=0,e=0;On(a);b=x[a>>2];c=Ko(a);if(b-268435457>>>0>=4026531840){b=b+208|0;d=D(b,c);sqa(c,0,b,0);d=lb?0:d}else{d=0}a:{if(!d){break a}x[114409]=0;b=S(2990,d|0)|0;c=x[114409];x[114409]=0;b:{c:{if((c|0)==1){Y(R(0)|0)|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;b=0;if((c|0)==1){break c}}break b}R(0)|0;zb();p()}if(!b){break a}e=Sb(b,0,d)- -64|0}x[a+20>>2]=e;if(!e){return 0}return el(a)|0}function PC(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}a=a+12|0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}a=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);c=(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))>>>0>27}return c}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114409]=0;b=Z(2153,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5408,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function J7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114409]=0;b=Z(2156,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5377,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function G7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114409]=0;b=Z(2159,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5571,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function F7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114409]=0;b=Z(2160,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8780,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function E7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114409]=0;b=Z(2161,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5493,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function D7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114409]=0;V(2138,a|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114409]=0;b=Z(2162,e|0,b|0,c|0,d|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8706,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function pP(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a=Xb(a);d=Cb(b);x[114409]=0;P(112,a|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){a:{e=c,f=td(b),x[e+12>>2]=f;e=c,f=nf(b),x[e+8>>2]=f;if(Hb(c+12|0,c+8|0)){while(1){b=y[x[c+12>>2]];if((b|0)==13){b=10}x[114409]=0;P(111,a|0,b<<24>>24);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=c+12|0;gg(b);if(Hb(b,c+8|0)){continue}break}}hb=c+16|0;return}}b=N()|0;xb(a);Q(b|0);p()}function E6(a,b){a=a|0;b=b|0;var c=0,d=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[114409]=0;b=O(d|0,c|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3016,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function C6(a,b){a=a|0;b=b|0;var c=0,d=0;x[114409]=0;V(2211,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[114409]=0;b=O(d|0,c|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3067,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function UJ(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(B[a+4228>>2]*E(1.999000072479248))+E(.0010000000474974513))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(B[a+4232>>2]*E(1.999000072479248))+E(.0010000000474974513))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=w[(x[b+12>>2]<<1)+i>>1];x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function CH(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){gc(a,21);return-1}if(x[a+1396>>2]<=9){wk(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Il(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){gc(a,21)}return c}ea(3778,9049,1793,2236);p()}function cx(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!ts(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}gc(a,32);return 0}ea(11746,9049,1564,2463);p()}function Jy(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;x[a+1074372>>2]=b;ZL(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(mb[x[x[b>>2]+132>>2]](b)|0){d=pK(x[b+16>>2]);e=x[b+16>>2];c=E(E(c*E(A[e+480232>>2]))/E(B[d+8>>2]*B[pK(e)+20>>2]))}B[b+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function F2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=x[a+16>>2];g=x[a+12>>2];b:{if(d>>>0>g>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=d-g;x[e+4>>2]=c-f;d=x[fe(e+12|0,fe(e+8|0,e+4|0))>>2];Se(b,x[a+12>>2],d);x[a+12>>2]=x[a+12>>2]+d;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1}b=b+d|0;f=d+f|0;continue}break}hb=e+16|0;return f|0}function BV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{if(!Hh(a,7)){break b}c=0;if(!BB(a,13668)){break a}if(!Hh(a,1)){break b}c=-1;if(!ad(a,Uu(a))){break a}c=hb-16|0;hb=c;d=c+8|0;f=e+9|0;rB(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){gV(f)}c=-1;if(!d){break a}c=0;if(!xB(e+9|0)){break a}c=of(a,b,wB(e+9|0),lb);break a}c=-1}hb=e+16|0;return c|0}function kT(a,b){var c=0,d=0,e=0,f=0;a:{b:{if(!b){break b}if(!Qb(a,b)){break b}if(b>>>0<=3){c=hb-16|0;hb=c;c:{if(!b){break c}if(!Qb(a,b)){break c}while(1){v[c+11|0]=0;d:{if(b>>>0>d>>>0){ag(a,c+11|0);e=v[c+11|0];f=e>>>31|0;break d}e=0-f|0}v[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}x[c+4>>2]=x[c+12>>2];d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24)}hb=c+16|0;break a}d=Kf(a);cc(a,b-4|0)}}return d}function V0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=E(0),g=0,h=E(0);e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[114232];x[114232]=0;me();d=hb-16|0;hb=d;uw(d,a,e+12|0,0);f=dG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[114232];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[114232]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return E(f)}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=v[x[b+12>>2]+i|0]<<8;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Qi(e+24|0,e+23|0,c);x[114409]=0;T(894,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(678,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(502,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function Cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;MA(e+24|0,e+23|0,c);x[114409]=0;T(677,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(678,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(502,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function N7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;T(2152,d|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,6302,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;x[e+28>>2]=d;g=_j(a,c);Af(e,x[a+28>>2]);d=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=d;a:{if(!g){if(Bd(a,5)){break a}}h=x[a+28>>2];i=x[e+28>>2];f=hb-16|0;hb=f;d=gd(f+4|0);x[114409]=0;Z(705,b|0,h|0,d|0,i|0)|0;b=x[114409];x[114409]=0;b:{if((b|0)!=1){xb(d);hb=f+16|0;break b}a=N()|0;xb(d);Q(a|0);p()}}qj(a,g,c,e+16|0);hb=e+32|0}function u5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){b=ec(8);x[114409]=0;c=O(122,f+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,2);c=Dx(a,c,d,e,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=f+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function r5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){b=ec(8);x[114409]=0;c=O(122,f+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,2);c=Cx(a,c,d,e,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=f+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function Ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,15);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;hb=c+16|0}return a|0}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=x[a+28>>2];g=x[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Qh(v[b|0]),h=x[x[a>>2]+52>>2],mb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=d-g;x[e+8>>2]=c-f;d=x[fe(e+12|0,e+8|0)>>2];Se(x[a+24>>2],b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}hb=e+16|0;return f|0}function Bpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Om(e+24|0,e+23|0,c);x[114409]=0;T(213,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(82,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function $na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Om(e+24|0,e+23|0,c);x[114409]=0;T(197,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(82,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function fY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Qi(e+24|0,e+23|0,c);x[114409]=0;T(197,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(82,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;mO(e+24|0,e+23|0,c);x[114409]=0;T(81,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(82,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function Q7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[114409]=0;e=+ka(2148,d|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,1836,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();e=0}return+e}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function MV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;$u(e+24|0,e+23|0,c);x[114409]=0;T(416,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(82,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function uz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Qt(d+24|0,a,b);g=d+12|0;pl(d+16|0,g,x[d+24>>2],x[d+28>>2],c);f=x[d+16>>2];b=hb-16|0;hb=b;x[b+12>>2]=a;a=f;f=b+12|0;h=a-Ot(f)>>1;a=hb-16|0;hb=a;x[a+12>>2]=x[f>>2];MO(a+12|0,h);hb=a+16|0;hb=b+16|0;x[d+12>>2]=x[a+12>>2];i=d,j=ji(c,x[d+20>>2]),x[i+8>>2]=j;Dc(e+8|0,g,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function t7(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;d=E(la(2173,c|0,b|0));b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5334,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function s7(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;d=E(la(2174,c|0,b|0));b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2616,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function r7(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;d=E(la(2175,c|0,b|0));b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2523,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function q7(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;d=E(la(2176,c|0,b|0));b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2659,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function p7(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;d=E(la(2177,c|0,b|0));b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2567,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function x6(a){a=a|0;var b=0,c=0,d=0;x[114409]=0;V(2211,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[114409]=0;c=+ha(d|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,7578,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function v6(a){a=a|0;var b=0,c=0,d=0;x[114409]=0;V(2211,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[114409]=0;c=+ha(d|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,4026,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function t6(a){a=a|0;var b=0,c=0,d=0;x[114409]=0;V(2211,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[114409]=0;c=+ha(d|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3974,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function b1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){g=x[114232];x[114232]=0;a=AE(a,e+12|0,d,me());d=lb;f=x[114232];c:{if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}x[114232]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0;break a}x[c>>2]=4;if(!!a&(d|0)>=0|(d|0)>0){a=-1;d=2147483647;break a}a=0;d=-2147483648}hb=e+16|0;lb=d;return a|0}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=Cq(a);f=d,g=bc(b),x[f+12>>2]=g;f=d,g=dc(b),x[f+8>>2]=g;a:{if(Hb(d+12|0,d+8|0)){while(1){a=x[d+12>>2];if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(c|0)){a=yb(a);x[114409]=0;P(600,e|0,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}a=d+12|0;bj(a);if(Hb(a,d+8|0)){continue}break}}hb=d+16|0;return}a=N()|0;hd(e);Q(a|0);p()}function Gv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;c=mi(e+8|0,b);f=hb-16|0;hb=f;g=f+8|0;i=hb-16|0;hb=i;h=hb-16|0;hb=h;d=hb-16|0;hb=d;b=h+4|0;x[b+4>>2]=1;j=b,k=xD(1),x[j+8>>2]=k;hb=d+16|0;d=x[b+8>>2];x[114409]=0;O(245,d|0,c|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){c=So(b);Ro(g,hc(c),c);zD(b);hb=h+16|0;break a}a=N()|0;zD(b);Q(a|0);p()}hb=i+16|0;Im(a,g);Ab(g);hb=f+16|0;hb=e+16|0}function CY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[114409]=0;a=Fa(2130,a|0,b|0,c|0,d|0)|0;b=x[114409];x[114409]=0;a:{b:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;fa(2124,7041,e|0,f|0,g|0,h|0,i|0,j|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}_();a=-255}break a}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}return a|0}function r8(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;a:{b:{if(!a){break b}a=uc(b+8|0,a);x[114409]=0;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=S(2120,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break a}Y(R(0)|0)|0;x[114409]=0;W(2113,8362,0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();break b}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}a=0}hb=b+16|0;return a|0}function nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;d=yb(c);x[114409]=0;U(1253,b+8|0,a+12|0,d|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];d=x[yb(c)>>2];e=yb(b),f=d,x[e>>2]=f;e=yb(c),f=0,x[e>>2]=f;x[c>>2]=0;x[c+4>>2]=0;hb=a+16|0;break a}R(0)|0;zb();p()}Jd(b+12|0,c+12|0);w[b+28>>1]=z[c+28>>1];x[b+24>>2]=x[c+24>>2]}function T0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[114232];x[114232]=0;me();d=hb-16|0;hb=d;uw(d,a,e+12|0,1);f=Uw(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[114232];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[114232]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return+f}function Gda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-896|0;hb=d;b=Sb(a,0,66);x[b+72>>2]=0;x[b+76>>2]=0;x[b+68>>2]=256;w[b+66>>1]=65535;x[b+80>>2]=0;x[b+84>>2]=0;v[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=OM(a)+896|0;if((e|0)!=(a|0)){continue}break}d=Sb(d,0,896);e=OM(d);a=((c+229376|0)-c|0)/896|0;if((a|0)>0){while(1){Qp(c,e);c=c+896|0;f=a>>>0>1;a=a-1|0;if(f){continue}break}}hb=d+896|0;return b|0}function De(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=pp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(xH(a,b)&3){case 0:c=pp(C[b>>3],C[b+8>>3]);break a;case 1:c=-op(C[b>>3],C[b+8>>3],1);break a;case 2:c=-pp(C[b>>3],C[b+8>>3]);break a;default:break b}}c=op(C[b>>3],C[b+8>>3],1)}a=c;hb=b+16|0;return a}function yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;x[c+12>>2]=477218588;x[114409]=0;x[c+8>>2]=2147483647;e=O(36,c+12|0,c+8|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){hb=c+16|0;c=x[e>>2];break a}R(0)|0;zb();p()}if(b>>>0>c>>>0){Sv(3950);p()}c=_d(D(b,9),1);x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;g=yb(a),h=b+D(x[d+12>>2],9)|0,x[g>>2]=h;hb=d+16|0}function LF(a,b,c){var d=0,e=0,f=0,g=0;g=hb-16|0;hb=g;d=hb-16|0;hb=d;a:{if(b>>>0<=1073741807){b:{if(bp(b)){Ie(a,b);e=a;break b}ck(d+8|0,a,wl(b)+1|0);e=x[d+8>>2];_e(a,e);Jf(a,x[d+12>>2]);ee(a,b)}f=hb-16|0;hb=f;x[114409]=0;x[f+12>>2]=c;sE(e,b,f+12|0);c=x[114409];x[114409]=0;c:{if((c|0)!=1){hb=f+16|0;break c}R(0)|0;zb();p()}x[d+4>>2]=0;wg((b<<2)+e|0,d+4|0);hb=d+16|0;break a}If();p()}hb=g+16|0;return a}function yV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;tV(e+24|0,c);x[114409]=0;T(197,e+36|0,e+22|0,d|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;P(82,e+12|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)==1){break b}x[114409]=0;T(76,a|0,b|0,e+12|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}pf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;pf(e+24|0)}Q(c|0);p()}function i0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-208|0;hb=a;f=me();x[a>>2]=e;g=a+176|0;i=kf(g,20,f,5233,a);e=i+g|0;g=yg(g,e,c);f=a+12|0;Fc(f,c);x[114409]=0;f=S(2606,f|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Ob(a+12|0);h=f;f=a+16|0;MF(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Zm(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);hb=a+208|0;return b|0}b=N()|0;Ob(a+12|0);Q(b|0);p()}function vr(a){var b=0,c=0;go(a,1,10452);x[114409]=0;b=$(201)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[a+12>>2]=b;x[114409]=0;b=$(202)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}v[a+16|0]=b;x[114409]=0;b=$(203)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}v[a+18|0]=0;v[a+17|0]=b;x[114409]=0;V(204,a+20|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}return}b=N()|0;xb(a);Q(b|0);p()}function bI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){if((up(a+8|0)|0)>(b|0)){break d}}a=ec(8);x[114409]=0;c=O(122,c+4|0,6687)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}hb=c+16|0;return+(+x[(x[a+32>>2]+D(b,896)|0)+1075744>>2]*.015625)}b=N()|0;ic(a)}Q(b|0)}p()}function aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;yb(b);Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{d=Tg(b);if(!d){break a}x[114409]=0;P(1280,a|0,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[114409]=0;W(1281,a|0,b|0,e|0,d|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;Ct(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);Ct(b);hb=c+16|0;return a|0}function Hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;yb(b);Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{d=Lb(b);if(!d){break a}x[114409]=0;P(381,a|0,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[114409]=0;W(1699,a|0,b|0,e|0,d|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;nm(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);nm(b);hb=c+16|0;return a|0}function tQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;yb(b);Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{d=xc(b);if(!d){break a}x[114409]=0;P(558,a|0,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[114409]=0;W(1024,a|0,b|0,e|0,d|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;jo(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);jo(b);hb=c+16|0;return a|0}function Y7(a,b){a=a|0;b=b|0;var c=0,d=0;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;P(2141,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,6840,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function W7(a,b){a=a|0;b=b|0;var c=0,d=0;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;P(2143,c|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2270,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function D5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-32|0;hb=b;x[b+24>>2]=e;x[b+28>>2]=f;a:{a=ft(a,fm(b+16|0,Db(c),d),b+24|0);if(a+1>>>0>=3){a=ec(8);x[114409]=0;b=O(122,b+4|0,4262)|0;c=x[114409];x[114409]=0;b:{if((c|0)!=1){a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}d=N()|0;xb(b);break b}d=N()|0;ic(a)}Q(d|0);p()}hb=b+32|0;return a|0}p()}function ii(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;g=hb-16|0;hb=g;e=d+8|0;f=hb-16|0;hb=f;b=hb-16|0;hb=b;c=f+4|0;x[c+4>>2]=1;h=c,i=TD(1),x[h+8>>2]=i;hb=b+16|0;b=x[c+8>>2];x[114409]=0;S(249,b|0)|0;b=x[114409];x[114409]=0;a:{if((b|0)!=1){b=So(c);Ro(e,hc(b),b);oD(c);hb=f+16|0;break a}a=N()|0;oD(c);Q(a|0);p()}hb=g+16|0;Im(a,e);Ab(e);hb=d+16|0;x[a+8>>2]=0;x[a+12>>2]=0;return a|0}function Wq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-16|0;hb=c;d=x[a+4>>2];e=x[a>>2];v[c+12|0]=0;f=e;d=d+e|0;e=c+12|0;Ms(f,d,e);d=Rb(b);g=Rb(b);h=c,i=Cb(b),x[h+12>>2]=i;x[c+8>>2]=x[a+4>>2]-1;f=d;d=c+8|0;ue(f,g+x[Mb(e,d)>>2]|0,x[a>>2]);g=x[a>>2];h=c,i=Cb(b),x[h+12>>2]=i;x[c+8>>2]=x[a+4>>2]-1;b=x[Mb(e,d)>>2];e=x[a+4>>2];d=x[a>>2];v[c+7|0]=0;Ms(b+g|0,d+e|0,c+7|0);hb=c+16|0;return a|0}function $H(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){if((up(a+8|0)|0)>(b|0)){break d}}a=ec(8);x[114409]=0;c=O(122,c+4|0,6687)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}hb=c+16|0;return(y[(x[a+32>>2]+D(b,896)|0)+1075073|0]&4)>>>2|0}b=N()|0;ic(a)}Q(b|0)}p()}function jR(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=y[b+1|0]<<8;if((y[b|0]|c)>>>0<512|(c|y[b|0])>>>0>767){break a}b=a+112|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>64){break a}b=a+106|0;if((y[b|0]|y[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((y[b|0]|y[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(y[a|0]|y[a+1|0]<<8)>>>0<4e3}return d}function d6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;b=b+4|0;yb(b);Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{d=qd(b);if(!d){break a}x[114409]=0;P(2245,a|0,d|0);e=x[114409];x[114409]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[114409]=0;W(2246,a|0,b|0,e|0,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}}a=N()|0;oJ(c+4|0);Q(a|0);p()}a=c+4|0;Xd(a);oJ(a);hb=c+16|0}function aq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;e=bc(a);f=dc(a);b=hb-16|0;hb=b;x[b+8>>2]=f;x[b+12>>2]=e;if(Hb(b+12|0,b+8|0)){while(1){e=b+12|0;d=C[x[e>>2]>>3]+d;jz(e);if(Hb(e,b+8|0)){continue}break}}hb=b+16|0;g=c,h=bc(a),x[g+12>>2]=h;g=c,h=dc(a),x[g+8>>2]=h;if(Hb(c+12|0,c+8|0)){d=-d;while(1){a=c+12|0;b=x[a>>2];d=C[b>>3]+d;C[b>>3]=d;jz(a);if(Hb(a,c+8|0)){continue}break}}hb=c+16|0}function v5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114409]=0;c=O(122,e+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,1);c=Dx(a,c,d,0,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function s5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114409]=0;c=O(122,e+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,1);c=Cx(a,c,d,0,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{a=tQ(b,c);x[114409]=0;d=O(1022,a+12|0,c+12|0)|0;b=x[114409];x[114409]=0;b:{c:{if((b|0)!=1){x[114409]=0;O(1023,a+24|0,c+24|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}b=x[c+40>>2];x[a+36>>2]=x[c+36>>2];x[a+40>>2]=b;w[a+52>>1]=z[c+52>>1];b=x[c+48>>2];x[a+44>>2]=x[c+44>>2];x[a+48>>2]=b;break a}b=N()|0;break b}b=N()|0;de(d)}de(a);Q(b|0);p()}}function vL(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=hb-16|0;hb=c;d=x[b>>2];e=x[b+4>>2];b=ju(d,e);a:{if(b>>>0<=sd(a)>>>0){if(Lb(a)>>>0<b>>>0){x[c+12>>2]=d;bS(c+12|0,Lb(a));ue(d,x[c+12>>2],x[a>>2]);hy(a,x[c+12>>2],e,b-Lb(a)|0);break a}rM(a,ue(d,e,x[a>>2]));break a}if(x[a>>2]){Bt(a);bf(yb(a),x[a>>2],sd(a));f=yb(a),g=0,x[f>>2]=g;x[a>>2]=0;x[a+4>>2]=0}_u(a,Fe(a,b));hy(a,d,e,b)}hb=c+16|0}}function b7(a,b){a=a|0;b=b|0;var c=0;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;b=O(2191,c|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5713,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function a7(a,b){a=a|0;b=b|0;var c=0;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;b=O(2192,c|0,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2953,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function H5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-32|0;hb=b;x[b+24>>2]=e;x[b+28>>2]=f;a:{a=ft(a,fm(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=ec(8);x[114409]=0;b=O(122,b+4|0,4262)|0;c=x[114409];x[114409]=0;b:{if((c|0)!=1){a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}d=N()|0;xb(b);break b}d=N()|0;ic(a)}Q(d|0);p()}hb=b+32|0;return a|0}p()}function vi(a){var b=0,c=0;b=hb-16|0;hb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=op(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(xH(a,b)&3){case 0:a=op(C[b>>3],C[b+8>>3],1);break a;case 1:a=pp(C[b>>3],C[b+8>>3]);break a;case 2:a=-op(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-pp(C[b>>3],C[b+8>>3])}hb=b+16|0;return a}function iaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;b=c+8|0;wK(b,a,0);if($g(b)){a=x[a+20>>2];x[a+148>>2]=-1;b=hb-16|0;hb=b;d=x[c+8>>2];f=x[c+12>>2];e=dj(d,f);a=a+4|0;a:{if(e>>>0<=tf(a)>>>0){if(xc(a)>>>0<e>>>0){x[b+12>>2]=d;qM(b+12|0,xc(a));ue(d,x[b+12>>2],x[a>>2]);vK(a,x[b+12>>2],f,e-xc(a)|0);break a}oA(a,ue(d,f,x[a>>2]));break a}$y(a);Yn(a,bi(a,e));vK(a,d,f,e)}hb=b+16|0}hb=c+16|0}function s0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-96|0;hb=a;f=me();x[a>>2]=e;g=a- -64|0;i=kf(g,20,f,5233,a);e=i+g|0;g=yg(g,e,c);f=a+12|0;Fc(f,c);x[114409]=0;f=S(21,f|0)|0;h=x[114409];x[114409]=0;if((h|0)!=1){Ob(a+12|0);h=f;f=a+16|0;NF(h,a- -64|0,e,f);h=b;b=f+i|0;b=sm(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);hb=a+96|0;return b|0}b=N()|0;Ob(a+12|0);Q(b|0);p()}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(tf(a)>>>0>=b>>>0){f=d,g=xc(a),x[f+8>>2]=g;$h(x[a>>2],x[Mb(d+12|0,d+8|0)>>2],c);b=x[d+12>>2];e=x[d+8>>2];if(b>>>0>e>>>0){Fq(a,b-e|0,c);break a}uv(a,b+x[a>>2]|0);break a}if(x[a>>2]){xc(a);IC(a);iq(a);fg(yb(a),x[a>>2],tf(a));f=yb(a),g=0,x[f>>2]=g;x[a>>2]=0;x[a+4>>2]=0}Yn(a,bi(a,b));Fq(a,b,c)}hb=d+16|0}function L6(a){a=a|0;var b=0;x[114409]=0;V(2211,a|0);b=x[114409];x[114409]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){mb[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){_b(b);x[a+20>>2]=0}_b(a);return}Y(R(0)|0)|0;x[114409]=0;W(2113,1558,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Cz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+8>>2]=c;g=f,h=zf(b),x[g+28>>2]=h;c=f+8|0;uf(c,b,x[Mb(c,f+28|0)>>2]);x[114409]=0;b=S(445,c|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}c=x[f+8>>2];x[114409]=0;a=aa(411,a|0,b|0,c|0,d|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}Jc(f+8|0);hb=f+32|0;return a|0}a=N()|0;Jc(f+8|0);Q(a|0);p()}function o5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114409]=0;c=O(122,e+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,2);c=_I(a,c,2,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function n5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114409]=0;c=O(122,e+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,4);c=_I(a,c,4,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function m5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114409]=0;c=O(122,e+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,2);c=ZI(a,c,2,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function l5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114409]=0;c=O(122,e+4|0,4405)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(b,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}Ci(a,b,4);c=ZI(a,c,4,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;ic(b)}Q(a|0)}p()}function g3(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=x[(((y[b|0]^a)&255)<<2)+37808>>2]^a>>>8;a=a>>>8^x[(((a^y[b+1|0])&255)<<2)+37808>>2];a=a>>>8^x[(((a^y[b+2|0])&255)<<2)+37808>>2];a=a>>>8^x[(((a^y[b+3|0])&255)<<2)+37808>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=x[(((y[b|0]^a)&255)<<2)+37808>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function b2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;pj(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){d=a,e=Rb(c)+Cb(c)|0,x[d+44>>2]=e;fn(a,Rb(c),Rb(c),x[a+44>>2]);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Cb(c);d=a,e=b+Rb(c)|0,x[d+44>>2]=e;kw(c,Hc(c));Kw(a,Rb(c),Rb(c)+Cb(c)|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){ds(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}ds(a,b)}}function T7(a,b){a=a|0;b=+b;var c=0;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114409]=0;b=+cb(2146,c|0,+b);c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3818,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return+b}a=N()|0;x[114409]=0;X(20);c=x[114409];x[114409]=0;if((c|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;if(iB(b,e+24|0)){d=e+28|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)}f=e+8|0;Ad(f,b,d);a=hB(a,e+24|0,f);Ab(f);a:{if(!c){break a}d=(d>>>0)%(c>>>0)|0;if(!d){break a}x[114409]=0;O(313,b|0,c-d|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break a}b=N()|0;qe(a);Q(b|0);p()}hb=e+32|0}function Ww(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(cH(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return mb[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=mb[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}sc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function rA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;qS(a,b);e=b+8|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);Tc(a,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))+504|0);pS(a,d);a:{b=b+32|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!Tc(a,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))){break a}fo(a,c);return}Sb(c,0,80)}function X7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2142,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,6870,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Px(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(cf(x[a+16>>2])>>>0);c=E(E(mb[x[x[a>>2]+200>>2]](a))*b);d=a,e=E(E(c*E(2.0480000972747803))*E(mb[x[x[a>>2]+192>>2]](a))),B[d+4248>>2]=e;d=a,f=_h(E(E(c*E(4.0960001945495605))+E(8192))),x[d+4256>>2]=f;c=E(mb[x[x[a>>2]+204>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(mb[x[x[a>>2]+188>>2]](a)|0)){b=dH(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function Naa(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[114409]=0;P(488,b+4|0,8);b=x[114409];x[114409]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=R(74984)|0;if((ib|0)==(ca(74984)|0)){Y(b|0)|0;ut(x[a+20>>2]+4|0);_();return}Q(b|0);p()}function Fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c|0]);Db(y[c+1|0]);f=a,g=Db(y[c+2|0])|Db(y[c+3|0])<<8,w[f>>1]=g;Db(y[c+4|0]);Db(y[c+5|0]);f=a,g=Db(y[c+6|0])|Db(y[c+7|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function Eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c+3|0]);Db(y[c+2|0]);f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;Db(y[c+7|0]);Db(y[c+6|0]);f=a,g=Db(y[c+5|0])|Db(y[c+4|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function z7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2167,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,8637,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function y7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2168,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5287,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function x7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2169,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,4917,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function w7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2170,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,5678,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function v7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2171,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,1805,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function u7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2172,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3416,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function n7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2178,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3502,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function m7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2179,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3384,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function l7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2180,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3191,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function k7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2181,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3259,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function j7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2182,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3112,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function i7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2183,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3692,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function V7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;b=S(2144,b|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,2302,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=f+D(b,52);a:{if(x[d>>2]!=x[d+4>>2]){while(1){b=x[a+16>>2];f=x[d>>2];x[114409]=0;T(1688,b|0,f|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[d>>2]+52|0;x[d>>2]=b;if((b|0)!=x[d+4>>2]){continue}break}}Bc(d);hb=e+16|0;return}a=N()|0;Bc(d);Q(a|0);p()}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=f+(b<<5);a:{if(x[d>>2]!=x[d+4>>2]){while(1){b=x[a+16>>2];f=x[d>>2];x[114409]=0;T(1231,b|0,f|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[d>>2]+32|0;x[d>>2]=b;if((b|0)!=x[d+4>>2]){continue}break}}Bc(d);hb=e+16|0;return}a=N()|0;Bc(d);Q(a|0);p()}function fO(a,b,c){var d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;x[a+4>>2]=0;a:{if(b){b:{if($t(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}Rz(a);d=Qz(e+20|0);x[114409]=0;f=O(958,a|0,b|0)|0;g=x[114409];x[114409]=0;if((g|0)==1){break a}x[114409]=0;P(959,d|0,f|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}x[d+4>>2]=b;Oz(a,d);ge(d)}d=e+8|0;cm(d,a);Tq(d,b,y[c|0])}hb=e+32|0;return}a=N()|0;ge(d);Q(a|0);p()}function Jj(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;if(!kd(a)){c=PO(a);e=tz(a);b=hb-16|0;hb=b;x[b+8>>2]=e;x[b+12>>2]=c;a:{if(!Kt(b+12|0,b+8|0)){break a}while(1){c=hb-16|0;hb=c;x[c+12>>2]=x[b+12>>2];e=x[Ch(c+12|0)>>2];hb=c+16|0;if(z[e>>1]!=65535){break a}c=b+12|0;Ch(c);if(Kt(c,b+8|0)){continue}break}}hb=b+16|0;x[d+12>>2]=x[b+12>>2];b=fB(bc(a),x[d+12>>2])}hb=d+16|0;return b&65535}function spa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(556,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(557,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;rU(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);rU(b);hb=c+16|0;v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function ry(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=c>=.999?.999:c;c=d*32768;h=d*3.141592653589793;i=dt(b);while(1){e=((f^-1)<<12&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=dt(M(g*-152587890625e-16*d+1)*b);d=h*d;d=g*vi(d)/(d*i)}else{d=1}d=J(c*d+.5);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}w[a>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function e2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=x[a+24>>2];g=x[a+28>>2];if(f>>>0>=g>>>0){if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{x[d+12>>2]=g-f>>2;x[d+8>>2]=c-e;f=x[fe(d+12|0,d+8|0)>>2];Ph(x[a+24>>2],b,f);g=f<<2;x[a+24>>2]=g+x[a+24>>2];e=e+f|0;b=b+g|0}continue}break}hb=d+16|0;return e|0}function U7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;c=+ha(2145,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3890,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Rfa(a){a=a|0;var b=0,c=0,d=0,e=0;rl(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-16|0;P(1292,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;yb(x[a>>2]);a=x[a>>2];b=x[a>>2];a=li(a);x[114409]=0;T(27,b|0,a<<4,8);a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}}}function R7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;c=+ha(2147,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,3854,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function QF(a,b,c,d,e){var f=0,g=0,h=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=hb-16|0;hb=f;e=c+e|0;a:{if((e|0)==(c|0)){b=d;break a}g=b-d|0;e=e-c|0;if((g|0)<(e|0)){break a}v[f+15|0]=y[c|0];while(1){d=Bo(d,(g-e|0)+1|0,f+15|0);if(!d){break a}if(!xn(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((e|0)<=(g|0)){continue}break}}hb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function A7(a){a=a|0;var b=0,c=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114409]=0;c=+ha(2166,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break b}}Y(R(0)|0)|0;x[114409]=0;W(2113,6130,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function oE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Vb(d+8|0,c);x[114409]=0;T(2996,d+20|0,b|0,e|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[114409]=0;a=O(2997,a|0,d+20|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}xb(d+20|0);xb(e);x[a>>2]=74228;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;hb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;xb(d+20|0)}xb(e);Q(c|0);p()}function nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=f+D(b,6);a:{if(x[d>>2]!=x[d+4>>2]){while(1){b=x[a+16>>2];f=x[d>>2];x[114409]=0;T(718,b|0,f|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[d>>2]+6|0;x[d>>2]=b;if((b|0)!=x[d+4>>2]){continue}break}}Bc(d);hb=e+16|0;return}a=N()|0;Bc(d);Q(a|0);p()}function m1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=hb-16|0;hb=g;e=x[b>>2];a:{if(!e|!c){break a}d=a?d:0;while(1){f=ms(d>>>0<4?g+12|0:a,x[e>>2],0);if((f|0)==-1){h=-1;break a}if(a){if(d>>>0<=3){if(d>>>0<f>>>0){break a}sc(a,g+12|0,f)}d=d-f|0;a=a+f|0}else{a=0}if(!x[e>>2]){e=0;break a}h=f+h|0;e=e+4|0;c=c-1|0;if(c){continue}break}}if(a){x[b>>2]=e}hb=g+16|0;return h|0}function iI(a,b){a=a|0;b=+b;var c=0,d=0;c=hb-16|0;hb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ec(8);x[114409]=0;c=O(122,c+4|0,4086)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(d,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=mg(65536/b);a=a+32|0;x[x[a>>2]+480244>>2]=d;Hp(x[a>>2]);hb=c+16|0;return}a=N()|0;ic(d)}Q(a|0)}p()}function gI(a,b){a=a|0;b=+b;var c=0,d=0;c=hb-16|0;hb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ec(8);x[114409]=0;c=O(122,c+4|0,4107)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(d,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=mg(b*65536);a=a+32|0;x[x[a>>2]+480240>>2]=d;Hp(x[a>>2]);hb=c+16|0;return}a=N()|0;ic(d)}Q(a|0)}p()}function dl(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-16|0;hb=h;if(2147483631-b>>>0>=c>>>0){j=Rb(a);i=h+4|0;if(b>>>0<1073741799){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=mj(x[$c(h+4|0,h+12|0)>>2])+1|0}else{c=2147483631}Mh(i,a,c);c=x[h+4>>2];if(e){Se(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){Se((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}b=b+1|0;if((b|0)!=11){fg(a,j,b)}_e(a,c);Jf(a,x[h+8>>2]);hb=h+16|0;return}If();p()}function Wfa(a){a=a|0;var b=0,c=0,d=0,e=0;jr(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-8|0;P(1290,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;yb(x[a>>2]);a=x[a>>2];b=x[a>>2];a=lj(a);x[114409]=0;T(27,b|0,a<<3,8);a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}}}function z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=hb-16|0;hb=d;a:{if(!we(f)){x[a+8>>2]=x[f+8>>2];b=x[f+4>>2];x[a>>2]=x[f>>2];x[a+4>>2]=b;break a}c=x[f>>2];e=hb-16|0;hb=e;b:{c:{f=x[f+4>>2];d:{if(bp(f)){b=a;Ie(a,f);break d}if(f>>>0>1073741807){break c}ck(e+8|0,a,wl(f)+1|0);b=x[e+8>>2];_e(a,b);Jf(a,x[e+12>>2]);ee(a,f)}Ph(b,c,f+1|0);hb=e+16|0;break b}If();p()}}hb=d+16|0}function w9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a+4208>>2]=1060320051;x[a+4212>>2]=1041865114;x[a+4224>>2]=1049951732;b=a+4216|0;x[b>>2]=1065353216;x[b+4>>2]=1049951732;x[a>>2]=79572;x[114409]=0;U(1760,a+44|0,2,2)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){break a}x[114409]=0;V(1761,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}return a|0}b=N()|0;Cf(a);Q(b|0);p()}function ppa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;NB(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function Zf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;a:{if(!we(b)){x[a+8>>2]=x[b+8>>2];c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;break a}f=x[b>>2];d=hb-16|0;hb=d;b:{c:{c=x[b+4>>2];d:{if(ml(c)){b=a;Ie(a,c);break d}if(c>>>0>2147483631){break c}Mh(d+8|0,a,mj(c)+1|0);b=x[d+8>>2];_e(a,b);Jf(a,x[d+12>>2]);ee(a,c)}Se(b,f,c+1|0);hb=d+16|0;break b}If();p()}}hb=e+16|0;return a|0}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;CQ(a,c+11|0);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){CQ(a,c+11|0);v[b|0]=1;a=0}else{a=1}b=hb-16|0;hb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Vb(b+4|0,a);x[114409]=0;d=S(1006,a|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break b}xb(a)}hb=b+16|0;break a}b=N()|0;xb(a);Q(b|0);p()}hb=c+16|0;return d|0}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=Re(64);x[114409]=0;e=S(1523,c|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){c=Fy(d+8|0,e);e=x[c>>2];x[114409]=0;a=U(1751,e|0,a|0,b|0)|0;b=x[114409];x[114409]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Ey(d+12|0);break b}a=N()|0;Xf(c);break a}yq(d+12|0,c)}Xf(c);hb=d+16|0;return x[d+12>>2]}a=N()|0;_b(c)}Q(a|0);p()}function y$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;e=Zc(a+8|0),f=0,v[e+128|0]=f;Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(2706,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(2707,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;kF(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);kF(b);hb=c+16|0;return a|0}function ica(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;f=-1;e=hb-16|0;hb=e;c=e+8|0;g=d+8|0;DL(c,g);h=Fb(c);c=nd(a,ac(e,c));if((h|0)==(c|0)){ad(a,Fb(e+8|0))}hb=e+16|0;a=(c|0)==(h|0);if(!a){EL(g)}a:{if(!a){break a}f=0;if(!JL(d+8|0)){break a}if(b){a=d+16|0;if(x[b>>2]!=(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))|x[b+4>>2]){break a}}f=1}hb=d+32|0;return f|0}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=e+(b<<11);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];e=x[c>>2];x[114409]=0;P(1771,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[c>>2]+2048|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Bc(c);hb=d+16|0;return}a=N()|0;Bc(c);Q(a|0);p()}function XH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){a=ec(8);x[114409]=0;c=O(122,c+4|0,6687)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}a=x[a+32>>2]+D(b,896)|0;x[a+1075e3>>2]=0;x[a+1075060>>2]=0;hb=c+16|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function Dz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+8>>2]=c;f=e,g=zf(b),x[f+28>>2]=g;c=e+8|0;uf(c,b,x[Mb(c,e+28|0)>>2]);x[114409]=0;b=S(445,c|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}c=x[e+8>>2];x[114409]=0;Z(1112,a|0,b|0,c|0,d|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}Jc(e+8|0);hb=e+32|0;return 1}a=N()|0;Jc(e+8|0);Q(a|0);p()}function $T(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))>>>0<14){break a}b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;d=!(y[a|0]|y[a+1|0]<<8)}return d}function taa(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;ij(a);e=x[b+4>>2];yb(a);f=Bb(d+8|0,c);g=Bb(d+4|0,x[a>>2]);h=Bb(d,x[b+4>>2]);i=d,j=CC(x[f>>2],x[g>>2],x[h>>2]),x[i+12>>2]=j;x[b+4>>2]=x[d+12>>2];i=b,j=rq(yb(a),c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Do(a,rc(a));hb=d+16|0;return e|0}function aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;Iu(a);e=x[b+4>>2];yb(a);f=Bb(d+8|0,c);g=Bb(d+4|0,x[a>>2]);h=Bb(d,x[b+4>>2]);i=d,j=PS(x[f>>2],x[g>>2],x[h>>2]),x[i+12>>2]=j;x[b+4>>2]=x[d+12>>2];yb(a);i=b,j=at(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];ZA(a,ng(a));hb=d+16|0;return e|0}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;Ge(a);e=x[b+4>>2];yb(a);f=Bb(d+8|0,c);g=Bb(d+4|0,x[a>>2]);h=Bb(d,x[b+4>>2]);i=d,j=qC(x[f>>2],x[g>>2],x[h>>2]),x[i+12>>2]=j;x[b+4>>2]=x[d+12>>2];i=b,j=rq(yb(a),c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=d+16|0;return e|0}function Uy(a,b,c,d){var e=0,f=0;a:{if(x[a+1074392>>2]!=(c|0)){break a}e=D(b,896)+a|0;f=e+1075072|0;b:{if(d){c=D(b,896)+a|0;x[c+1075680>>2]=0;d=c+1074992|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075072>>2]|4096;break b}c=D(b,896)+a|0;x[c+1075672>>2]=0;c=x[c+1075072>>2]}x[f>>2]=c|2097152;Vl(a,b,255,0);if(!(y[e+1075073|0]&2)){break a}a=a+1304392|0;if(!yd(a)){break a}Pi(x[a>>2],b,0)}}function Lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;io(a);e=x[b+4>>2];yb(a);f=Bb(d+8|0,c);g=Bb(d+4|0,x[a>>2]);h=Bb(d,x[b+4>>2]);i=d,j=ST(x[f>>2],x[g>>2],x[h>>2]),x[i+12>>2]=j;x[b+4>>2]=x[d+12>>2];i=b,j=rq(yb(a),c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];QA(a,xc(a));hb=d+16|0;return e|0}function qna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=e+D(b,48);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];e=x[c>>2];x[114409]=0;P(752,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[c>>2]+48|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Bc(c);hb=d+16|0;return}a=N()|0;Bc(c);Q(a|0);p()}function at(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=hb-32|0;hb=d;Ae(d+24|0,a,b);e=x[d+24>>2];b=hb-16|0;hb=b;g=x[d+28>>2];x[b+12>>2]=g;h=e;e=g-e|0;i=b,j=vk(c,h,e)+D((e|0)/6|0,6)|0,x[i+8>>2]=j;Dc(d+16|0,b+12|0,b+8|0);hb=b+16|0;i=d,j=rL(a,x[d+16>>2]),x[i+12>>2]=j;i=d,j=gy(c,x[d+20>>2]),x[i+8>>2]=j;Dc(f+8|0,d+12|0,d+8|0);hb=d+32|0;hb=f+16|0;return x[f+12>>2]}function Rma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=e+D(b,33);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];e=x[c>>2];x[114409]=0;P(780,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[c>>2]+33|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Bc(c);hb=d+16|0;return}a=N()|0;Bc(c);Q(a|0);p()}function Lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[d+12>>2]=0;U(1297,a+8|0,d+12|0,d+11|0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){hb=d+16|0;break a}R(0)|0;zb();p()}d=Jk(a+12|0);v[a+30|0]=c;w[a+28>>1]=0;x[a+24>>2]=b;x[114409]=0;P(1296,a|0,1);b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}b=N()|0;Me(d);hO(a);Q(b|0);p()}function xk(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=hb-32|0;hb=c;f=uc(c+24|0,x[a>>2]);d=x[e+12>>2];g=x[d>>2];d=x[d+4>>2];x[c+16>>2]=g;x[c+20>>2]=d;h=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=h;x[c>>2]=g;x[c+4>>2]=d;f=Mc(c+8|0,c);hb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}hb=e+16|0;return a}function lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=-1;a:{if(!Yj(a,d+8|0)){break a}c=d+8|0;b:{if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(Vj(5099)|0)){break b}c=c+4|0;if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>259){break b}e=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>255}c=0;if(!e){break a}c=of(a,b,36,0)}hb=d+16|0;return c|0}function hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=e+(b<<3);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];e=x[c>>2];x[114409]=0;P(951,b|0,e|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=x[c>>2]+8|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Bc(c);hb=d+16|0;return}a=N()|0;Bc(c);Q(a|0);p()}function pja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=x[a>>2];b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1076,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){R(0)|0;zb();p()}LP(e,a);Hr(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function ofa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=x[a>>2];b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1340,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){R(0)|0;zb();p()}ep(e,a);Hr(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function _K(a,b){var c=0,d=0,e=0,f=E(0),g=0,h=E(0);c=hb-16|0;hb=c;e=0;a:{if(!Nf(x[x[a>>2]-12>>2]+a|0)){break a}x[c+12>>2]=0;Xi(a,c+12|0);d=x[c+12>>2];e=0;if(d>>>0>65535){break a}Nl(b,d);if(x[c+12>>2]){d=0;while(1){x[c+8>>2]=0;Ap(a,c+8|0);f=B[c+8>>2];g=Pb(b,d),h=f,B[g>>2]=h;d=d+1|0;if(d>>>0<A[c+12>>2]){continue}break}}e=Nf(x[x[a>>2]-12>>2]+a|0)}d=e;hb=c+16|0;return d}function ZK(a,b){var c=0,d=0,e=0,f=E(0),g=0,h=E(0);c=hb-16|0;hb=c;e=0;a:{if(!Nf(x[x[a>>2]-12>>2]+a|0)){break a}w[c+14>>1]=0;Ef(a,c+14|0);d=z[c+14>>1];e=0;if(d>>>0>65535){break a}Nl(b,d);if(z[c+14>>1]){d=0;while(1){x[c+8>>2]=0;Ap(a,c+8|0);f=B[c+8>>2];g=Pb(b,d),h=f,B[g>>2]=h;d=d+1|0;if(d>>>0<z[c+14>>1]){continue}break}}e=Nf(x[x[a>>2]-12>>2]+a|0)}a=e;hb=c+16|0;return a}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/6;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c|0]);f=a,g=Db(y[c+1|0])|Db(y[c+2|0])<<8,w[f>>1]=g;Db(y[c+3|0]);f=a,g=Db(y[c+4|0])|Db(y[c+5|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+6|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,6)|0}function Iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/6;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c+2|0]);f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;Db(y[c+5|0]);f=a,g=Db(y[c+4|0])|Db(y[c+3|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+6|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,6)|0}function V_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=x[a>>2];b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(179,c|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){R(0)|0;zb();p()}ep(e,a);Hr(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function R$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;f=x[mc(a)>>2];d=x[c>>2]-x[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d>>>0<=1?1:d;h=x[b>>2];i=x[a>>2];g=ls((f|0)!=2638?x[a>>2]:0,d);if(g){if((f|0)!=2638){oe(a)}x[e+4>>2]=2580;f=Sd(e+8|0,g,e+4|0);wF(a,f);Lc(f);x[b>>2]=x[a>>2]+(h-i|0);x[c>>2]=d+x[a>>2];hb=e+16|0;return}gw();p()}function Jl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+47360|0]}if(a>>>0<=511){return v[(a>>>5|0)+47360|0]+5|0}return v[(a>>>10|0)+47360|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+47360|0]+15|0}return v[(a>>>20|0)+47360|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+47360|0]+25|0}a=v[(a>>>30|0)+47360|0]+30|0}else{a=0}return a}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if($t(a)>>>0<b>>>0){if(iv(a)>>>0<b>>>0){break b}Rz(a);d=Qz(c+20|0);x[114409]=0;P(962,d|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}b=c+8|0;cm(b,a);lq(c,a);x[114409]=0;T(963,d|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}Oz(a,d);ge(d)}hb=c+32|0;return}Xc();p()}a=N()|0;ge(d);Q(a|0);p()}function Ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{b=ym(d,a+8|0,fB(b,c));if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];f=x[d+12>>2];x[114409]=0;T(507,c|0,e|0,f|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}x[b>>2]=x[b>>2]+2;ke(d+12|0);if(x[b>>2]!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function zF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;f=x[mc(a)>>2];d=x[c>>2]-x[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=x[b>>2];i=x[a>>2];g=ls((f|0)!=2638?x[a>>2]:0,d);if(g){if((f|0)!=2638){oe(a)}x[e+4>>2]=2580;f=Sd(e+8|0,g,e+4|0);wF(a,f);Lc(f);x[b>>2]=x[a>>2]+(h-i|0);x[c>>2]=x[a>>2]+(d&-4);hb=e+16|0;return}gw();p()}function e8(a){a=a|0;var b=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;if((b|0)!=1){b=x[a+24>>2];if(b){_b(Js(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){_b(b);x[a+20>>2]=0}_b(a);return}Y(R(0)|0)|0;x[114409]=0;W(2113,1585,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Nr(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function Dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c|0]);Db(y[c+1|0]);Db(y[c+2|0]);Db(y[c+3|0]);Db(y[c+4|0]);Db(y[c+5|0]);f=a,g=Db(y[c+6|0])|Db(y[c+7|0])<<8,w[f>>1]=g;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function Cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c+7|0]);Db(y[c+6|0]);Db(y[c+5|0]);Db(y[c+4|0]);Db(y[c+3|0]);Db(y[c+2|0]);f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function kU(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=89478485;x[114409]=0;x[b+8>>2]=2147483647;e=O(36,b+12|0,b+8|0)|0;f=x[114409];x[114409]=0;a:{if((f|0)!=1){hb=b+16|0;b=x[e>>2];break a}R(0)|0;zb();p()}if(b>>>0>=d>>>0){a=im(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function eI(a,b){a=a|0;b=+b;var c=0,d=0;c=hb-16|0;hb=c;a:{b:{c:{if(!(!(b<0)&b<=1)){d=ec(8);x[114409]=0;c=O(122,c+4|0,7596)|0;a=x[114409];x[114409]=0;if((a|0)==1){break c}a=oc(d,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=mg(b*256);x[x[a+32>>2]+1074444>>2]=d;hb=c+16|0;return}a=N()|0;ic(d)}Q(a|0)}p()}function Sp(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+830|0]=y[b+830|0]&15|c<<4;break a}c=y[b+830|0]>>>4|0;break a}if(d){if(c){v[b+854|0]=c;break a}c=y[b+854|0];break a}if(c){v[b+830|0]=c;break a}c=y[b+830|0]}b:{if(!(v[b+872|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(x[a+480180>>2]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a=Cq(a);e=d,f=bc(b),x[e+12>>2]=f;e=d,f=dc(b),x[e+8>>2]=f;a:{if(Hb(d+12|0,d+8|0)){while(1){b=x[d+12>>2];if((Vj(b)|0)==(c|0)){b=yb(b);x[114409]=0;P(600,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}}b=d+12|0;bj(b);if(Hb(b,d+8|0)){continue}break}}hb=d+16|0;return}b=N()|0;hd(a);Q(b|0);p()}function AQ(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26|(y[a+66|0]|y[a+65|0]!=16&y[a+65|0]!=1)){break a}if(y[a- -64|0]&3){break a}b=a+78|0;if((y[b|0]|y[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((y[a|0]|y[a+1|0]<<8)>>>0>127){break a}c=hb-16|0;hb=c;d=SB(b,a);hb=c+16|0;a=d?a:b;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function tE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;if(1073741807-b>>>0>=c>>>0){h=Rb(a);g=f+4|0;if(b>>>0<536870887){x[f+12>>2]=b<<1;x[f+4>>2]=b+c;c=wl(x[$c(f+4|0,f+12|0)>>2])+1|0}else{c=1073741807}ck(g,a,c);c=x[f+4>>2];if(e){Ph(c,h,e)}if((d|0)!=(e|0)){g=e<<2;Ph(g+c|0,h+g|0,d-e|0)}b=b+1|0;if((b|0)!=2){ap(h,b)}_e(a,c);Jf(a,x[f+8>>2]);hb=f+16|0;return}If();p()}function sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+4>>2]=0;Zc(a+8|0);Yd(d+4|0,x[Bb(d,a)>>2]);a:{if(!b){break a}x[114409]=0;P(944,a|0,b|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;T(945,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;Vn(d+4|0);Q(a|0);p()}b=d+4|0;Xd(b);Vn(b);hb=d+16|0;return a|0}function jI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-513>>>0<=4294966814){a=ec(8);x[114409]=0;c=O(122,c+4|0,5320)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);hb=c+16|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function _7(a,b){a=a|0;b=b|0;var c=0;x[114409]=0;V(2138,a|0);c=x[114409];x[114409]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}_b(b);x[a+20>>2]=0;return}Y(R(0)|0)|0;x[114409]=0;W(2113,2146,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;c=e+4|0;x[c>>2]=a;d=x[a+4>>2];x[c+4>>2]=d;x[c+8>>2]=d+D(b,20);a:{b=x[c+4>>2];d=x[c+8>>2];if((b|0)!=(d|0)){while(1){f=yb(a);x[114409]=0;P(903,f|0,b|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+20|0;x[c+4>>2]=b;if((b|0)!=(d|0)){continue}break}}Jb(c);hb=e+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function vT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+4>>2]=0;Zc(a+8|0);Yd(d+4|0,x[Bb(d,a)>>2]);a:{if(!b){break a}x[114409]=0;P(690,a|0,b|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;T(691,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;co(d+4|0);Q(a|0);p()}b=d+4|0;Xd(b);co(b);hb=d+16|0;return a|0}function rV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+4>>2]=0;Zc(a+8|0);Yd(d+4|0,x[Bb(d,a)>>2]);a:{if(!b){break a}x[114409]=0;P(443,a|0,b|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;T(444,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;qV(d+4|0);Q(a|0);p()}b=d+4|0;Xd(b);qV(b);hb=d+16|0;return a|0}function dW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+4>>2]=0;Zc(a+8|0);Yd(d+4|0,x[Bb(d,a)>>2]);a:{if(!b){break a}x[114409]=0;P(381,a|0,b|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;T(382,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;nm(d+4|0);Q(a|0);p()}b=d+4|0;Xd(b);nm(b);hb=d+16|0;return a|0}function Lu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+4>>2]=0;Zc(a+8|0);Yd(d+4|0,x[Bb(d,a)>>2]);a:{if(!b){break a}x[114409]=0;P(558,a|0,b|0);e=x[114409];x[114409]=0;if((e|0)!=1){x[114409]=0;T(559,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;jo(d+4|0);Q(a|0);p()}b=d+4|0;Xd(b);jo(b);hb=d+16|0;return a|0}function PZ(a){a=a|0;if(y[461120]){return x[115279]}if(!y[461640]){v[461640]=1}bd(461472,70820);bd(461484,70848);bd(461496,70876);bd(461508,70908);bd(461520,70948);bd(461532,70984);bd(461544,71012);bd(461556,71048);bd(461568,71064);bd(461580,71080);bd(461592,71096);bd(461604,71112);bd(461616,71128);bd(461628,71144);v[461120]=1;x[115279]=461472;return 461472}function hJ(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=x[d+12>>2];b:{c:{e=x[a>>2];f=Bf(e);if((f|0)==(Cb(c)|0)){x[114409]=0;c=aa(320,c|0,0,-1,e|0,f|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}R(0)|0;zb();p()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}hb=d+16|0;return a}function Ula(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=E(0);if(d){e=a+e|0;a=0;while(1){h=he(E(rf(B[b>>2],E(-1))*E(128)));a:{if(E(F(h))<E(2147483648)){g=~~h;break a}g=-2147483648}f=hb-16|0;hb=f;x[f+12>>2]=g;x[f+8>>2]=-128;x[f+4>>2]=127;g=v[Yf(f+8|0,fe(f+12|0,f+4|0))|0];hb=f+16|0;v[e|0]=g;e=c+e|0;b=b+4|0;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function kI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){a=ec(8);x[114409]=0;c=O(122,c+4|0,2334)|0;b=x[114409];x[114409]=0;if((b|0)==1){break c}a=oc(a,c);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}x[x[a+32>>2]+1074416>>2]=b;hb=c+16|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function _m(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+12|0;Fc(d,b);x[114409]=0;b=S(2607,d|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}x[114409]=0;d=S(2616,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}x[c>>2]=d;x[114409]=0;P(2617,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ob(e+12|0);hb=e+16|0;return}a=N()|0;Ob(e+12|0);Q(a|0);p()}function cy(a,b,c){var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=f+4|0;x[d>>2]=a;e=x[a+4>>2];x[d+4>>2]=e;x[d+8>>2]=e+D(b,52);a:{b=x[d+4>>2];e=x[d+8>>2];if((b|0)!=(e|0)){while(1){g=yb(a);x[114409]=0;T(1688,g|0,b|0,c|0);g=x[114409];x[114409]=0;if((g|0)==1){break a}b=b+52|0;x[d+4>>2]=b;if((b|0)!=(e|0)){continue}break}}Jb(d);hb=f+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function bn(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+12|0;Fc(d,b);x[114409]=0;b=S(2576,d|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}x[114409]=0;d=S(2590,b|0)|0;f=x[114409];x[114409]=0;if((f|0)==1){break a}v[c|0]=d;x[114409]=0;P(2591,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ob(e+12|0);hb=e+16|0;return}a=N()|0;Ob(e+12|0);Q(a|0);p()}function Mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;a:{b:{e=GN(b,c);if((e|0)!=-1){f=d,g=td(b),x[f+16>>2]=g;f=d,g=Le(d+16|0,e),x[f+20>>2]=g;f=d,g=Le(d+20|0,1),x[f+24>>2]=g;c=rd(d+28|0,d+24|0);f=d,g=nf(b),x[f+8>>2]=g;e=rd(d+12|0,d+8|0);Rx(b,x[c>>2],x[e>>2]);break b}if(!Cb(b)){break b}if(SJ(b,c)){break b}gd(a);break a}Jd(a,b)}hb=d+32|0}function vJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=Re(12);b=x[b>>2];a=x[a>>2];x[114409]=0;a=U(2125,c|0,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=a;a=U(2127,d+12|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){hb=b+16|0;break a}R(0)|0;zb();p()}hb=d+16|0;return x[a>>2]}a=N()|0;_b(c);Q(a|0);p()}function qi(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(Cg(a,f+12|0)){break b}g=4;h=tk(a);if(!Bg(d,64,h)){break b}b=Ym(d,h);while(1){c:{Dl(a);b=b-48|0;if(Cg(a,f+12|0)|(e|0)<2){break c}g=tk(a);if(!Bg(d,64,g)){break a}e=e-1|0;b=Ym(d,g)+D(b,10)|0;continue}break}g=2;if(!Cg(a,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function pi(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(mh(a,f+12|0)){break b}g=4;h=Bl(a);if(!rk(d,64,h)){break b}b=Xm(d,h);while(1){c:{gn(a);b=b-48|0;if(mh(a,f+12|0)|(e|0)<2){break c}g=Bl(a);if(!rk(d,64,g)){break a}e=e-1|0;b=Xm(d,g)+D(b,10)|0;continue}break}g=2;if(!mh(a,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;a:{b:{e=GN(b,c);if((e|0)!=-1){f=d,g=td(b),x[f+16>>2]=g;f=d,g=Le(d+16|0,e),x[f+20>>2]=g;f=d,g=Le(d+20|0,1),x[f+24>>2]=g;c=rd(d+28|0,d+24|0);f=d,g=nf(b),x[f+8>>2]=g;e=rd(d+12|0,d+8|0);Rx(b,x[c>>2],x[e>>2]);break b}if(!Cb(b)){break b}if(SJ(b,c)){break b}Xb(a);break a}Jd(a,b)}hb=d+32|0}function J8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a+4272>>2]=1065353216;x[a+4208>>2]=1056880300;x[a+4212>>2]=1050733080;x[a>>2]=80620;x[a+4216>>2]=1056964608;x[114409]=0;U(1760,a+44|0,2,2)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){break a}x[114409]=0;V(1761,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}return a|0}b=N()|0;Cf(a);Q(b|0);p()}function mka(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1020,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}qe(a);oo(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function lga(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1257,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}Qk(a);gD(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function fca(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1664,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}qe(a);oo(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function eka(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1034,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}Zt(a);kQ(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Z7(a){a=a|0;var b=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}_b(b);x[a+20>>2]=0;return}Y(R(0)|0)|0;x[114409]=0;W(2113,5037,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_()}return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Waa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1757,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}Xf(a);je(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Dfa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1307,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}ge(a);Hr(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Dba(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(1706,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}Ik(a);dm(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function jy(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(y[b|0]|(e-5&255)>>>0>1){break a}v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=39;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=39;v[b|0]=y[d|0]}v[c|0]=0}}function Zoa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(572,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}qe(a);oo(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function T3(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(2335,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}Vi(a);RT(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Mma(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(790,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}qe(a);oo(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Kpa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(519,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}qe(a);oo(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Foa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(612,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}qe(a);oo(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Boa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(619,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}Ab(a);RT(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function yfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(1318,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(1319,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;YN(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);YN(b);hb=c+16|0;return a|0}function pX(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;a=S(255,c|0)|0;e=x[114409];x[114409]=0;if((e|0)==1){R(0)|0;zb();p()}pr(a);gD(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function C5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=hb-32|0;hb=b;a:{a=ft(a,fm(b+24|0,Db(c),d),0);if(a+1>>>0>=3){a=ec(8);x[114409]=0;b=O(122,b+12|0,4262)|0;c=x[114409];x[114409]=0;b:{if((c|0)!=1){a=oc(a,b);x[114409]=0;T(2132,a|0,82416,2140);a=x[114409];x[114409]=0;if((a|0)!=1){break a}d=N()|0;xb(b);break b}d=N()|0;ic(a)}Q(d|0);p()}hb=b+32|0;return a|0}p()}function cja(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(381,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(1105,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;nm(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);nm(b);hb=c+16|0;return a|0}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;g=d;while(1){g=(Db(y[c|0])+g|0)+(Db(y[c+1|0])<<8)|0;w[a>>1]=g;d=(Db(y[c+2|0])+d|0)+(Db(y[c+3|0])<<8)|0;w[a+2>>1]=d;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<2}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;g=d;while(1){g=(Db(y[c+1|0])+g|0)+(Db(y[c|0])<<8)|0;w[a>>1]=g;d=(Db(y[c+3|0])+d|0)+(Db(y[c+2|0])<<8)|0;w[a+2>>1]=d;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<2}function $7(a){a=a|0;var b=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Ld(a)|0}Y(R(0)|0)|0;x[114409]=0;W(2113,8009,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();return 0}return Ld(17381)|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function fma(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(895,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(896,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;MR(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);MR(b);hb=c+16|0;return a|0}function cma(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(897,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(898,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;LR(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);LR(b);hb=c+16|0;return a|0}function OV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=-1;a:{if(!Hh(a,7)){break a}c=0;if(!BB(a,7618)){break a}c=hb-16|0;hb=c;d=c+8|0;f=e+5|0;mV(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){nV(f)}c=-1;if(!d){break a}c=0;if(!AB(e+5|0)){break a}c=of(a,b,zB(e+5|0),lb)}hb=e+16|0;return c|0}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+28>>2]=d;d=_j(a,c);Af(e,x[a+28>>2]);f=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=f;a:{if(!d){if(Bd(a,5)){break a}}f=x[a+28>>2];XB(b,x[e+28>>2]);if(x[e+28>>2]){while(1){IO(f,vc(b,g));g=g+1|0;if(g>>>0<A[e+28>>2]){continue}break}}}a=qj(a,d,c,e+16|0);hb=e+32|0;return a|0}function wT(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(558,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(679,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;jo(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);jo(b);hb=c+16|0;return a|0}function jZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=c;c=Cb(a);if(!((e|0)==-1|c>>>0<b>>>0)){x[f>>2]=c-b;g=f,h=x[Mb(f+12|0,f)>>2],x[g+4>>2]=h;b=xn(Rb(a)+b|0,d,x[Mb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=x[f+4>>2];c=x[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}hb=f+16|0;return b|0}wm();p()}function XV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(384,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(385,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;TB(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);TB(b);hb=c+16|0;return a|0}function WP(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=y[b|0]|y[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|y[a+6|0]>128){break a}b=a+200|0;b=y[b|0]|y[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>3999){break a}b=a+140|0;if(!(y[b|0]|y[b+1|0]<<8)){break a}a=a+148|0;c=(y[a|0]|y[a+1|0]<<8)==12800}return c}function Pz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(y[a+20|0]){break a}d=b;b=-1-b|0;b=d+(b>>>0<c>>>0?b:c)|0;if(b>>>0<=A[a+16>>2]){break a}b=Wz(b,4096);iR(a,b-x[a+16>>2]|0);e=a,f=(h=a,i=Cc(a+4|0,x[a+16>>2]),j=b-x[a+16>>2]|0,g=x[x[a>>2]+48>>2],mb[g](h|0,i|0,j|0)|0)+x[a+16>>2]|0,x[e+16>>2]=f;if(!(mb[x[x[a>>2]+44>>2]](a)|0)){break a}v[a+20|0]=1}}function Maa(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((xc(x[a+20>>2]+4|0)|0)!=8){break b}c=x[x[a+20>>2]+4>>2];if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133){break b}b=x[x[a+20>>2]+4>>2];c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=c;x[a+4264>>2]=b;break a}lK(a,b)}Ys(a)}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a+4208>>2]=1065353216;x[a+4212>>2]=1065353216;b=a+4216|0;x[b>>2]=1051372203;x[b+4>>2]=0;x[a>>2]=80824;x[114409]=0;U(1760,a+44|0,2,2)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){break a}x[114409]=0;V(1761,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}return a|0}b=N()|0;Cf(a);Q(b|0);p()}function kna(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(40,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(41,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;uS(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);uS(b);hb=c+16|0;return a|0}function iy(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;a:{b:{while(1){h=g&255;if(ky(b,c,h>>>0>1)){break b}zh(b,d);zh(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(Bn(y[b|0])>>>0>Bn(y[d|0])>>>0){zh(b,d);zh(c,e)}v[f+13|0]=y[b|0];wz(a,f+13|0,c);v[b|0]=0;v[c|0]=0;break a}v[f+15|0]=0;v[f+14|0]=0;wz(a,f+15|0,f+14|0)}hb=f+16|0}function Rp(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+830|0];if(c){v[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+854|0]=c;break a}c=y[b+854|0];break a}if(c){v[b+830|0]=c;break a}c=y[b+830|0]}b:{if(!(v[b+872|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(x[a+480180>>2]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function Nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+8>>2]=b;e=d,f=$z(a,b,c),x[e+12>>2]=f;a:{if(!Hb(d+12|0,d+8|0)){break a}x[d+4>>2]=x[d+12>>2];if(!Hb(ke(d+4|0),d+8|0)){break a}while(1){if(z[x[d+4>>2]>>1]!=z[c>>1]){a=d+12|0;w[x[a>>2]>>1]=z[x[d+4>>2]>>1];ke(a)}if(Hb(ke(d+4|0),d+8|0)){continue}break}}hb=d+16|0;return x[d+12>>2]}function K1(a){a=a|0;a:{x[114409]=0;S(2551,459896)|0;a=x[114409];x[114409]=0;b:{if((a|0)==1){break b}x[114409]=0;S(2551,460232)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}x[114409]=0;S(2552,459980)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}x[114409]=0;S(2552,460316)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}break a}R(0)|0;zb();p()}}function Eka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=d;Pz(a,c,d);d=0;e=x[a+16>>2];if(e>>>0>c>>>0){x[f+8>>2]=e-c;d=x[Mb(f+8|0,f+12|0)>>2];e=hb-16|0;hb=e;a=a+4|0;h=e,i=bc(a),x[h+12>>2]=i;g=Le(e+12|0,c);h=e,i=bc(a),x[h+4>>2]=i;h=e,i=Le(e+4|0,c),x[h+8>>2]=i;AR(g,Le(e+8|0,d),b);hb=e+16|0}hb=f+16|0;return d|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{c=ym(e+4|0,a+8|0,gz(b,c));if(x[c>>2]!=x[c+4>>2]){while(1){d=x[a+16>>2];f=x[c>>2];x[114409]=0;T(1325,d|0,f|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;if((d|0)!=x[c+4>>2]){continue}break}}Bc(c);hb=e+16|0;return}a=N()|0;Bc(c);Q(a|0);p()}function r1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=x[a+84>>2];f=x[e+4>>2];g=x[a+28>>2];d=x[a+20>>2]-g|0;d=d>>>0>f>>>0?f:d;if(d){sc(x[e>>2],g,d);x[e>>2]=d+x[e>>2];f=x[e+4>>2]-d|0;x[e+4>>2]=f}d=x[e>>2];f=c>>>0>f>>>0?f:c;if(f){sc(d,b,f);d=f+x[e>>2]|0;x[e>>2]=d;x[e+4>>2]=x[e+4>>2]-f}v[d|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function Yy(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{if(x[b+480180>>2]&64671904){b=y[c+4|0];v[e+15|0]=0;x[a>>2]=y[(b&15)+25920|0];v[a+4|0]=y[e+15|0];break a}v[e+14|0]=0;f=y[c+4|0];if(!(y[c+3|0]!=4|x[b+480180>>2]!=4)){v[e+14|0]=1;f=f<<1}if(!(!d|!$b(b+1074312|0,66))){x[e+8>>2]=0;Wi(a,e+8|0,e+14|0);break a}x[e+4>>2]=f<<4;Wi(a,e+4|0,e+14|0)}hb=e+16|0}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Db(y[c|0])|Db(y[c+1|0])<<8)^32768,w[f>>1]=g;f=a,g=(Db(y[c+2|0])|Db(y[c+3|0])<<8)^32768,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function Nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Db(y[c+1|0])|Db(y[c|0])<<8)^32768,w[f>>1]=g;f=a,g=(Db(y[c+3|0])|Db(y[c+2|0])<<8)^32768,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function mX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;g=hb-16|0;hb=g;f=hb-16|0;hb=f;e=g+4|0;x[e+4>>2]=1;i=e,j=jD(1),x[i+8>>2]=j;hb=f+16|0;f=x[e+8>>2];x[114409]=0;Z(260,f|0,b|0,c|0,d|0)|0;b=x[114409];x[114409]=0;a:{if((b|0)!=1){b=a;a=So(e);Ro(b,hc(a),a);YC(e);hb=g+16|0;break a}a=N()|0;YC(e);Q(a|0);p()}hb=h+16|0}function Zv(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function YP(a){var b=0,c=0,d=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=y[a|0]-32&255;d=c>>>0<95;if(c>>>0>94){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}}return d}function RZ(a){a=a|0;if(y[461112]){return x[115277]}if(!y[461464]){v[461464]=1}Rc(461296,1730);Rc(461308,1737);Rc(461320,1703);Rc(461332,1711);Rc(461344,1694);Rc(461356,1744);Rc(461368,1721);Rc(461380,5670);Rc(461392,5950);Rc(461404,7174);Rc(461416,8702);Rc(461428,1989);Rc(461440,6737);Rc(461452,2916);v[461112]=1;x[115277]=461296;return 461296}function rQ(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=mb[d|0](b)|0;e=lb;if((e|0)<0){break b}if((mb[c|0](b,0,0,0)|0)<0){break a}if((mb[c|0](b,0,0,2)|0)<0){break a}d=mb[d|0](b)|0;f=lb;mb[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=wR(d,f)}return g}mb[c|0](b,a,e,0)|0;return 0}function VY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb+-64|0;hb=d;e=1;a:{if(vg(a,b,0)){break a}e=0;if(!b){break a}b=aw(b,74480,74528);e=0;if(!b){break a}Sb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;mb[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;hb=d- -64|0;return a|0}function rfa(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(qc(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;S(1327,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}Ch(c);if(qc(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;d=yb(c);x[114409]=0;U(1075,b+8|0,a+12|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];d=x[yb(c)>>2];e=yb(b),f=d,x[e>>2]=f;e=yb(c),f=0,x[e>>2]=f;x[c>>2]=0;x[c+4>>2]=0;hb=a+16|0;break a}R(0)|0;zb();p()}}function gka(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(qc(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;S(1028,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}Au(c);if(qc(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Xca(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(qc(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;S(1538,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}Au(c);if(qc(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Sba(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(qc(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;S(1683,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}hg(c);if(qc(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Nfa(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(qc(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;S(1295,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}Tz(c);if(qc(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function Kd(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;Km(b);d=hb-16|0;hb=d;x[d+12>>2]=b;b=rd(e+12|0,d+12|0);hb=d+16|0;a:{a=a+8|0;if(Lb(a)>>>0<=c>>>0){x[114409]=0;P(2711,a|0,c+1|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}}if(x[Pb(a,c)>>2]){Jm(x[Pb(a,c)>>2])}d=oe(b);f=Pb(a,c),g=d,x[f>>2]=g;bF(b);hb=e+16|0;return}a=N()|0;bF(b);Q(a|0);p()}function uG(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){c=hb-16|0;hb=c;b=ec(16);a=hb-16|0;hb=a;if(!y[457644]){v[457644]=1}Hd(a+8|0,1,83624);d=x[a+12>>2];c=c+8|0;x[c>>2]=x[a+8>>2];x[c+4>>2]=d;hb=a+16|0;x[114409]=0;U(2531,b|0,5064,c|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){da(b|0,60576,2532);p()}a=N()|0;ic(b);Q(a|0);p()}}function Hpa(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Bb(d+12|0,x[x[a+8>>2]>>2]);a=Bb(d+8|0,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];x[b+12>>2]=c;if(jd(b+12|0,b+8|0)){while(1){x[114409]=0;c=b+12|0;S(525,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}ke(c);if(jd(c,b+8|0)){continue}break}}hb=b+16|0;hb=d+16|0}function uk(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function mn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Es(a+60|0);x[a>>2]=60280;x[d>>2]=60300;x[114409]=0;e=a+8|0;a=U(154,a|0,60312,e|0)|0;f=x[114409];x[114409]=0;a:{b:{if((f|0)!=1){x[a>>2]=60280;x[d>>2]=60300;x[114409]=0;U(155,e|0,b|0,c|8)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}return a|0}a=N()|0;break a}a=N()|0}lh(d);Q(a|0);p()}function TA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;zc(c,256);zc(c,65535);h=z[f+12>>1];Og(a,h);if(h){c=0;while(1){g=y[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=il(a,c),j=g,w[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}hb=f+16|0;return 1}function wO(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function nG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=mb[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((wj(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=nn(x[a+32>>2])?-1:0}hb=b+16|0;return d|0}function qO(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+4>>2]=0;Zc(a+8|0);Yd(c+4|0,x[Bb(c,a)>>2]);a:{if(!b){break a}x[114409]=0;P(1284,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[114409]=0;P(1285,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){break a}}a=N()|0;kO(c+4|0);Q(a|0);p()}b=c+4|0;Xd(b);kO(b);hb=c+16|0;return a}function qq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=hb-32|0;hb=d;Ae(d+24|0,a,b);g=x[d+24>>2];b=hb-16|0;hb=b;e=x[d+28>>2];x[b+12>>2]=e;e=e-g|0;h=c-e|0;x[b+8>>2]=h;vk(h,g,e);Dc(d+16|0,b+12|0,b+8|0);hb=b+16|0;i=d,j=Wo(a,x[d+16>>2]),x[i+12>>2]=j;i=d,j=ji(c,x[d+20>>2]),x[i+8>>2]=j;Dc(f+8|0,d+12|0,d+8|0);hb=d+32|0;hb=f+16|0}function $1(a,b){a=a|0;b=b|0;if(A[a+24>>2]>A[a+44>>2]){x[a+44>>2]=x[a+24>>2]}a:{if(A[a+8>>2]>=A[a+12>>2]){break a}if(re(b,-1)){fn(a,x[a+8>>2],x[a+12>>2]-1|0,x[a+44>>2]);return bs(b)|0}if(!(y[a+48|0]&16)){if(!re(b<<24>>24,v[x[a+12>>2]-1|0])){break a}}fn(a,x[a+8>>2],x[a+12>>2]-1|0,x[a+44>>2]);v[x[a+12>>2]]=b<<24>>24;return b|0}return-1}function Je(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Cb(a)|(c-b|0)<5){break a}ip(b,c);e=c-4|0;c=Rb(a);f=c+Cb(a)|0;b:{while(1){c:{a=v[c|0];if(b>>>0>=e>>>0){break c}if(!((a|0)<=0|(a|0)>=127)&x[b>>2]!=v[c|0]){break b}b=b+4|0;c=((f-c|0)>1)+c|0;continue}break}if((a|0)<=0|(a|0)>=127|v[c|0]>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function Cf(a){a=a|0;var b=0,c=0;x[a>>2]=78656;b=x[a+12>>2];if(x[b>>2]==(a|0)){x[b>>2]=x[a+4>>2]}b=x[a+20>>2];if(b){x[b>>2]=0;x[a+20>>2]=0}b=x[a+4>>2];if(b){x[b+8>>2]=x[a+8>>2]}c=x[a+8>>2];if(c){x[c+4>>2]=b}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;b=a+44|0;Rs(b+36|0);Rs(b+24|0);Qs(b+12|0);Qs(b);return a|0}function b8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(R(0)|0)|0;x[114409]=0;W(2113,8908,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function Yoa(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!YA(a,b+20|0)){break a}c=0;if(!bU(b+20|0)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!ad(a,4)){break a}}c=-1;if(!Yj(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}hb=b+32|0;return c|0}function zt(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=c+15|0;b=hb-16|0;hb=b;x[114409]=0;S(1330,a+4|0)|0;e=x[114409];x[114409]=0;a:{b:{if((e|0)==1){break b}x[114409]=0;x[b+12>>2]=0;U(1331,a+8|0,b+12|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}f=a,g=mc(a),x[f>>2]=g;hb=b+16|0;break a}R(0)|0;zb();p()}hb=c+16|0;return a}function kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=hi(e+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114409]=0;T(1719,d|0,f|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[b>>2]+4|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=e+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function RJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=cf(x[a+16>>2]);b=hb-16|0;hb=b;h=b,i=Si(E(B[a+4208>>2]*E(999))),x[h+12>>2]=i;x[b+8>>2]=0;x[b+4>>2]=-2;e=b+4|0;f=hb-16|0;hb=f;c=b+12|0;d=b+8|0;if(!Go(c,d)){d=Go(e,c)?e:c}hb=f+16|0;hb=b+16|0;b=(g>>>0)/(x[d>>2]+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;zc(a+4224|0,b)}function zB(a){var b=0,c=0,d=0,e=0;c=a+9|0;d=y[c|0]|y[c+1|0]<<8;c=sqa(y[a+3|0],0,18,0);d=d+c|0;b=lb;e=c>>>0>d>>>0?b+1|0:b;b=a+6|0;c=y[b|0]|y[b+1|0]<<8;b=c>>>31|0;c=c<<1;d=c+d|0;b=b+e|0;c=c>>>0>d>>>0?b+1|0:b;a=a+4|0;a=y[a|0]|y[a+1|0]<<8;b=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+3|0;lb=b>>>0<3?a+1|0:a;return b}function ona(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=Rt(e+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114409]=0;T(565,d|0,f|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[b>>2]+1|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=e+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=hi(e+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114409]=0;T(390,d|0,f|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[b>>2]+4|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=e+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function L5(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;a=sh(a);x[114409]=0;P(2281,c+4|0,0);b=x[114409];x[114409]=0;a:{b:{if((b|0)!=1){b=c+4|0;d=bc(b);b=dc(b);e=x[Bb(c,a)>>2];x[114409]=0;U(2282,d|0,b|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}sy(c+4|0);hb=c+16|0;return}b=N()|0;break a}b=N()|0;sy(c+4|0)}pd(a);Q(b|0);p()}function IT(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}a=a+116|0;if((y[a|0]|y[a+1|0]<<8)>>>0>=10){break a}b=(y[a|0]|y[a+1|0]<<8)!=0}return b}function lW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=ym(e+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114409]=0;T(361,d|0,f|0,c|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}d=x[b>>2]+2|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=e+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function Rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Db(y[c|0])|Db(y[c+1|0])<<8,w[f>>1]=g;f=a,g=Db(y[c+2|0])|Db(y[c+3|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;f=a,g=Db(y[c+3|0])|Db(y[c+2|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function E4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{if(!(y[c+1|0]&4)){break a}c=x[c+4>>2];g=d,h=td(b),x[g+12>>2]=h;b:{if(!Cb(b)){break b}if(y[pc(b,0)|0]!=43){if(y[pc(b,0)|0]!=45){break b}}ex(d+12|0);c=c+1|0}if(Cb(b)>>>0>=c>>>0){break a}e=rd(d+8|0,d+12|0);f=Cb(b);jx(b,x[e>>2],c-f|0,48)}Jd(a,b);hb=d+16|0}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[c+12>>2]=0;U(1228,a+8|0,c+12|0,c+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=c+16|0;break a}R(0)|0;zb();p()}v[a+16|0]=0;x[a+12>>2]=b;x[114409]=0;V(1227,a|0);b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}b=N()|0;sz(a);Q(b|0);p()}function xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;Xe(b);x[d+12>>2]=0;a:{if(!Xi(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{v[d+11|0]=0;if(!gh(a,d+11|0)){break b}$o(b,v[d+11|0]);e=1;c=c+1|0;if((c|0)!=x[d+12>>2]){continue}break a}break}e=0}hb=d+16|0;return e|0}function _J(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=(cf(x[a+16>>2])|0)/5|0;b=Ec(b,b>>31);x[a+4272>>2]=b;x[114409]=0;x[c+12>>2]=0;T(1768,a+4256|0,b<<1,c+12|0);b=x[114409];x[114409]=0;a:{if((b|0)==1){b=R(74984)|0;if((ib|0)!=(ca(74984)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;_()}x[a+4276>>2]=0;x[a+4268>>2]=0;hb=c+16|0;return}Q(b|0);p()}function Lda(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Re(2500);x[114409]=0;a=U(98,b|0,a|0,0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){b=hb-16|0;hb=b;x[114409]=0;x[b+12>>2]=a;a=U(103,c+12|0,b+12|0,b+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=b+16|0;break a}R(0)|0;zb();p()}hb=c+16|0;return x[a>>2]}a=N()|0;_b(b);Q(a|0);p()}function zW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=cd(a,y[d|0]&2?16:8,1,0,(y[b|0]^-1)&1);if(!(!(y[d|0]&4)|c>>>0<532)){tC(a)}a:{b:{if(y[d|0]&8){b=y[b|0]&4?5:4;break b}if(!(y[d|0]&2|y[b|0]!=255)){b=11;break b}if(y[b|0]&2){v[a+2|0]=1}if(y[b|0]&4){vm(a,2)}if(!(y[b|0]&8)){break a}b=9;if(!(y[d|0]&2)){break a}}vm(a,b)}}function vna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;Xe(b);v[d+15|0]=0;a:{if(!gh(a,d+15|0)){break a}f=c;c=y[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{v[d+14|0]=0;if(!gh(a,d+14|0)){break b}$o(b,v[d+14|0]);e=1;c=c+1|0;if(y[d+15|0]!=(c&255)){continue}break a}break}e=0}hb=d+16|0;return e|0}function Qka(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!YA(a,b+20|0)){break a}c=0;if(!HQ(b+20|0)){break a}c=-1;if(!Yj(a,b+12|0)){break a}a=b+16|0;c=0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}a=b+12|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;hb=b+32|0;return a|0}function WB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=ne(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(390,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+4|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Rq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=bh(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(361,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+2|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function KA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=Gq(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(718,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+6|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Fq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=xh(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(565,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+1|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function FW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=xh(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(345,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+1|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function lJ(){var a=0,b=0,c=0,d=0;c=hb-16|0;hb=c;b=Re(1304568);x[114409]=0;d=S(2258,b|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){a=hb-16|0;hb=a;x[114409]=0;x[a+12>>2]=d;b=U(2262,c+12|0,a+12|0,a+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}hb=c+16|0;return x[b>>2]}a=N()|0;_b(b);Q(a|0);p()}function c8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[114409]=0;V(2138,a|0);d=x[114409];x[114409]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:2121;return}Y(R(0)|0)|0;x[114409]=0;W(2113,8938,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();return}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function XT(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function SJ(a,b){var c=0,d=0,e=0,f=0;d=Rb(a);c=Cb(a);e=Rb(b);a=Cb(b);if(!a|!c){a=-1}else{f=a+e|0;a=d;c=c+a|0;a:{if((a|0)==(c|0)){break a}while(1){b=e;if((f|0)!=(b|0)){while(1){if(re(v[a|0],v[b|0])){break a}b=b+1|0;if((f|0)!=(b|0)){continue}break}}a=a+1|0;if((c|0)!=(a|0)){continue}break}a=c}a=(a|0)==(c|0)?-1:a-d|0}return a}function EL(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=JP(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(1069,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+12|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function lQ(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;c=yb(b);x[114409]=0;U(1033,a+8|0,d+12|0,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=x[yb(b)>>2];e=yb(a),f=c,x[e>>2]=f;e=yb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0;hb=d+16|0;return a}R(0)|0;zb();p()}function WQ(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;f=y[b|0]|y[b+1|0]<<8;c=sqa(y[a+30|0],0,37,0);d=lb;b=a+24|0;b=sqa(y[b|0]|y[b+1|0]<<8,0,192,0);c=b+c|0;d=lb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;lb=b>>>0<192?a+1|0:a;return b}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=JP(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(1302,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+12|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=hi(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(1773,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function lS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=mg(+(D(a,d)>>>0)*2500);break a}b:{if(!(!a|!b)){zc(e+12|0,10);a=y[x[e+12>>2]+23856|0];x[e+12>>2]=a;break b}if(a-1>>>0>9){break b}a=mg(7338401.379310345/+(a>>>0));break a}a=mg(+(a>>>0)*37878.78787878787)}hb=e+16|0;return a|0}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=hi(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(1738,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function Lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=UD(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(391,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+16|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function rna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=hi(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(751,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function qma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=hi(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(845,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=ym(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(851,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+2|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function lY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=UD(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(189,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+16|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function cO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;f=hb-16|0;hb=f;a:{if(rc(Yp(a))>>>0<=b>>>0){break a}b:{c:{if(Ac(a)>>>0>b>>>0){if(A[ud(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}hz(a,b,c,1);break b}e=f+8|0;se(e,ud(a,b),c);e=Ib(e);if(e|!d){break a}d=f+8|0;se(d,ud(a,b),c);le(d,1);eO(a,b,c)}e=0}hb=f+16|0;return e|0}function YV(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;x[c+8>>2]=b;x[c+12>>2]=a;a:{if(!Hb(c+12|0,c+8|0)){break a}x[c+4>>2]=x[c+12>>2];if(!Hb(ke(c+4|0),c+8|0)){break a}while(1){if(SB(x[c+12>>2],x[c+4>>2])){x[c+12>>2]=x[c+4>>2]}if(Hb(ke(c+4|0),c+8|0)){continue}break}}hb=c+16|0;hb=d+16|0;return x[c+12>>2]}function Rka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=hi(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(975,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function Dy(a,b){var c=0,d=0,e=0;$R(a);$l(a,b);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=x[yb(b)>>2];d=yb(a),e=c,x[d>>2]=e;d=yb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0;v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function wW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=hi(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(351,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=Rt(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(42,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+1|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function lC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}while(1){v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){ag(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}x[c+4>>2]=x[c+12>>2];a=c+4|0;d=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}hb=c+16|0;return d}function iY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=Rt(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(191,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+1|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function SV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=ym(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(392,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+2|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function RV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=ym(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(396,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+2|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function PY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(vg(a,x[b+8>>2],e)){Yv(b,c,d);return}a:{if(!vg(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function K9(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=cf(x[a+16>>2]);b=Ec(tqa(sqa(b,b>>31,3840,0),lb,1e3,0),lb);x[a+4276>>2]=b;x[114409]=0;x[c+12>>2]=0;T(1768,a+4260|0,b|0,c+12|0);b=x[114409];x[114409]=0;a:{if((b|0)==1){b=R(74984)|0;if((ib|0)!=(ca(74984)|0)){break a}Y(b|0)|0;x[a+4276>>2]=0;_()}hb=c+16|0;return}Q(b|0);p()}function HW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=Rt(d+4|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114409]=0;P(343,c|0,e|0);c=x[114409];x[114409]=0;if((c|0)==1){break a}c=x[b>>2]+1|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Bc(b);hb=d+16|0;return}a=N()|0;Bc(b);Q(a|0);p()}function nqa(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;v[d+15|0]=b;a:{b:{c:{if(!we(a)){c=10;b=Io(a);if((b|0)==10){break c}Rb(a);c=a;Ie(a,b+1|0);break a}c=Di(a);b=x[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}dl(a,c,1,c,c,0,0);b=c}Rb(a);c=x[a>>2];ee(a,b+1|0)}a=b+c|0;$d(a,d+15|0);v[d+14|0]=0;$d(a+1|0,d+14|0);hb=d+16|0}function Yw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-240|0;hb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((Gl(a,f,b)|0)>=0){if((Gl(a,e,b)|0)>=0){break a}}j=f;f=(Gl(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}gH(g,h);hb=g+240|0}function U5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=d+4|0;tn(c,a);if(x[b>>2]){vd(b);AI(b);kq(b);Mp(yb(b),x[b>>2],ff(b));e=yb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}$l(b,c);x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=x[yb(c)>>2];e=yb(b),f=a,x[e>>2]=f;e=yb(c),f=0,x[e>>2]=f;x[c>>2]=0;x[c+4>>2]=0;Qf(c);hb=d+16|0}function PX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;b=Zf(d+8|0,b);x[114409]=0;T(226,d+20|0,b|0,c|0);e=x[114409];x[114409]=0;a:{b:{if((e|0)!=1){x[114409]=0;T(5,a|0,d+20|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}xb(d+20|0);xb(b);hb=d+32|0;return}a=N()|0;break a}a=N()|0;xb(d+20|0)}xb(b);Q(a|0);p()}function PL(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}b=a+20|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}a=a+28|0;c=(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=0}return c}function FJ(a){var b=0;x[a+4116>>2]=0;x[a+4132>>2]=0;x[a+4136>>2]=0;w[a+4128>>1]=0;x[a+4104>>2]=0;x[a+4108>>2]=0;b=a+4140|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4148|0;x[b>>2]=0;x[b+4>>2]=0;EJ(a+4164|0);EJ(a+4156|0);Lp(a+54060|0);Lp(a+62252|0);Lp(a+70444|0);Lp(a+78636|0);Sb(a+4332|0,0,32768);Ez(a+37100|0);Sb(a+37612|0,0,16384)}function aA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;w[d+14>>1]=b;w[d+12>>1]=c;if((b|0)!=(c|0)){b=bc(a);c=dc(a);a=hb-16|0;hb=a;x[a+8>>2]=c;x[a+12>>2]=b;if(Hb(a+12|0,a+8|0)){while(1){if(z[x[a+12>>2]>>1]==z[d+14>>1]){w[x[a+12>>2]>>1]=z[d+12>>1]}b=a+12|0;ke(b);if(Hb(b,a+8|0)){continue}break}}hb=a+16|0}hb=d+16|0}function Sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=Qm(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(1291,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+16|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function gea(){var a=0,b=0,c=0,d=0;c=hb-16|0;hb=c;b=Re(1);x[114409]=0;d=S(90,b|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){a=hb-16|0;hb=a;x[114409]=0;x[a+12>>2]=d;b=U(95,c+12|0,a+12|0,a+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}hb=c+16|0;return x[b>>2]}a=N()|0;_b(b);Q(a|0);p()}function gZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=b;e=we(a);a:{if(!e){b=1;d=Io(a);break a}b=Di(a)-1|0;d=x[a+4>>2]}b:{c:{if((b|0)==(d|0)){tE(a,b,1,b,b);Rb(a);break c}Rb(a);if(e){break c}b=a;Ie(a,d+1|0);break b}b=x[a>>2];ee(a,d+1|0)}a=(d<<2)+b|0;wg(a,c+12|0);x[c+8>>2]=0;wg(a+4|0,c+8|0);hb=c+16|0}function Xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=ne(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(1107,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+4|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=kr(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(1289,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+8|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function Uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=Gq(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(1679,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+6|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function $o(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;v[c+15|0]=b;e=we(a);a:{if(!e){b=10;d=Io(a);break a}b=Di(a)-1|0;d=x[a+4>>2]}b:{c:{if((b|0)==(d|0)){dl(a,b,1,b,b,0,0);Rb(a);break c}Rb(a);if(e){break c}b=a;Ie(a,d+1|0);break b}b=x[a>>2];ee(a,d+1|0)}a=b+d|0;$d(a,c+15|0);v[c+14|0]=0;$d(a+1|0,c+14|0);hb=c+16|0}function fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=Gq(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(563,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+6|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function UB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=Qm(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(391,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+16|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function Rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=ne(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(902,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+4|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function yJ(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;f=dj(b,c);if(f>>>0<=2147483631){a:{if(ml(f)){Ie(a,f);e=a;break a}Mh(d+8|0,a,mj(f)+1|0);e=x[d+8>>2];_e(a,e);Jf(a,x[d+12>>2]);ee(a,f)}if((b|0)!=(c|0)){while(1){$d(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}v[d+7|0]=0;$d(e,d+7|0);hb=d+16|0;return}If();p()}function Nla(a){a=a|0;var b=0,c=0,d=0,e=0;b=x[a>>2];oq(b);oq(b);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-20|0;P(907,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];pq(b,x[a>>2],oq(a))}}function NQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=ne(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(975,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+4|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function KB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=bh(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(392,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+2|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c|0]);Db(y[c+1|0]);f=a,g=Db(y[c+2|0])|Db(y[c+3|0])<<8,w[f>>1]=g;a=a+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<2}function HX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=kr(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(243,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+8|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c+3|0]);Db(y[c+2|0]);f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<2}function GW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=bh(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(344,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+2|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function GC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=xh(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(343,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+1|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function BS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=xh(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114409]=0;P(42,e|0,b|0);e=x[114409];x[114409]=0;if((e|0)==1){break a}b=b+1|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function qz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:IO(a,b);return;default:break a}}d=hb-16|0;hb=d;x[d+12>>2]=c;w[d+10>>1]=0;x[d+4>>2]=2;sl(a,d+10|0,x[Mb(d+12|0,d+4|0)>>2]);a=lb;if((a|0)>0|(a|0)>=0){x[d+4>>2]=2;Mb(d+12|0,d+4|0)}w[d+4>>1]=z[d+10>>1];w[b>>1]=y[d+4|0]|y[d+5|0]<<8;hb=d+16|0}function Apa(a,b){a=a|0;b=b|0;var c=0;gu(a,b);Mj(b);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}v[b+5|0]=159;v[b+3|0]=20;return}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;return}v[b+3|0]=20;v[b+5|0]=a&15|160;return}v[b+3|0]=0}}function qh(a){var b=0,c=0,d=0;c=Es(a+56|0);x[a>>2]=60100;x[c>>2]=60120;x[114409]=0;b=a+4|0;a=U(129,a|0,60132,b|0)|0;d=x[114409];x[114409]=0;a:{b:{if((d|0)!=1){x[a>>2]=60100;x[c>>2]=60120;x[114409]=0;O(130,b|0,16)|0;b=x[114409];x[114409]=0;if((b|0)==1){break b}return a}a=N()|0;break a}a=N()|0}lh(c);Q(a|0);p()}function HK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){if(b>>>0>2097151){Be();p()}d=_d(b<<11,4);x[e+8>>2]=b;x[e+4>>2]=d;f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<11)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<11)+f|0,x[g>>2]=h;hb=e+16|0;return a|0}function yp(a,b,c){var d=0,e=0;a=Dg(a);d=Cb(b);x[114409]=0;P(114,a|0,d|0);d=x[114409];x[114409]=0;if((d|0)!=1){a:{if(Cb(b)){while(1){d=x[(y[pc(b,e)|0]<<2)+c>>2];x[114409]=0;P(113,a|0,d|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}e=e+1|0;if(Cb(b)>>>0>e>>>0){continue}break}}return}}b=N()|0;Pc(a);Q(b|0);p()}function rz(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=No(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(1231,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+32|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function e_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[e>>2]=c;a=lw(f+12|0,0,b,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}d=f+12|0;while(1){if(c){a=y[d|0];b=x[e>>2];x[e>>2]=b+1;v[b|0]=a;c=c-1|0;d=d+1|0;continue}break}b=0}a=b;hb=f+16|0;return a|0}function b0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=x[16283];x[g+24>>2]=x[16282];x[g+28>>2]=h;h=x[16281];x[g+16>>2]=x[16280];x[g+20>>2]=h;h=x[16279];x[g+8>>2]=x[16278];x[g+12>>2]=h;h=x[16277];x[g>>2]=x[16276];x[g+4>>2]=h;h=a;a=g+32|0;b=rj(h,b,c,d,e,f,g,a);hb=a;return b|0}function aN(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=cl(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(1467,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+24|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function KK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[114409]=0;x[c+12>>2]=0;T(1768,a+4208|0,b<<1,c+12|0);b=x[114409];x[114409]=0;a:{if((b|0)==1){b=R(74984)|0;if((ib|0)!=(ca(74984)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;_()}x[a+4224>>2]=0;hb=c+16|0;return}Q(b|0);p()}function Yx(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=ne(e+4|0,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114409]=0;T(1719,f|0,b|0,c|0);f=x[114409];x[114409]=0;if((f|0)==1){break a}b=b+4|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c|0]);f=a,g=Db(y[c+1|0])|Db(y[c+2|0])<<8,w[f>>1]=g;a=a+2|0;c=c+3|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,3)|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(d){a=x[a+20>>2];b=d;while(1){Db(y[c+2|0]);f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+3|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,3)|0}function wQ(a){var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=mb[e|0](c)|0;f=lb;if((f|0)<0){break a}b=0;b:{if((mb[d|0](c,0,0,0)|0)<0){break b}b=0;if((mb[d|0](c,0,0,2)|0)<0){break b}mb[e|0](c)|0;b=lb;b=(b|0)>0|(b|0)>=0}mb[d|0](c,a,f,0)|0}return b}function qba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0),f=0,g=0,h=E(0);c=hb-16|0;hb=c;$j(a,c+8|0);f=c,g=id(x[c+8>>2],x[c+12>>2]),x[f+4>>2]=g;x[c>>2]=256;Nl(b,x[Mb(c+4|0,c)>>2]);if(Lb(b)){while(1){x[c+4>>2]=0;Ap(a,c+4|0);e=B[c+4>>2];f=Pb(b,d),h=e,B[f>>2]=h;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}hb=c+16|0}function Yr(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[114258]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Fw(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Fw(a)}x[b>>2]=0}return a}function Ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;b=-1;a:{if(!fA(a,1084)){break a}Tk(a,1080);e=d+60|0;HR(a,e);c=e;e=GR(d+44|0);b=0;if(!FR(c,e)){break a}Tk(a,20);b=1;while(1){c=d+14|0;ER(a,c);f=eA(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=A[e+4>>2]>=f>>>0}hb=d- -64|0;return b|0}function C3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[f+12>>2]=d;d=x[wp(f+8|0,f+12|0)>>2];x[114409]=0;aa(2137,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){a=nI(a);b=mI(a+88|0);x[a>>2]=83128;x[b>>2]=83216;od(f+12|0);hb=f+16|0;return a|0}a=N()|0;od(f+12|0);Q(a|0);p()}function Ts(a){var b=0,c=0,d=0;b=oh(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b<=45e-5){b=0}else{b=mp(b)*1.4426950408889634;d=J(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=oh(c+d)*.5}C[a+4248>>3]=b}Ss(a)}function xka(a){a=a|0;var b=0,c=0,d=0,e=0;vQ(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-56|0;P(1021,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Xt(b,x[a>>2],Un(a))}}function gH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=4;f=hb-256|0;hb=f;if((b|0)>=2){h=(b<<2)+a|0;x[h>>2]=f;while(1){e=c>>>0>=256?256:c;sc(x[h>>2],x[a>>2],e);d=0;while(1){g=(d<<2)+a|0;d=d+1|0;sc(x[g>>2],x[(d<<2)+a>>2],e);x[g>>2]=x[g>>2]+e;if((b|0)!=(d|0)){continue}break}c=c-e|0;if(c){continue}break}}hb=f+256|0}function dla(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!Hh(a,8)){break a}c=0;if(!oV(a,9899,8)){break a}c=-1;if(!Yj(a,b+8|0)){break a}c=0;if(!(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))){break a}c=!((y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))&-2139062144)}hb=b+16|0;return c|0}function dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Db(y[c|0])^128,v[f|0]=g;f=a,g=Db(y[c+1|0])^128,v[f+1|0]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;g=d;while(1){g=Db(y[c|0])+g|0;v[a|0]=g;d=Db(y[c+1|0])+d|0;v[a+1|0]=d;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function Sn(a,b,c,d){var e=0,f=0,g=0;a:{if(x[c>>2]|x[d>>2]){if(b){while(1){e=x[d>>2];f=x[c>>2];x[c>>2]=f-(((-2147483648-f>>>31|0)-1&255)+f>>8);x[d>>2]=x[d>>2]-(e+((-2147483648-e>>>31|0)-1&255)>>8);e=(g<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];g=g+1|0;if((g|0)!=(b|0)){continue}break}}break a}nP(a,b<<1)}}function sda(a){a=a|0;var b=0,c=0,d=0,e=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-4|0;P(1539,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function mk(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function ipa(a){a=a|0;var b=0,c=0,d=0,e=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-24|0;P(566,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Lf(b,x[a>>2],ff(a))}}function iR(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;c=a+4|0;a:{if(xc(c)>>>0>=x[a+16>>2]+b>>>0){break a}if(!xc(c)){Uk(c,Wz(x[a+16>>2]+b|0,65536));break a}f=d,g=xc(c),x[f+12>>2]=g;e=bR(d+12|0);a=x[a+16>>2]+b|0;if(e>>>0<a>>>0){Uk(c,Wz(a,65536));break a}f=d,g=xc(c),x[f+8>>2]=g;Uk(c,bR(d+8|0))}hb=d+16|0}function Sma(a){a=a|0;var b=0,c=0,d=0,e=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-24|0;P(783,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Lf(b,x[a>>2],ff(a))}}function Rca(a){a=a|0;var b=0,c=0,d=0,e=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-4|0;P(1623,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function O5(a){a=a|0;var b=0,c=0,d=0,e=0;rl(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-16|0;P(2332,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];ki(b,x[a>>2],li(a))}}function Npa(a){a=a|0;var b=0,c=0,d=0,e=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-24|0;P(512,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Lf(b,x[a>>2],ff(a))}}function Hoa(a){a=a|0;var b=0,c=0,d=0,e=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-24|0;P(605,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Lf(b,x[a>>2],ff(a))}}function Gla(a){a=a|0;var b=0,c=0,d=0,e=0;Gm(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-32|0;P(919,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];eu(b,x[a>>2],Gh(a))}}function $ca(a){a=a|0;var b=0,c=0,d=0,e=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-4|0;P(1533,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function s1(a){a=a|0;var b=0,c=0,d=0,e=0;ri(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-12|0;P(180,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Lh(b,x[a>>2],xg(a))}}function dpa(a){a=a|0;var b=0,c=0,d=0,e=0;Iu(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-6|0;P(564,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Hu(b,x[a>>2],$i(a))}}function Wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;MA(e,d+19|0,c);x[114409]=0;P(501,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(502,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}
function SW(a){a=a|0;var b=0,c=0,d=0,e=0;ri(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-12|0;P(324,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Lh(b,x[a>>2],xg(a))}}function Q9(a){a=a|0;var b=0,c=0,d=0,e=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-4|0;P(1887,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function Mla(a){a=a|0;var b=0,c=0,d=0,e=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-4|0;P(906,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Nj(b,x[a>>2],sd(a))}}function Jma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb+-64|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+12|0;eS(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){fS(f)}c=-1;a:{if(!d){break a}c=0;if(!sS(e+12|0)){break a}c=of(a,b,rS(e+12|0),lb)}hb=e- -64|0;return c|0}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;if(iB(b,d+24|0)){e=Nz(d+24|0)}f=d+8|0;Ad(f,b,e);a=hB(a,d+24|0,f);Ab(f);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}x[114409]=0;O(313,b|0,c-e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break a}b=N()|0;qe(a);Q(b|0);p()}hb=d+32|0}function yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-112|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+14|0;LT(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){MT(f)}c=-1;a:{if(!d){break a}c=0;if(!PT(e+14|0)){break a}c=of(a,b,OT(e+14|0),lb)}hb=e+112|0;return c|0}function mT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:Jh(a,b);return;default:break a}}d=hb-32|0;hb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+20>>2]=1;sl(a,d+27|0,x[Mb(d+28|0,d+20|0)>>2]);a=lb;if((a|0)>0|(a|0)>=0){x[d+16>>2]=1;Mb(d+28|0,d+16|0)}v[d+15|0]=y[d+27|0];v[b|0]=y[d+15|0];hb=d+32|0}function Ur(a,b,c,d){var e=0,f=0,g=0;e=hb-160|0;hb=e;f=b?a:e+158|0;x[e+148>>2]=f;a=-1;g=b-1|0;x[e+152>>2]=b>>>0>=g>>>0?g:0;e=Sb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=2575;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[114232]=61;break a}v[f|0]=0;a=aH(e,c,d,2437,2438)}hb=e+160|0;return a}function Upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;Qi(e,d+19|0,c);x[114409]=0;P(501,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(502,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}function TW(a){a=a|0;var b=0,c=0,d=0,e=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-4|0;P(325,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function NW(a){a=a|0;var b=0,c=0,d=0,e=0;ij(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-2|0;P(340,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Fo(b,x[a>>2],_f(a))}}function MW(a){a=a|0;var b=0,c=0,d=0,e=0;io(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-1|0;P(338,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];fg(b,x[a>>2],tf(a))}}function FX(a){a=a|0;var b=0,c=0,d=0,e=0;jr(x[a>>2]);b=x[a>>2];if(x[b>>2]){e=x[b>>2];c=x[b+4>>2];a:{while(1){if((c|0)==(e|0)){break a}d=yb(b);x[114409]=0;c=c-8|0;P(257,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[b+4>>2]=e;b=yb(x[a>>2]);a=x[a>>2];Bv(b,x[a>>2],lj(a))}}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-96|0;hb=c;QK(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;hb=c+96|0;x[a+112>>2]=0;return a|0}function pW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-512|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+15|0;eC(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){fC(f)}c=-1;a:{if(!d){break a}c=0;if(!jC(e+15|0)){break a}c=of(a,b,iC(e+15|0),lb)}hb=e+512|0;return c|0}function Uj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;zc(c,128);zc(c,65535);h=z[f+12>>1];Og(a,h);if(h){c=0;while(1){g=y[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=il(a,c),j=g,w[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}hb=f+16|0}function Qq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;zc(c,256);zc(c,65535);h=z[f+12>>1];Og(a,h);if(h){c=0;while(1){g=y[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=il(a,c),j=g,w[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}hb=f+16|0}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;while(1){g=Db(y[c|0])+d|0;d=g+Db(y[c+1|0])|0;w[a>>1]=d<<8|g&255;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;Qi(e,d+19|0,c);x[114409]=0;P(75,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(76,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}function jW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-48|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+10|0;QB(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){RB(f)}c=-1;a:{if(!d){break a}c=0;if(!bC(e+10|0)){break a}c=of(a,b,aC(e+10|0),lb)}hb=e+48|0;return c|0}function fW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;$u(e,d+19|0,c);x[114409]=0;P(75,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(76,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}function dda(a){a=a|0;var b=0,c=0,d=0;b=x[a+2496>>2];c=(b+1>>>0)%624|0;d=x[(c<<2)+a>>2];b=0-(d&1)&-1727483681^(x[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|x[(b<<2)+a>>2]&-2147483648)>>>1);x[(x[a+2496>>2]<<2)+a>>2]=b;x[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function RX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;Om(e,d+19|0,c);x[114409]=0;P(75,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(76,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}function $Y(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(x[b>>2]){if(!Yc(c)){Pv(c,13619)}e=d+4|0;f=x[b+4>>2];mb[x[x[f>>2]+24>>2]](e,f,x[b>>2]);x[114409]=0;O(1328,c|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}xb(d+4|0)}Jd(a,c);hb=d+16|0;return}a=N()|0;xb(d+4|0);Q(a|0);p()}function a9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Hi(a,b,c,d);x[a+4208>>2]=1017370378;x[a+4212>>2]=0;x[a>>2]=80212;x[114409]=0;U(1760,a+44|0,2,2)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){break a}x[114409]=0;V(1761,a|0);b=x[114409];x[114409]=0;if((b|0)==1){break a}return a|0}b=N()|0;Cf(a);Q(b|0);p()}function nN(a,b,c){var d=0,e=0,f=0,g=0;e=x[a+1074416>>2];a=x[a+1074392>>2];v[b+872|0]=y[b+872|0]|16;d=a?y[b+833|0]:0;g=(c|0)<0?d:0-d|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(F(f)<2147483648){d=~~f;break a}d=-2147483648}x[b+876>>2]=g+(d+x[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;v[b+833|0]=(a^c)-a}function mna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;Iu(a);yb(a);d=Bb(c+8|0,x[a+4>>2]);e=Bb(c+4|0,x[a>>2]);f=Bb(c,x[b+4>>2]);g=c,h=PS(x[d>>2],x[e>>2],x[f>>2]),x[g+12>>2]=h;x[b+4>>2]=x[c+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];ZA(a,ng(a));hb=c+16|0}function jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-1968|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+14|0;$U(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){aV(f)}c=-1;a:{if(!d){break a}c=0;if(!fV(e+14|0)){break a}c=of(a,b,1024,0)}hb=e+1968|0;return c|0}function efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=lm(y[c|0]),v[f|0]=g;f=a,g=lm(y[c+1|0]),v[f+1|0]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function RF(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;f=ju(b,c);if(f>>>0<=1073741807){a:{if(bp(f)){Ie(a,f);e=a;break a}ck(d+8|0,a,wl(f)+1|0);e=x[d+8>>2];_e(a,e);Jf(a,x[d+12>>2]);ee(a,f)}while(1){if((b|0)!=(c|0)){wg(e,b);e=e+4|0;b=b+4|0;continue}break}x[d+4>>2]=0;wg(e,d+4|0);hb=d+16|0;return}If();p()}function vW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;Ge(a);yb(a);d=Bb(c+8|0,x[a+4>>2]);e=Bb(c+4|0,x[a>>2]);f=Bb(c,x[b+4>>2]);g=c,h=qC(x[d>>2],x[e>>2],x[f>>2]),x[g+12>>2]=h;x[b+4>>2]=x[c+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Wh(a,Lb(a));hb=c+16|0}function kW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;ij(a);yb(a);d=Bb(c+8|0,x[a+4>>2]);e=Bb(c+4|0,x[a>>2]);f=Bb(c,x[b+4>>2]);g=c,h=CC(x[d>>2],x[e>>2],x[f>>2]),x[g+12>>2]=h;x[b+4>>2]=x[c+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];Do(a,rc(a));hb=c+16|0}function dB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;io(a);yb(a);d=Bb(c+8|0,x[a+4>>2]);e=Bb(c+4|0,x[a>>2]);f=Bb(c,x[b+4>>2]);g=c,h=ST(x[d>>2],x[e>>2],x[f>>2]),x[g+12>>2]=h;x[b+4>>2]=x[c+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(yb(a),hc(b));x[b>>2]=x[b+4>>2];QA(a,xc(a));hb=c+16|0}function tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;eR(e,c);x[114409]=0;P(501,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(502,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}function dd(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(x[a>>2]!=x[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function Bf(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function $m(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+12|0;Fc(d,a);x[114409]=0;a=S(2606,d|0)|0;d=x[114409];x[114409]=0;a:{b:{if((d|0)==1){break b}x[114409]=0;Z(2619,a|0,64896,64922,b|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break b}Ob(c+12|0);hb=c+16|0;break a}a=N()|0;Ob(c+12|0);Q(a|0);p()}return b}function wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+20|0;tV(e,c);x[114409]=0;P(75,d+8|0,e|0);c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}x[114409]=0;T(76,a|0,b|0,d+8|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Gb(d+20|0);hb=d+32|0;return}a=N()|0;Gb(d+20|0);Q(a|0);p()}
function kC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}f=1;while(1){v[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){ag(a,c+13|0);d=y[c+13|0]}else{d=0}v[e|0]=d;d=1;e=f;f=0;if(e){continue}break}w[c+10>>1]=z[c+14>>1];a=c+10|0;d=y[a|0]|y[a+1|0]<<8}hb=c+16|0;return d}function hz(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;e=Yp(a);a:{if(rc(e)>>>0<=b>>>0){break a}if(iz(a,z[vc(e,b)>>1])>>>0<=c>>>0){break a}b:{if(Ac(a)>>>0>b>>>0){if(A[ud(a,b)+4>>2]>c>>>0){break b}}Nk(a,0);if(Ac(a)>>>0<=b>>>0){break a}}e=f+8|0;se(e,ud(a,b),c);le(e,d);if(!d){break a}eO(a,b,c)}hb=f+16|0}function Ag(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);lf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;hb=d+16|0}function a8(a){a=a|0;var b=0;x[114409]=0;V(2138,a|0);b=x[114409];x[114409]=0;if((b|0)!=1){return x[a+16>>2]}Y(R(0)|0)|0;x[114409]=0;W(2113,2176,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)!=1){_();return-1}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function TJ(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[114409]=0;x[c+12>>2]=0;T(1768,a+4208|0,b<<2,c+12|0);b=x[114409];x[114409]=0;a:{if((b|0)==1){b=R(74984)|0;if((ib|0)!=(ca(74984)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;_()}x[a+4244>>2]=0;hb=c+16|0;return}Q(b|0);p()}function Qj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=hb-16|0;hb=d;a:{if(b>>>0<=2147483631){b:{if(ml(b)){Ie(a,b);e=a;break b}Mh(d+8|0,a,mj(b)+1|0);e=x[d+8>>2];_e(a,e);Jf(a,x[d+12>>2]);ee(a,b)}In(e,b,c);v[d+7|0]=0;$d(b+e|0,d+7|0);hb=d+16|0;break a}If();p()}hb=f+16|0;return a|0}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-128|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+2|0;cR(d,f);g=Fb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){dR(f)}c=-1;a:{if(!d){break a}c=0;if(!jR(e+2|0)){break a}c=of(a,b,256,0)}hb=e+128|0;return c|0}function kj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(b){c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}f=c;d=d-1|0;x[a>>2]=d;c=f>>>1|0;x[a+4>>2]=c;g=f&1|g<<1;h=h+1|0;if((h|0)!=(b|0)){continue}break}}return g}function afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Db(y[c|0])|Db(y[c+1|0])<<8)^32768,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Db(y[c+1|0])|Db(y[c|0])<<8)^32768,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function K6(a){a=a|0;var b=0;x[114409]=0;V(2211,a|0);b=x[114409];x[114409]=0;a:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;W(2113,7818,a|0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();a=0}return a|0}a=N()|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;if((b|0)!=1){Q(a|0);p()}R(0)|0;zb();p()}function uw(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Oh(f,0,0);fG(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;hb=e+160|0}function pZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;b=hi(d+4|0,a+8|0,b);c=x[b>>2];a:{while(1){if(x[b+4>>2]==(c|0)){break a}c=x[a+16>>2];e=x[b>>2];x[114409]=0;iw(c,e);c=x[114409];x[114409]=0;if((c|0)!=1){c=x[b>>2]+4|0;x[b>>2]=c;continue}break}a=N()|0;Bc(b);Q(a|0);p()}Bc(b);hb=d+16|0}function XQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!y[a+20|0]){if(!(mb[x[x[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){iR(a,65536);c=a,d=(f=a,g=Cc(b,x[a+16>>2]),h=65536,e=x[x[a>>2]+48>>2],mb[e](f|0,g|0,h|0)|0)+x[a+16>>2]|0,x[c+16>>2]=d;if(!(mb[x[x[a>>2]+44>>2]](a)|0)){continue}break}}v[a+20|0]=1}}function XJ(a,b,c){var d=0,e=0,f=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<=0)){while(1){d=b-1|0;e=e<<1;if(b>>>0<2){break a}b=d;if((e|0)>=0){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return E((f?b^-1|f:b)|0)}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;while(1){d=(Db(y[c+1|0])+d|0)+(Db(y[c|0])<<8)|0;w[a>>1]=d;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function Wt(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}a=a+4|0;a=y[a|0]|y[a+1|0]<<8;b=((a<<8|a>>>8)&65535)>>>0>177}return b}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;while(1){d=(Db(y[c|0])+d|0)+(Db(y[c+1|0])<<8)|0;w[a>>1]=d;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function Vla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=E(0),g=0,h=0,i=0;if(d){e=(e<<1)+a|0;a=0;c=c<<1;while(1){f=he(E(rf(B[b>>2],E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){g=~~f;break a}g=-2147483648}h=e,i=Wc(g),w[h>>1]=i;b=b+4|0;e=c+e|0;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function M4(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;a:{b:{if(Bi(a)){vp(b+12|0);break b}tn(b,a);x[114409]=0;c=S(2298,b|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}x[b+12>>2]=c;Qf(b)}if(Bi(a)){a=a+36|0}else{a=x[b+12>>2]}a=vd(a);zk(b+12|0);hb=b+16|0;return a|0}a=N()|0;Qf(b);Q(a|0);p()}function jU(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){if(b>>>0>89478485){Be();p()}d=_d(D(b,48),4);x[e+8>>2]=b;x[e+4>>2]=d;f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=D(c,48)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=D(b,48)+f|0,x[g>>2]=h;hb=e+16|0;return a}function cX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=0;if(A[a+16>>2]>c>>>0){d=x[a+4>>2];f=x[a+12>>2];x[e+8>>2]=x[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=x[Mb(e+12|0,e+8|0)>>2],g=x[x[d>>2]+28>>2],mb[g](h|0,i|0,j|0,k|0)|0)}hb=e+16|0;return d|0}function bK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=hb-16|0;hb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Rb(d);Fi(b,a,Cb(d)+a|0);break c}f=e+4|0;zK(f,c,d);x[114409]=0;T(116,a|0,b|0,f|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Pc(e+4|0)}hb=e+16|0;break a}a=N()|0;Pc(e+4|0);Q(a|0);p()}}function F3(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;d=x[a>>2];b=Bb(c+12|0,x[x[a+8>>2]>>2]);e=Bb(c+8|0,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[e>>2];x[a+12>>2]=b;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;ep(d,SN(b));Kh(b);if(qc(b,a+8|0)){continue}break}}hb=a+16|0;hb=c+16|0}function xU(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+8>>2]=b;x[d+12>>2]=a;x[d+4>>2]=c;a:{if(!Hb(d+12|0,d+8|0)){break a}while(1){a=x[d+12>>2];if(x[x[d+4>>2]>>2]==(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}a=d+12|0;bj(a);if(Hb(a,d+8|0)){continue}break}}hb=d+16|0;return x[d+12>>2]}function w8(){var a=0,b=0;x[114409]=0;a=$(2112)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;W(2113,5855,0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();a=0}return a|0}b=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){Q(b|0);p()}R(0)|0;zb();p()}function uQ(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-56|0;x[a+8>>2]=c;x[114409]=0;P(1021,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Xt(x[a+16>>2],x[a>>2],(x[hc(a)>>2]-x[a>>2]|0)/56|0)}}function u8(){var a=0,b=0;x[114409]=0;a=$(2116)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;W(2113,5883,0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();a=0}return a|0}b=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){Q(b|0);p()}R(0)|0;zb();p()}function j8(){var a=0,b=0;x[114409]=0;a=$(2128)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;W(2113,7084,0,0,0);a=x[114409];x[114409]=0;if((a|0)==1){break a}_();a=0}return a|0}b=N()|0;x[114409]=0;X(20);a=x[114409];x[114409]=0;if((a|0)!=1){Q(b|0);p()}R(0)|0;zb();p()}function iga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[114409]=0;a=U(1259,a|0,c+15|0,c+14|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=c+16|0;break a}R(0)|0;zb();p()}v[a+530|0]=0;x[114409]=0;P(1258,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}b=N()|0;kg(a);Q(b|0);p()}function hL(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-52|0;x[a+8>>2]=c;x[114409]=0;P(1532,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){By(x[a+16>>2],x[a>>2],(x[hc(a)>>2]-x[a>>2]|0)/52|0)}}function RW(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!SC(a,c+12|0)){break a}d=0;if(!PC(c+12|0)){break a}if(b){a=c+16|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);if(!x[b+4>>2]&A[b>>2]<(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))-8>>>0){break a}}d=1}hb=c+48|0;return d|0}function kpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[ah(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[ah(d+13|0,d+12|0)|0]}hb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function IS(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-33|0;x[a+8>>2]=c;x[114409]=0;P(781,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){FS(x[a+16>>2],x[a>>2],(x[hc(a)>>2]-x[a>>2]|0)/33|0)}}function Fu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-48|0;x[a+8>>2]=c;x[114409]=0;P(567,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){hU(x[a+16>>2],x[a>>2],(x[hc(a)>>2]-x[a>>2]|0)/48|0)}}function yL(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>28){break c}d=1<<a;c=1;if(d&270014517){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function wh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;g=_j(a,c);e=f+8|0;Af(e,x[a+28>>2]);h=x[e+12>>2];x[f+24>>2]=x[e+8>>2];x[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!Bd(a,5)){break b}break a}e=x[g+8>>2]}mb[d|0](x[a+28>>2],b,e)}a=qj(a,g,c,f+24|0);hb=f+32|0;return a|0}function tG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=js(a);x[a+32>>2]=b;x[a>>2]=60748;b=d+12|0;cs(b,a);x[114409]=0;b=S(2548,b|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Ob(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=en(b),v[f+44|0]=g;hb=d+16|0;return}b=N()|0;Ob(d+12|0);El(a);Q(b|0);p()}function rG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=GG(a);x[a+32>>2]=b;x[a>>2]=60952;b=d+12|0;cs(b,a);x[114409]=0;b=S(2550,b|0)|0;e=x[114409];x[114409]=0;if((e|0)!=1){Ob(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=en(b),v[f+44|0]=g;hb=d+16|0;return}b=N()|0;Ob(d+12|0);kp(a);Q(b|0);p()}function Pla(a){a=a|0;var b=0,c=0,d=0,e=0;if(!y[a+8|0]){if(y[a+24|0]){v[a+24|0]=0;c=a+40|0;while(1){d=Ui(c,b),e=0,v[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;Uk(b,0);gS(b)}b=a+12|0;Uk(b,x[a+4>>2]);mb[x[x[a>>2]+44>>2]](a,x[b>>2],0,x[a+4>>2])|0;v[a+8|0]=1}return x[a+12>>2]}function Mq(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){if(b>>>0>2147483647){Be();p()}d=_d(b<<1,1);x[e+8>>2]=b;x[e+4>>2]=d;f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<1)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<1)+f|0,x[g>>2]=h;hb=e+16|0;return a}function xE(a,b,c){var d=0,e=0,f=0;f=hb-16|0;hb=f;e=Cb(a);d=Hc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Rb(a);if(e){kl(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}kl(d,b,c);b=c+e|0;ch(a,b);v[f+15|0]=0;$d(b+d|0,f+15|0);break a}Lo(a,d,(c+e|0)-d|0,e,0,0,c,b)}hb=f+16|0;return a}function qu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-6|0;x[a+8>>2]=c;x[114409]=0;P(747,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Hu(x[a+16>>2],x[a>>2],(x[hc(a)>>2]-x[a>>2]|0)/6|0)}}function g2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Iw(d+24|0,a,(b<<2)+a|0);b=d+12|0;pl(d+16|0,b,x[d+24>>2],x[d+28>>2],c);f=d,g=Hw(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=ji(c,x[d+20>>2]),x[f+8>>2]=g;Dc(e+8|0,b,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Db(y[c|0])|Db(y[c+1|0])<<8,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function _ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Db(y[c+1|0])|Db(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function Vs(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2048|0;x[a+8>>2]=c;x[114409]=0;P(1772,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){DK(x[a+16>>2],x[a>>2],x[hc(a)>>2]-x[a>>2]>>11)}}function Kba(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;d=c+30|0;b=z[b>>1];v[d|0]=b;v[d+1|0]=b>>>8;b=c+8|0;xm(b,d);b=Db(x[b>>2]);xm(c,d);b=Fi(c+16|0,b,Db(x[c>>2]+2|0));x[114409]=0;O(1246,a|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){xb(b);hb=c+32|0;return}a=N()|0;xb(b);Q(a|0);p()}function f4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a=Qo(a);x[a>>2]=82696;e=hc(a);x[114409]=0;d=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=d;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;O(2327,e|0,c+8|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+32|0;return a|0}Q(N()|0);p()}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a=Qo(a);x[a>>2]=82736;e=hc(a);x[114409]=0;d=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=d;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;O(2328,e|0,c+8|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+32|0;return a|0}Q(N()|0);p()}function lF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=ne(d+4|0,a,b);b=x[c+4>>2];f=x[c+8>>2];a:{while(1){if((b|0)==(f|0)){break a}e=ul(a);x[114409]=0;iw(e,b);e=x[114409];x[114409]=0;if((e|0)!=1){b=b+4|0;x[c+4>>2]=b;continue}break}a=N()|0;Jb(c);Q(a|0);p()}Jb(c);hb=d+16|0}function d_(a){a=a|0;var b=0,c=0;b=x[a+8>>2];x[114409]=0;b=Z(2723,0,0,4,b|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=x[a+8>>2];if(!a){return 1}x[114409]=0;a=S(2724,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}R(0)|0;zb();p()}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;b=0;a:{if(Lb(a)>>>0>511){break a}if(!yd(c+12|0)){break a}d=c+12|0;b=x[d>>2];x[114409]=0;P(1749,a|0,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;Xf(c+12|0);Q(a|0);p()}Xf(c+12|0);hb=c+16|0;return b|0}function yT(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=y[b|0]|y[b+1|0]<<8;b=a+38|0;e=y[b|0]|y[b+1|0]<<8;b=a+34|0;a=a+36|0;c=y[a|0]|y[a+1|0]<<8;b=(y[b|0]|y[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;lb=b>>>0<d>>>0?a+1|0:a;return b}function kt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(!b){return 0}j=$b(a+1074312|0,73)?c- -64|0:c;c=120;h=Op(a);k=h^-1;e=1;while(1){f=c>>>1|0;i=f+e|0;g=jg(a,i,j,d);a:{if(!(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0))){e=i+1|0;c=(f^-1)+c|0;break a}c=f}if(c){continue}break}return e}function he(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function Um(a,b){var c=0,d=0,e=0,f=0;f=hb-16|0;hb=f;c=BE(b);d=hb-16|0;hb=d;a:{if(c>>>0<=1073741807){b:{if(bp(c)){Ie(a,c);e=a;break b}ck(d+8|0,a,wl(c)+1|0);e=x[d+8>>2];_e(a,e);Jf(a,x[d+12>>2]);ee(a,c)}Ph(e,b,c);x[d+4>>2]=0;wg((c<<2)+e|0,d+4|0);hb=d+16|0;break a}If();p()}hb=f+16|0}function uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-576|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;AT(d,e);f=Fb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){BT(e)}c=-1;a:{if(!d){break a}c=0;if(!ET(e)){break a}c=of(a,b,DT(e),lb)}hb=e+576|0;return c|0}function moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-192|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;Su(d,e);f=Fb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){ZS(e)}c=-1;a:{if(!d){break a}c=0;if(!zT(e)){break a}c=of(a,b,yT(e),lb)}hb=e+192|0;return c|0}function lX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=Qo(a);x[f>>2]=76100;g=hc(f);a=nl(e+20|0,b);b=x[d>>2];c=x[c>>2];d=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=d;a=vq(g);x[a>>2]=76140;d=e+8|0;nl(a+4|0,d);x[a+16>>2]=b;x[a+12>>2]=c;Ab(d);hb=e+32|0;return f|0}function aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-608|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;eQ(d,e);f=Fb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){fQ(e)}c=-1;a:{if(!d){break a}c=0;if(!hQ(e)){break a}c=of(a,b,gQ(e),lb)}hb=e+608|0;return c|0}function ZQ(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-8|0;x[a+8>>2]=c;x[114409]=0;P(948,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Bv(x[a+16>>2],x[a>>2],x[hc(a)>>2]-x[a>>2]>>3)}}function Vd(a,b){var c=0,d=0,e=0,f=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if((d|0)<=x[a+8>>2]){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=a>>>0>16;c=y[d+1|0];d=d+1|0;a=b;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function xV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=Qb(a,120);a:{if(f){c=hb-16|0;hb=c;d=e+8|0;jc(d,b,120);hb=c+16|0;Cd(a,d);break a}a=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=120){continue}break}hb=d+16|0;hb=c+16|0}hb=e+16|0;return f|0}function ey(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[c+12>>2]=0;U(1689,a+8|0,c+12|0,c+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=c+16|0;break a}R(0)|0;zb();p()}x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Jk(a+24|0);Xb(a+36|0);x[a+48>>2]=b;return a}function Vl(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,896)+a|0)+1075640>>2];if(!f){break a}if(!Ri(f)){break a}e=y[f+34|0];if((e-1&255)>>>0>249){break a}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break a}mb[x[x[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,896)+a|0)+1075846>>1]=65535}}function hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-80|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;SS(d,e);f=Fb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){ad(a,Fb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){TS(e)}c=-1;a:{if(!d){break a}c=0;if(!CP(e)){break a}c=of(a,b,BP(e),lb)}hb=e+80|0;return c|0}function qj(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=hb-48|0;hb=c;a:{if(!b){b=1;if(Bd(a,5)){break a}e=cE(c+32|0),f=x[d>>2]-x[a+8>>2]|0,x[e+4>>2]=f;Af(c,x[a+28>>2]);hE(c+16|0,c,x[d>>2],x[d+4>>2])}x[a>>2]=x[a>>2]|134217728;x[a+20>>2]=x[a+20>>2]+1;b=0}hb=c+48|0;return b|0}function lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;if(!Qb(b,c)){c=zf(b)}x[a>>2]=c;d=x[b>>2];if(mb[x[x[d>>2]+16>>2]](d)|0){c=a;a=x[b>>2];e=c,f=(mb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;return}d=a+8|0;Uk(d,x[a>>2]);if(!kd(d)){qg(b,Cc(d,0),c)}}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Yb(lm(y[c|0]),-64,63)<<1,v[f|0]=g;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e|0}function dD(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function zT(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1297108297){b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((y[c|0]|y[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(y[a|0]|y[a+1|0]<<8)>>>0<4e3}return b}function Cr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=ec(16);if(!y[462889]){v[462889]=1}a=Hd(c+8|0,a,83928);x[114409]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;U(2998,d|0,c|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){da(d|0,74264,2999);p()}a=N()|0;ic(d);Q(a|0);p()}function pD(a){a=a|0;var b=0,c=0;a=gd(a);x[114409]=0;S(247,a+12|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){b=hb-16|0;hb=b;x[114409]=0;U(248,a+28|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){hb=b+16|0;break a}R(0)|0;zb();p()}return a|0}b=N()|0;xb(a);Q(b|0);p()}function S9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[a+4>>2]=b;x[a>>2]=0;b=Jt(a+8|0,e);x[114409]=0;O(1884,a+20|0,d|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&240|c|8;return a|0}a=N()|0;Gb(b);Q(a|0);p()}function mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[ah(d+15|0,d+14|0)|0]}a=e;hb=d+16|0;return a&255}function lma(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(tf(a)>>>0<b>>>0){if(Pu(a)>>>0<b>>>0){break b}d=yb(a);b=ci(c+12|0,b,xc(a),d);x[114409]=0;P(342,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Dh(b)}hb=c+32|0;return}Xc();p()}a=N()|0;Dh(b);Q(a|0);p()}
function l1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Y3(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Bb(c+12|0,x[x[a+8>>2]>>2]);d=Bb(c+8|0,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];x[a+12>>2]=b;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;Vi(DI(b));ql(b);if(qc(b,a+8|0)){continue}break}}hb=a+16|0;hb=c+16|0}function Ica(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(xg(a)>>>0<b>>>0){if(Or(a)>>>0<b>>>0){break b}d=yb(a);b=ok(c+12|0,b,Ac(a),d);x[114409]=0;P(1334,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}xt(b)}hb=c+32|0;return}Xc();p()}a=N()|0;xt(b);Q(a|0);p()}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(xg(a)>>>0<b>>>0){if(Or(a)>>>0<b>>>0){break b}d=yb(a);b=ok(c+12|0,b,Ac(a),d);x[114409]=0;P(1060,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ut(b)}hb=c+32|0;return}Xc();p()}a=N()|0;Ut(b);Q(a|0);p()}function xma(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(_f(a)>>>0<b>>>0){if(tv(a)>>>0<b>>>0){break b}d=yb(a);b=Eo(c+12|0,b,rc(a),d);x[114409]=0;P(360,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Tj(b)}hb=c+32|0;return}Xc();p()}a=N()|0;Tj(b);Q(a|0);p()}function _$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+12>>2]=b;b=g+8|0;Fc(b,d);x[114409]=0;b=S(2606,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){Ob(g+8|0);FF(a,f+16|0,g+12|0,c,e,b);hb=g+16|0;return x[g+12>>2]}a=N()|0;Ob(g+8|0);Q(a|0);p()}function U9(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(sd(a)>>>0<b>>>0){if(Dk(a)>>>0<b>>>0){break b}d=yb(a);b=Rf(c+12|0,b,Lb(a),d);x[114409]=0;P(1883,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ps(b)}hb=c+32|0;return}Xc();p()}a=N()|0;Ps(b);Q(a|0);p()}function Td(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function $$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+12>>2]=b;b=g+8|0;Fc(b,d);x[114409]=0;b=S(2606,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){Ob(g+8|0);GF(a,f+24|0,g+12|0,c,e,b);hb=g+16|0;return x[g+12>>2]}a=N()|0;Ob(g+8|0);Q(a|0);p()}function by(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Lg(a)){break a}while(1){if(!Ah(Ye(a,e))){break a}d=d+1|0;e=d&65535;if(Lg(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(z[x[x[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=Zg(a,d&65535,b)?d:-1}return c&65535}function YF(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+12|0;Fc(d,a);x[114409]=0;a=S(21,d|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}x[114409]=0;a=O(22,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}Ob(c+12|0);hb=c+16|0;return a}a=N()|0;Ob(c+12|0);Q(a|0);p()}function XW(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(sd(a)>>>0<b>>>0){if(Dk(a)>>>0<b>>>0){break b}d=yb(a);b=Rf(c+12|0,b,Lb(a),d);x[114409]=0;P(319,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}er(b)}hb=c+32|0;return}Xc();p()}a=N()|0;er(b);Q(a|0);p()}function sga(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Bb(c+12|0,x[x[a+8>>2]>>2]);d=Bb(c+8|0,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];x[a+12>>2]=b;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;Wj(b);Ch(b);if(qc(b,a+8|0)){continue}break}}hb=a+16|0;hb=c+16|0}function f0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+12>>2]=b;b=g+8|0;Fc(b,d);x[114409]=0;b=S(21,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){Ob(g+8|0);JF(a,f+24|0,g+12|0,c,e,b);hb=g+16|0;return x[g+12>>2]}a=N()|0;Ob(g+8|0);Q(a|0);p()}function e0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+12>>2]=b;b=g+8|0;Fc(b,d);x[114409]=0;b=S(21,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){Ob(g+8|0);IF(a,f+16|0,g+12|0,c,e,b);hb=g+16|0;return x[g+12>>2]}a=N()|0;Ob(g+8|0);Q(a|0);p()}function Qba(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Bb(c+12|0,x[x[a+8>>2]>>2]);d=Bb(c+8|0,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];x[a+12>>2]=b;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;xA(b);wA(b);if(qc(b,a+8|0)){continue}break}}hb=a+16|0;hb=c+16|0}function KC(a,b,c,d){var e=0,f=0;b=x[a+1072>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1072>>2]=b;c=b+x[a+1076>>2]|0;x[a+1076>>2]=c;w[(x[a+1064>>2]<<1)+d>>1]=y[a+1080|0]?c:b;x[a+1060>>2]=x[a+1060>>2]+1;e=a,f=Qe(x[a+1056>>2])+x[a+1064>>2]|0,x[e+1064>>2]=f;x[a+1068>>2]=x[a+1068>>2]-1}function Fpa(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Bb(c+12|0,x[x[a+8>>2]>>2]);d=Bb(c+8|0,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];x[a+12>>2]=b;if(qc(a+12|0,a+8|0)){while(1){b=a+12|0;LU(b);Ch(b);if(qc(b,a+8|0)){continue}break}}hb=a+16|0;hb=c+16|0}function Df(a,b){var c=0,d=0,e=0,f=0;c=Cb(a);a:{if((c|0)!=(Cb(b)|0)){break a}d=Rb(a);b=Rb(b);b:{if(!we(a)){if(c){break b}return 1}return!xn(d,b,c)}while(1){a=y[b|0];e=y[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function zj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Rb(c);Fi(b,a,Cb(c)+a|0);break c}e=d+4|0;jK(e,c);x[114409]=0;T(116,a|0,b|0,e|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Pc(d+4|0)}hb=d+16|0;break a}a=N()|0;Pc(d+4|0);Q(a|0);p()}}function g9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=6){Vh(d+12|0);c=B[d+12>>2];a:{if(!((b|0)!=1|c>=E(1))){x[d+12>>2]=0;c=E(0);break a}if((b|0)!=4){break a}c=E(he(E(c*E(4)))*E(.25));B[d+12>>2]=c}B[((b<<2)+a|0)+4208>>2]=c;Px(a)}hb=d+16|0}function _z(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;a:{if((d|0)==(a|0)){b=0;break a}f=b?224:240;b=0;while(1){a=c;e=a+16|0;if((a|0)!=(e|0)){while(1){b=((y[fc(a,0)|0]&f)!=0)+b|0;a=a+4|0;if((e|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return b}function M9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=6){Vh(d+12|0);c=B[d+12>>2];a:{if(!((b|0)!=3|c>=E(1))){x[d+12>>2]=0;c=E(0);break a}if((b|0)!=4){break a}c=E(he(E(c*E(4)))*E(.25));B[d+12>>2]=c}B[((b<<2)+a|0)+4208>>2]=c;Px(a)}hb=d+16|0}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a>>2]){Ac(a);aO(a);Vt(a);Lh(yb(a),x[a>>2],xg(a));d=yb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}$l(a,b);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=x[yb(b)>>2];d=yb(a),e=c,x[d>>2]=e;d=yb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0}function op(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function nX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;x[114409]=0;x[e+24>>2]=d;x[e+28>>2]=c;W(259,e+8|0,b|0,e+28|0,e+24|0);c=x[114409];x[114409]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;ZC(c,d);Im(a,c);Ab(c);Ab(d);Ab(b);hb=e+32|0;return}a=N()|0;Ab(b);Q(a|0);p()}function Rf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){ay(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<2)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<2)+f|0,x[g>>2]=h;hb=e+16|0;return a|0}function E1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Qh(v[b|0]),e=x[x[a>>2]+52>>2],mb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=wj(b,1,c,x[a+32>>2])}return c|0}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Db(y[c|0])^128,v[f|0]=g;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e|0}function Os(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Rb(c);Fi(b,a,Cb(c)+a|0);break c}e=d+4|0;zK(e,b,c);x[114409]=0;P(117,a|0,e|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}Pc(d+4|0)}hb=d+16|0;break a}a=N()|0;Pc(d+4|0);Q(a|0);p()}}function Lca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=hb-16|0;hb=b;c=qd(a);e=b,f=bc(a),x[e+12>>2]=f;e=b,f=dc(a),x[e+8>>2]=f;if(Hb(b+12|0,b+8|0)){d=+(c>>>0);while(1){c=b+12|0;a=x[c>>2];C[a>>3]=C[a>>3]/d;C[a+8>>3]=C[a+8>>3]/d;sf(c);if(Hb(c,b+8|0)){continue}break}}hb=b+16|0}function zb(){var a=0;a=x[20983];x[114409]=0;X(a|0);a=x[114409];x[114409]=0;a:{if((a|0)!=1){x[114409]=0;P(3011,8438,0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}}Y(R(0)|0)|0;x[114409]=0;P(3011,5772,0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb()}p()}function bR(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;b=hb-16|0;hb=b;d=2;e=x[a>>2];if((e|0)!=1){x[b+12>>2]=e>>>1;x[b+8>>2]=-1-x[a>>2];d=Mb(b+12|0,b+8|0);x[b+12>>2]=x[a>>2]+x[d>>2];x[b+8>>2]=x[c+12>>2];d=x[Mb(b+12|0,b+8|0)>>2]}hb=b+16|0;hb=c+16|0;return d}function R4(a,b){a=a|0;b=b|0;var c=E(0),d=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);c=E(E(y[(b+x[a>>2]|0)+1075847|0])*E(.0078125));d=E(c*c);c=E(E(y[(b+x[a>>2]|0)+1075846|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return E(c)}function zI(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(2336,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Mp(x[a+16>>2],x[a>>2],jm(a))}}function yQ(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(1013,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lf(x[a+16>>2],x[a>>2],jm(a))}}function vga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;d=c+31|0;v[d|0]=y[b|0];b=c+8|0;fr(b,d);b=Db(x[b>>2]);fr(c,d);b=Fi(c+16|0,b,Db(x[c>>2]+1|0));x[114409]=0;O(1246,a|0,b|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){xb(b);hb=c+32|0;return}a=N()|0;xb(b);Q(a|0);p()}function _N(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114409]=0;P(1301,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lh(x[a+16>>2],x[a>>2],hp(a))}}function Zr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Tw(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function Ut(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114409]=0;P(1068,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lh(x[a+16>>2],x[a>>2],hp(a))}}function SY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(vg(a,x[b+8>>2],0)){$v(b,c,d);return}e=x[a+12>>2];f=a+16|0;jE(f,b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){jE(a,b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function R8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=td(b);f=nf(b);e=td(b);c=hb-16|0;hb=c;x[c+8>>2]=f;x[c+12>>2]=d;x[c+4>>2]=e;if(Hb(c+12|0,c+8|0)){while(1){d=c+12|0;f=vn(v[x[d>>2]]);e=c+4|0;v[x[e>>2]]=f;gg(d);gg(e);if(Hb(d,c+8|0)){continue}break}}hb=c+16|0;Jd(a,b)}function KP(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114409]=0;P(1066,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lh(x[a+16>>2],x[a>>2],hp(a))}}function Ht(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-32|0;x[a+8>>2]=c;x[114409]=0;P(1249,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){dh(x[a+16>>2],x[a>>2],Ev(a))}}function GL(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(1658,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lf(x[a+16>>2],x[a>>2],jm(a))}}function CI(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-16|0;x[a+8>>2]=c;x[114409]=0;P(2332,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){ki(x[a+16>>2],x[a>>2],Qv(a))}}function xt(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114409]=0;P(324,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lh(x[a+16>>2],x[a>>2],hp(a))}}function wS(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(783,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lf(x[a+16>>2],x[a>>2],jm(a))}}function vP(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(1110,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Nj(x[a+16>>2],x[a>>2],Eg(a))}}function nr(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-32|0;x[a+8>>2]=c;x[114409]=0;P(246,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){dh(x[a+16>>2],x[a>>2],Ev(a))}}function nM(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(1539,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function dU(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(566,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lf(x[a+16>>2],x[a>>2],jm(a))}}function ZM(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-32|0;x[a+8>>2]=c;x[114409]=0;P(919,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){eu(x[a+16>>2],x[a>>2],Ev(a))}}function Yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Dv(a)>>>0<b>>>0){Xc();p()}yb(a);if(b>>>0>536870911){Be();p()}d=_d(b<<3,8);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<3)|0,x[e>>2]=f;Cv(a,0);hb=c+16|0}function YD(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-16|0;x[a+8>>2]=c;x[114409]=0;P(190,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){ki(x[a+16>>2],x[a>>2],Qv(a))}}function WT(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(605,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lf(x[a+16>>2],x[a>>2],jm(a))}}function Us(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(1774,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Rv(a)>>>0<b>>>0){Xc();p()}yb(a);if(b>>>0>268435455){Be();p()}d=_d(b<<4,8);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<4)|0,x[e>>2]=f;Xo(a,0);hb=c+16|0}function TL(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(1623,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function SK(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(1533,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function Ps(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(1887,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function Pr(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114409]=0;P(180,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lh(x[a+16>>2],x[a>>2],hp(a))}}function OU(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114409]=0;P(512,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Lf(x[a+16>>2],x[a>>2],jm(a))}}function JC(a,b,c,d){var e=0,f=0;b=x[a+1072>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1072>>2]=b;c=b+x[a+1076>>2]|0;x[a+1076>>2]=c;v[x[a+1064>>2]+d|0]=y[a+1080|0]?c:b;x[a+1060>>2]=x[a+1060>>2]+1;e=a,f=Qe(x[a+1056>>2])+x[a+1064>>2]|0,x[e+1064>>2]=f;x[a+1068>>2]=x[a+1068>>2]-1}function Bu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-16|0;x[a+8>>2]=c;x[114409]=0;P(397,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){ki(x[a+16>>2],x[a>>2],Qv(a))}}function yn(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(746,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Db(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=lm(y[c|0]),v[f|0]=g;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e|0}function kJ(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=bJ(Re(8));x[b+4>>2]=a;x[b>>2]=82776;c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=b;a=U(2264,d+12|0,c+12|0,c+11|0)|0;b=x[114409];x[114409]=0;a:{if((b|0)!=1){hb=c+16|0;break a}R(0)|0;zb();p()}hb=d+16|0;return x[a>>2]}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Db(b);if(f){a=x[a+20>>2];b=f;while(1){d=Db(y[c|0])+d|0;v[a|0]=d;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f|0}function fj(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(352,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){jv(x[a+16>>2],x[a>>2],Eg(a))}}function er(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(325,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function cS(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(842,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Nj(x[a+16>>2],x[a>>2],Eg(a))}}function XR(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114409]=0;P(848,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){mm(x[a+16>>2],x[a>>2],Co(a))}}function VS(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(748,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Nj(x[a+16>>2],x[a>>2],Eg(a))}}function Tm(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-1|0;x[a+8>>2]=c;x[114409]=0;P(188,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){fg(x[a+16>>2],x[a>>2],PA(a))}}function Tj(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114409]=0;P(362,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Fo(x[a+16>>2],x[a>>2],Co(a))}}function Ru(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114409]=0;P(520,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){mm(x[a+16>>2],x[a>>2],Co(a))}}function RE(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=0;x[d+4>>2]=4;sl(a,d+8|0,x[Mb(d+12|0,d+4|0)>>2]);a=lb;if((a|0)>0|(a|0)>=0){x[d+4>>2]=4;Mb(d+12|0,d+4|0)}x[d+4>>2]=x[d+8>>2];a=d+4|0;x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);hb=d+16|0}function IQ(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(976,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Nj(x[a+16>>2],x[a>>2],Eg(a))}}function FC(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114409]=0;P(340,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){Fo(x[a+16>>2],x[a>>2],Co(a))}}function FB(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114409]=0;P(393,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){mm(x[a+16>>2],x[a>>2],Co(a))}}function Ek(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114409]=0;P(109,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){bf(x[a+16>>2],x[a>>2],Eg(a))}}function Dh(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-1|0;x[a+8>>2]=c;x[114409]=0;P(339,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){fg(x[a+16>>2],x[a>>2],PA(a))}}function Cj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+480180>>2]&1|b){e=x[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function wk(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=us(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+12>>2]=b;b=a+8|0;Fc(b,d);x[114409]=0;b=S(2606,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){Ob(a+8|0);EF(f+20|0,a+12|0,c,e,b);hb=a+16|0;return x[a+12>>2]}b=N()|0;Ob(a+8|0);Q(b|0);p()}function Ou(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-1|0;x[a+8>>2]=c;x[114409]=0;P(37,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){fg(x[a+16>>2],x[a>>2],PA(a))}}function kn(a,b,c){var d=0,e=0,f=0,g=0;if(b){while(1){c=c-1|0;e=a;a=vqa(a,b,10,0);d=lb;f=c,g=e-sqa(a,d,10,0)|48,v[f|0]=g;e=b>>>0>9;b=d;if(e){continue}break}}if(a){while(1){c=c-1|0;b=(a>>>0)/10|0;v[c|0]=a-D(b,10)|48;d=a>>>0>9;a=b;if(d){continue}break}}return c}function dn(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){b=0;break a}d=b;b=G(b);lf(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;hb=c+16|0}function b6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;x[d+28>>2]=b;zj(d,0,c);b=d+12|0;x[b>>2]=x[d+28>>2];Jd(b+4|0,d);x[114409]=0;P(2249,a+4|0,b|0);a=x[114409];x[114409]=0;if((a|0)!=1){Vi(d+12|0);xb(d);hb=d+32|0;return}a=N()|0;Vi(d+12|0);xb(d);Q(a|0);p()}function aE(a,b){var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;x[b>>2]=0;v[c+15|0]=0;f=gh(a,c+15|0);d=y[c+15|0];x[b>>2]=d>>>2;d=d&3;if(d){while(1){v[c+15|0]=0;g=gh(a,c+15|0);e=e+1|0;x[b>>2]=x[b>>2]|y[c+15|0]<<(e<<3)-2;f=f&g;if((d|0)!=(e|0)){continue}break}}hb=c+16|0}function d0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+12>>2]=b;b=a+8|0;Fc(b,d);x[114409]=0;b=S(21,b|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){Ob(a+8|0);HF(f+20|0,a+12|0,c,e,b);hb=a+16|0;return x[a+12>>2]}b=N()|0;Ob(a+8|0);Q(b|0);p()}function hZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=Vm(a);e=Cb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Rb(a);Ph(d+(e<<2)|0,b,c);b=c+e|0;ch(a,b);x[f+12>>2]=0;wg(d+(b<<2)|0,f+12|0);break a}uE(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function h9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=hK(a,b,c,d);x[a+4208>>2]=1056964608;x[a+4212>>2]=1065353216;x[a+4232>>2]=1056964608;b=a+4224|0;x[b>>2]=1056964608;x[b+4>>2]=1048406533;b=a+4216|0;x[b>>2]=1020054733;x[b+4>>2]=1065353216;x[a>>2]=79980;return a|0}function gO(a,b){var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(sd(a)>>>0<b>>>0){if(Dk(a)>>>0<b>>>0){break b}d=yb(a);b=Rf(c+12|0,b,Lb(a),d);x[114409]=0;P(102,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Ek(b)}hb=c+32|0;return}Xc();p()}a=N()|0;Ek(b);Q(a|0);p()}function ew(a,b){var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(tf(a)>>>0<b>>>0){if(Pu(a)>>>0<b>>>0){break b}d=yb(a);b=ci(c+12|0,b,xc(a),d);x[114409]=0;P(183,a|0,b|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}Tm(b)}hb=c+32|0;return}Xc();p()}a=N()|0;Tm(b);Q(a|0);p()}function ue(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ae(d+24|0,a,b);b=d+12|0;pl(d+16|0,b,x[d+24>>2],x[d+28>>2],c);f=d,g=Wo(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=ji(c,x[d+20>>2]),x[f+8>>2]=g;Dc(e+8|0,b,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function sF(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;JE(d+24|0,a,b);b=d+12|0;pl(d+16|0,b,x[d+24>>2],x[d+28>>2],c);f=d,g=oP(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=ji(c,x[d+20>>2]),x[f+8>>2]=g;Dc(e+8|0,b,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function rF(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;JE(d+24|0,a,b);b=d+12|0;pl(d+16|0,b,x[d+24>>2],x[d+28>>2],c);f=d,g=Xx(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=ji(c,x[d+20>>2]),x[f+8>>2]=g;Dc(e+8|0,b,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function ci(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){Mh(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=c+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=b+f|0,x[g>>2]=h;hb=e+16|0;return a|0}function $ja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(!x[a+300>>2]){return 0}a:{if(!d|(mb[x[a+304>>2]](x[a+296>>2],c,0,0)|0)<0){break a}while(1){c=mb[x[a+300>>2]](x[a+296>>2],b,d)|0;if(!c){break a}e=c+e|0;b=b+c|0;d=d-c|0;if(d){continue}break}}return e|0}function tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=hb-2496|0;hb=c;QK(b,c,c+2496|0);b=sc(a,c,2496);x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}d=1;while(1){if(x[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}x[b>>2]=-2147483648}hb=c+2496|0;return a|0}function nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(!((c|0)!=4&(c|0)!=-1)){c=hb-16|0;hb=c;x[c+12>>2]=0;Ap(a,c+12|0);B[b>>2]=B[c+12>>2];hb=c+16|0;return}d=hb-16|0;hb=d;x[d+12>>2]=0;x[d+8>>2]=c;x[d+4>>2]=4;sl(a,d+12|0,x[Mb(d+8|0,d+4|0)>>2]);x[b>>2]=0;hb=d+16|0}function i1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{if(y[a+40|0]){break b}if(!x[a+28>>2]){break a}if(!c){break b}while(1){d=mb[x[a+28>>2]](x[a+24>>2],b,c)|0;if(!d){break a}e=d+e|0;b=b+d|0;c=c-d|0;if(c){continue}break}}return e|0}v[a+40|0]=1;return e|0}function Fga(a){a=a|0;var b=0,c=0,d=0;c=hb-32|0;hb=c;b=255;a:{if(ai(a)>>>0<=49){b=vz(c,x[a+12>>2]);x[114409]=0;P(1232,a|0,b|0);d=x[114409];x[114409]=0;if((d|0)==1){break a}Qk(b);cq(a,ai(a)-1&255);b=ai(a)-1|0}hb=c+32|0;return b&255}a=N()|0;Qk(b);Q(a|0);p()}function As(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;x[b+12>>2]=12;x[b+8>>2]=32;if(x[Mb(b+12|0,b+8|0)>>2]){while(1){e=Pp(a);x[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<A[Mb(b+12|0,b+8|0)>>2]){continue}break}}hb=b+16|0;a=x[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function pF(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=66248;b=x[a+8>>2];x[114409]=0;c=$(2603)|0;d=x[114409];x[114409]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){b=x[a+8>>2];x[114409]=0;xw(b);b=x[114409];x[114409]=0;if((b|0)==1){break a}}return a|0}R(0)|0;zb();p()}function Zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=C[b>>3];d=C[b+8>>3];if(d==0){d=C[b+8>>3];e=a;c=rs(c);o(0);a=j(1)|0;f=j(0)|0;o(+d);b=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|b&-2147483648);_l(e,c,+n());return}c=rs(C[b>>3]);g=vi(d);_l(a,c*De(d),c*g)}function yI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=_h(E(d*E(65536)));if((e|0)==65536){break a}f=D(b,c);if(!f){break a}g=e>>31;b=0;while(1){c=x[a>>2];h=a,i=Ec(tqa(sqa(c,c>>31,e,g),lb,65536,0),lb),x[h>>2]=i;a=a+4|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}}function Tw(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){mb[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function fga(a){a=a|0;var b=0,c=0,d=0,e=0;x[a>>2]=0;if(!(v[86148]&1)){while(1){d=0;c=(b&255)<<24;while(1){e=c<<1;c=(c|0)<0?e^79764919:e;d=d+1|0;if((d|0)!=8){continue}break}x[(b<<2)+86160>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}v[86148]=1}return a|0}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+12>>2]=b;b=x[a>>2];e=d,f=bc(a),x[e+4>>2]=f;c=d+12|0;b=b+D(bt(c,d+4|0),6)|0;if(Hb(c,d+8|0)){JA(a,at(b+D(bt(d+8|0,d+12|0),6)|0,x[a+4>>2],b))}a=Rg(b);hb=d+16|0;return a|0}function Qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,64);a:{if(e){c=d+8|0;eB(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){Yu((a<<1)+b|0);a=a+1|0;if((a|0)!=32){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+12>>2]=b;b=x[a>>2];e=d,f=bc(a),x[e+4>>2]=f;c=d+12|0;b=b+(Jq(c,d+4|0)<<1)|0;if(Hb(c,d+8|0)){vo(a,ue(b+(Jq(d+8|0,d+12|0)<<1)|0,x[a+4>>2],b))}a=Rg(b);hb=d+16|0;return a|0}function wN(a,b,c){var d=0,e=0;d=x[(D(b,896)+a|0)+1075072>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(z[a+480188>>1]<=b>>>0){c=z[(D(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=y[((b<<5)+a|0)+480288|0]}return e}function qo(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){d=xD(b);x[e+8>>2]=b;x[e+4>>2]=d;f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=D(c,24)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=D(b,24)+f|0,x[g>>2]=h;hb=e+16|0;return a}function jw(a){a=a|0;var b=0,c=0,d=0;b=x[a+8>>2];x[114409]=0;c=$(2603)|0;d=x[114409];x[114409]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=x[a+8>>2];x[114409]=0;xw(b);b=x[114409];x[114409]=0;if((b|0)==1){break b}}break a}R(0)|0;zb();p()}return a|0}function wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+14|0;iQ(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){jQ(f)}if(a){e=AQ(b+14|0)}hb=b+160|0;return e|0}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-624|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+14|0;EU(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){FU(f)}if(a){e=HU(b+14|0)}hb=b+624|0;return e|0}function joa(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;a:{if(b){Vb(c+8|0,b);break a}Xb(c+8|0)}x[114409]=0;P(674,c+20|0,c+8|0);b=x[114409];x[114409]=0;if((b|0)!=1){b=a;a=c+20|0;b=Jd(b,a);xb(a);xb(c+8|0);hb=c+32|0;return b|0}a=N()|0;xb(c+8|0);Q(a|0);p()}function woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+3|0;FT(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){GT(f)}if(a){e=IT(b+3|0)}hb=b+160|0;return e|0}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+11|0;sB(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){pV(f)}if(a){e=LS(b+11|0)}hb=b+16|0;return e|0}function ZT(a){a=a|0;var b=0,c=0,d=0,e=0;b=x[a>>2];c=YT(a);d=hb-16|0;hb=d;e=hb-16|0;hb=e;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Go(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}hb=e+16|0;hb=d+16|0;return x[b>>2]}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+10|0;Cu(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){XT(f)}if(a){e=$T(b+10|0)}hb=b+32|0;return e|0}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-208|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+4|0;NP(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){OP(f)}if(a){e=WP(b+4|0)}hb=b+208|0;return e|0}function zpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,64);a:{if(e){c=d+8|0;eB(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=64){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,27);a:{if(e){c=d+8|0;tO(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=27){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function P2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a=js(a);x[a>>2]=59400;e=WG(a+32|0,d+15|0);x[a+48>>2]=c;x[a+44>>2]=0;x[114409]=0;P(161,a|0,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){hb=d+16|0;return a|0}b=N()|0;xb(e);El(a);Q(b|0);p()}function Gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;d=_j(a,c);Af(e,x[a+28>>2]);f=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=f;a:{if(!d){if(Bd(a,5)){break a}}nT(x[a+28>>2],b,x[e+28>>2],0)}qj(a,d,c,e+16|0);hb=e+32|0}function wB(a){var b=0,c=0,d=0,e=0;b=a+5|0;c=y[b|0]|y[b+1|0]<<8;b=c+y[a+2|0]|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=a+3|0;a=y[a|0]|y[a+1|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;lb=b>>>0<47?a+1|0:a;return b}function ir(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=Hc(a);e=Cb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Rb(a);Se(d+e|0,b,c);b=c+e|0;ch(a,b);v[f+15|0]=0;$d(b+d|0,f+15|0);break a}Lo(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=0;a:{if(!Lb(a)){break a}while(1){e=d+4|0;Zf(e,x[Pb(a,c)>>2]+40|0);f=zq(e,b);xb(e);if(f){c=x[Pb(a,c)>>2];break a}c=c+1|0;if(Lb(a)>>>0>c>>>0){continue}break}c=0}hb=d+16|0;return c|0}function bH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=bH(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function YB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,16);a:{if(e){c=d+8|0;NB(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=16){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function IM(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){f=Db(y[b|0]);d=x[a>>2];e=x[a+4>>2];g=e>>>8|0;e=(e&255)<<24|d>>>8;d=(((d^f)&255)<<3)+84096|0;f=x[d>>2];d=x[d+4>>2]^g;x[a>>2]=f^e;x[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function BN(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Nt(b,e,a);if(!$b(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;d=_j(a,c);Af(e,x[a+28>>2]);f=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=f;a:{if(!d){if(Bd(a,5)){break a}}YK(x[a+28>>2],b,x[e+28>>2])}qj(a,d,c,e+16|0);hb=e+32|0}function pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=bh(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1251,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,6);a:{if(e){c=d+8|0;UA(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=6){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=xh(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1025,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function hW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-48|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+7|0;OB(c,f);g=Fb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){PB(f)}if(a){e=_B(b+7|0)}hb=b+48|0;return e|0}function gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,2);a:{if(e){c=d+8|0;xm(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=2){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function Xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=kr(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1288,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Ul(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{switch(c|0){case 2:e=xN(a,b,d);if((e+5&255)>>>0>5){break a}case 0:return wN(a,b,d);case 3:e=wN(a,b,d);if((e+5&255)>>>0>5){break a}break;case 1:break b;default:break a}}e=xN(a,b,d)}return e}function HN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=hb-16|0;hb=a;d=x[b+104>>2];if(!(!d|!x[b+76>>2])){x[b+88>>2]=x[b+88>>2]&-131|128;d=x[d>>2];x[b+76>>2]=d;x[a+12>>2]=c<<8;x[a+8>>2]=d-1;c=d+(x[Mb(a+12|0,a+8|0)>>2]^-1)|0;x[b>>2]=0;x[b+4>>2]=c}hb=a+16|0}function kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,1030);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,1030);hb=c+16|0}return a|0}function hy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=ne(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1680,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function fy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=Gq(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1684,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function c6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=Qm(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(2247,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function a5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;d=xl(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(2306,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function TU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,8);a:{if(e){c=d+8|0;zv(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){qf(a+b|0);a=a+1|0;if((a|0)!=8){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function IA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Pj(a+8|0);x[114409]=0;d=S(305,b|0)|0;e=x[114409];x[114409]=0;b:{if((e|0)==1){break b}x[114409]=0;T(448,a|0,b|0,d|0);a=x[114409];x[114409]=0;if((a|0)==1){break b}break a}a=N()|0;yh(c);Q(a|0);p()}}function zfa(){var a=0,b=0,c=0,d=0;b=hb-16|0;hb=b;c=Sb(Re(6668),0,6668);a=hb-16|0;hb=a;x[114409]=0;x[a+12>>2]=c;c=U(1322,b+12|0,a+12|0,a+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}hb=b+16|0;return x[c>>2]}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=4896;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;BA(e,b);qg(a,x[e>>2],c);BA(e,b);Sb(x[e>>2]+c|0,0,4896-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function CO(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(y[a+530|0]){while(1){d=c&65535;Pi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}v[a+530|0]=0}v[b+15|0]=0;$h(a+4|0,18,b+15|0);pA(a+22|0,18,25738);v[b+14|0]=255;$h(a+58|0,256,b+14|0);hb=b+16|0}function v0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=b;x[e+8>>2]=d;b=Nh(e+4|0,e+12|0);x[114409]=0;a=U(2626,a|0,c|0,x[e+8>>2])|0;c=x[114409];x[114409]=0;if((c|0)!=1){Te(b);hb=e+16|0;return a|0}a=N()|0;Te(b);Q(a|0);p()}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,274);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,274);hb=c+16|0}return a|0}function tca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,225);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,225);hb=c+16|0}return a|0}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,106);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,106);hb=c+16|0}return a|0}function pca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,326);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,326);hb=c+16|0}return a|0}function ok(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){KF(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=D(c,12)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=D(b,12)+f|0,x[g>>2]=h;hb=e+16|0;return a}function ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,422);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,422);hb=c+16|0}return a|0}function ema(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,826);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,826);hb=c+16|0}return a|0}function Spa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,136);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,136);hb=c+16|0}return a|0}function Gj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=z[a+20>>1];if(c){d=z[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0>=2048){w[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function pp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function pS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,284);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,284);hb=c+16|0}return a|0}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=263;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;wP(e,b);qg(a,x[e>>2],c);wP(e,b);Sb(x[e>>2]+c|0,0,263-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function Zp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=z[a+24>>1]<<17;e=z[a+20>>1];if(e){d=z[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-D(x[ef(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function Sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;if(!(!a|!b)){f=lt(a);e=hb-16|0;hb=e;a=lt(a);c=lt(b);if(c){while(1){g=a;a=c;c=(g>>>0)%(a>>>0)|0;if(c){continue}break}}hb=e+16|0;c=D(lt(b),(f|0)/(a|0)|0)}hb=d+16|0;return c|0}function yma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,42);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,42);hb=c+16|0}return a|0}function wr(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){VD(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<4)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<4)+f|0,x[g>>2]=h;hb=e+16|0;return a}function wca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,73);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,73);hb=c+16|0}return a|0}function tu(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){US(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<2)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<2)+f|0,x[g>>2]=h;hb=e+16|0;return a}function pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,72);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,72);hb=c+16|0}return a|0}function or(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){kD(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<5)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<5)+f|0,x[g>>2]=h;hb=e+16|0;return a}function nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,60);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,60);hb=c+16|0}return a|0}function fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,91);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,91);hb=c+16|0}return a|0}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,71);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,71);hb=c+16|0}return a|0}function RS(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){oU(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=D(c,6)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=D(b,6)+f|0,x[g>>2]=h;hb=e+16|0;return a}function Qia(a){a=a|0;var b=0,c=0,d=0;b=a;c=sP(a);if((c|0)!=(a|0)){while(1){a=0;lT(b);a:{while(1){d=a+b|0;if(y[d|0]){a=a+1|0;if((a|0)!=32){continue}break a}break}if(a>>>0>31){break a}Sb(d,0,32-a|0)}b=b+32|0;if((c|0)!=(b|0)){continue}break}}}function ON(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!c){break a}x[b+40>>2]=c;if(x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[$c(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=CN(c&255),x[e+44>>2]=f}hb=d+16|0}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,34);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,34);hb=c+16|0}return a|0}function Eo(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){DC(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<1)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<1)+f|0,x[g>>2]=h;hb=e+16|0;return a}function Ao(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;We(a+12|0,d);if(b){rC(e+4|0,x[a+16>>2],b);f=x[e+4>>2];b=x[e+8>>2]}else{b=0}x[a>>2]=f;c=(c<<2)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=hc(a),h=(b<<2)+f|0,x[g>>2]=h;hb=e+16|0;return a}function qX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;b=Jd(b,c);Dm(b+12|0,c+12|0);a=hb-16|0;hb=a;c=c+28|0;d=a,e=oe(c),x[d+12>>2]=e;x[114409]=0;U(254,b+28|0,a+12|0,c|0)|0;b=x[114409];x[114409]=0;a:{if((b|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=33;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;tA(e,b);qg(a,x[e>>2],c);tA(e,b);Sb(x[e>>2]+c|0,0,33-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function cW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,59);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,59);hb=c+16|0}return a|0}function YU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,50);hb=e+16|0;e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,50);hb=c+16|0}return a|0}function Dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=22;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;Cu(e,b);qg(a,x[e>>2],c);Cu(e,b);Sb(x[e>>2]+c|0,0,22-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function Ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=40;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;nA(e,b);qg(a,x[e>>2],c);nA(e,b);Sb(x[e>>2]+c|0,0,40-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function uf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Pj(a+8|0);x[114409]=0;T(448,a|0,b|0,c|0);c=x[114409];x[114409]=0;a:{if((c|0)!=1){a=x[a>>2];x[114409]=0;O(313,b|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){break a}}a=N()|0;yh(d);Q(a|0);p()}}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;b=PR(d,b);e=hb-16|0;hb=e;b=PR(e+4|0,b);f=hb-16|0;hb=f;g=d+8|0;yr(g,x[b>>2],x[b>>2]+IR(b)|0);hb=f+16|0;hb=e+16|0;Gv(a,g);x[a+12>>2]=c;x[a+8>>2]=0;hb=d+16|0;return a|0}function j6(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;b=b+4|0;d=x[b+48>>2];a:{if(d&16){if(A[b+24>>2]>A[b+44>>2]){x[b+44>>2]=x[b+24>>2]}Fi(a,x[b+20>>2],x[b+44>>2]);break a}if(d&8){Fi(a,x[b+8>>2],x[b+16>>2]);break a}WG(a,c+13|0)}hb=c+16|0}function aW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=65;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;Zu(e,b);qg(a,x[e>>2],c);Zu(e,b);Sb(x[e>>2]+c|0,0,65-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function TM(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;c=b+12|0;d=hb-16|0;hb=d;Bb(d+12|0,a+116|0);x[114409]=0;a=Ja(167,a|0)|0;e=x[114409];x[114409]=0;a:{if((e|0)!=1){hb=d+16|0;break a}Q(N()|0);p()}x[c>>2]=a;Pp(c);hb=b+16|0;return x[c>>2]}function AR(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Qt(d+24|0,a,b);b=d+12|0;pl(d+16|0,b,x[d+24>>2],x[d+28>>2],c);f=d,g=oP(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=ji(c,x[d+20>>2]),x[f+8>>2]=g;Dc(e+8|0,b,d+8|0);hb=d+32|0;hb=e+16|0}function jM(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function $p(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(C[x[a+4>>2]-8>>3]-C[x[a>>2]>>3]);while(1){d=-Td(C[ol(a,c)>>3]*131072*f);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=ef(b,c),h=e,x[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function Oh(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function kk(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=a;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;x[c+8>>2]=b;if(a>>>0>=b>>>0){break a}zh(x[c+12>>2],x[c+8>>2]);a=x[c+12>>2]+1|0;x[c+12>>2]=a;b=x[c+8>>2];continue}}hb=c+16|0}function ip(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=a;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;x[c+8>>2]=b;if(a>>>0>=b>>>0){break a}Ub(x[c+12>>2],x[c+8>>2]);a=x[c+12>>2]+4|0;x[c+12>>2]=a;b=x[c+8>>2];continue}}hb=c+16|0}function a2(a){a=a|0;if(A[a+24>>2]>A[a+44>>2]){x[a+44>>2]=x[a+24>>2]}a:{if(!(y[a+48|0]&8)){break a}if(A[a+16>>2]<A[a+44>>2]){fn(a,x[a+8>>2],x[a+12>>2],x[a+44>>2])}if(A[a+12>>2]>=A[a+16>>2]){break a}return Qh(v[x[a+12>>2]])|0}return-1}function L9(a){a=a|0;var b=0;mb[x[x[a>>2]+124>>2]](a);Px(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=mb[x[x[a>>2]+188>>2]](a)|0;x[a+4272>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4292>>2]=b;x[a+4288>>2]=b;x[a+4284>>2]=b;x[a+4280>>2]=b}function $L(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ec(tqa(sqa(d,d>>31,g,h),lb,256,0),lb);x[a+4>>2]=f-d;x[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function yg(a,b,c){c=x[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;cv(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;hb=c+16|0}return a|0}function Nv(){var a=0,b=0,c=0,d=0;b=hb-16|0;hb=b;c=DE(Re(12));a=hb-16|0;hb=a;x[114409]=0;x[a+12>>2]=c;c=U(242,b+12|0,a+12|0,a+11|0)|0;d=x[114409];x[114409]=0;a:{if((d|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}hb=b+16|0;return x[c>>2]}function xz(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1216,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){hb=b+16|0;break a}R(0)|0;zb();p()}x[a+12>>2]=0;w[a+16>>1]=65280;return a}function w1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=wj(b,4,c,x[a+32>>2])}return c|0}function MD(){var a=0,b=0,c=0;b=hb-16|0;hb=b;a=Vb(b+4|0,10518);a:{if(!Cb(a)){break a}c=1;if((bg(a,10181)|0)!=-1){break a}if((bg(a,12738)|0)!=-1){break a}if((bg(a,9547)|0)!=-1){break a}c=(bg(a,9590)|0)!=-1}xb(a);hb=b+16|0;return c|0}function wt(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;if(c>>>0<=2147483631){a:{if(ml(c)){Ie(a,c);e=a;break a}Mh(d+8|0,a,mj(c)+1|0);e=x[d+8>>2];_e(a,e);Jf(a,x[d+12>>2]);ee(a,c)}Se(e,b,c);v[d+7|0]=0;$d(c+e|0,d+7|0);hb=d+16|0;return}If();p()}function nZ(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Rd(b,6246)){a=c+4|0;rE(a,13345,b);a=Rb(a);x[114409]=0;P(2992,44,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;xb(c+4|0);Q(a|0);p()}hb=c+16|0;return a|0}p()}function vF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+8>>2]=b;x[d+12>>2]=a;x[d+4>>2]=c;while(1){a=Hb(d+12|0,d+8|0);if(!(!a|x[x[d+12>>2]>>2]!=x[x[d+4>>2]>>2])){je(d+12|0);je(d+4|0);continue}break}hb=d+16|0;return a^1}function tqa(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=vqa(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;lb=(g^lb)-((a>>>0<f>>>0)+g|0)|0;return b}function sD(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;hb=b+16|0}function cM(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+12>>2]=7;x[b+8>>2]=32;if(x[Mb(b+12|0,b+8|0)>>2]){while(1){d=Pp(a);x[b+12>>2]=7;x[b+8>>2]=32;c=c+15|0;if(c>>>0<A[Mb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}hb=b+16|0;return c}function Xp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;if(b){e=Hc(a);d=Cb(a);g=d+b|0;if(e-d>>>0<b>>>0){dl(a,e,g-e|0,d,d,0,0)}e=d;d=Rb(a);In(e+d|0,b,c);ch(a,g);v[f+15|0]=0;$d(d+g|0,f+15|0)}hb=f+16|0;return a|0}function Uo(a,b){var c=0,d=0;c=b+4|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);a:{if(b>>>0>=xc(a)>>>0){break a}if(xc(a)>>>0<c>>>0){break a}d=c-1>>>0<xc(a)-b>>>0}return d}function P8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=12){Vh(d+12|0);c=B[d+12>>2];e=((b<<2)+a|0)+4208|0;if((b|0)==12){c=E(he(E(c*E(3)))*E(.3333333432674408))}B[e>>2]=c;v[a+5046|0]=1}hb=d+16|0}function O4(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(!(v[(b+x[a>>2]|0)+1075073|0]&1)){break a}c=E(E(y[(b+x[a>>2]|0)+1075846|0])*E(.0078125))}return E(c)}function N4(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(!(v[(b+x[a>>2]|0)+1075073|0]&1)){break a}c=E(E(y[(b+x[a>>2]|0)+1075847|0])*E(.0078125))}return E(c)}function q1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=c;e=-1;c=Ur(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=xd(c);x[f>>2]=a;if(!a){break a}e=Ur(a,c,b,x[d+12>>2])}hb=d+16|0;return e|0}function gt(a,b){var c=0;c=78220;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=78236;break a;case 2:c=78232;break a;case 1:break b;case 0:break c}}c=78228;break a}c=78224}x[a>>2]=x[c>>2]}function go(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(c){Vb(d+4|0,c);break a}Xb(d+4|0)}x[114409]=0;T(13,a|0,b|0,d+4|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(d+4|0);hb=d+16|0;return}a=N()|0;xb(d+4|0);Q(a|0);p()}function bU(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function CE(a){var b=0,c=0;b=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(b|0)){break a}x[a+8>>2]=x[a+8>>2]-4;x[114409]=0;c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}if(x[a>>2]){GE(x[a+16>>2],x[a>>2],Eg(a))}}function hda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a+480180>>2]=b;JM(c,Jp(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;gt(a+8|0,Jp(a));hb=c+16|0}function fda(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(z[x[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!x[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(z[x[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function eV(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{if(Qb(a,512)){c=d+8|0;qB(c,b);Cd(a,c);break a}a=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;while(1){pB((a<<2)+b|0);a=a+1|0;if((a|0)!=128){continue}break}hb=e+16|0;hb=c+16|0}hb=d+16|0}function Vja(a,b){a=a|0;b=b|0;var c=0;a=vq(a);x[a>>2]=75576;Pj(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;x[a>>2]=75692;c=x[b+4>>2];x[a+24>>2]=x[b>>2];x[a+28>>2]=c;c=x[b+12>>2];x[a+32>>2]=x[b+8>>2];x[a+36>>2]=c;v[a+40|0]=0;return a|0}function Q4(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(v[(b+x[a>>2]|0)+1075073|0]&1){break a}c=E(E(y[(b+x[a>>2]|0)+1075846|0])*E(.0078125))}return E(c)}function P4(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(v[(b+x[a>>2]|0)+1075073|0]&1){break a}c=E(E(y[(b+x[a>>2]|0)+1075847|0])*E(.0078125))}return E(c)}function yS(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=ne(d+4|0,a,1);a=yb(a);e=x[c+4>>2];x[114409]=0;T(782,a|0,e|0,b|0);a=x[114409];x[114409]=0;if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function bq(a,b,c,d){var e=0;a:{e=Pk(a,b);if((e|0)==255){break a}if(Ij(a)){break a}b=Ui(a+314|0,e);e=AO(e);if(v[fc(b,10)|0]&1|d){th(x[a>>2],e- -64|0,zO(c,y[fc(b,2)|0]))}if(d){break a}th(x[a>>2],e+67|0,zO(c,y[fc(b,3)|0]))}}function $z(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+8>>2]=b;x[d+12>>2]=a;a:{if(!Hb(d+12|0,d+8|0)){break a}while(1){if(z[x[d+12>>2]>>1]==z[c>>1]){break a}a=d+12|0;ke(a);if(Hb(a,d+8|0)){continue}break}}hb=d+16|0;return x[d+12>>2]}function vK(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=xh(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1822,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function pM(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=xh(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1535,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function RO(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=bh(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(1222,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Pg(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;v[a+8|0]=0;x[a>>2]=0;x[a+4>>2]=4194432;c=Vb(b+4|0,17381);x[114409]=0;O(358,a+9|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){xb(c);hb=b+16|0;return}a=N()|0;xb(c);Q(a|0);p()}function iP(a){a=a|0;var b=0;b=w[a+796>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+796>>1]=0}b=y[a+817|0];if(b){v[a+817|0]=0;v[a+858|0]=b-1}b=y[a+818|0];if(b){v[a+818|0]=0;v[a+857|0]=b-1}}function aS(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=ne(e+4|0,a,d);a=yb(a);f=x[d+4>>2];x[114409]=0;a=Z(846,a|0,b|0,c|0,f|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Qy(a,b){var c=0,d=0;c=D(b,896)+a|0;a:{if(x[c+1075072>>2]&134218752){break a}if(!Ej(c+1074984|0)){break a}b=y[x[(D(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=x[(D(b,160)+a|0)+906140>>2]}return d}function Ol(a,b){var c=E(0),d=0,e=0;e=w[a+28>>1];d=a+4|0;Lb(d);c=E(1);a:{if((b|0)<(e|0)){break a}if((z[a+28>>1]+Lb(d)|0)-1<<16>>16<(b|0)){break a}c=B[Pb(d,b-w[a+28>>1]|0)>>2];c=c>E(10000000036274937e-31)?c:E(1)}return c}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=a;a=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=a;a=x[c+12>>2];x[b+8>>2]=x[c+8>>2];x[b+12>>2]=a}function Ay(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}sc(a+24604|0,b,40);mM(a,c)}function AF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+8>>2]=b;x[d+12>>2]=a;x[d+4>>2]=c;while(1){a=Hb(d+12|0,d+8|0);if(!(!a|y[x[d+12>>2]]!=y[x[d+4>>2]])){gg(d+12|0);gg(d+4|0);continue}break}hb=d+16|0;return a^1}function $P(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){v[d+14|0]=(z[(b<<1)+25886>>1]-z[(c<<1)+25886>>1]|0)/5;a=y[tc(d+15|0,d+14|0)|0]}hb=d+16|0;return a&255}function us(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!cx(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=Ee(a)}return b}ea(11703,9049,1578,1915);p()}function _5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a=x[a+24>>2];e=d+4|0;Os(e,0,c);x[114409]=0;T(655,a|0,b|0,e|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(d+4|0);hb=d+16|0;return}a=N()|0;xb(d+4|0);Q(a|0);p()}function TR(a){var b=0,c=0;a:{if(dd(a,10602,3)){break a}b=a+4|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0<423|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0>2147483646){break a}c=y[a+3|0]<6}return c}function lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Ne(b);c=EP(d+12|0,c);x[114409]=0;ba(1080,a|0,b|0,0,e-1&65535,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){ge(c);hb=d+32|0;return}a=N()|0;ge(c);Q(a|0);p()}function _G(a){var b=0,c=0,d=0;if(!nh(v[x[a>>2]])){return 0}while(1){d=x[a>>2];b=-1;if(c>>>0<=214748364){b=v[d|0]-48|0;c=D(c,10);b=(c^2147483647)<(b|0)?-1:b+c|0}x[a>>2]=d+1;c=b;if(nh(v[d+1|0])){continue}break}return b}function EO(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function sqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;lb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function cea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=(x[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(mp(b)+-4.8737671609324025),C[d+8>>3]=e;QN(c+8|0,127);a=lu(C[c+8>>3]);hb=c+16|0;return a|0}function bA(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-1024|0;hb=f;e=hb-16|0;hb=e;d=e+8|0;Yz(d,f);g=Fb(d);d=nc(a,ac(e,d));if((g|0)==(d|0)){cc(a,Fb(e+8|0))}hb=e+16|0;if((d|0)==(g|0)){h=_z(f,c)>>>0<=b>>>0}hb=f+1024|0;return h}function Nn(a){a=a|0;zc(a+16|0,x[a>>2]);zc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function ID(a){var b=0,c=0;b=a+2|0;a:{if(!(y[b|0]|y[b+1|0]<<8)){break a}a=a+4|0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}c=(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))>>>0<2147483649}return c}function dx(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!ts(a)){break a}if(!(v[a+1375|0]&1)){continue}break}gc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function zQ(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-24|0;P(1013,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function nO(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=c*C[a+8>>3]+C[a>>3]*b+e*C[a+16>>3]-(f*C[a+32>>3]+d*C[a+24>>3]);C[a+56>>3]=b;return b}function eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;BA(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,4896);hb=c+16|0}return a|0}function SP(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-12|0;P(1068,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function IL(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-24|0;P(1658,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function AI(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-24|0;P(2336,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function xP(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-4|0;P(1110,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function ln(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function FD(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-32|0;P(246,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function uB(a,b,c){var d=0;a=a+3|0;a=(y[a|0]|y[a+1|0]<<8)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function eT(a){var b=0,c=0,d=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114409]=0;c=S(741,b+16|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}Vi(c)}if(b){dh(x[a>>2],b,1)}break a}R(0)|0;zb();p()}}}function dga(a,b){a=a|0;b=b|0;var c=0,d=0;c=bc(b);d=dc(b);b=hb-16|0;hb=b;x[b+12>>2]=d;x[b+8>>2]=c;if(Hb(b+8|0,b+12|0)){while(1){c=b+8|0;uO(a,y[x[c>>2]]);gg(c);if(Hb(c,b+12|0)){continue}break}}hb=b+16|0;return a|0}function c_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Nh(e+8|0,e+12|0);x[114409]=0;a=WF(a,b,c);b=x[114409];x[114409]=0;if((b|0)!=1){Te(d);hb=e+16|0;return a|0}a=N()|0;Te(d);Q(a|0);p()}function bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;nA(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,40);hb=c+16|0}return a|0}function aB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;e=d,f=xU(bc(b),dc(b),d+12|0),x[e+8>>2]=f;e=d,f=dc(b),x[e+4>>2]=f;a:{if(Hb(d+8|0,d+4|0)){hf(a,yb(x[d+8>>2]));break a}ii(a)}hb=d+16|0}function VK(a){var b=0,c=0,d=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114409]=0;c=S(745,b+16|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break b}Vi(c)}if(b){dh(x[a>>2],b,1)}break a}R(0)|0;zb();p()}}}function PU(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114409]=0;b=b-2|0;P(520,c|0,b|0);c=x[114409];x[114409]=0;if((c|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=d}function BM(a){var b=0,c=0,d=0;c=hb-544|0;hb=c;if(!(!(y[a+480210|0]&128)|!x[a+24668>>2])){d=a+1304360|0;b=a+1074984|0;a=lO(c,cf(a));while(1){sc(b+112|0,a,538);b=b+896|0;if((d|0)!=(b|0)){continue}break}}hb=c+544|0}function BG(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=mb[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!re(b,-1)){break a}x[a>>2]=0}return a|0}function $B(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;e=hb-16|0;hb=e;c=d+8|0;jc(c,b,37);hb=e+16|0;e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;if((c|0)!=(e|0)){a=hb-16|0;hb=a;Sb(b,0,37);hb=a+16|0}}function sV(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+4>>2]=192;c=x[Mb(d+12|0,d+4|0)>>2];if(!Qb(a,c)){c=zf(a)}e=d+4|0;Su(e,b);qg(a,x[e>>2],c);Su(e,b);Sb(x[e>>2]+c|0,0,192-c|0);cc(a,x[d+12>>2]);hb=d+16|0}function eW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;Zu(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,65);hb=c+16|0}return a|0}function M5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=d+12|0;x[e>>2]=82672;x[e>>2]=82628;x[114409]=0;a=Z(2280,a|0,b|0,c|0,e|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=d+16|0;return a|0}Q(N()|0);p()}function Eq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;eB(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,64);hb=c+16|0}return a|0}function BP(a){var b=0,c=0,d=0;b=a- -64|0;d=y[b|0]|y[b+1|0]<<8;b=a+70|0;a=a+72|0;c=y[a|0]|y[a+1|0]<<8;a=(y[b|0]|y[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a<<2;d=c+d|0;a=b<<2|a>>>30;lb=d>>>0<c>>>0?a+1|0:a;return d}function zX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=0;f=x[a+8>>2];if(f>>>0>c>>>0){x[e+8>>2]=f-c;d=Mb(e+8|0,e+12|0);a=x[a+4>>2]+c|0;d=x[d>>2];ue(a,a+d|0,b)}hb=e+16|0;return d|0}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;a=x[a+1304560>>2];a:{if(a){mb[x[x[a>>2]+8>>2]](a,b,c);break a}if(x[18872]<(b|0)){break a}a=d+12|0;KM(a,5124,6831,132);qD(d+31|0,a,b,9105,c)}hb=d+32|0}function zy(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;lM(a+24648|0);BM(a)}function zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=b;if(Hb(d+8|0,d+12|0)){while(1){b=d+8|0;x[d+4>>2]=x[x[b>>2]>>2];Ry(a,d+4|0);je(b);if(Hb(b,d+12|0)){continue}break}}hb=d+16|0}
function cQ(a){var b=0,c=0,d=0;b=a+32|0;d=y[b|0]|y[b+1|0]<<8;b=a+34|0;a=a+36|0;c=y[a|0]|y[a+1|0]<<8;a=(y[b|0]|y[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a<<1;d=c+d|0;a=b<<1|a>>>31;lb=d>>>0<c>>>0?a+1|0:a;return d}function Vr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;f=hb-16|0;hb=f;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Cb(b);if(d>>>0<c>>>0){wm();p()}b=Rb(b);x[e+4>>2]=d-c;wt(a,b+c|0,x[Mb(e+12|0,e+4|0)>>2]);hb=e+16|0;hb=f+16|0}function Dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;w[a+34>>1]=0;f=a+43|0;d=hb-16|0;hb=d;e=hb-16|0;hb=e;while(1){qf(c+f|0);c=c+1|0;if((c|0)!=22){continue}break}hb=e+16|0;hb=d+16|0;x[a+20>>2]=0;zd(a,b);return a|0}function sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;g=x[x[b>>2]+20>>2];f=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=f;f=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=f;mb[g|0](a,b,e,d);hb=e+16|0}function Xh(a){var b=0,c=0,d=0,e=0;b=te(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=te(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?0-c|0:c}function $v(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function $5(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a=x[a+24>>2];d=c+4|0;Os(d,0,b);x[114409]=0;T(655,a|0,1,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(c+4|0);hb=c+16|0;return}a=N()|0;xb(c+4|0);Q(a|0);p()}function b5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Or(a)>>>0<b>>>0){Xc();p()}KF(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+D(d,12)|0,x[e>>2]=f;Wm(a,0);hb=c+16|0}function Uma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;tA(d,b);e=Fb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Fb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;ES(b);hb=c+16|0}return a|0}function lpa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Yb(128/(D(x[Yf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[ah(c+7|0,c+6|0)|0];hb=c+16|0;return a|b<<4&240}function cu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(tv(a)>>>0<b>>>0){Xc();p()}DC(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<1)|0,x[e>>2]=f;Do(a,0);hb=c+16|0}function _u(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Dk(a)>>>0<b>>>0){Xc();p()}ay(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<2)|0,x[e>>2]=f;Wh(a,0);hb=c+16|0}function _A(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(pU(a)>>>0<b>>>0){Xc();p()}oU(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+D(d,6)|0,x[e>>2]=f;ZA(a,0);hb=c+16|0}function YY(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=dw(a);if(nE(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[114409]=0;S(b|0,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}}ic(a)}return}R(0)|0;zb();p()}function VB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Rv(a)>>>0<b>>>0){Xc();p()}VD(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<4)|0,x[e>>2]=f;Xo(a,0);hb=c+16|0}function V8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;b=Ec(tqa(sqa(d,d>>31,b,b>>31),lb,1e3,0),lb);x[a+16>>2]=0;x[a+12>>2]=b+c;QJ(a,e);b=x[a+12>>2];x[f+12>>2]=0;aL(a,b,f+12|0);hb=f+16|0}function NR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Dk(a)>>>0<b>>>0){Xc();p()}US(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<2)|0,x[e>>2]=f;Wh(a,0);hb=c+16|0}function I_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(IE(a)>>>0<b>>>0){Xc();p()}HE(c+8|0,ul(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<2)|0,x[e>>2]=f;Wh(a,0);hb=c+16|0}function IX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Dv(a)>>>0<b>>>0){Xc();p()}bD(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<3)|0,x[e>>2]=f;Cv(a,0);hb=c+16|0}function Hj(a,b){a=a|0;b=b|0;var c=0;if(z[a+24>>1]!=(b&65535)){w[a+22>>1]=z[a+22>>1]-1&127;if(z[a+20>>1]<128){w[a+20>>1]=z[a+20>>1]+1}c=(z[a+22>>1]<<2)+a|0;w[c+28>>1]=0;w[c+26>>1]=b-z[a+24>>1];w[a+24>>1]=b}}function Gca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=Xh(a),x[g>>2]=h;Xh(a);if(f>>>0>=60){cc(a,4)}g=e,h=Xh(a),x[g>>2]=h;cc(a,4);b=Xh(a);x[d>>2]=b;if((b|0)>0){g=c,h=Xh(a),x[g>>2]=h}}function DF(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){zh(g+13|0,g+14|0)}h=c,i=(Ma(b|0,qU(b,x[c>>2])|0,g+12|0,d|0,x[a>>2])|0)+b|0,x[h>>2]=i;hb=g+16|0}function oz(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=x[c>>2];if(d){Ln(d);FO(x[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function UM(a,b){a=PM(a);PM(a+368680|0);if(b){VL(a,1);return}UL();ue(218304,283840,a+131112|0);ue(283840,349376,a+196648|0);ue(349376,414912,a+262184|0);ue(87216,218304,a+24|0);sc(a+327720|0,414912,40960)}function Qp(a,b){a=sc(a,b,88);x[a+88>>2]=x[b+88>>2];sc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];sc(a+672|0,b+672|0,52);Vy(a+724|0,b+724|0);Vy(a+736|0,b+736|0);Vy(a+748|0,b+748|0);sc(a+760|0,b+760|0,135)}function Mw(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(b>>>0<=2147483631){a:{if(ml(b)){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;Ie(a,b);break a}d=mj(b)+1|0;e=oF(d);Jf(a,d);_e(a,e);ee(a,b)}hb=c+16|0;return a}If();p()}function FK(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-2048|0;P(1772,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function tv(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=2147483647;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function mf(a,b,c,d,e){var f=0;f=hb-256|0;hb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Sb(f,b&255,c?d:256);if(!c){while(1){af(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}af(a,f,d)}hb=f+256|0}function lh(a){a=a|0;var b=0;x[a>>2]=60512;x[114409]=0;P(2530,a|0,0);b=x[114409];x[114409]=0;if((b|0)!=1){Ob(a+28|0);_b(x[a+32>>2]);_b(x[a+36>>2]);_b(x[a+48>>2]);_b(x[a+60>>2]);return a|0}R(0)|0;zb();p()}function UC(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function Ec(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;x[c+24>>2]=a;x[c+28>>2]=b;x[c+16>>2]=-2147483648;x[c+20>>2]=-1;x[c+8>>2]=2147483647;x[c+12>>2]=0;a=nR(c+16|0,Zz(c+24|0,c+8|0));hb=c+32|0;return x[a>>2]}function Dk(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=1073741823;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function sM(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-52|0;P(1532,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function pU(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=715827882;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function lD(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=134217727;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function bN(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-24|0;P(1465,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function XM(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114409]=0;S(1466,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}}if(b){pq(x[a>>2],b,1)}break a}R(0)|0;zb();p()}}}function VM(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114409]=0;S(1470,b+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}}if(b){eu(x[a>>2],b,1)}break a}R(0)|0;zb();p()}}}function Ud(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=xd(b)}return c}function Rv(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=268435455;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function Or(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=357913941;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function NU(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=178956970;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function MP(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-12|0;P(1066,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function KO(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-32|0;P(1249,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function Dv(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=536870911;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function $N(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-12|0;P(1301,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function mU(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-48|0;P(567,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function kL(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=82595524;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function fka(a,b,c){a=a|0;b=b|0;c=c|0;a=lQ(b,c);lQ(a+12|0,c+12|0);Jz(a+24|0,c+24|0);w[a+52>>1]=z[c+52>>1];b=x[c+48>>2];x[a+44>>2]=x[c+44>>2];x[a+48>>2]=b;b=x[c+40>>2];x[a+36>>2]=x[c+36>>2];x[a+40>>2]=b}function bd(a,b){var c=0,d=0,e=0;a:{d=BE(b);c=Vm(a);if(d>>>0<=c>>>0){c=Rb(a);e=d<<2;vk(c,b,e);b=hb-16|0;hb=b;ch(a,d);x[b+12>>2]=0;wg(c+e|0,b+12|0);hb=b+16|0;break a}e=a;a=Cb(a);uE(e,c,d-c|0,a,0,a,d,b)}}function Yn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Pu(a)>>>0<b>>>0){Xc();p()}Mh(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+d|0,x[e>>2]=f;QA(a,0);hb=c+16|0}function XD(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-16|0;P(190,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function VR(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114409]=0;S(847,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}}if(b){pq(x[a>>2],b,1)}break a}R(0)|0;zb();p()}}}function Q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;yI(b,c,d,B[a+28>>2]);xI(a,b,c,d);b=x[a+24>>2];x[e+8>>2]=x[a+20>>2];x[e+12>>2]=b;b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;hb=e+16|0}function Om(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b=hb-16|0;hb=b;d=b+4|0;Jx(d,c);x[114409]=0;T(13,a|0,0,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(b+4|0);hb=b+16|0;break a}a=N()|0;xb(b+4|0);Q(a|0);p()}}function HS(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-33|0;P(781,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function DB(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-16|0;P(397,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function AK(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(1774,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function sC(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(352,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function dS(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(842,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function cC(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-2|0;P(362,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function bT(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(746,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function _Q(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-8|0;P(948,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function YR(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-2|0;P(848,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function WS(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(748,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function SD(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-1|0;P(188,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function NL(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(109,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function JQ(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-4|0;P(976,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function IB(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-2|0;P(393,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function HC(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-1|0;P(339,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function $S(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-6|0;P(747,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function _T(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114409]=0;c=c-1|0;P(37,d|0,c|0);d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function Uu(a){var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;b=c+8|0;fr(b,d+15|0);e=Fb(b);b=nd(a,ac(c,b));if((e|0)==(b|0)){ad(a,Fb(c+8|0))}hb=c+16|0;hb=d+16|0;return((b|0)==(e|0)?y[d+15|0]:0)&255}function Uq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;if(iv(a)>>>0<b>>>0){Xc();p()}ay(c+8|0,yb(a),(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;b=x[c+12>>2];d=yb(a),e=b,x[d>>2]=e;hb=c+16|0}function IE(a){var b=0,c=0;b=hb-16|0;hb=b;ul(a);x[b+12>>2]=1073741823;x[114409]=0;x[b+8>>2]=2147483647;a=Mb(b+12|0,b+8|0);c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=iv(a);if(d>>>0>=b>>>0){a=$t(a);if(a>>>0<d>>>1>>>0){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[$c(c+12|0,c+8|0)>>2]}hb=c+16|0;return d|0}Xc();p()}function dQ(a){var b=0,c=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16){break a}a=a+42|0;b=y[a+1|0]<<8;if((y[a|0]|b)!=1&(b|y[a|0])!=2){break a}c=1}return c}function cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=hb-16|0;hb=c;Ef(a,c+14|0);HM(b,z[c+14>>1],16777216);if(z[c+14>>1]){while(1){Xi(a,Pb(b,d));d=d+1|0;if(d>>>0<z[c+14>>1]){continue}break}}Gy(b);hb=c+16|0}function Cd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;d=x[a>>2];b=(f=d,g=x[a+8>>2],h=ac(c+8|0,b),e=x[x[d>>2]+32>>2],mb[e](f|0,g|0,h|0)|0);x[a+8>>2]=b+x[a+8>>2];hb=c+16|0;return b|0}function CM(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=x[a>>2];a:{if(!b){break a}if(!(mb[x[x[b>>2]+112>>2]](b)|0)){break a}mb[x[x[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=1;a=a+32|0;if(A[x[b>>2]>>2]<xc(a)>>>0){a=Sm(d+4|0,Cc(a,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);b=Wv(c,a);Gb(a);e=b^1}hb=d+16|0;return e|0}function Sg(a,b){var c=0;a:{if(A[a+4>>2]<=b>>>0){a=ec(8);x[114409]=0;b=S(328,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break a}b=N()|0;ic(a);Q(b|0);p()}return y[x[a>>2]+b|0]}da(b|0,76196,238);p()}function tja(a,b){a=a|0;b=b|0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[114409]=0;x[a+12>>2]=0;U(1072,b+8|0,a+12|0,a+11|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}}function oO(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function QP(a){var b=0;b=x[a>>2];if(x[b>>2]){ee(b,x[b>>2]);a=x[a>>2];b=x[a>>2];a=(x[yb(a)>>2]-x[a>>2]|0)/9|0;x[114409]=0;T(27,b|0,D(a,9)|0,1);a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}}}function Aca(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!Yj(a,b+8|0)){break a}c=0;if(!ML(b+8|0)){break a}c=b+4|0;a=_P(a,c);if(!a){XS(c)}c=-1;if(!a){break a}c=LL(b+4|0)}hb=b+16|0;return c|0}function zi(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function xN(a,b,c){var d=0,e=0;d=x[(D(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=x[(D(b,896)+a|0)+1075088>>2];if(!a){break b}if(y[a+35|0]&4){break a}}e=y[d+34|0]}return e}function Vg(a){var b=0;x[114409]=0;a=S(1482,a|0)|0;b=x[114409];x[114409]=0;a:{if((b|0)==1){Y(R(0)|0)|0;x[114409]=0;X(20);b=x[114409];x[114409]=0;a=0;if((b|0)==1){break a}}return a}R(0)|0;zb();p()}function UN(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{if(y[mc(a)+4|0]){x[114409]=0;a=S(1335,b+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break b}Zl(a)}if(b){dz(b)}break a}R(0)|0;zb();p()}}}function Pu(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=-1;x[114409]=0;x[b+8>>2]=2147483647;a=O(36,b+12|0,b+8|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}R(0)|0;zb();p()}function JD(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1129474426&(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))==1634291279){a=a+8|0;a=(y[a|0]|y[a+1|0]<<8)==14}else{a=0}return a}function Gg(a){var b=0,c=0,d=0,e=0,f=0;b=hb-32|0;hb=b;C[b+16>>3]=1;C[b+24>>3]=-1;C[b+8>>3]=a;e=b+16|0;f=hb-16|0;hb=f;c=b+8|0;d=b+24|0;if(!Tt(c,d)){d=Tt(e,c)?e:c}hb=f+16|0;hb=b+32|0;return C[d>>3]}function ioa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+4|0;At(d,b);x[114409]=0;T(655,a|0,4,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(c+4|0);hb=c+16|0;return}a=N()|0;xb(c+4|0);Q(a|0);p()}function hE(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;b=x[a+8>>2];d=x[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;b=b-c|0;x[a+8>>2]=b;x[a+12>>2]=d}function _d(a,b){var c=0;if(QD(b)){b=b>>>0<=4?4:b;a=a>>>0<=1?1:a;a:{while(1){c=zE(b,a);if(c){break a}c=x[115723];if(c){mb[c|0]();continue}break}da(bk(ec(4))|0,74984,26);p()}return c}return Re(a)}function DT(a){var b=0,c=0;b=a+36|0;b=sqa(y[b|0]|y[b+1|0]<<8,0,384,0);a=a+34|0;a=y[a|0]|y[a+1|0]<<8;c=a<<2;b=b+c|0;a=lb+(a>>>30|0)|0;a=b>>>0<c>>>0?a+1|0:a;b=b+256|0;lb=b>>>0<256?a+1|0:a;return b}function U4(a){a=a|0;var b=0;a=a+24|0;b=QI(x[a>>2]);if(Jj(Wb(x[a>>2]+484360|0))>>>0<=b>>>0){return z[x[a>>2]+1074436>>1]}b=z[vc(Wb(x[a>>2]+484360|0),b)>>1];return(so(x[a>>2]+484344|0,b)?b:-1)|0}function OO(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;v[a+16|0]=0;c=vz(b,x[a+12>>2]);x[114409]=0;T(1229,a|0,1,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){Qk(c);hb=b+32|0;return}a=N()|0;Qk(c);Q(a|0);p()}function wC(a,b,c){var d=0,e=0,f=0;f=hb-16|0;hb=f;e=x[a+4>>2];d=e+b|0;x[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){x[x[a>>2]+((d>>>0>=33?d-1>>>5|0:0)<<2)>>2]=0}d=f+8|0;zo(d,a,e);Tq(d,b,c);hb=f+16|0}function Sx(a){var b=0,c=0,d=0,e=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=Pp(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}C[c+4280>>3]=E(E(a|0)*E(-4.656612873077393e-10))}function Bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=c,e=bc(a),x[d+8>>2]=e;b=mu(c+12|0,c+8|0);b=x[a>>2]+(b<<2)|0;rv(a,ue(b+4|0,x[a+4>>2],b));a=Rg(b);hb=c+16|0;return a|0}function b_(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+12>>2]=a;a=Nh(b+8|0,b+12|0);x[114409]=0;c=VF();d=x[114409];x[114409]=0;if((d|0)!=1){Te(a);hb=b+16|0;return c|0}b=N()|0;Te(a);Q(b|0);p()}function QH(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;if((b|0)>0){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=B[c>>2];g=B[e>>2];B[e>>2]=f+g;B[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function zA(a,b,c){a=a|0;b=b|0;c=c|0;a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b|0]=a;v[b+1|0]=a>>>8;v[b+2|0]=a>>>16;v[b+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[b+4|0]=a;v[b+5|0]=a>>>8}function sh(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1332,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function rK(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1860,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function qK(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1861,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function my(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1654,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function ig(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb+-64|0;hb=c;d=ey(c+12|0,a);x[114409]=0;T(1690,a|0,b|0,d|0);a=x[114409];x[114409]=0;if((a|0)!=1){Ik(d);hb=c- -64|0;return}a=N()|0;Ik(d);Q(a|0);p()}function Ypa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>0){while(1){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Xi(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=0;a=sl(a,c+12|0,4);x[c+8>>2]=x[c+12>>2];d=b;b=c+8|0;x[d>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);hb=c+16|0;return!lb&(a|0)==4}function XE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;x[f+12>>2]=e;e=Nh(f+8|0,f+12|0);x[114409]=0;a=jp(a,b,c,d);b=x[114409];x[114409]=0;if((b|0)!=1){Te(e);hb=f+16|0;return a}a=N()|0;Te(e);Q(a|0);p()}function Pi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Pk(a,b);if((d|0)==255){break a}Ok(a,b);bq(a,b,0,0);if(!c){break a}e=fd(a+22|0,d),f=65535,w[e>>1]=f;a=fc(a+58|0,b);v[a|0]=y[a|0]|128}}function Lz(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1005,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Fx(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(2254,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Ck(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(1708,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function wy(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=ev(d,c);a=a+1074312|0;if(!$b(a,31)){e=$b(a,93)^1}a:{if(!(v[bM(b,c)|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=kd(d)^1}return a}function vA(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(771,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function tB(a,b,c){var d=0,e=0;a:{d=hb-16|0;hb=d;e=d+4|0;LI(e,b,c);x[114409]=0;T(13,a|0,0,e|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(d+4|0);hb=d+16|0;break a}a=N()|0;xb(d+4|0);Q(a|0);p()}}function pm(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(380,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function fx(a,b,c){var d=0,e=0;a:{d=hb-16|0;hb=d;e=d+4|0;Is(e,b,c);x[114409]=0;T(13,a|0,0,e|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(d+4|0);hb=d+16|0;break a}a=N()|0;xb(d+4|0);Q(a|0);p()}}function es(a,b,c){var d=0,e=0;a:{d=hb-16|0;hb=d;e=d+4|0;Bx(e,b,c);x[114409]=0;T(13,a|0,0,e|0);a=x[114409];x[114409]=0;if((a|0)!=1){xb(d+4|0);hb=d+16|0;break a}a=N()|0;xb(d+4|0);Q(a|0);p()}}function bu(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(957,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function br(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(330,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function X1(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=b+4|0;zj(c,0,a);x[114409]=0;a=S(171,c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){xb(b+4|0);hb=b+16|0;return a|0}a=N()|0;xb(b+4|0);Q(a|0);p()}function Qz(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[b+12>>2]=0;x[114409]=0;U(961,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Oq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(383,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Gw(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(173,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function FA(a,b){var c=0,d=0;a:{if(b){FA(a,x[b>>2]);FA(a,x[b+4>>2]);a=mc(a);x[114409]=0;c=S(745,b+16|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}Vi(c);dh(a,b,1)}return}R(0)|0;zb();p()}function DE(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(181,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function DA(a,b){var c=0,d=0;a:{if(b){DA(a,x[b>>2]);DA(a,x[b+4>>2]);a=mc(a);x[114409]=0;c=S(741,b+16|0)|0;d=x[114409];x[114409]=0;if((d|0)==1){break a}Vi(c);dh(a,b,1)}return}R(0)|0;zb();p()}function Cq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(602,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Aq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(675,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function cH(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function cG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function Uda(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;c=Vb(b+4|0,6246);x[114409]=0;a=O(94,a|0,c|0)|0;d=x[114409];x[114409]=0;if((d|0)!=1){xb(c);hb=b+16|0;return a|0}a=N()|0;xb(c);Q(a|0);p()}function Pj(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(34,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Jk(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114409]=0;x[b+12>>2]=0;U(96,a+8|0,b+12|0,b+11|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Bw(a,b,c,d,e,f,g,h,i){var j=0;j=hb-16|0;hb=j;eg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;hb=j+16|0}function uP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function lw(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Nh(e+8|0,e+12|0);x[114409]=0;a=ms(a,b,c);b=x[114409];x[114409]=0;if((b|0)!=1){Te(d);hb=e+16|0;return a}a=N()|0;Te(d);Q(a|0);p()}function l9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=4){Vh(d+12|0);c=B[d+12>>2];if((b|0)==4){c=he(c);B[d+12>>2]=c}B[((b<<2)+a|0)+4220>>2]=c;UJ(a)}hb=d+16|0}function eA(a){var b=0,c=0;c=(y[a+24|0]>15)+(y[a+25|0]>64)|0;b=a+26|0;b=y[b|0]|y[b+1|0]<<8;a=a+22|0;a=y[a|0]|y[a+1|0]<<8;return c+(((b<<8|b>>>8)&65535)>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}function _h(a){var b=0;a=he(a);b=2147483647;a:{if(!(a<E(2147483648))){break a}b=-2147483648;if(!(a>E(-2147483648))){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function Z8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=1){Vh(d+12|0);c=B[d+12>>2];if((b|0)==1){c=he(c);B[d+12>>2]=c}B[((b<<2)+a|0)+4208>>2]=c;RJ(a)}hb=d+16|0}function Js(a){var b=0,c=0;c=a+24|0;b=x[c>>2];x[114409]=0;S(1490,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){pd(a+68|0);Qf(a+36|0);kg(a+32|0);Ai(c);od(a+4|0);return od(a)}R(0)|0;zb();p()}function xj(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4304);if(d){x[114409]=0;Z(1821,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Zw(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;sc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4268);if(d){x[114409]=0;Z(1758,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function Od(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;x[a+8>>2]=x[c+8>>2];v[a+12|0]=0;hb=c+16|0}function D8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(86224);if(d){x[114409]=0;Z(2089,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function CJ(a,b){var c=0,d=0,e=0;if(a>E(.9999989867210388)){d=0}else{a=E(a*a);e=+a;c=De(31415.926535897932/+b);d=Mn((32768-(M((1-c)*+E(a+a)+(c*c+-1)*+E(a*a))+c*e)*32768)/(1-e))}return d}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4276);if(d){x[114409]=0;Z(1956,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4268);if(d){x[114409]=0;Z(1979,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4296);if(d){x[114409]=0;Z(2003,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function i8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=tJ(f,b,c,d,0,0,0,0,e);hb=f+16|0;return a|0}function h0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=sj(h,b,c,d,e,f,g+8|0,a);hb=a;return b|0}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4228);if(d){x[114409]=0;Z(2016,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(5048);if(d){x[114409]=0;Z(2039,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4296);if(d){x[114409]=0;Z(1899,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4276);if(d){x[114409]=0;Z(2066,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Vg(4280);if(d){x[114409]=0;Z(1932,d|0,a|0,b|0,c|0)|0;a=x[114409];x[114409]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(y[b+30|0]!=4){break a}d=b+31|0;if(y[d|0]&4|y[d|0]&2){break a}cd(a,8,1,0,11);return}d=a;a=b+31|0;cd(d,y[a|0]&4?16:8,y[a|0]&2|1,0,c^1)}function xp(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=oe(b),x[d+12>>2]=e;x[114409]=0;a=U(2126,a|0,c+12|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+16|0;return a}R(0)|0;zb();p()}function wp(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=oe(b),x[d+12>>2]=e;x[114409]=0;a=U(2288,a|0,c+12|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+16|0;return a}R(0)|0;zb();p()}function Lv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];b=(f=d,g=Db(b),h=x[a+8>>2],i=c,e=x[x[d>>2]+28>>2],mb[e](f|0,g|0,h|0,i|0)|0);x[a+8>>2]=b+x[a+8>>2];return b|0}function Faa(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=hb-16|0;hb=d;e=d,f=E(E(mb[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;Vh(d+12|0);mb[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);hb=d+16|0}function FE(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}ul(a);x[114409]=0;c=c-4|0;d=x[114409];x[114409]=0;if((d|0)!=1){continue}break}R(0)|0;zb();p()}x[a+4>>2]=b}function yq(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=oe(b),x[d+12>>2]=e;x[114409]=0;a=U(737,a|0,c+12|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+16|0;return a}R(0)|0;zb();p()}function mB(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(lr(a,b+12|0)){a=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);c=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}hb=b+16|0;return c|0}function Ida(a){a=a|0;var b=0,c=0,d=0,e=0;x[a>>2]=0;e=a+9|0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){qf(b+e|0);b=b+1|0;if((b|0)!=20){continue}break}hb=d+16|0;hb=c+16|0;Pg(a);return a|0}function Gz(a,b,c){a=a|0;b=b|0;c=c|0;a=Dd(a,b);b=x[a+4>>2];a:{if((c|0)>=0){b=b+c|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function yv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;dr(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){QC(b)}return a|0}function yA(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=pU(a);if(d>>>0<=b>>>0){a=$i(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function xr(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=Rv(a);if(d>>>0<=b>>>0){a=li(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function xJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=wJ(f,b,c,d,e,0,0,0,0);hb=f+16|0;return+c}function vB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;rB(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){gV(b)}return a|0}function oL(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=kL(a);if(d>>>0<=b>>>0){a=Bj(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=mb[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function hj(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=tv(a);if(d>>>0<=b>>>0){a=_f(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function gda(a){a=a|0;var b=0;b=1;a=x[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function fo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;SS(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){TS(b)}return a|0}function bl(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=NU(a);if(d>>>0<=b>>>0){a=ff(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function bi(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=Pu(a);if(d>>>0<=b>>>0){a=tf(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function an(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=Or(a);if(d>>>0<=b>>>0){a=xg(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function _t(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;KQ(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){LQ(b)}return a|0}function ZB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;OB(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){PB(b)}return a|0}function Xu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;mV(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){nV(b)}return a|0}function Vo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;cD(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){dD(b)}return a|0}function Tu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;sB(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){pV(b)}return a|0}function Rw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+D(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((D(b,306)+5<<16>>16)/10<<16>>16)|0)-1|0}function Rd(a,b){var c=0;a:{c=Bf(b);if((c|0)==(Cb(a)|0)){x[114409]=0;a=aa(320,a|0,0,-1,b|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}R(0)|0;zb();p()}function Q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Hd(a+12|0,0,0);d=a+20|0;while(1){Zc((c<<2)+d|0);c=c+1|0;if((c|0)!=4){continue}break}e=d,f=TM(b),x[e+16>>2]=f;x[a+40>>2]=1;return a|0}function PQ(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+93|0];b=a+94|0;b=c+(y[b|0]|y[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;lb=0;return b}function Hm(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=lD(a);if(d>>>0<=b>>>0){a=Gh(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function HD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;tD(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){uD(b)}return a|0}function GD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;rD(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){sD(b)}return a|0}function Fe(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=Dk(a);if(d>>>0<=b>>>0){a=sd(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Xc();p()}function Eu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;WA(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){aU(b)}return a|0}function ez(a,b){var c=0;a:{if(b){ez(a,x[b>>2]);ez(a,x[b+4>>2]);mc(a);x[114409]=0;a=S(1335,b+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}Zl(a);dz(b)}return}R(0)|0;zb();p()}function Vna(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;pT(b,c,32);oT(a,c);hb=c+32|0}function LL(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179012417){b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=538987841){break a}}b=1}return b}function ih(a,b){var c=0;c=x[a>>2];a=Ed(b);b=c+8|0;if(Lb(b)>>>0>a>>>0){b=x[Pb(b,a)>>2]!=0}else{b=0}if(!b){a=un(ec(4));x[a>>2]=75420;da(a|0,75468,2465);p()}return x[Pb(c+8|0,a)>>2]}function aU(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;hb=b+16|0}function P1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;a=oE(a,d,b);x[a>>2]=60492;hb=d+16|0;return a|0}function rJ(a){a=a|0;var b=0,c=0;a:{if(!a){a=ec(8);x[114409]=0;b=S(2139,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break a}b=N()|0;ic(a);Q(b|0);p()}return}da(b|0,82300,2140);p()}function nV(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;hb=b+16|0}function it(a,b){var c=0;a:{if(b){it(a,x[b>>2]);it(a,x[b+4>>2]);a=mc(a);x[114409]=0;S(1466,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}pq(a,b,1)}return}R(0)|0;zb();p()}function Xz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-16|0;hb=c;d=a,e=(g=a,h=x[a+12>>2],i=ac(c+8|0,b),f=x[x[a>>2]+32>>2],mb[f](g|0,h|0,i|0)|0)+x[a+12>>2]|0,x[d+12>>2]=e;hb=c+16|0}function Ny(a,b){var c=0;a:{if(b){Ny(a,x[b>>2]);Ny(a,x[b+4>>2]);a=mc(a);x[114409]=0;S(1470,b+16|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}eu(a,b,1)}return}R(0)|0;zb();p()}function Lx(a){a=a|0;var b=0,c=0;a:{if(!a){a=ec(8);x[114409]=0;b=S(2151,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){break a}b=N()|0;ic(a);Q(b|0);p()}return}da(b|0,82312,2140);p()}function xba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(Lb(a+4|0)+e|0)-1|0,w[f+14>>1]=g;a=cL(a,b,c,d+12|0);hb=d+16|0;return a|0}function vca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=c,e=xU(bc(a),dc(a),c+12|0),x[d+8>>2]=e;d=c,e=dc(a),x[d+4>>2]=e;a=Hb(c+8|0,c+4|0);hb=c+16|0;return a|0}function lA(a,b){var c=0;a:{if(b){lA(a,x[b>>2]);lA(a,x[b+4>>2]);a=mc(a);x[114409]=0;S(847,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)==1){break a}pq(a,b,1)}return}R(0)|0;zb();p()}function jn(a){var b=0,c=0;b=x[20905];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>nb()<<16>>>0){if(!(Sa(a|0)|0)){break a}}x[20905]=a;return b}x[114232]=48;return-1}function jP(a,b){var c=0;c=y[a+822|0];a:{if(c){break a}c=_k(y[a+819|0]-x[a+772>>2]|0);if(!b|!c|(!x[a+656>>2]|c>>>0>=129)){break a}c=y[fc(x[a+656>>2]+108|0,c-1|0)|0]}return c&255}function A_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+65216>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;Pz(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+8|0,d+12|0)>>2]}hb=d+16|0;return c|0}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;mb[x[x[a>>2]+12>>2]](e,a,b);if(re(x[e+4>>2],x[c+4>>2])){a=x[e>>2]==x[c>>2]}else{a=0}hb=d+16|0;return a|0}function Vv(a,b){var c=0,d=0;c=hb-16|0;hb=c;w[b>>1]=0;v[c+15|0]=0;gh(a,c+15|0);d=y[c+15|0];w[b>>1]=d>>>1;if(d&1){v[c+15|0]=0;gh(a,c+15|0);w[b>>1]=z[b>>1]|y[c+15|0]<<7}hb=c+16|0}function QQ(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16){break a}b=a+54|0;if(!y[b|0]|y[b|0]>32){break a}c=y[a+4|0]>95}return c}function PT(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(dd(a+44|0,13676,3)){break a}a=a+47|0;b=(y[a|0]|y[a+1|0]<<8)>>>0>97}return b}function Ef(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;w[c+14>>1]=0;a=sl(a,c+14|0,2);w[c+12>>1]=z[c+14>>1];d=b;b=c+12|0;w[d>>1]=y[b|0]|y[b+1|0]<<8;hb=c+16|0;return!lb&(a|0)==2}function Eb(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(we(a)){fg(a,x[a>>2],Di(a))}x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;Ie(b,0);v[c+15|0]=0;$d(b,c+15|0);hb=c+16|0}function oi(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(we(a)){ap(x[a>>2],Di(a))}x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;Ie(b,0);x[c+12>>2]=0;wg(b,c+12|0);hb=c+16|0}function mL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!pg(a,b)){break a}c=by(a,x[Ye(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=Ye(a,b);wL(Ye(a,c),b);d=c}return d|0}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;yI(b,c,d,B[a+24>>2]);sI(a,b,c,d);x[e+8>>2]=x[a+20>>2];b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;hb=e+16|0}function Jv(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=d+4|0;x[c>>2]=x[b>>2];e=c,f=x[b>>2]+VC(b)|0,x[e+4>>2]=f;b=hb-16|0;hb=b;yr(a,x[c>>2],x[c>>2]+VC(c)|0);hb=b+16|0;hb=d+16|0}function Mda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=x[d>>2];c=x[a+12>>2];c=z[c>>1]|z[c+2>>1]<<16;w[b+4>>1]=0;w[b>>1]=c;w[b+2>>1]=c>>>16;hb=a+16|0}function F8(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=bz(E(E(E(cf(x[a+16>>2])>>>0)*E(20938023226335645e-21))+E(-.005025125574320555)),E(0),E(1)),B[b+4272>>2]=c;KJ(a);JJ(a)}function wR(a,b){var c=0;c=hb-32|0;hb=c;x[c+24>>2]=a;x[c+28>>2]=b;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=-1;x[c+12>>2]=0;a=nR(c+16|0,Zz(c+24|0,c+8|0));hb=c+32|0;return x[a>>2]}function qka(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=cd(d,y[a|0]&4?16:8,1,0,0);a:{b:{if(y[a|0]&8){break b}c=2;if(y[a|0]&16){break b}if(y[a|0]&127){break a}}vm(b,c)}}function OD(a){var b=0;a:{if(!(A[a>>2]<=18285140|A[a>>2]>=18350592)){b=1;if(x[a>>2]!=18350080){break a}}a=x[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function xq(a){var b=0,c=0;c=x[a+4>>2];b=x[c>>2];x[a+4>>2]=b;if(b){_n(b,a)}x[c+8>>2]=x[a+8>>2];a:{if(Hg(a)){b=x[a+8>>2];break a}b=x[a+8>>2]+4|0}x[b>>2]=c;x[c>>2]=a;_n(a,c)}function wq(a){var b=0,c=0;c=x[a>>2];b=x[c+4>>2];x[a>>2]=b;if(b){_n(b,a)}x[c+8>>2]=x[a+8>>2];a:{if(Hg(a)){b=x[a+8>>2];break a}b=x[a+8>>2]+4|0}x[b>>2]=c;x[c+4>>2]=a;_n(a,c)}function aF(a){a=a|0;var b=0,c=0;x[a>>2]=65144;b=a+8|0;while(1){if(Lb(b)>>>0>c>>>0){if(x[Pb(b,c)>>2]){Jm(x[Pb(b,c)>>2])}c=c+1|0;continue}break}xb(a+152|0);mF(b);return a|0}function y_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+65216>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=mb[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function o2(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;if(Nf(x[x[b>>2]-12>>2]+b|0)){if(x[(x[x[b>>2]-12>>2]+b|0)+72>>2]){gs(x[(x[x[b>>2]-12>>2]+b|0)+72>>2])}v[a|0]=1}return a|0}function c2(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;if(Nf(x[x[b>>2]-12>>2]+b|0)){if(x[(x[x[b>>2]-12>>2]+b|0)+72>>2]){FG(x[(x[x[b>>2]-12>>2]+b|0)+72>>2])}v[a|0]=1}return a|0}function Ni(a){a=a|0;var b=0,c=0;while(1){b=c&65535;if(b>>>0<=126){Pg(((b<<5)+a|0)+480280|0);Qn((D(b,896)+a|0)+1074984|0,7,a,b,1024)}c=c+1|0;if(b>>>0<126){continue}break}}function $M(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;a=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=a;a=x[c+12>>2];x[b+8>>2]=x[c+8>>2];x[b+12>>2]=a}function hB(a,b,c){var d=0;d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a>>2]=d;x[a+4>>2]=b;Dm(a+8|0,c);return a}function _B(a){var b=0,c=0;a:{if(dd(a,9922,3)){break a}b=a+3|0;if(y[b|0]<=7&y[b|0]!=1|y[b|0]>14){break a}a=a+40|0;if(!(y[a|0]<33?y[a|0]:0)&y[b|0]>8){break a}c=1}return c}function Ig(a){var b=0,c=0;b=hb-16|0;hb=b;c=Bb(b+12|0,a+44|0);x[114409]=0;V(733,c|0);c=x[114409];x[114409]=0;a:{if((c|0)!=1){hb=b+16|0;break a}R(0)|0;zb();p()}eD(a+32|0)}function z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+65216>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function zM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;if((b|0)!=(c|0)){while(1){x[d+12>>2]=x[b>>2];Ry(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}hb=d+16|0}function _pa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(ag(a,d+11|0)){x[d+4>>2]=y[d+11|0];c=QU(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function MN(a,b,c){var d=0;d=c&15;if(d){v[b+844|0]=d}c=c&240;if(c){v[b+843|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!$b(a+1074312|0,80))){v[b+844|0]=y[b+844|0]<<2}}function Hl(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function GN(a,b){var c=0,d=0,e=0;c=Rb(a);a=Cb(a);d=Rb(b);e=Cb(b);a=a+c|0;b=-1;a:{while(1){if((a|0)==(c|0)){break a}a=a-1|0;if(Bo(d,e,a)){continue}break}b=a-c|0}return b}function DW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Id(a+8|0,d+12|0,d+11|0);if(b){Uq(a,b);wC(a,b,y[c|0])}hb=d+16|0;return a|0}function uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=hu(x[b>>2]),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[gl(c+12|0,c+8|0,35976)>>2],x[d+36>>2]=e;Bp(a);hb=c+16|0}function rla(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=Kf(b);Kf(b);break a}a=tg(b);tg(b)}if(a){while(1){if(a&1){cc(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function qS(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;eS(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){fS(b)}return a}function cB(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;Gu(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){nU(b)}return a}function cA(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;oR(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){pR(b)}return a}function bQ(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;cD(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){dD(b)}return a}function ZP(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;JT(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){KT(b)}return a}function Yj(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;zv(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){$C(b)}return a}function YA(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;WA(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){aU(b)}return a}function SC(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;dr(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){QC(b)}return a}function SA(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;JT(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){KT(b)}return a}function RQ(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;KQ(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){LQ(b)}return a}function RH(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function JV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(ag(a,d+11|0)){x[d+4>>2]=y[d+11|0];c=lV(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function IV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(ag(a,d+11|0)){x[d+4>>2]=y[d+11|0];c=iV(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(ag(a,d+11|0)){x[d+4>>2]=y[d+11|0];c=hV(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function ER(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;qR(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){rR(b)}return a}function DU(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;Gu(c,b);e=Fb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){nU(b)}return a}function B4(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if(Jj(Wb(x[a>>2]+484360|0))>>>0<=b>>>0){break a}c=z[vc(Wb(x[a>>2]+484360|0),b)>>1]}return c|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a=Aj(a);if(a){a=(e=a,f=mi(c+8|0,b),d=x[x[a>>2]+72>>2],mb[d](e|0,f|0)|0)}else{a=1}hb=c+16|0;return a|0}function Mi(a,b,c){var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;C[a>>3]=C[a>>3]-C[c>>3];C[a+8>>3]=C[a+8>>3]-C[c+8>>3]}function Fy(a,b){var c=0;c=hb-16|0;hb=c;x[114409]=0;x[c+12>>2]=b;a=U(1527,a|0,c+12|0,c+11|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+16|0;return a}R(0)|0;zb();p()}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=x[b+24>>2];g=x[b+8>>2];h=x[b+4>>2];i=x[b>>2];e=x[b+12>>2]}else{e=0}AJ(a,i,h,g,e,f,b,c,d)}function q2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;e=Cb(b);d=a;a=Cb(c);d=Rb(Mw(d,e+a|0));Se(d,Rb(b),e);b=e+d|0;Se(b,Rb(c),a);In(a+b|0,1,0);hb=f+16|0}function aX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function Nt(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(!$b(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+796>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+796>>1]=c|32768}x[a+692>>2]=b}function Lq(a,b){var c=0;c=hb-16|0;hb=c;hb=c+16|0;return(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0<(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))>>>0?b:a}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Pz(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function xX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function rP(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function S2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=ns(Ba(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);hb=e+16|0;lb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function N1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=dp(d,a);$E(a,c);x[114409]=0;P(2530,b|0,1);a=x[114409];x[114409]=0;if((a|0)==1){a=N()|0;Ob(d);Q(a|0);p()}}function HQ(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function $9(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;x[d+12>>2]=0;c=d+12|0;v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;a=mK(a,c);hb=d+16|0;return a|0}function fla(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-80|0;hb=d;c=-1;a:{if(!DU(a,d+14|0)){break a}c=0;if(!YQ(d+14|0)){break a}c=of(a,b,WQ(d+14|0),lb)}hb=d+80|0;return c|0}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=_O(y[a|0]+b|0),v[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function KG(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Qh(b),d=x[x[a>>2]+52>>2],mb[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Qh(b)}function ys(a,b){a=a|0;b=b|0;x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Sb(a+32|0,0,40);nw(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;d=x[a>>2];a=(f=d,g=x[a+8>>2],h=ac(c+8|0,b),e=x[x[d>>2]+32>>2],mb[e](f|0,g|0,h|0)|0);hb=c+16|0;return a}function lea(a){a=E(a);var b=0;a=he(a);b=65535;a:{if(!(a<E(65535))){break a}b=0;if(!(a>E(0))){break a}b=~~a>>>0;if(a<E(4294967296)&a>=E(0)){break a}b=0}return b|0}function cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Qb(a,b);if(c){x[a+8>>2]=x[a+8>>2]+b;return c|0}b=a;a=x[a>>2];d=b,e=mb[x[x[a>>2]+24>>2]](a)|0,x[d+8>>2]=e;return c|0}function Wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Pj(a+8|0);x[114409]=0;T(448,a|0,b|0,c|0);a=x[114409];x[114409]=0;if((a|0)!=1){break a}a=N()|0;yh(d);Q(a|0);p()}}function OM(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;lO(a+112|0,48e3);x[a+668>>2]=0;Cy(a+724|0);Cy(a+736|0);Cy(a+748|0);ei(a+810|0);return a}function rE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;e=Bf(b);d=a;a=Cb(c);d=Rb(Mw(d,e+a|0));Se(d,b,e);b=e+d|0;Se(b,Rb(c),a);In(a+b|0,1,0);hb=f+16|0}function hq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function LY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=x[c>>2];a=mb[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}hb=d+16|0;return a|0}function Ew(a,b){var c=0;c=Es(a+4|0);x[a>>2]=59196;x[c>>2]=59216;x[114409]=0;P(2547,c|0,b|0);a=x[114409];x[114409]=0;if((a|0)!=1){return}a=N()|0;lh(c);Q(a|0);p()}function Dw(a,b){var c=0;c=qG(a+4|0);x[a>>2]=59356;x[c>>2]=59376;x[114409]=0;P(2549,c|0,b|0);a=x[114409];x[114409]=0;if((a|0)!=1){return}a=N()|0;lh(c);Q(a|0);p()}function Cs(a,b,c,d){var e=0;a:{if(d==E(1)){break a}c=D(b,c);if(!c){break a}e=+d;b=0;while(1){C[a>>3]=C[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function p1(a){a=a|0;var b=0,c=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){TF(a);c=c-!b|0;b=b-1|0;if(c|b){continue}break}b=0}x[a+112>>2]=b+1;a=TF(a);return a|0}function Re(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=xd(a);if(b){break a}b=x[115723];if(b){mb[b|0]();continue}break}da(bk(ec(4))|0,74984,26);p()}return b|0}function Dg(a){var b=0,c=0;b=hb-16|0;hb=b;x[114409]=0;a=U(115,a|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){fp(a);hb=b+16|0;return a}R(0)|0;zb();p()}function wo(a,b,c){a=a|0;b=b|0;c=c|0;v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a|0}function ts(a){var b=0;a:{if((Ee(a)|0)!=79){break a}if((Ee(a)|0)!=103){break a}if((Ee(a)|0)!=103){break a}b=(Ee(a)|0)==83}if(!b){gc(a,30);return 0}return FH(a)}function ou(a){var b=0,c=0;c=a;a=x[a>>2];b=x[a+4>>2];a:{if(!b){if(!Hg(a)){while(1){a=x[a+8>>2];if(!Hg(a)){continue}break}}a=x[a+8>>2];break a}a=ZR(b)}x[c>>2]=a}function oK(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;x[c+8>>2]=127;b=Mb(c+12|0,c+8|0);B[x[a+20>>2]+144>>2]=E(E(A[b>>2])*E(-.007874015718698502))+E(1);hb=c+16|0}function ec(a){var b=0,c=0;x[114409]=0;b=LE(a+24|0);a=S(3008,b|0)|0;c=x[114409];x[114409]=0;a:{if((c|0)!=1){if(!a){break a}return wM(Sb(a,0,b))}R(0)|0}zb();p()}function boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Qb(a,12);a:{if(d){e=c+8|0;WA(e,b);Cd(a,e);break a}v[c+7|0]=0;$h(b,12,c+7|0)}hb=c+16|0;return d|0}function Xb(a){var b=0,c=0;b=hb-16|0;hb=b;x[114409]=0;a=U(14,a|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){fp(a);hb=b+16|0;return a}R(0)|0;zb();p()}function Ce(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[mc(a)>>2];x[114409]=0;V(a|0,c|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function zu(a){var b=0,c=0;b=hb-16|0;hb=b;c=b+8|0;Hd(c,a,0);x[114409]=0;T(680,c|0,110,0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function md(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}v[c+15|0]=0;ag(a,c+15|0);v[c+14|0]=y[c+15|0];d=y[c+14|0]}hb=c+16|0;return d}function mC(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}v[c+15|0]=0;ag(a,c+15|0);v[c+14|0]=y[c+15|0];d=v[c+14|0]}hb=c+16|0;return d}function jE(a,b,c,d){var e=0,f=0;f=x[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=_v(x[c>>2],e)}a=x[a>>2];mb[x[x[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function gd(a){var b=0,c=0;b=hb-16|0;hb=b;x[114409]=0;a=U(1,a|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){fp(a);hb=b+16|0;return a}R(0)|0;zb();p()}function P0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=b;x[e+8>>2]=d;b=Nh(e+4|0,e+12|0);a=bG(a,c,x[e+8>>2]);Te(b);hb=e+16|0;return a|0}function In(a,b,c){var d=0;d=hb-16|0;hb=d;x[114409]=0;v[d+15|0]=c;U(84,a|0,b|0,d+15|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){hb=d+16|0;return}R(0)|0;zb();p()}function w_(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[Gr()+(x[b>>2]<<2)>>2]}x[b>>2]=a;b=b+4|0;continue}break}return c|0}function u_(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[Fr()+(x[b>>2]<<2)>>2]}x[b>>2]=a;b=b+4|0;continue}break}return c|0}function g1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function epa(a,b){a=a|0;b=b|0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4}function LP(a,b){a=a|0;b=b|0;a:{a=hb-16|0;hb=a;b=Bb(a+12|0,b);x[114409]=0;V(1067,b|0);b=x[114409];x[114409]=0;if((b|0)!=1){hb=a+16|0;break a}R(0)|0;zb();p()}}function JJ(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function qg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];return(f=d,g=Db(b),h=x[a+8>>2],i=c,e=x[x[d>>2]+28>>2],mb[e](f|0,g|0,h|0,i|0)|0)|0}function j1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function a0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;return rj(g,b,c,d,e,f,Rb(a),Rb(a)+(Cb(a)<<2)|0)|0}function Mr(a){a=a|0;var b=0,c=0;b=ec(8);x[114409]=0;a=O(2185,b|0,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){da(a|0,75324,238);p()}a=N()|0;ic(b);Q(a|0);p()}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;c=x[b>>2];if(!(($g(b)|0)!=8|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){sc(a+4260|0,c,$g(b));Ys(a)}}function uD(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;hb=b+16|0}function ov(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[tc(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;hb=d+16|0}function nv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[tc(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;hb=d+16|0}function kda(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[114409]=0;a=O(1521,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){hb=c+16|0;return a|0}Q(N()|0);p()}function XI(a){var b=0,c=0;b=hb-16|0;hb=b;x[114409]=0;a=U(2292,a|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function WI(a){var b=0,c=0;b=hb-16|0;hb=b;x[114409]=0;a=U(2293,a|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function WG(a,b){var c=0;c=hb-16|0;hb=c;x[114409]=0;a=U(162,a|0,c+15|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){fp(a);hb=c+16|0;return a}R(0)|0;zb();p()}function VI(a){var b=0,c=0;b=hb-16|0;hb=b;x[114409]=0;a=U(2294,a|0,b+15|0,b+14|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Sd(a,b,c){var d=0;d=hb-16|0;hb=d;x[114409]=0;x[d+12>>2]=b;a=gp(a,d+12|0,c);b=x[114409];x[114409]=0;if((b|0)!=1){hb=d+16|0;return a}R(0)|0;zb();p()}function HZ(a){a=a|0;if(y[461152]){return x[115287]}if(!y[462312]){v[462312]=1}bd(462288,71680);bd(462300,71692);v[461152]=1;x[115287]=462288;return 462288}function Az(a,b,c,d,e){var f=0;if(d){while(1){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function yR(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;qR(c,b);e=Fb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;if((c|0)!=(e|0)){rR(b)}}function r$(){var a=0,b=0,c=0;a:{a=Fd(462368);x[a>>2]=66248;x[114409]=0;b=$(2603)|0;c=x[114409];x[114409]=0;if((c|0)!=1){x[a+8>>2]=b;break a}Q(N()|0);p()}}function lx(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(E(B[((c&3)<<2)+40480>>2]*a)*E(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function lp(a,b){var c=0,d=0;a:{if(!a){break a}c=sqa(a,0,b,0);d=lb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=xd(c);if(!(!a|!(y[a-4|0]&3))){Sb(a,0,c)}return a}function bX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Si(a){var b=0;a=he(a);b=-1;a:{if(!(a<E(4294967296))){break a}b=0;if(!(a>E(0))){break a}b=~~a>>>0;if(a<E(4294967296)&a>=E(0)){break a}b=0}return b}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;e=d+8|0;Xq(e,a);a=c+4|0;Vq(a,e);hb=d+16|0;b=Df(a,b);xb(a);hb=c+16|0;return b|0}function Rh(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Ok(a,b){var c=0,d=0;a:{b=Pk(a,b);if((b|0)==255){break a}if(Ij(a)){break a}c=a+4|0;d=fc(c,b);v[d|0]=y[d|0]&223;th(x[a>>2],Ft(b)|176,y[fc(c,b)|0])}}function NN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(x[a+480180>>2]&2){break a}}x[b+56>>2]=0;d=Vp(a,z[b+60>>1],x[b+48>>2],c,0)}return d|0}function Fma(a,b){a=a|0;b=b|0;var c=0;a=tS(a,b);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;hb=c+16|0}return a|0}function A4(a,b){a=a|0;b=b|0;var c=0;a:{if(!Fs(b)){break a}a=a+24|0;if(!pg(x[a>>2]+484344|0,b&65535)){break a}c=x[Zb(x[a>>2]+484344|0,b)+12>>2]}return c|0}function $K(a){a=E(a);var b=0;b=hb-16|0;hb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[GA(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;return E(a)}function yX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Tl(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;c=x[a+1074400>>2];d=x[a+1074416>>2];x[b+12>>2]=1;a=x[$c(a+1074396|0,b+12|0)>>2];hb=b+16|0;return D(a,c+d|0)}function JZ(a){a=a|0;if(y[461144]){return x[115285]}if(!y[462280]){v[462280]=1}Rc(462256,9658);Rc(462268,9637);v[461144]=1;x[115285]=462256;return 462256}function Ip(a,b){var c=0;x[a>>2]=75808;x[a>>2]=75932;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;return a}function Bs(a){var b=0,c=0,d=0;b=wqa(x[a>>2],1)^270549120;c=x[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;x[a>>2]=d;b=a;a=D(wqa(d,16),5)+c|0;x[b+4>>2]=a;return a}function w4(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=Zf(a,b);x[114409]=0;O(121,a+12|0,c|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){break a}b=N()|0;xb(a);Q(b|0);p()}}function on(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=xd(b)}return c}function o_(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b|0];if((a|0)>=0){a=x[Gr()+(v[b|0]<<2)>>2]}v[b|0]=a;b=b+1|0;continue}break}return c|0}function nq(a,b,c){var d=0;d=b;b=y[a|0]|y[a+1|0]<<8;if((d|0)<=((b<<8|b>>>8)&65535)){a=y[a|0]|y[a+1|0]<<8;a=((a<<8|a>>>8)&65535)<=(c|0)}else{a=0}return a}function m_(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b|0];if((a|0)>=0){a=x[Fr()+(v[b|0]<<2)>>2]}v[b|0]=a;b=b+1|0;continue}break}return c|0}function iK(a){var b=0,c=0;b=hb-16|0;hb=b;c=Bb(b+12|0,a);x[114409]=0;V(1885,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Qf(a){var b=0,c=0;b=hb-16|0;hb=b;c=Bb(b+12|0,a);x[114409]=0;V(2255,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function yO(a){var b=0,c=0,d=0;b=a+26|0;c=y[b|0]+27|0;if(y[b|0]){while(1){c=y[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<y[b|0]){continue}break}}return c&65535}function r_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function lg(a){var b=0,c=0;b=hb-16|0;hb=b;c=Bb(b+12|0,a);x[114409]=0;V(744,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function kZ(a,b){a=a|0;b=b|0;a=un(a);x[a>>2]=75036;b=Rb(b);x[114409]=0;O(2993,a+4|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}Q(N()|0);p()}function g0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;return sj(g,b,c,d,e,f,Rb(a),Rb(a)+Cb(a)|0)|0}function eD(a){var b=0,c=0;b=hb-16|0;hb=b;c=Bb(b+12|0,a);x[114409]=0;V(256,c|0);c=x[114409];x[114409]=0;if((c|0)!=1){hb=b+16|0;return a}R(0)|0;zb();p()}function Tc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(mb[x[x[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}x[a+8>>2]=b;c=1}return c|0}function J1(a,b){a=a|0;b=b|0;var c=0,d=0;b=Jw(b);x[a+36>>2]=b;c=a,d=Cn(b),x[c+44>>2]=d;c=a,d=en(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Mr(2049);p()}}function C1(a,b){a=a|0;b=b|0;var c=0,d=0;b=Cw(b);x[a+36>>2]=b;c=a,d=Cn(b),x[c+44>>2]=d;c=a,d=en(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Mr(2049);p()}}function u4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;MI(i,b,c,d,e,f,g);Jd(a,h+20|0);Zl(i);hb=h+32|0}function Th(a,b,c){x[b+12>>2]=x[b+12>>2]+c;x[b+8>>2]=x[b+8>>2]-c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function nd(a,b){var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;a=(e=a,f=x[a+12>>2],g=ac(c+8|0,b),d=x[x[a>>2]+32>>2],mb[d](e|0,f|0,g|0)|0);hb=c+16|0;return a}function mg(a){a=+a;var b=0;a=Td(a);b=-1;a:{if(!(a<4294967295)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function lZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Bf(b);d=Re(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=sc(d+12|0,b,c+1|0),x[e>>2]=f;return a|0}function h4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Sb(x[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function gu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;qm(c+12|0,a);x[c+8>>2]=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);fu(c+8|0,b);hb=c+16|0}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Sb(x[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function EM(a){if(x[a+480224>>2]==2){return+A[a+1074420>>2]*1e-4}return+A[a+24620>>2]*60/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))}function z8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=3){Vh(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];IJ(a)}hb=d+16|0}function tp(a,b,c){var d=0;d=x[b+4>>2];x[b+8>>2]=x[b+8>>2]-c;x[b>>2]=x[b>>2]+(D(c,d)<<2);c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function t9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=4){Vh(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];WJ(a)}hb=d+16|0}function qn(a,b,c){var d=0;d=x[b+4>>2];x[b+8>>2]=x[b+8>>2]-c;x[b>>2]=x[b>>2]+(D(c,d)<<1);c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function nja(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!ZP(a,d)){break a}c=0;if(!HP(d)){break a}c=of(a,b,GP(d),lb)}hb=d+48|0;return c|0}function j_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function iea(a){a=+a;var b=0;a=Td(a);b=65535;a:{if(!(a<65535)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function fN(a){var b=0;a=he(a);b=255;a:{if(!(a<E(255))){break a}b=0;if(!(a>E(0))){break a}b=~~a>>>0;if(a<E(4294967296)&a>=E(0)){break a}b=0}return b}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!RQ(a,d)){break a}c=0;if(!QQ(d)){break a}c=of(a,b,PQ(d),lb)}hb=d+96|0;return c|0}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!RQ(a,d)){break a}c=0;if(!dQ(d)){break a}c=of(a,b,cQ(d),lb)}hb=d+96|0;return c|0}function Xe(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(we(a)){c=x[a>>2];v[b+15|0]=0;$d(c,b+15|0);ee(a,0);break a}v[b+14|0]=0;$d(a,b+14|0);Ie(a,0)}hb=b+16|0}function Vw(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=c*(d&1?a:1);if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function Qja(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!ZP(a,d)){break a}c=0;if(!YP(d)){break a}c=of(a,b,XP(d),lb)}hb=d+48|0;return c|0}function Pda(a,b,c){a=a|0;b=b|0;c=c|0;a=Jk(a);x[114409]=0;T(97,a|0,b|0,c|0);b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}b=N()|0;Me(a);Q(b|0);p()}function G8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=2){Vh(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];KJ(a)}hb=d+16|0}function B9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=5){Vh(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];$J(a)}hb=d+16|0}function $Z(a){a=a|0;var b=0;a=x[a+8>>2];if(!a){return 1}x[114409]=0;a=S(2724,a|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}R(0)|0;zb();p()}function vp(a){var b=0;b=hb-16|0;hb=b;x[114409]=0;U(2299,a|0,b+15|0,b+14|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function gj(a){var b=0,c=0;b=ec(8);x[114409]=0;a=O(29,b|0,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){da(a|0,75256,25);p()}a=N()|0;ic(b);Q(a|0);p()}function Sv(a){var b=0,c=0;b=ec(8);x[114409]=0;a=O(24,b|0,a|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){da(a|0,75204,25);p()}a=N()|0;ic(b);Q(a|0);p()}function NY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(vg(a,x[b+8>>2],f)){Zv(b,c,d,e);return}a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function Ey(a){var b=0;b=hb-16|0;hb=b;x[114409]=0;U(1528,a|0,b+15|0,b+14|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function zP(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1106,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function uqa(a,b,c){var d=0;d=b>>31;a=a^d;qqa(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);lb=kb;a=d^jb;b=a-d|0;lb=(d^lb)-((a>>>0<d>>>0)+d|0)|0;return b}function tR(a){return(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165&(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878}function sz(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1230,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function sy(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1617,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function mz(a,b,c){var d=0,e=0,f=0;d=Pk(a,b);if((d|0)!=255){e=fd(a+22|0,d),f=c,w[e>>1]=f;a=a+58|0;e=fc(a,b),f=255,v[e|0]=f;e=fc(a,c),f=d,v[e|0]=f}}function mF(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(2708,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function iH(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function hn(a,b){var c=0;c=x[x[b>>2]-12>>2];x[114409]=0;b=x[(b+c|0)+24>>2];c=x[114409];x[114409]=0;if((c|0)!=1){x[a>>2]=b;return a}R(0)|0;zb();p()}function hO(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1298,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function gh(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c+15|0]=0;a=sl(a,c+15|0,1);v[c+14|0]=y[c+15|0];v[b|0]=y[c+14|0];hb=c+16|0;return!lb&(a|0)==1}function fba(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(!Bd(a,4)){Uv(a)}c=b,d=bc(a+44|0),x[c+8>>2]=d;a=x[rd(b+12|0,b+8|0)>>2];hb=b+16|0;return a|0}function eba(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(!Bd(a,4)){Uv(a)}c=b,d=dc(a+44|0),x[c+8>>2]=d;a=x[rd(b+12|0,b+8|0)>>2];hb=b+16|0;return a|0}function bm(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1001,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function _p(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1286,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Tf(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1282,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function TP(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1062,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Rs(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1862,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Rl(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1653,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Qs(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1863,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function QM(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1486,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function O1(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;mb[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function LM(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1489,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Kda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-16|0;hb=a;x[a+12>>2]=x[d>>2];f=C[x[a+12>>2]>>3];x[b+8>>2]=0;C[b>>3]=f;hb=a+16|0}function Hy(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1513,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function FM(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1515,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Ex(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(2248,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function EQ(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1004,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function EN(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(1457,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Bca(a,b){a=a|0;b=b|0;var c=0;if(!(y[b+14|0]&48|y[b+17|0]!=173)){cd(a,8,1,0,11);return}c=a;a=b+14|0;cd(c,y[a|0]&16?16:8,y[a|0]&32?3:1,0,2)}function Ap(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=c+8|0;Ih(e,b);d=hb-16|0;hb=d;f=d+8|0;XK(f,ac(d,e));YS(a,f);hb=d+16|0;Ih(c,b);Fb(c);hb=c+16|0}function vf(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(388,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function v4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;MI(i,b,c,d,e,f,g);Jd(a,i);Zl(i);hb=h+32|0}function uA(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(775,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function tU(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(560,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function tS(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;UA(c,b);b=Fb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function qA(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(837,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function pd(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(322,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function lr(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;Ih(c,b);b=Fb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function kB(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(503,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function iS(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(838,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function hm(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(692,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function hd(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(387,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function ge(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(349,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function fR(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(947,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function em(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(912,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function de(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(334,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function ar(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(332,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function ag(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;fr(c,b);b=Fb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function _i(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(707,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function _P(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;Ih(c,b);b=Fb(c);c=nd(a,ac(d,c));if((b|0)==(c|0)){ad(a,Fb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function Zq(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;xm(c,b);b=Fb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function Zn(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(774,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Wn(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(841,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function VA(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(601,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function UU(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(500,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Rj(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(386,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function RR(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(899,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function RC(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(321,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function QR(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(900,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;kz(a,C[c>>3])}function OQ(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(974,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Kv(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(239,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function Av(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;zv(c,b);b=Fb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Fb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function Al(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(172,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function AU(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(550,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function $q(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(333,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function yh(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(35,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function wba(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=1;es(a,b,c+8|0);hb=c+32|0}function sp(a,b){var c=0;a:{if(!RH(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Zja(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1042;x[c+12>>2]=2;tB(a,b,c+8|0);hb=c+32|0}function Vpa(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=2;Is(a,b,c+8|0);hb=c+32|0}function Tia(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=3;OR(a,b,c+8|0);hb=c+32|0}function Sna(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1042;x[c+12>>2]=2;es(a,b,c+8|0);hb=c+32|0}function Me(a){var b=0;b=hb-16|0;hb=b;a=Bb(b+12|0,a);x[114409]=0;V(99,a|0);a=x[114409];x[114409]=0;if((a|0)!=1){hb=b+16|0;return}R(0)|0;zb();p()}function JN(a,b){v[a+860|0]=b;v[a+832|0]=b;v[a+831|0]=b;v[a+829|0]=b;v[a+828|0]=b;w[a+800>>1]=b;v[a+853|0]=b;v[a+846|0]=b>>>4;v[a+847|0]=b<<2&60}function Fw(a){var b=0,c=0;b=hb-16|0;hb=b;c=-1;a:{if(Tw(a)){break a}if((mb[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}hb=b+16|0;return c}function zV(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1025;x[c+12>>2]=2;tB(a,b,c+8|0);hb=c+32|0}function yE(a,b){a=a|0;b=b|0;a=un(a);x[a>>2]=75036;x[114409]=0;O(2993,a+4|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a|0}Q(N()|0);p()}function y2(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1025;x[c+12>>2]=2;es(a,b,c+8|0);hb=c+32|0}function wj(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=Ww(a,e,d);break a}a=Ww(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function upa(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;w[b+14>>1]=1;c=b,d=Nu(a),w[c+12>>1]=d;a=z[jj(b+14|0,b+12|0)>>1];hb=b+16|0;return a-1&65535}function lu(a){a=+a;var b=0;a=Td(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function jl(a,b){var c=0;c=x[x[b>>2]-12>>2];x[114409]=0;b=S(30,b+c|0)|0;c=x[114409];x[114409]=0;if((c|0)!=1){x[a>>2]=b;return a}R(0)|0;zb();p()}function jA(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=2;OR(a,b,c+8|0);hb=c+32|0}function iu(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=2;LI(a,b,c+8|0);hb=c+32|0}function gY(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1058;x[c+12>>2]=2;fx(a,b,c+8|0);hb=c+32|0}function eqa(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=274;x[c+12>>2]=0;tB(a,b,c+8|0);hb=c+32|0}function dO(a,b,c){var d=0,e=0,f=0;d=Hc(a);if(d>>>0>=c>>>0){d=Rb(a);kl(d,b,c);return kv(a,d,c)}e=d;f=c-d|0;d=Cb(a);Lo(a,e,f,d,0,d,c,b);return a}function Zla(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=257;x[c+12>>2]=0;fx(a,b,c+8|0);hb=c+32|0}function Yp(a){var b=0,c=0,d=0;c=y[a+30|0];d=ai(x[a+24>>2]+484360|0);b=x[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Wb(b)}return Ti(b,y[a+30|0])}function Uoa(a,b){a=a|0;b=b|0;var c=0;a=cd(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(y[b|0]&64)){c=0;if(!(y[b|0]&2)){break a}}vm(a,c)}if(y[b|0]&4){XA(a)}}function R2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b>>2];x[a>>2]=d;x[x[d-12>>2]+a>>2]=x[b+4>>2];x[a+4>>2]=0;ys(x[x[a>>2]-12>>2]+a|0,c);return a|0}function Ll(a,b,c){a:{if((a|0)==(b|0)){break a}c=y[c|0];while(1){if((c|0)==y[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function C2(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=1025;x[c+12>>2]=4;es(a,b,c+8|0);hb=c+32|0}function hY(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=44;x[c+16>>2]=-1;x[c+20>>2]=0;x[c+8>>2]=290;x[c+12>>2]=0;fx(a,b,c+8|0);hb=c+32|0}function Via(a,b,c){a=a|0;b=b|0;c=c|0;a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b|0]=a;v[b+1|0]=a>>>8;v[b+2|0]=a>>>16;v[b+3|0]=a>>>24}function P_(){var a=0,b=0;a:{a=Fd(462600);x[114409]=0;S(2712,a+8|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[a>>2]=69184;break a}Q(N()|0);p()}}function N_(){var a=0,b=0;a:{a=Fd(462616);x[114409]=0;S(2712,a+8|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){x[a>>2]=69340;break a}Q(N()|0);p()}}function AH(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function bv(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;a:{if(Qb(a,256)){d=hb-16|0;hb=d;e=c+8|0;jc(e,b,256);hb=d+16|0;Cd(a,e);break a}bE(b)}hb=c+16|0}function YQ(a){var b=0;a:{if(dd(a,9626,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64)){break a}a=a+33|0;if(y[a|0]>32){break a}b=y[a|0]!=0}return b}function Sh(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function y4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;NI(h,b,c,d,e,f);Jd(a,g+20|0);Zl(h);hb=g+32|0}function nw(a){var b=0,c=0;x[114409]=0;c=$(2715)|0;b=x[114409];x[114409]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;Km(a);return}R(0)|0;zb();p()}function j4(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;wt(a,x[c>>2],x[c+4>>2]);hb=c+16|0;return a|0}function WM(a,b){var c=0,d=0,e=0;d=y[a|0];e=y[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=z[a+2>>1]<z[b+2>>1]}return c}function Vq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=x[b+4>>2];d=x[b>>2];v[c+15|0]=0;d=Ll(d,d+e|0,c+15|0);Fi(a,x[b>>2],d);hb=c+16|0}function PP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=x[c>>2],g=b,h=Fb(c),d=x[x[a>>2]+28>>2],mb[d](e|0,f|0,g|0,h|0)|0)|0}function pl(a,b,c,d,e){var f=0,g=0,h=0;b=hb-16|0;hb=b;x[b+12>>2]=d;f=c;c=d-c|0;g=b,h=vk(e,f,c)+c|0,x[g+8>>2]=h;Dc(a,b+12|0,b+8|0);hb=b+16|0}function Ss(a){var b=0;b=C[a+4248>>3]/+(cf(x[a+16>>2])>>>0);C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*.016666666666666666*C[a+4288>>3]}}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=250){gj(7976);p()}e=d+8|0;Kb(e,a,b);le(e,c);hb=d+16|0;return a|0}function Kj(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(F(a)<2147483648){return~~a}return-2147483648}function oma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=x[d>>2];c=z[x[a+12>>2]>>1];w[b+2>>1]=0;w[b>>1]=c;hb=a+16|0}function id(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;x[c+12>>2]=b;x[c>>2]=-1;x[c+4>>2]=0;a=mv(c+8|0,c);hb=c+16|0;return x[a>>2]}function i_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Mb(a+12|0,a+8|0);hb=a+16|0;return x[b>>2]}function hR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Qb(a,32);a:{if(d){e=c+8|0;aR(e,b);Cd(a,e);break a}$Q(b)}hb=c+16|0;return d|0}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=43){gj(7976);p()}e=d+8|0;Kb(e,a,b);le(e,c);hb=d+16|0;return a|0}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,5)){d=c+8|0;sB(d,a);Cd(b,d);break a}v[c+7|0]=0;$h(a,5,c+7|0)}hb=c+16|0}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=110){gj(7976);p()}e=d+8|0;Kb(e,a,b);le(e,c);hb=d+16|0;return a|0}function Loa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,6)){d=c+8|0;UA(d,a);Cd(b,d);break a}v[c+7|0]=0;$h(a,6,c+7|0)}hb=c+16|0}function $da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=16){gj(7976);p()}e=d+8|0;tl(e,a,b);le(e,c);hb=d+16|0;return a|0}function qm(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,4)){d=c+8|0;Ih(d,a);Cd(b,d);break a}v[c+7|0]=0;$h(a,4,c+7|0)}hb=c+16|0}function kR(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){qf(a+b|0);b=b+1|0;if((b|0)!=512){continue}break}hb=d+16|0;hb=c+16|0}function eo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Qb(a,4);a:{if(d){e=c+8|0;Ih(e,b);Cd(a,e);break a}OS(b)}hb=c+16|0;return d|0}function bE(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){qf(a+b|0);b=b+1|0;if((b|0)!=256){continue}break}hb=d+16|0;hb=c+16|0}function _k(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Yf(b+8|0,fe(b+12|0,b+4|0))|0];hb=b+16|0;return a|0}function Wc(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Yf(b+8|0,fe(b+12|0,b+4|0))>>1];hb=b+16|0;return a}function VC(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114409]=0;a=O(261,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a}R(0)|0;zb();p()}function Sq(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,3)){d=c+8|0;cv(d,a);Cd(b,d);break a}v[c+7|0]=0;$h(a,3,c+7|0)}hb=c+16|0}function Jz(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=yb(b),d=0,x[c>>2]=d;return a}function IR(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114409]=0;a=O(905,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a}R(0)|0;zb();p()}function CN(a){a=50-(D(y[(a>>>4|0)+25760|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ec((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function kf(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;x[f+12>>2]=c;x[f+8>>2]=e;c=Nh(f+4|0,f+12|0);a=Ur(a,b,d,x[f+8>>2]);Te(c);hb=f+16|0;return a}function Zd(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=Im(c+8|0,b);AD(d,a);Ab(d);hb=c+16|0;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return a}function Fb(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114409]=0;a=O(38,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a}R(0)|0;zb();p()}function DJ(a){var b=0,c=E(0);if(!a){return E(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=E(oh(b-L(b+.5)))}else{c=E(0)}return c}function $g(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114409]=0;a=O(32,a|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a}R(0)|0;zb();p()}function $Q(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){qf(a+b|0);b=b+1|0;if((b|0)!=32){continue}break}hb=d+16|0;hb=c+16|0}function z4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;NI(h,b,c,d,e,f);Jd(a,h);Zl(h);hb=g+32|0}function mP(a){var b=0;b=x[a+16>>2];a=x[a+32>>2];b=sqa(b,b>>31,a,a>>31);a=lb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Ec(tqa(b,a,1e6,0),lb)}function lP(a){var b=0;b=x[a+16>>2];a=x[a+36>>2];b=sqa(b,b>>31,a,a>>31);a=lb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Ec(tqa(b,a,1e6,0),lb)}function av(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,2)){d=c+8|0;xm(d,a);Cd(b,d);break a}v[c+7|0]=0;MB(a,c+7|0)}hb=c+16|0}function ad(a,b){var c=0,d=0,e=0;c=Hh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=mb[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function Wd(a,b){a=a|0;b=b|0;return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|0}function OS(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){qf(a+b|0);b=b+1|0;if((b|0)!=4){continue}break}hb=d+16|0;hb=c+16|0}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=Uw(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function Kf(a){var b=0,c=0;b=hb-16|0;hb=b;if(lr(a,b+12|0)){a=b+12|0;c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}hb=b+16|0;return c}function laa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!be(c&255))){yK(a,8,E(0))}a=Aj(a);if(a){mb[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function Yo(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;b=mi(c+4|0,b);d=hb-16|0;hb=d;yr(a,x[b>>2],x[b>>2]+$g(b)|0);hb=d+16|0;hb=c+16|0}function $s(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=(b|0)!=0&(c|0)!=0;if(e){v[d+15|0]=0;qJ(a+36|0,b,Ll(b,b+c|0,d+15|0))}hb=d+16|0;return e}function wE(a){var b=0,c=0,d=0;c=Rb(a);b=Cb(a);a=hb-16|0;hb=a;v[a+15|0]=0;d=-1;if(b){b=Bo(c,b,a+15|0);d=b?b-c|0:-1}hb=a+16|0;return d}function vX(a,b){a=a|0;b=b|0;x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;pD(b)}function gV(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;hb=b+16|0}function Xv(a,b,c,d,e,f){var g=0,h=0;g=x[a+4>>2];h=g>>8;if(g&1){h=_v(x[d>>2],h)}a=x[a>>2];mb[x[x[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function WX(){var a=0,b=0;a=hb-16|0;hb=a;x[a+12>>2]=19469602;a:{if(OD(a+12|0)){break a}if(ND()){break a}b=MD()^1}hb=a+16|0;return b|0}function zH(a,b){a:{if(y[a+23|0]){a=1;if((b|0)!=255){break a}ea(9933,9049,1180,2220);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function iC(a){var b=0,c=0;b=sqa(y[a+111|0],0,1536,0);c=lb;a=sqa(y[a+110|0],0,25,0);b=b+a|0;c=lb+c|0;lb=a>>>0>b>>>0?c+1|0:c;return b}function HE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=ME(c)}hb=d+16|0;x[a+4>>2]=c;x[a>>2]=b}function os(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function fT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=x[d>>2];w[b>>1]=z[x[a+12>>2]>>1];gd(b+4|0);hb=a+16|0}function b4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b>>2];x[a>>2]=d;x[x[d-12>>2]+a>>2]=x[b+4>>2];ys(x[x[a>>2]-12>>2]+a|0,c);return a|0}function Pw(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Qh(v[b|0])|0}function Gaa(a){a=a|0;a=hb-16|0;hb=a;x[a+12>>2]=1869112133;hb=a+16|0;a=a+12|0;return y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}function qs(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function Kg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=110){gj(7941);p()}d=c+8|0;Kb(d,a,b);le(d,0);hb=c+16|0;return a|0}function DX(a,b,c){a=a|0;b=b|0;c=c|0;if(QD(c)){x[114409]=0;_b(a);a=x[114409];x[114409]=0;if((a|0)==1){R(0)|0;zb();p()}return}_b(a)}function Br(a,b,c,d,e){var f=0,g=0;f=x[a+4>>2];g=f>>8;if(f&1){g=_v(x[c>>2],g)}a=x[a>>2];mb[x[x[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}
function xW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=wqa(0-wqa(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function fw(a,b){a=un(a);x[a>>2]=75016;x[114409]=0;O(2993,a+4|0,b|0)|0;b=x[114409];x[114409]=0;if((b|0)!=1){return a}Q(N()|0);p()}function ND(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Vb(a+4|0,10518);if(Cb(b)){c=(bg(b,9659)|0)!=-1}else{c=0}xb(b);hb=a+16|0;return c|0}function LD(a){a=a|0;var b=0;a=gd(a);x[114409]=0;O(211,a|0,9498)|0;b=x[114409];x[114409]=0;if((b|0)==1){b=N()|0;xb(a);Q(b|0);p()}}function C_(a){a=a|0;var b=0,c=0;b=x[x[a>>2]>>2];c=x[b+8>>2];a=x[b+4>>2];b=x[b>>2]+(c>>1)|0;if(c&1){a=x[a+x[b>>2]>>2]}mb[a|0](b)}function z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zx(a+8|0,b,c,d,2);if(a>>>0<16){a=y[a+35904|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zx(a+8|0,b,c,d,3);if(a>>>0<43){a=y[a+35856|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function vO(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){uO(a,y[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function t_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function sR(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=nl(c+8|0,b);AD(d,a);Ab(d);hb=c+16|0;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function nB(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Zq(a,b+14|0)){a=y[b+14|0]|y[b+15|0]<<8;c=a<<8|a>>>8}hb=b+16|0;return c&65535}function hx(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}sc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function Qt(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;e=d,f=Pt(b),x[e+12>>2]=f;e=d,f=Pt(c),x[e+8>>2]=f;Dc(a,d+12|0,d+8|0);hb=d+16|0}function JE(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;e=d,f=Pt(b),x[e+12>>2]=f;e=d,f=Pt(c),x[e+8>>2]=f;qr(a,d+12|0,d+8|0);hb=d+16|0}function IF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Tr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function FF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Rr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function Aj(a){var b=0,c=0;b=Xj(x[a+20>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[(x[a+16>>2]+D(b,160)|0)+906300>>2]}return c}function Ab(a){var b=0;a=x[a+4>>2];if(a){if(Jm(a)){a:{b=a+8|0;if(x[b>>2]){if((Fv(b)|0)!=-1){break a}}mb[x[x[a>>2]+16>>2]](a)}}}}function rf(a,b){var c=0;c=hb-16|0;hb=c;B[c+8>>2]=1;B[c+12>>2]=b;B[c+4>>2]=a;a=B[GA(c+4|0,c+12|0,c+8|0)>>2];hb=c+16|0;return a}function l_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function HO(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){ee(b,a)}if(c){ee(c,a)}if(d){ee(d,a)}if(e){ee(e,a)}}function xQ(a){a:{if(!y[a+12|0]){x[114409]=0;V(1018,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function uL(a){a:{if(!y[a+12|0]){x[114409]=0;V(1682,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function sL(a){var b=0,c=0;if(x[a>>2]){ng(a);aT(a);QS(a);Hu(yb(a),x[a>>2],$i(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function qQ(a){a:{if(!y[a+12|0]){x[114409]=0;V(1027,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function qL(a){a:{if(!y[a+12|0]){x[114409]=0;V(1686,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function oM(a){a:{if(!y[a+12|0]){x[114409]=0;V(1537,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function oI(a){a:{if(!y[a+12|0]){x[114409]=0;V(2339,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function mQ(a){a:{if(!y[a+12|0]){x[114409]=0;V(1031,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function iO(a){a:{if(!y[a+12|0]){x[114409]=0;V(1294,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function fL(a){a:{if(!y[a+12|0]){x[114409]=0;V(1702,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function ZN(a){a:{if(!y[a+12|0]){x[114409]=0;V(1305,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function XN(a){a:{if(!y[a+12|0]){x[114409]=0;V(1326,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Tk(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(mb[x[x[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}x[a+12>>2]=b;c=1}return c}function TY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(vg(a,x[b+8>>2],0)){$v(b,c,d);return}a=x[a+8>>2];mb[x[x[a>>2]+28>>2]](a,b,c,d)}function RN(a){a:{if(!y[a+12|0]){x[114409]=0;V(1338,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function RK(a){a:{if(!y[a+12|0]){x[114409]=0;V(1755,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Lk(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=x[b>>2];x[d+8>>2]=x[b+4>>2];Hd(a,c,x[Mb(d+12|0,d+8|0)>>2]);hb=d+16|0}function JO(a){a:{if(!y[a+12|0]){x[114409]=0;V(1255,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function It(a){a:{if(!y[a+12|0]){x[114409]=0;V(1248,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function IP(a){a:{if(!y[a+12|0]){x[114409]=0;V(1073,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Hda(a){a=a|0;x[a>>2]=0;Pj(a+4|0);x[a+152>>2]=0;x[a+156>>2]=0;x[a+144>>2]=0;x[a+148>>2]=0;Sb(a+16|0,0,128);return a|0}function FL(a){a:{if(!y[a+12|0]){x[114409]=0;V(1662,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function EI(a){a:{if(!y[a+12|0]){x[114409]=0;V(2330,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function E2(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=x[a+12>>2];x[b+12>>2]=a+1;return Qh(v[a|0])|0}function BI(a){a:{if(!y[a+12|0]){x[114409]=0;V(2334,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function vS(a){a:{if(!y[a+12|0]){x[114409]=0;V(788,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function tX(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;a=Qo(a);x[a>>2]=75996;c=vq(hc(a)),d=76036,x[c>>2]=d;hb=b+16|0;return a|0}function oJ(a){a:{if(!y[a+4|0]){x[114409]=0;V(2248,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function nF(a){a:{if(!y[a+12|0]){x[114409]=0;V(177,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function kO(a){a:{if(!y[a+4|0]){x[114409]=0;V(1286,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function kF(a){a:{if(!y[a+4|0]){x[114409]=0;V(2708,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function js(a){x[a>>2]=59080;nw(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function iD(a){a:{if(!y[a+12|0]){x[114409]=0;V(252,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function cU(a){a:{if(!y[a+12|0]){x[114409]=0;V(570,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function c3(a){a=a|0;var b=0;if(!a){return-2}b=x[a+28>>2];if(!b){return 0}mb[x[a+36>>2]](x[a+40>>2],b);x[a+28>>2]=0;return 0}function VT(a){a:{if(!y[a+12|0]){x[114409]=0;V(610,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function UT(a){a:{if(!y[a+12|0]){x[114409]=0;V(617,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Sf(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Jn(a,d)}function MU(a){a:{if(!y[a+12|0]){x[114409]=0;V(517,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function KU(a){a:{if(!y[a+12|0]){x[114409]=0;V(522,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function JU(a){a:{if(!y[a+12|0]){x[114409]=0;V(523,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function JF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Tr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function GG(a){x[a>>2]=59240;nw(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function GF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Rr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Ct(a){a:{if(!y[a+4|0]){x[114409]=0;V(1282,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function $f(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Sg(d,a);return((Sg(d,a+1|0)<<8|e<<16|Sg(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function yo(a,b){var c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=3){c=lC(a,b);break a}c=Kf(a);cc(a,b-4|0)}return c}function rU(a){a:{if(!y[a+4|0]){x[114409]=0;V(560,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function qV(a){a:{if(!y[a+4|0]){x[114409]=0;V(333,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function oc(a,b){var c=0;a=un(a);x[a+4>>2]=0;x[a>>2]=82404;c=xd(Cb(b)+1|0);x[a+4>>2]=c;if(c){sc(c,Rb(b),Cb(b)+1|0)}return a}function lL(a){a=a|0;var b=0,c=0;b=Ne(a);while(1){c=b;if(c&65535){b=c-1|0;if(!pg(a,b&65535)){continue}}break}return c&65535}function jo(a){a:{if(!y[a+4|0]){x[114409]=0;V(334,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function hu(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Mb(b+12|0,b+8|0)>>2];hb=b+16|0;return a|0}function gv(a,b){var c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=1){c=kC(a,1);break a}c=tg(a);cc(a,b-2|0)}return c}function dt(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function co(a){a:{if(!y[a+4|0]){x[114409]=0;V(692,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function YN(a){a:{if(!y[a+4|0]){x[114409]=0;V(332,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Xj(a){a=a+28|0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))>>>0>=128){a=y[a|0]^-128}else{a=255}return a&255}function Vn(a){a:{if(!y[a+4|0]){x[114409]=0;V(388,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function TB(a){a:{if(!y[a+4|0]){x[114409]=0;V(387,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function SI(a){a:{if(!y[a+4|0]){x[114409]=0;V(322,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function MR(a){a:{if(!y[a+4|0]){x[114409]=0;V(900,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function MQ(a){a:{if(!y[a+4|0]){x[114409]=0;V(974,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function MJ(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=lg(b-24|0);if((c|0)!=(b|0)){continue}break}return Cf(a)|0}function LR(a){a:{if(!y[a+4|0]){x[114409]=0;V(899,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function DD(a){a:{if(!y[a+4|0]){x[114409]=0;V(239,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function yna(a){a=a|0;var b=0;rl(x[a>>2]);b=x[a>>2];if(x[b>>2]){XD(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];ki(b,x[a>>2],li(a))}}function xja(a){a=a|0;var b=0;ri(x[a>>2]);b=x[a>>2];if(x[b>>2]){MP(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];Lh(b,x[a>>2],xg(a))}}function uS(a){a:{if(!y[a+4|0]){x[114409]=0;V(35,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function tma(a){a=a|0;var b=0;ij(x[a>>2]);b=x[a>>2];if(x[b>>2]){YR(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];mm(b,x[a>>2],_f(a))}}function sma(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){dS(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];Nj(b,x[a>>2],sd(a))}}function qy(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function nm(a){a:{if(!y[a+4|0]){x[114409]=0;V(99,a|0);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function kP(a){a=a|0;x[a+700>>2]=0;w[a+862>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function k6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=x[d>>2];Xb(Jd(b,x[a+12>>2])+12|0);hb=a+16|0}function ila(a){a=a|0;var b=0;jr(x[a>>2]);b=x[a>>2];if(x[b>>2]){_Q(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];Bv(b,x[a>>2],lj(a))}}function XK(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=ac(c+4|0,b);d=hb-16|0;hb=d;yr(a,x[b>>2],x[b>>2]+Fb(b)|0);hb=d+16|0;hb=c+16|0}function Vz(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Tma(a){a=a|0;var b=0;GS(x[a>>2]);b=x[a>>2];if(x[b>>2]){HS(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];FS(b,x[a>>2],gm(a))}}function Tka(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){JQ(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];Nj(b,x[a>>2],sd(a))}}function Ena(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){WS(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];Nj(b,x[a>>2],sd(a))}}function p4(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;x[c+12>>2]=y[b|0];Jx(a,c+12|0);hb=c+16|0;hb=d+16|0}function ow(a,b,c){c=x[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=x[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function oX(a){a=a|0;var b=0;io(x[a>>2]);b=x[a>>2];if(x[b>>2]){SD(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];fg(b,x[a>>2],tf(a))}}function ce(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function ama(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Zq(a,b+14|0)){c=(y[b+14|0]|y[b+15|0]<<8)<<16>>16}hb=b+16|0;return c|0}function VV(a){a=a|0;var b=0;ij(x[a>>2]);b=x[a>>2];if(x[b>>2]){IB(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];mm(b,x[a>>2],_f(a))}}function UV(a){a=a|0;var b=0;rl(x[a>>2]);b=x[a>>2];if(x[b>>2]){DB(b,x[b>>2]);b=yb(x[a>>2]);a=x[a>>2];ki(b,x[a>>2],li(a))}}function LK(a,b,c){var d=0;b=b-a>>2;if((b|0)>0){while(1){x[a>>2]=x[c>>2];a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Jo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function mW(a){a=a|0;var b=0;a:{if(!re(-1,x[a+76>>2])){a=x[a+76>>2];break a}b=a;a=YF(a,32);x[b+76>>2]=a}return a<<24>>24}function f2(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=x[a+12>>2];x[b+12>>2]=a+4;return x[a>>2]}function VO(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){TO(a,1);TO(a,0)}}function UO(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){SO(a,1);SO(a,0)}}function Te(a){a:{a=x[a>>2];if(a){x[114409]=0;vw(a);a=x[114409];x[114409]=0;if((a|0)==1){break a}}return}R(0)|0;zb();p()}function Gk(a,b,c){var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;ny(a,c)}function DG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function To(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;Yo(e,mi(d,b));Gv(a,e);x[a+12>>2]=c;x[a+8>>2]=0;hb=d+16|0;return a}function vY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return mb[a|0](h|b,c,d,e,b|f,g)|0}function Ms(a,b,c){var d=0;b=b-a|0;if((b|0)>0){while(1){v[a|0]=y[c|0];a=a+1|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function HU(a){var b=0,c=0;a:{if(dd(a,23460,20)){break a}b=a+25|0;if(!y[b|0]|y[b|0]>8){break a}c=v[a+47|0]>=0}return c}function Ee(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function CP(a){var b=0,c=0,d=0;b=a+68|0;c=y[b+1|0]<<8;if(!(!(y[b|0]|c)|(c|y[b|0])>>>0>127)){d=!dd(a,13533,17)}return d}function $A(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Mb(b+12|0,b+8|0)>>1];hb=b+16|0;return a|0}function pq(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,20)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function jV(a,b){a=a|0;b=b|0;var c=0;c=x[b+4>>2];if(c){jc(a,c,x[b>>2]);return}b=b+8|0;if(!kd(b)){nj(a,b);return}Po(a)}function jS(a){a=a|0;var b=0;b=hb-16|0;hb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Gf(b+14|0,b+12|0)|0];hb=b+16|0;return a|0}function hU(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,48)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function ak(a,b,c){var d=0,e=0;e=a+24|0;a=hb-16|0;hb=a;if(b>>>0>=12){gj(7976);p()}d=a+8|0;tl(d,e,b);le(d,c);hb=a+16|0}function Xt(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,56)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function Op(a){var b=0;a:{if(!(y[a+480208|0]&16)){break a}if(!$b(a+1074312|0,7)){break a}b=x[a+480180>>2]!=4}return b}function Mp(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,24)|0,8);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function Lh(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,12)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function Lf(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,24)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function FS(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,33)|0,1);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function By(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,52)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function XP(a){var b=0,c=0;b=y[a+33|0];c=b>>>24|0;a=y[a+31|0]?1120:1056;b=a+(b<<8)|0;lb=a>>>0>b>>>0?c+1|0:c;return b}function Tb(a,b){var c=0,d=0;c=x[b>>2];d=c+x[a>>2]|0;b=x[a+4>>2]+x[b+4>>2]|0;x[a>>2]=d;x[a+4>>2]=d>>>0<c>>>0?b+1|0:b}function Pk(a,b){a=a+58|0;if(v[fc(a,b)|0]<0){return 255}if(y[fc(a,b)|0]!=255){a=y[fc(a,b)|0]&127}else{a=255}return a}function II(a,b){a:{x[114409]=0;T(27,a|0,D(b,324)|0,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function Hu(a,b,c){a:{x[114409]=0;T(27,b|0,D(c,6)|0,1);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function EX(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a=Qo(a);x[a>>2]=75892;yD(hc(a),mi(c+4|0,b));hb=c+16|0;return a|0}function ll(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Mb(b+12|0,b+8|0)|0];hb=b+16|0;return a|0}function jG(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function eaa(a){a=a|0;var b=0,c=0;x[x[a+20>>2]>>2]=a;c=x[a+12>>2];b=x[c>>2];x[a+4>>2]=b;if(b){x[b+8>>2]=a}x[c>>2]=a}function d8(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=Vb(b+4|0,8336);a=oc(a,c);xb(c);x[a>>2]=82364;hb=b+16|0;return a|0}function Pn(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=x[a>>2];x[c+12>>2]=x[c+12>>2]+(b<<2);hb=c+16|0;return x[c+12>>2]}function O7(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=Vb(b+4|0,4396);a=oc(a,c);xb(c);x[a>>2]=82384;hb=b+16|0;return a|0}function yka(a){a=a|0;var b=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){zQ(b);b=yb(x[a>>2]);a=x[a>>2];Lf(b,x[a>>2],ff(a))}}function wja(a){a=a|0;var b=0;ri(x[a>>2]);b=x[a>>2];if(x[b>>2]){SP(b);b=yb(x[a>>2]);a=x[a>>2];Lh(b,x[a>>2],xg(a))}}function uda(a){a=a|0;var b=0;Gm(x[a>>2]);b=x[a>>2];if(x[b>>2]){FD(b);b=yb(x[a>>2]);a=x[a>>2];dh(b,x[a>>2],Gh(a))}}function tna(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){cT(b);b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function rma(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){zS(b);b=yb(x[a>>2]);a=x[a>>2];jv(b,x[a>>2],sd(a))}}function oda(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){YL(b);b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function oH(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function jpa(a){a=a|0;var b=0;io(x[a>>2]);b=x[a>>2];if(x[b>>2]){eU(b);b=yb(x[a>>2]);a=x[a>>2];fg(b,x[a>>2],tf(a))}}function jd(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=x[a>>2];x[c+8>>2]=x[b>>2];a=qc(c+12|0,c+8|0);hb=c+16|0;return a}function jca(a){a=a|0;var b=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){IL(b);b=yb(x[a>>2]);a=x[a>>2];Lf(b,x[a>>2],ff(a))}}function bda(a){a=a|0;var b=0;uM(x[a>>2]);b=x[a>>2];if(x[b>>2]){tM(b);b=yb(x[a>>2]);a=x[a>>2];By(b,x[a>>2],Bj(a))}}function Wia(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){xP(b);b=yb(x[a>>2]);a=x[a>>2];Nj(b,x[a>>2],sd(a))}}function SU(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function Qda(a){a=a|0;var b=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){cN(b);b=yb(x[a>>2]);a=x[a>>2];Mp(b,x[a>>2],ff(a))}}function Ppa(a){a=a|0;var b=0;ij(x[a>>2]);b=x[a>>2];if(x[b>>2]){PU(b);b=yb(x[a>>2]);a=x[a>>2];mm(b,x[a>>2],_f(a))}}function Lna(a){a=a|0;var b=0;Iu(x[a>>2]);b=x[a>>2];if(x[b>>2]){aT(b);b=yb(x[a>>2]);a=x[a>>2];Hu(b,x[a>>2],$i(a))}}function Kt(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=x[a>>2];x[c+8>>2]=x[b>>2];a=Hb(c+12|0,c+8|0);hb=c+16|0;return a}function Kfa(a){a=a|0;var b=0;ri(x[a>>2]);b=x[a>>2];if(x[b>>2]){aO(b);b=yb(x[a>>2]);a=x[a>>2];Lh(b,x[a>>2],xg(a))}}function Kaa(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=fN(E(c*E(255))),v[d|0]=e;Ys(a)}}function Hga(a){a=a|0;var b=0;Gm(x[a>>2]);b=x[a>>2];if(x[b>>2]){LO(b);b=yb(x[a>>2]);a=x[a>>2];dh(b,x[a>>2],Gh(a))}}function Eda(a){a=a|0;var b=0;iU(x[a>>2]);b=x[a>>2];if(x[b>>2]){zU(b);b=yb(x[a>>2]);a=x[a>>2];hU(b,x[a>>2],im(a))}}function $h(a,b,c){a=a|0;b=b|0;c=c|0;if(b){while(1){v[a|0]=y[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}return a|0}function ox(a,b){var c=0;c=(D(D(mx(a),nx(a)),125)>>>0)/(UH(a)>>>0)|0;a=(y[a+1|0]&6)==6?c&134217724:c;return a?a:b}function Y9(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){GK(b);b=yb(x[a>>2]);a=x[a>>2];bf(b,x[a>>2],sd(a))}}function X9(a){a=a|0;var b=0;EK(x[a>>2]);b=x[a>>2];if(x[b>>2]){JK(b);b=yb(x[a>>2]);a=x[a>>2];DK(b,x[a>>2],Bk(a))}}function VJ(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function V5(a){a=a|0;var b=0;og(x[a>>2]);b=x[a>>2];if(x[b>>2]){AI(b);b=yb(x[a>>2]);a=x[a>>2];Mp(b,x[a>>2],ff(a))}}function TV(a){a=a|0;var b=0;ij(x[a>>2]);b=x[a>>2];if(x[b>>2]){LB(b);b=yb(x[a>>2]);a=x[a>>2];Fo(b,x[a>>2],_f(a))}}function QO(a){var b=0,c=0;if(x[a>>2]){Kq(a);Fo(yb(a),x[a>>2],_f(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function LW(a){a=a|0;var b=0;io(x[a>>2]);b=x[a>>2];if(x[b>>2]){IC(b);b=yb(x[a>>2]);a=x[a>>2];fg(b,x[a>>2],tf(a))}}function LN(a,b){var c=0;c=b&15;if(c){v[a+847|0]=c<<2}b=b&240;if(b){v[a+846|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function Kk(a,b){var c=0;c=b&15;if(c){v[a+844|0]=c<<2}b=b&240;if(b){v[a+843|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function H_(a){a=a|0;var b=0;Ge(x[a>>2]);b=x[a>>2];if(x[b>>2]){jF(b);b=ul(x[a>>2]);a=x[a>>2];GE(b,x[a>>2],sd(a))}}function HG(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!re(KG(c,b),-1)){break a}x[a>>2]=0}return a|0}function Eca(a,b){a=a|0;b=b|0;v[b+38|0]=y[a+202|0];v[b+39|0]=y[a+203|0];v[b+40|0]=y[a+204|0];v[b+41|0]=y[a+205|0]}function DK(a,b,c){a:{x[114409]=0;T(27,b|0,c<<11,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function $y(a){var b=0,c=0;if(x[a>>2]){ut(a);fg(yb(a),x[a>>2],tf(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function $R(a){var b=0,c=0;if(x[a>>2]){AS(a);jv(yb(a),x[a>>2],sd(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function n6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=mb[x[x[b>>2]+8>>2]](b)|0;d=c,e=Ld(a?a:17381),x[d>>2]=e}}function mm(a,b,c){a:{x[114409]=0;T(27,b|0,c<<1,1);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function ki(a,b,c){a:{x[114409]=0;T(27,b|0,c<<4,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function jv(a,b,c){a:{x[114409]=0;T(27,b|0,c<<2,2);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function eu(a,b,c){a:{x[114409]=0;T(27,b|0,c<<5,8);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function dh(a,b,c){a:{x[114409]=0;T(27,b|0,c<<5,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function bf(a,b,c){a:{x[114409]=0;T(27,b|0,c<<2,4);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function YO(a){var b=0,c=0;b=a+68|0;a=0;while(1){c=(a<<2)+b|0;a=a+1|0;x[c>>2]=a<<11;if((a|0)!=9){continue}break}}function SN(a){var b=0;x[114409]=0;a=S(1339,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){R(0)|0;zb();p()}return a}function Ph(a,b,c){x[114409]=0;U(2461,b|0,c|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){return}R(0)|0;zb();p()}function Nj(a,b,c){a:{x[114409]=0;T(27,b|0,c<<2,1);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function ML(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179011410){a=Nz(a)>>>0>80}else{a=0}return a}function Fo(a,b,c){a:{x[114409]=0;T(27,b|0,c<<1,2);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function DI(a){var b=0;x[114409]=0;a=S(2331,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){R(0)|0;zb();p()}return a}function Bv(a,b,c){a:{x[114409]=0;T(27,b|0,c<<3,1);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function x1(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=Cw(b);x[a+36>>2]=b;c=a,d=en(b),v[c+44|0]=d}function tt(a){var b=0;b=1;a:{switch(y[a+3|0]-4|0){default:b=y[a+2|0]==11;break;case 0:case 2:break a}}return b}function hh(a){a:{a=x[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function fg(a,b,c){a:{x[114409]=0;T(27,b|0,c|0,1);a=x[114409];x[114409]=0;if((a|0)!=1){break a}R(0)|0;zb();p()}}function aJ(a){var b=0;a:{while(1){if(!x[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function LU(a){var b=0;x[114409]=0;a=S(524,a|0)|0;b=x[114409];x[114409]=0;if((b|0)==1){R(0)|0;zb();p()}return a}function F1(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=Jw(b);x[a+36>>2]=b;c=a,d=en(b),v[c+44|0]=d}function vg(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!xj(x[a+4>>2],x[b+4>>2])}function qda(a,b){a=a|0;b=b|0;if(b>>>0>255){return 17381}a=x[((b<<2)+a|0)+900380>>2];return(a?a+492|0:17381)|0}function le(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function dL(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Mb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function Vj(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function Se(a,b,c){x[114409]=0;U(23,b|0,c|0,a|0)|0;a=x[114409];x[114409]=0;if((a|0)!=1){return}R(0)|0;zb();p()}function Le(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=x[a>>2];x[c+12>>2]=x[c+12>>2]+b;hb=c+16|0;return x[c+12>>2]}function Ju(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=(D(a,b)>>>0)/255;ce(c+12|0,0,15);hb=c+16|0;return y[c+12|0]}function zR(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(!(b<0)){C[a+8>>3]=b;x[a+16>>2]=3}return a}function sE(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}return a|0}function bM(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function ae(a){a=a|0;var b=0;b=x[15032];x[a>>2]=b;x[x[b-12>>2]+a>>2]=x[15035];xs(a+4|0);lh(a+56|0);return a|0}function Zna(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+4|0;sT(d,b);a=Jd(a,d);xb(d);hb=c+16|0;return a|0}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+4|0;vC(d,a);a=Df(d,b);xb(d);hb=c+16|0;return a|0}function Pf(a){a=a|0;var b=0;b=x[15077];x[a>>2]=b;x[x[b-12>>2]+a>>2]=x[15080];xs(a+8|0);lh(a+60|0);return a|0}function Bn(a){var b=0;while(1){if(y[b+35920|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function ypa(a,b){a=a|0;b=b|0;var c=0;b=hb-80|0;hb=b;c=-1;if(DU(a,b+14|0)){c=CU(b+14|0)}hb=b+80|0;return c|0}function mS(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;if((Nu(a)|0)!=65535){uV(a,c+14|0)}hb=c+16|0}function dq(a,b){a=a|0;b=b|0;if(rc(a)>>>0>b>>>0){a=pg(x[a+24>>2]+484344|0,z[il(a,b)>>1])}else{a=0}return a|0}function LG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return Qh(v[b|0])}function HF(a,b,c,d,e){b=qi(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function EF(a,b,c,d,e){b=pi(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function tg(a){var b=0,c=0;b=hb-16|0;hb=b;if(Zq(a,b+14|0)){a=b+14|0;c=y[a|0]|y[a+1|0]<<8}hb=b+16|0;return c}function rh(a,b){var c=0;c=a;b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Gc(c,(b>>31&a)+b|0)>>2]}function lv(a,b){var c=0,d=0;d=x[b>>2];c=x[a+4>>2];b=x[b+4>>2];return(c|0)==(b|0)&A[a>>2]<d>>>0|b>>>0>c>>>0}function gl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;if(!Nq(a,b)){b=Nq(c,a)?c:a}hb=d+16|0;return b|0}function NH(a,b,c,d){B[d+4>>2]=c+a;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=a+b}function Mz(a,b){var c=0;c=hb-16|0;hb=c;a=Ib(Hd(c+8|0,x[a>>2]+(b>>>3&536870908)|0,1<<b));hb=c+16|0;return a}function GA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;if(!uu(a,b)){b=uu(c,a)?c:a}hb=d+16|0;return b|0}function nma(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Yj(a,b+8|0)){c=TR(b+8|0)}hb=b+16|0;return c|0}function hqa(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Yj(a,b+8|0)){c=_U(b+8|0)}hb=b+16|0;return c|0}function ev(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Pp(a){var b=0,c=0,d=0;b=a;a=x[a>>2];c=b,d=Db(D(a,214013)+2531011|0),x[c>>2]=d;return a>>>16&32767}function HR(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(Hh(a,4)){d=c+8|0;Ih(d,b);Xz(a,d);break a}OS(b)}hb=c+16|0}function Bla(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(YA(a,b+4|0)){c=tR(b+4|0)}hb=b+16|0;return c|0}function y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;Yo(e,mi(d,b));To(a,e,c);hb=d+16|0}function mZ(a){a=a|0;a=hb-16|0;hb=a;if(La(a+12|0,4)|0){Cr(x[114232],8482);p()}hb=a+16|0;return x[a+12>>2]}function YE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function KE(a,b){x[114409]=0;T(27,a|0,b<<2,4);a=x[114409];x[114409]=0;if((a|0)!=1){return}R(0)|0;zb();p()}function Jd(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];fp(b);we(a);return a}function EG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function CU(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function $W(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Yj(a,b+8|0)){c=UC(b+8|0)}hb=b+16|0;return c|0}function vw(a){a=a|0;var b=0;b=x[114276];if(a){x[114276]=(a|0)==-1?456984:a}return((b|0)==456984?-1:b)|0}function ug(a,b){var c=0,d=0;c=x[a>>2];d=x[b>>2];lb=x[a+4>>2]-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Yh(a,b,c){var d=0,e=0,f=0,g=0;d=C[c>>3];e=C[b>>3];f=C[c+8>>3];g=C[b+8>>3];_l(a,d*e-f*g,e*f+d*g)}function FO(a){w[a+70>>1]=y[((z[x[a+4>>2]+22>>1]<<4|z[x[a+4>>2]+20>>1]>>>6)&65535)+25600|0]>>>z[a+68>>1]}function x2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function u2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function r2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function k2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function Xpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+4|0;Ng(d,1,a);BC(d,b);hb=c+16|0;return a|0}function Wpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+4|0;Qu(d,1,a);BC(d,b);hb=c+16|0;return a|0}function Ro(a,b,c){var d=0;d=hb-16|0;hb=d;a=Po(a);x[a+4>>2]=c;x[a>>2]=b;x[d+4>>2]=b;x[d>>2]=b;hb=d+16|0}function E_(){if(y[461020]){return x[115254]}dp(461012,cF());v[461020]=1;x[115254]=461012;return 461012}function A2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function fB(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=b;x[c+12>>2]=a;a=Jq(c+8|0,c+12|0);hb=c+16|0;return a}function RL(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){a=mc(a);if(y[a+4|0]){mw(x[a>>2],b+16|0)}if(b){SL(b)}}}function Gr(){var a=0;x[114409]=0;a=x[114409];x[114409]=0;if((a|0)!=1){return x[15450]}R(0)|0;zb();p()}function Fr(){var a=0;x[114409]=0;a=x[114409];x[114409]=0;if((a|0)!=1){return x[15836]}R(0)|0;zb();p()}function nx(a){var b=0;b=y[a+1|0];return y[(D(b>>>1&3,15)+D(b>>>3&1,45)+(y[a+2|0]>>>4)|0)+39377|0]<<1}function iz(a,b){if(pg(x[a+24>>2]+484344|0,b)){a=x[Zb(x[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function dz(a){x[114409]=0;T(27,a|0,40,4);a=x[114409];x[114409]=0;if((a|0)!=1){return}R(0)|0;zb();p()}function bka(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=Kz(kQ(b+12|0));hb=b+16|0;return a|0}function Vaa(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=Yg(je(b+12|0));hb=b+16|0;return a|0}function SL(a){x[114409]=0;T(27,a|0,28,4);a=x[114409];x[114409]=0;if((a|0)!=1){return}R(0)|0;zb();p()}function QN(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(b>=c){break a}}C[a>>3]=d}}function Gpa(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=Wj(ke(b+12|0));hb=b+16|0;return a|0}function Bba(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=$x(dm(b+12|0));hb=b+16|0;return a|0}function pV(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;hb=b+16|0}function no(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=cj(bj(b+12|0));hb=b+16|0;return a|0}function nW(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;gC(d,a);Wq(d,b);hb=c+16|0;return a|0}function jT(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){dT(c+52|0);xb(c+40|0);lg(c+16|0);lg(c+4|0);_b(c)}}function fD(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=Fm(Mo(b+12|0));hb=b+16|0;return a|0}function QT(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=Pm(sf(b+12|0));hb=b+16|0;return a|0}function PM(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function Laa(a,b){a=a|0;b=b|0;return E((b|0)<=3?E(E(y[(a+b|0)+4264|0])*E(.003921568859368563)):E(0))}function GR(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;w[a+14>>1]=0;return a}function GE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}KE(b,c)}hb=d+16|0}function Er(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];a=ek(dk(b+12|0));hb=b+16|0;return a|0}function EW(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Xq(d,a);Wq(d,b);hb=c+16|0;return a|0}function Cm(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function AW(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;uC(d,a);Wq(d,b);hb=c+16|0;return a|0}function xL(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=x[a>>2];uT(c+12|0,b);hb=c+16|0;return x[c+12>>2]}function gP(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];return(c|0)<=(d|0)&A[b>>2]>A[a>>2]|(c|0)<(d|0)}function Wk(a,b,c){a=a|0;b=b|0;c=c|0;a=rd(a,b);b=x[c+4>>2];x[a+4>>2]=x[c>>2];x[a+8>>2]=b;return a|0}function WK(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=a;a=c+12|0;a=Pn(a,b-Ot(a)>>2);hb=c+16|0;return a}function UH(a){var b=0;b=x[(y[a+2|0]&12)+39380>>2];a=y[a+1|0]^-1;return b>>>(a>>>3&1)>>>(a>>>4&1)|0}function Pba(a,b){a=a|0;b=b|0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;ei(b)}function Gd(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=82448;x[b+8>>2]=82552;Dc(a,b+12|0,b+8|0);hb=b+16|0}function oY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return mb[a|0](b,c,d,e,f,g)|0}function oP(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=a;a=c+12|0;a=Le(a,b-Ot(a)|0);hb=c+16|0;return a}function l6(a,b){a=a|0;b=b|0;var c=0;c=x[a+4>>2];b=Rb(b);if(c){mb[c|0](b,x[a+8>>2]);return}Ns(b,a)}function jj(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ho(c+15|0,a,b);hb=c+16|0;return(d?b:a)|0}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;a=Aj(a);if(!a){return 0}return mb[x[x[a>>2]+96>>2]](a,b,c)|0}function fv(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=ag(a,b+15|0);hb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function Vh(a){var b=E(0),c=E(0);a:{b=B[a>>2];if(!(b<E(0))){c=E(1);if(b<=E(1)){break a}}B[a>>2]=c}}function V3(a,b){a=a|0;b=b|0;a=js(a);x[a>>2]=59400;Xb(a+32|0);x[a+48>>2]=b;x[a+44>>2]=0;return a|0}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Jd(c+4|0,b);Gt(d,a);xb(a);hb=c+16|0}function Gf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ho(c+15|0,b,a);hb=c+16|0;return(d?b:a)|0}function Ema(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;pA(a+236|0,128,c+14|0);hb=c+16|0}function zna(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=lr(a,b+12|0);hb=b+16|0;return E(a?B[b+12>>2]:E(0))}function tW(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(ag(a,b+15|0)){c=y[b+15|0]}hb=b+16|0;return c|0}function oja(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;x[b+8>>2]=x[c+8>>2]}function lB(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Vb(c+4|0,b);Gt(d,a);xb(a);hb=c+16|0}function kv(a,b,c){var d=0;d=hb-16|0;hb=d;ch(a,c);v[d+15|0]=0;$d(b+c|0,d+15|0);hb=d+16|0;return a}function kK(a){a=a|0;var b=0;b=x[a>>2];if(b){mb[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;ut(a);gS(a)}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;mb[x[x[b>>2]+8>>2]](b,c);d=a;a=b+4|0;dp(d,a);$E(a,c)}function sl(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;jc(e,Db(b),c);a=YS(a,e);hb=d+16|0;return a}function ic(a){x[114409]=0;lE(dw(a));a=x[114409];x[114409]=0;if((a|0)!=1){return}R(0)|0;zb();p()}function una(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[b>>2]+16>>2]](a,b,c,d,e,f)}function haa(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;nj(b,x[a+20>>2]+4|0);uK(a,Dd(b+8|0,b),0);hb=b+16|0}function gR(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function W1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function Vu(a,b){a=a|0;b=b|0;var c=0;a=Zq(a,b);if(!a){c=hb-16|0;hb=c;Yu(b);hb=c+16|0}return a|0}function MY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(vg(a,x[b+8>>2],f)){Zv(b,c,d,e)}}function Jaa(a){a=a|0;var b=0,c=0;v[a+4202|0]=1;b=a,c=cf(x[a+16>>2]),x[b+4232>>2]=c;Ys(a);KK(a)}function Iw(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=b;x[d+8>>2]=c;qr(a,d+12|0,d+8|0);hb=d+16|0}function Hk(a,b,c){a=x[a>>2]+1074984|0;return x[(a+D(b,896)|0)+680>>2]>x[(a+D(c,896)|0)+680>>2]}function Hca(a,b){a=a|0;b=b|0;Xh(a);Xh(a);a:{if(b>>>0>=60){cc(a,4);break a}Xh(a)}return Xh(a)|0}function CW(a){a=a|0;var b=0;b=x[a>>2];if(x[b>>2]){b=yb(b);a=x[a>>2];bf(b,x[a>>2],x[yb(a)>>2])}}function Ae(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=b;x[d+8>>2]=c;Dc(a,d+12|0,d+8|0);hb=d+16|0}function wU(a,b){return(Yb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((D(a&15,b)>>>0)/15|0,1,15))&255}function kw(a,b){a=a|0;b=b|0;var c=0;a:{c=Cb(a);if(c>>>0<b>>>0){Xp(a,b-c|0,0);break a}zC(a,b)}}function k9(a){a=a|0;var b=0,c=0;v[a+4202|0]=1;b=a,c=cf(x[a+16>>2]),x[b+4256>>2]=c;UJ(a);TJ(a)}function Ns(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;x[b>>2]=a;a=x[14644];pH(a,13684,b);nn(a);hb=b+16|0}function Lt(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=mg(oh(b)*+(c>>>0)),x[d+24>>2]=e}function JH(a){var b=0;b=+((a&2097151)>>>0);return E(uk(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function m2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[x[x[a>>2]+16>>2]](a,b,c,d,e)|0}function l2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0}function k8(a,b,c){a=a|0;b=b|0;c=c|0;a=Hx(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=82332;return a|0}function dZ(a,b,c){a=a|0;b=b|0;c=c|0;if(re(a,x[b+4>>2])){a=x[b>>2]==(c|0)}else{a=0}return a|0}function aC(a){var b=0;a=y[a+35|0];b=(a<<11)+2624|0;a=a>>>21|0;lb=b>>>0<2624?a+1|0:a;return b}function LS(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function Jf(a,b){x[a+8>>2]=x[a+8>>2]&-2147483648|b&2147483647;x[a+8>>2]=x[a+8>>2]|-2147483648}function JP(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function Bd(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;_D(d,a+24|0,b);a=Ib(d);hb=c+16|0;return a}function ym(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<1)+d;return a}function yD(a,b){var c=0,d=0;a=vq(a);x[a>>2]=75932;x[a+4>>2]=x[b>>2];c=a,d=$g(b),x[c+8>>2]=d}function j2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return mb[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function hi(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<2)+d;return a}function ZE(a){a=a|0;var b=0;x[a>>2]=65164;b=x[a+8>>2];if(!(!b|!y[a+12|0])){_b(b)}return a|0}function UD(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<4)+d;return a}function Np(a,b,c){a=Tl(a)-x[a+1074392>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function Jla(a,b){a=a|0;b=b|0;var c=0;a=hb-16|0;hb=a;c=b;b=ii(a);SR(c,b,0,0);Ab(b);hb=a+16|0}function Iq(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;Dm(b+8|0,c+8|0)}function BE(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function zq(a,b){var c=0;c=Cb(a);if((c|0)==(Cb(b)|0)){a=xn(Rb(a),Rb(b),c)}else{a=1}return!a}function tc(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=$D(b,a);hb=c+16|0;return(d?b:a)|0}function mv(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=lv(b,a);hb=c+16|0;return(d?b:a)|0}function lla(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Av(a,b+8|0);hb=b+16|0;return+(a?C[b+8>>3]:0)}function fe(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nq(b,a);hb=c+16|0;return(d?b:a)|0}function ah(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=$D(a,b);hb=c+16|0;return(d?b:a)|0}function _U(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function Zia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wt(a,b,c);hb=d+16|0;return a|0}function Yf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nq(a,b);hb=c+16|0;return(d?b:a)|0}function Xy(a){var b=0;x[a+72>>2]=0;x[a+76>>2]=0;b=x[a+68>>2];x[a+80>>2]=b;x[a+84>>2]=b<<12}function TC(a){a=a|0;var b=0;b=x[a>>2];return Db((mb[x[x[b>>2]+20>>2]](b)|0)+x[a+8>>2]|0)|0}function Qb(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];return mb[x[x[c>>2]+36>>2]](c,x[a+8>>2],b)|0}function Mb(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Go(b,a);hb=c+16|0;return(d?b:a)|0}function $u(a,b,c){a=a|0;b=b|0;c=c|0;b=hb-16|0;hb=b;v[b+15|0]=y[c|0];TI(a,b+15|0);hb=b+16|0}function $c(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Go(a,b);hb=c+16|0;return(d?b:a)|0}function xG(a){var b=0;b=x[a>>2];if(b){if(!re(LG(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function wY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=mb[a|0](b,c,d,e)|0;ib=lb;return a|0}function wG(a){var b=0;b=x[a>>2];if(b){if(!re(EG(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function qca(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;cd(c,(y[a|0]|y[a+1|0]<<8)&4?16:8,1,0,0)}function oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){mb[x[x[a>>2]+76>>2]](a,b,c,d)}}function nj(a,b){a=a|0;b=b|0;var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+xc(b)|0,x[c+4>>2]=d}function naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){mb[x[x[a>>2]+80>>2]](a,b,c,d)}}function mj(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){mb[x[x[a>>2]+84>>2]](a,b,c,d)}}function lca(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;cd(c,(y[a|0]|y[a+1|0]<<8)&4?16:8,1,0,0)}function l8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;AJ(a,b,c,d,e,0,0,f,g)}function aaa(a,b,c){a=a|0;b=b|0;c=c|0;a=Dd(a,b);b=x[c+4>>2];x[a+8>>2]=x[c>>2];x[a+12>>2]=b}function QJ(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function GP(a){var b=0;a=y[a+47|0];b=(a<<5)+259|0;a=a>>>27|0;lb=b>>>0<259?a+1|0:a;return b}function Fi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;yJ(a,b,c);hb=d+16|0;return a|0}function yw(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;a=Ur(a,b,c,d);hb=e+16|0;return a}function yf(a,b){var c=0;c=x[b+4>>2]+x[a+4>>2]|0;a=x[a>>2];lb=a+x[b>>2]>>>0<a>>>0?c+1|0:c}function xK(a){a=a|0;var b=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];C[a+4256>>3]=b-L(b)}function wv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0>4){b=5654}else{b=x[(b<<2)+75492>>2]}Vb(a,b)}function wqa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function vH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function pY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;mb[a|0](b,c,d,e,f,g)}function pJ(a){a=a|0;var b=0;x[a>>2]=82404;b=x[a+4>>2];if(b){_b(b);x[a+4>>2]=0}return a|0}function mqa(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=b+8|0;kV(c,a);hb=b+16|0;return x[c>>2]}function hf(a,b){var c=0;a=nl(a,b);c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return a}function Oma(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2];w[b+4>>1]=z[c+4>>1];Dm(b+8|0,c+8|0)}function H4(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;gC(d,b);Vq(a,d);hb=c+16|0}function wl(a){var b=0;if(a>>>0>=2){b=LE(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function te(a){var b=0;b=hb-16|0;hb=b;a=ag(a,b+15|0);hb=b+16|0;return(a?y[b+15|0]:0)&255}function qaa(a,b){a=a|0;b=b|0;a=Aj(a);if(!a){return 1}return mb[x[x[a>>2]+68>>2]](a,b)|0}function pA(a,b,c){if(b){while(1){w[a>>1]=z[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function mN(a,b){var c=0;c=y[a+872|0];if(c&1){v[a+872|0]=c|16;x[a+876>>2]=x[a+876>>2]+b}}function _E(){var a=0;a=Fd(462336);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=65164;x[a+8>>2]=65216}function Vba(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=4&(c|0)!=-1)){Xi(a,b);return}RE(a,b,c)}function SM(a){a=gd(a);gd(a+12|0);gd(a+24|0);gd(a+36|0);gd(a+48|0);x[a+60>>2]=0;return a}function $b(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;NC(d,a,b);a=Ib(d);hb=c+16|0;return a}function xS(a,b,c){a=a|0;b=b|0;c=c|0;a=z[c>>1]|z[c+2>>1]<<16;w[b>>1]=a;w[b+2>>1]=a>>>16}function uO(a,b){var c=0;b=Db(b);c=a;a=x[a>>2];x[c>>2]=a<<8^x[((b^a>>>24)<<2)+86160>>2]}function mi(a,b){var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+$g(b)|0,x[c+4>>2]=d;return a}function ei(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function eX(a){a=a|0;var b=0;b=x[a+4>>2];return(mb[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function ac(a,b){var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+Fb(b)|0,x[c+4>>2]=d;return a}function Rt(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function PR(a,b){var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+IR(b)|0,x[c+4>>2]=d;return a}function Jm(a){var b=0;b=Fv(a+4|0);if((b|0)==-1){mb[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function Bg(a,b,c){a=a|0;b=b|0;c=c|0;return(x[x[a+8>>2]+((c&255)<<2)>>2]&b)!=0&(c|0)>=0}function zO(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function pf(a){var b=0;b=a+24|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function j$(){var a=0;a=Fd(462440);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=66336;Xb(a+16|0)}function bV(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+23408|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function ZF(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;a=bG(a,7037,b);hb=c+16|0;return a}function Vb(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;wt(a,b,Bf(b));hb=c+16|0;return a|0}function PD(a){var b=0;b=a+48|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Nm(a){var b=0;b=a+36|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function hH(a){var b=0;b=fH(x[a>>2]-1|0);if(!b){a=fH(x[a+4>>2]);b=a?a+32|0:0}return b}function et(a,b){if(!(v[b+872|0]&1&x[a+480180>>2]==8)){vy(a,b,0);vy(a,b,1);vy(a,b,2)}}function _M(a,b,c){if(c>>>0>178956970){Be();p()}b=_d(D(c,24),8);x[a+4>>2]=c;x[a>>2]=b}function Yt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function X2(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function W2(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function S$(a,b,c){a=a|0;b=b|0;c=c|0;c=Pw(x[b>>2])<<24;x[a+4>>2]=x[b>>2];v[a|0]=c>>24}function Rg(a){var b=0,c=0;b=hb-16|0;hb=b;c=b+12|0;x[c>>2]=a;hb=b+16|0;return x[c>>2]}function QZ(a){a=a|0;a=461464;while(1){a=xb(a-12|0);if((a|0)!=461296){continue}break}}function OZ(a){a=a|0;a=461640;while(1){a=Pc(a-12|0);if((a|0)!=461472){continue}break}}function MZ(a){a=a|0;a=461936;while(1){a=xb(a-12|0);if((a|0)!=461648){continue}break}}function KZ(a){a=a|0;a=462240;while(1){a=Pc(a-12|0);if((a|0)!=461952){continue}break}}function KF(a,b,c){if(c>>>0>357913941){Be();p()}b=_d(D(c,12),4);x[a+4>>2]=c;x[a>>2]=b}function IZ(a){a=a|0;a=462280;while(1){a=xb(a-12|0);if((a|0)!=462256){continue}break}}function GZ(a){a=a|0;a=462312;while(1){a=Pc(a-12|0);if((a|0)!=462288){continue}break}}function zf(a){a=a|0;var b=0;b=x[a>>2];return(mb[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function p_(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[Gr()+((b&255)<<2)>>2]}return b<<24>>24}function oU(a,b,c){if(c>>>0>715827882){Be();p()}b=_d(D(c,6),1);x[a+4>>2]=c;x[a>>2]=b}function n_(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[Fr()+((b&255)<<2)>>2]}return b<<24>>24}function jL(a,b,c){if(c>>>0>82595524){Be();p()}b=_d(D(c,52),4);x[a+4>>2]=c;x[a>>2]=b}function di(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;ei(a)}function Ot(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=x[a>>2];hb=b+16|0;return x[b+12>>2]}function rC(a,b,c){if(c>>>0>1073741823){Be();p()}b=_d(c<<2,2);x[a+4>>2]=c;x[a>>2]=b}function hS(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,x[a>>2])>>2];hb=b+16|0;return a}function f8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return sJ(a,b,c,d,0,0,0,0,e)|0}function ay(a,b,c){if(c>>>0>1073741823){Be();p()}b=_d(c<<2,4);x[a+4>>2]=c;x[a>>2]=b}function US(a,b,c){if(c>>>0>1073741823){Be();p()}b=_d(c<<2,1);x[a+4>>2]=c;x[a>>2]=b}function NF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[x[x[a>>2]+32>>2]](a,b,c,d)|0}function MF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[x[x[a>>2]+48>>2]](a,b,c,d)|0}function Im(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function DC(a,b,c){if(c>>>0>2147483647){Be();p()}b=_d(c<<1,2);x[a+4>>2]=c;x[a>>2]=b}function $F(a){return(a|0)!=0&(a|0)!=61672&(a|0)!=61696&(a|0)!=460776&(a|0)!=460800}function il(a,b){a=a|0;b=b|0;if(rc(a)>>>0<=b>>>0){dC();p()}return x[a>>2]+(b<<1)|0}function bD(a,b,c){if(c>>>0>536870911){Be();p()}b=_d(c<<3,1);x[a+4>>2]=c;x[a>>2]=b}function Vy(a,b){var c=0;v[a|0]=y[b|0];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c}function Pt(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;a=Ot(b+12|0);hb=b+16|0;return a}function KN(a,b){var c=0;c=b&15;if(c){v[a+850|0]=c}b=b&240;if(b){v[a+849|0]=b>>>4}}function KH(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function xl(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,12);return a}function tz(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,bc(a))>>2];hb=b+16|0;return a}function lU(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,48);return a}function gB(a,b,c){a=a|0;b=b|0;c=c|0;a=y[c|0]|y[c+1|0]<<8;v[b|0]=a;v[b+1|0]=a>>>8}function cl(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,24);return a}function Zi(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,Oj(a))>>2];hb=b+16|0;return a}function ZC(a,b){var c=0;x[a>>2]=x[b>>2];c=a;a=x[b+4>>2];x[c+4>>2]=a;if(a){Km(a)}}function Xn(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,hS(a))>>2];hb=b+16|0;return a}function PO(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,dc(a))>>2];hb=b+16|0;return a}function Oj(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,mc(a))>>2];hb=b+16|0;return a}function Hz(a,b){a=sc(a,b,34);w[a+34>>1]=z[b+34>>1];sc(a+36|0,b+36|0,68);return a}function HP(a){if((y[a+14|0]-53&255)>>>0>=252){a=dd(a,11609,14)}else{a=1}return!a}function sY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=mb[a|0](b,c,d)|0;ib=lb;return a|0}function ne(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<2);return a}function kr(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<3);return a}function bh(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<1);return a}function ZO(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){a=mc(a);if(b){ki(x[a>>2],b,1)}}}function Qm(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<4);return a}function No(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<5);return a}function Kx(a,b){if(Rb(a)>>>0<=b>>>0){a=Rb(a)+Cb(a)>>>0>=b>>>0}else{a=0}return a}function Gq(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,6);return a}function Dm(a,b){var c=0;a=Im(a,b);c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function rY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[a|0](b,c,d,e,f)}function rH(){var a=0;a=hb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function iT(a,b){a=a|0;b=b|0;return x[b+8>>2]==x[a+8>>2]&x[a+12>>2]==x[b+12>>2]}function h1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=hb-16|0;hb=b;RF(a,c,d);hb=b+16|0}function B_(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+65216>>2]&b)!=0&c>>>0<=127}function zZ(a){a=a|0;if(!y[461216]){Um(461204,66448);v[461216]=1}return 461204}function vZ(a){a=a|0;if(!y[461248]){Um(461236,66484);v[461248]=1}return 461236}function uY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[a|0](b,c,d,e)|0}function rda(a,b){a=a|0;b=b|0;return(b>>>0>=4e3?17381:((b<<5)+a|0)+946304|0)|0}function rZ(a){a=a|0;if(!y[461280]){Um(461268,66568);v[461280]=1}return 461268}function pH(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;aH(a,b,c,0,0);hb=d+16|0}function i3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return YH(a-88|0,b,c,d,e)|0}function au(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function Mt(a,b){return mg(oh((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function DZ(a){a=a|0;if(!y[461184]){Um(461172,66412);v[461184]=1}return 461172}function xi(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}_b(b)}function xZ(a){a=a|0;if(!y[461232]){Vb(461220,9340);v[461232]=1}return 461220}function vC(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;uC(d,b);Vq(a,d);hb=c+16|0}function tZ(a){a=a|0;if(!y[461264]){Vb(461252,5224);v[461264]=1}return 461252}function qx(a){var b=0;b=hb-16|0;hb=b;a=x[Bb(b+12|0,a)>>2];hb=b+16|0;return a}function nl(a,b){x[a>>2]=x[b>>2];b=x[b+4>>2];x[a+4>>2]=b;if(b){Km(b)}return a}function ao(a){var b=0;b=hb-16|0;hb=b;a=x[gT(b+12|0,a)>>2];hb=b+16|0;return a}function aZ(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[462888]){v[462888]=1}Hd(a,c,83924)}function UY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(vg(a,x[b+8>>2],0)){$v(b,c,d)}}function Q8(a,b){a=a|0;b=b|0;return E((b|0)<=12?B[((b<<2)+a|0)+4208>>2]:E(0))}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Cs(b,c,d,B[a+28>>2]);wI(a,b,c,d)}function M3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Cs(b,c,d,B[a+28>>2]);tI(a,b,c,d)}function K3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Cs(b,c,d,B[a+24>>2]);rI(a,b,c,d)}function I3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Cs(b,c,d,B[a+24>>2]);pI(a,b,c,d)}function FZ(a){a=a|0;if(!y[461168]){Vb(461156,1755);v[461168]=1}return 461156}function EP(a,b){a=sQ(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function BZ(a){a=a|0;if(!y[461200]){Vb(461188,9540);v[461200]=1}return 461188}function wF(a,b){var c=0,d=0;Ce(a,oe(b));b=x[mc(b)>>2];c=mc(a),d=b,x[c>>2]=d}function u9(a,b){a=a|0;b=b|0;return E((b|0)<=4?B[((b<<2)+a|0)+4208>>2]:E(0))}function py(a,b){if(b){py(a,x[b>>2]);py(a,x[b+4>>2]);mw(mc(a),b+16|0);SL(b)}}function nR(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=gP(a,b);hb=c+16|0;return d?b:a}function n9(a,b){a=a|0;b=b|0;return E((b|0)<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function _8(a,b){a=a|0;b=b|0;return E((b|0)<=1?B[((b<<2)+a|0)+4208>>2]:E(0))}function Zz(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=gP(b,a);hb=c+16|0;return d?b:a}function YX(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Om(a,c+15|0,b);hb=c+16|0}function Qx(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=uu(a,b);hb=c+16|0;return d?b:a}function Nz(a){a=a+4|0;return y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}function N9(a,b){a=a|0;b=b|0;return E((b|0)<=6?B[((b<<2)+a|0)+4208>>2]:E(0))}function Ml(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=uu(b,a);hb=c+16|0;return d?b:a}function KD(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Qi(a,c+15|0,b);hb=c+16|0}function H8(a,b){a=a|0;b=b|0;return E((b|0)<=2?B[((b<<2)+a|0)+4208>>2]:E(0))}function C9(a,b){a=a|0;b=b|0;return E((b|0)<=5?B[((b<<2)+a|0)+4208>>2]:E(0))}function Ad(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];cc(b,c);Hv(a,b,d,c)}function A8(a,b){a=a|0;b=b|0;return E((b|0)<=3?B[((b<<2)+a|0)+4208>>2]:E(0))}function $I(a,b,c,d){x[a+12>>2]=0;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function xh(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function rg(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function l$(){var a=0;a=Fd(462416);w[a+8>>1]=11310;x[a>>2]=66296;Xb(a+12|0)}function dV(a,b){a=a|0;b=b|0;a=x[a>>2];return mb[x[x[a>>2]+36>>2]](a,0,b)|0}function as(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function ZR(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function Q1(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){qE(a,c);return}Vb(a,4152)}function AG(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function x_(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[Gr()+(b<<2)>>2]}return b|0}function wn(a,b){a=x[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function v_(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[Fr()+(b<<2)>>2]}return b|0}function uJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){mb[x[x[c>>2]+4>>2]](c)}}function rX(a){a=a|0;var b=0;b=hb-16|0;hb=b;hc(a);ki(b+15|0,a,1);hb=b+16|0}function pg(a,b){a=a|0;b=b|0;if(so(a,b)){a=Ah(Ye(a,b))}else{a=0}return a|0}function jX(a){a=a|0;var b=0;b=hb-16|0;hb=b;hc(a);dh(b+15|0,a,1);hb=b+16|0}function _g(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function BX(a){a=a|0;var b=0;b=hb-16|0;hb=b;hc(a);Lf(b+15|0,a,1);hb=b+16|0}function BL(a,b){a=a|0;b=b|0;return(b>>>0>15?63:v[x[a+88>>2]+b|0])<<24>>24}function AL(a,b){a=a|0;b=b|0;return(b>>>0>42?63:v[x[a+84>>2]+b|0])<<24>>24}function $3(a){a=a|0;var b=0;b=hb-16|0;hb=b;hc(a);Xt(b+15|0,a,1);hb=b+16|0}function rk(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+12>>2]](a,b,c)|0}function p2(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+32>>2]](a,b,c)|0}function om(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+48>>2]](a,b,c)|0}function daa(a,b){a=a|0;b=b|0;a=x[a+20>>2]+24|0;v[a|0]=y[a|0]&253|(b?2:0)}function cd(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=yo(a,b),x[d>>2]=e}function Mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=gv(a,b),w[d>>1]=e}function Li(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;return a}function BR(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function qT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=kT(a,b),x[d>>2]=e}function SB(a,b){return(y[a|0]|y[a+1|0]<<8)>>>0<(y[b|0]|y[b+1|0]<<8)>>>0}function RG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;_g(a,-1,-1)}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=kT(a,b),v[d|0]=e}function HB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,x[b>>2],rc(b)<<1);hb=c+16|0}function CA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,x[b>>2],Lb(b)<<2);hb=c+16|0}function uc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=Bf(b),x[c+4>>2]=d;return a}function rx(a,b){a=a|0;b=b|0;mb[b|0](x[x[a>>2]-12>>2]+a|0)|0;return a|0}function fI(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function cp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function cE(a){w[a+12>>1]=0;x[a+8>>2]=-1;x[a>>2]=0;x[a+4>>2]=0;return a}function bx(a){return((Wg(a)+(Wg(a)<<8)|0)+(Wg(a)<<16)|0)+(Wg(a)<<24)|0}function GO(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function AO(a){if(a>>>0<=8){return y[a+25728|0]}return y[a+25719|0]|256}function vz(a,b){a=pm(a);gd(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function ny(a,b){C[a>>3]=C[b>>3]+C[a>>3];C[a+8>>3]=C[b+8>>3]+C[a+8>>3]}function lm(a){a=a|0;var b=0;b=hb-16|0;hb=b;hb=b+16|0;return a<<24>>24}function ik(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function gr(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Yv(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function YS(a,b){sk(a,Db(x[b>>2]),Fb(b));a=x[a+4>>2];lb=a>>31;return a}function M1(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){xa();p()}}function Gc(a,b){if(Lb(a)>>>0<=b>>>0){dC();p()}return x[a>>2]+(b<<2)|0}function gp(a,b,c){a=a|0;b=b|0;c=c|0;a=rd(a,b);rd(a+4|0,c);return a|0}function TX(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;RD(a,b);hb=c+16|0}function Sk(a,b){return(x[a+4>>2]-x[b+4>>2]|0)+(x[a>>2]-x[b>>2]<<3)|0}function Ls(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;eR(a,b);hb=c+16|0}function KY(a){a=a|0;if(!a){return 0}return(aw(a,74480,74624)|0)!=0|0}function tY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[a|0](b,c,d)|0}function hN(a,b){return x[(b<<2)+($b(a+1074312|0,7)?30272:30336)>>2]}function gN(a,b){return x[(b<<2)+($b(a+1074312|0,7)?30336:30272)>>2]}function eca(a,b){a=a|0;b=b|0;return y[x[a+84>>2]+b|0]!=63&b>>>0<=42}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2];Zf(b+4|0,c+4|0)}function W3(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2];Jd(b+4|0,c+4|0)}function Py(a,b){return x[(b<<2)+($b(a+1074312|0,7)?30400:31424)>>2]}function Oz(a,b){Ub(a,b);Ub(a+4|0,b+4|0);Ub(yb(a),yb(b));yb(a);yb(b)}function Oy(a,b){return x[(b<<2)+($b(a+1074312|0,7)?31424:30400)>>2]}function M2(a,b){a=a|0;b=b|0;if(!x[114409]){x[114409]=a;x[114410]=b}}function D_(a){a=a|0;var b=0;b=x[115256]+1|0;x[115256]=b;x[a+4>>2]=b}function DP(a,b){a=Jz(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function Be(){var a=0;a=bk(ec(4));x[a>>2]=74888;da(a|0,74996,26);p()}function A$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Zf(a,f)}function yl(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function mA(a,b){if(b){mA(a,x[b>>2]);mA(a,x[b+4>>2]);ki(mc(a),b,1)}}function lN(a,b){x[a+876>>2]=x[a+876>>2]+b;v[a+872|0]=y[a+872|0]|16}function fE(a,b,c,d,e,f,g){return Ga(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function d4(a){a=a|0;var b=0;b=hb-16|0;hb=b;hc(a);II(a,1);hb=b+16|0}function _2(a){a=a|0;var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b|0}function KM(a,b,c,d){x[a+12>>2]=0;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function CL(a,b){a=a|0;b=b|0;return y[x[a+88>>2]+b|0]!=63&b>>>0<=15}function AP(a){a=a|0;x[a>>2]=75520;yh(a+28|0);yh(a+12|0);return a|0}function s_(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function rn(a,b,c){return x[x[a>>2]+(b<<2)>>2]+(x[a+12>>2]+c<<1)|0}function gpa(a){a=a|0;return x[a+16>>2]+(x[a+8>>2]-x[a+20>>2]|0)|0}function ck(a,b,c){a=a|0;b=b|0;c=c|0;b=ME(c);x[a+4>>2]=c;x[a>>2]=b}function UR(a,b){if(b>>>0>214748364){Be();p()}return _d(D(b,20),4)}function UF(a,b,c){a=a|0;b=b|0;c=c|0;return jp(0,a,b,c?c:460828)|0}function Rn(a,b,c){return x[x[a>>2]+(b<<2)>>2]+(x[a+12>>2]+c<<2)|0}function On(a){var b=0;b=x[a+20>>2];if(b){_b(b+-64|0)}x[a+20>>2]=0}function Mh(a,b,c){a=a|0;b=b|0;c=c|0;b=oF(c);x[a+4>>2]=c;x[a>>2]=b}function Ie(a,b){v[a+11|0]=y[a+11|0]&128|b;v[a+11|0]=y[a+11|0]&127}function Hf(a,b,c){a=a|0;b=b|0;c=c|0;return Sc(a,D(Fk(a),b)+c|0)|0}function $O(a,b){var c=0,d=0;c=Bb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function mx(a){a=y[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function gX(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+12>>2]](a)|0}function gQ(a){a=a+34|0;a=sqa(y[a|0]|y[a+1|0]<<8,0,80,0);return a}function fX(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+16>>2]](a)|0}function dI(a){a=a|0;return+(+x[x[a+32>>2]+1074444>>2]*.00390625)}function Zo(a,b,c,d,e){b=Ha(a|0,b|0,c|0,d|0,e|0)|0;lb=ib;return b}function SR(a,b,c,d){a=hf(a,b);w[a+18>>1]=d;w[a+16>>1]=c;return a}function OT(a){a=a+47|0;a=(y[a|0]|y[a+1|0]<<8)-98|0;lb=0;return a}function Nh(a,b){var c=0,d=0;c=a,d=vw(x[b>>2]),x[c>>2]=d;return a}function Lj(a){a=x[a+656>>2];if(!a){return 0}return x[a+44>>2]!=0}function xD(a){if(a>>>0>178956970){Be();p()}return _d(D(a,24),4)}function oZ(a){a=a|0;var b=0,c=0;b=a,c=me(),x[b>>2]=c;return a|0}function hX(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+8>>2]](a)|0}function cga(a,b){a=a|0;b=b|0;vO(a,x[b>>2],x[b+4>>2]);return a|0}function UP(a){var b=0;b=hb-16|0;hb=b;QP(Bb(b+12|0,a));hb=b+16|0}function My(a){xb(a+48|0);xb(a+36|0);xb(a+24|0);xb(a+12|0);xb(a)}function Db(a){a=a|0;var b=0;b=hb-16|0;hb=b;hb=b+16|0;return a|0}function Bda(a,b){a=a|0;b=b|0;a=fw(a,b);x[a>>2]=75116;return a|0}function zw(a,b){a=a|0;b=b|0;return(nh(a)|0)!=0|(a|32)-97>>>0<6}function vn(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function sw(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+12>>2]](a,b)|0}function rq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ue(b,c,d)|0}function rO(a,b){b=1/(564505.8718779281/b+1);oO(a,b,0,0,b+-1,0)}function qW(a,b){a=a|0;b=b|0;a=fw(a,b);x[a>>2]=75224;return a|0}function oj(a){a=a|0;a=x[a>>2];return mb[x[x[a>>2]+24>>2]](a)|0}function oQ(a){if(a>>>0>76695844){Be();p()}return _d(D(a,56),4)}function mY(a,b){a=a|0;b=b|0;a=fw(a,b);x[a>>2]=75172;return a|0}function m8(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function fl(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+28>>2]](a,b)|0}function dK(a){a=a|0;return E(E(E(B[a+4228>>2]*E(198))+E(-99)))}function _w(a){var b=0;b=hb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function YM(a,b){if(b>>>0>134217727){Be();p()}return _d(b<<5,8)}function Oc(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function $r(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+44>>2]](a,b)|0}function yu(a,b){a=a|0;b=b|0;a=lr(a,b);if(!a){XS(b)}return a|0}function xv(a){a=a|0;a=x[a>>2];return mb[x[x[a>>2]+8>>2]](a)|0}function mJ(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function gK(a){a=a|0;x[a>>2]=79136;lg(a+4260|0);return Cf(a)|0}function _q(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function Yz(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,1024);hb=c+16|0}function Mf(a,b){a=a|0;b=b|0;a=Av(a,b);if(!a){$C(b)}return a|0}function ME(a){if(a>>>0>1073741823){Be();p()}return _d(a<<2,4)}function L$(a,b,c){a=a|0;b=b|0;c=c|0;Hd(a,DG(x[b>>2]),x[b>>2])}function Hh(a,b){return mb[x[x[a>>2]+36>>2]](a,x[a+12>>2],b)|0}function HT(a){a=a|0;a=y[a|0];return be(a)^1|(a-49&255)>>>0<36}function BA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,4896);hb=c+16|0}function $U(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,1954);hb=c+16|0}function xga(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,1245)|0}function wP(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,263);hb=c+16|0}function vma(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,xE(c,Rb(b),Cb(b)))}function vE(a,b){if(Cb(a)>>>0<=b>>>0){wm();p()}return pc(a,b)}function sH(a){var b=0;b=hb-16|0;C[b+8>>3]=a;return C[b+8>>3]}function qB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,512);hb=c+16|0}function pba(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,1730)|0}function oba(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,1731)|0}function oR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,130);hb=c+16|0}function nE(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function lR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,600);hb=c+16|0}function jD(a){if(a>>>0>134217727){Be();p()}return _d(a<<5,4)}function iQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,146);hb=c+16|0}function eQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,608);hb=c+16|0}function eC(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,497);hb=c+16|0}function cq(a,b){a=a|0;b=b|0;if(ze(a)>>>0>b>>>0){v[a+16|0]=b}}function cR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,126);hb=c+16|0}function _S(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,674);hb=c+16|0}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;bK(a,0,HA(x[b+24>>2]),c)}function Xba(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,1678)|0}function Wz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function UG(a,b){b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return a}function TD(a){if(a>>>0>268435455){Be();p()}return _d(a<<4,4)}function Su(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,192);hb=c+16|0}function NS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,128);hb=c+16|0}function NP(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,204);hb=c+16|0}function MM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){_b(kg(c))}}function FT(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,157);hb=c+16|0}function EU(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,610);hb=c+16|0}function ED(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){_b(eD(c))}}function Dd(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];return a}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,1239)|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,1240)|0}function AT(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,576);hb=c+16|0}function yY(a,b){a=a|0;b=b|0;a=mb[a|0](b)|0;ib=lb;return a|0}function xs(a){a=a|0;x[a>>2]=59400;xb(a+32|0);return El(a)|0}function wi(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function tO(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,27);hb=c+16|0}function tD(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,10);hb=c+16|0}function tA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,33);hb=c+16|0}function rD(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,14);hb=c+16|0}function qR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,30);hb=c+16|0}function nA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,40);hb=c+16|0}function mV(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,11);hb=c+16|0}function kaa(a){a=a|0;a=Aj(a);if(a){mb[x[x[a>>2]+92>>2]](a)}}function hI(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function fH(a){var b=0,c=0,d=0;return b=rqa(a),c=0,d=a,d?b:c}function eS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,52);hb=c+16|0}function eB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,64);hb=c+16|0}function dr(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,36);hb=c+16|0}function cD(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,20);hb=c+16|0}function aV(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,1954);hb=b+16|0}function aR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,32);hb=c+16|0}function Zu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,65);hb=c+16|0}function WA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,12);hb=c+16|0}function Uc(a){return(a|0)<-32768?-32768:(a|0)>32767?32767:a}function Ub(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function Tx(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function SS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,80);hb=c+16|0}function QB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,38);hb=c+16|0}function OB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,41);hb=c+16|0}function NB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,16);hb=c+16|0}function LT(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,98);hb=c+16|0}function KQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,96);hb=c+16|0}function Jna(a,b,c){a=a|0;b=b|0;c=c|0;return wh(a,b,c,721)|0}function JT(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,48);hb=c+16|0}function Gu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,66);hb=c+16|0}function DL(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,24);hb=c+16|0}function Cu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,22);hb=c+16|0}function zv(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,8);hb=c+16|0}function zk(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){_b(Qf(b))}}function zD(a){var b=0;b=x[a+8>>2];if(b){Lf(a,b,x[a+4>>2])}}function xm(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,2);hb=c+16|0}function sB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,5);hb=c+16|0}function rB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,7);hb=c+16|0}function pR(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,130);hb=b+16|0}function oD(a){var b=0;b=x[a+8>>2];if(b){ki(a,b,x[a+4>>2])}}function mR(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,600);hb=b+16|0}function jQ(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,146);hb=b+16|0}function fr(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,1);hb=c+16|0}function fQ(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,608);hb=b+16|0}function fC(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,497);hb=b+16|0}function dR(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,126);hb=b+16|0}function cv(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,3);hb=c+16|0}function _Y(a,b,c){a=a|0;b=b|0;c=c|0;return ue(a,a+b|0,c)|0}function _C(a,b,c){a=nl(a,b);x[a+12>>2]=c;x[a+8>>2]=0;Ab(b)}function ZS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,192);hb=b+16|0}function YC(a){var b=0;b=x[a+8>>2];if(b){dh(a,b,x[a+4>>2])}}function UA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,6);hb=c+16|0}function OP(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,204);hb=b+16|0}function KT(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,48);hb=b+16|0}
function Ih(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,4);hb=c+16|0}function GT(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,157);hb=b+16|0}function GI(a){var b=0;b=x[a+8>>2];if(b){Xt(a,b,x[a+4>>2])}}function Fv(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function FU(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,610);hb=b+16|0}function BT(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,576);hb=b+16|0}function xY(a,b,c){a=a|0;b=b|0;c=c|0;return mb[a|0](b,c)|0}function nU(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,66);hb=b+16|0}function k_(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function fn(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function fS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,52);hb=b+16|0}function eE(a,b,c){b=Da(2201,a|0,b|0,c|0)|0;lb=ib;return b}function Y5(a){a=a|0;nJ(a,2,100);cq(x[a+24>>2]+484360|0,0)}function Wf(a,b){a=tqa(x[a>>2],x[a+4>>2],b,b>>31);return a}function W4(a){a=a|0;return A[x[a+24>>2]+1074420>>2]/1e4|0}function TS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,80);hb=b+16|0}function RB(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,38);hb=b+16|0}function QC(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,36);hb=b+16|0}function PB(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,41);hb=b+16|0}function OW(a){a=a|0;a=CD(a,9186);x[a>>2]=76216;return a|0}function MT(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,98);hb=b+16|0}function LQ(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,96);hb=b+16|0}function L1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb=0;return 0}function Gl(a,b,c){a=a|0;b=b|0;c=c|0;return mb[c|0](a,b)|0}function GX(a){a=a|0;a=CD(a,4896);x[a>>2]=75872;return a|0}function zo(a,b,c){Hd(a,x[b>>2]+(c>>>3&536870908)|0,c&31)}function se(a,b,c){Hd(a,x[b>>2]+(c>>>3&536870908)|0,1<<c)}function pn(a,b,c){return x[a>>2]+(D(x[a+4>>2],c)+b<<1)|0}function ph(a,b,c){return x[a>>2]+(D(x[a+4>>2],c)+b<<3)|0}function nt(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){_b(c)}}function ix(a,b){return x[((a>>>24^b)<<2)+455904>>2]^a<<8}function Vf(a,b,c){return x[a>>2]+(D(x[a+4>>2],c)+b<<2)|0}function Qo(a){a=wD(a);x[a+8>>2]=0;x[a>>2]=71840;return a}function L4(a){a=a|0;return Jj(Wb(x[a+24>>2]+484360|0))|0}function Kw(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function JI(a){var b=0;b=x[a+8>>2];if(b){II(b,x[a+4>>2])}}function HH(a){while(1){if((us(a)|0)!=-1){continue}break}}function Ej(a){a=x[a+656>>2];if(!a){return 0}return Ri(a)}function zh(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function yi(a){return Ee(a)|Ee(a)<<8|Ee(a)<<16|Ee(a)<<24}function ska(a,b){a=a|0;b=b|0;return XG(a,Rb(b),Cb(b))|0}function qpa(a,b,c){a=a|0;b=b|0;c=c|0;return iV(a,b,c)|0}function pB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function nu(a){Wn(a+88|0);Wn(a+68|0);Wn(a+48|0);return a}function kz(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function iF(){var a=0,b=0;a=Fd(462504),b=69468,x[a>>2]=b}function hF(){var a=0,b=0;a=Fd(462536),b=69964,x[a>>2]=b}function hC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gf(a,c,d,b)}function gF(){var a=0,b=0;a=Fd(462544),b=70128,x[a>>2]=b}function gE(a){a=x[a>>2]-12|0;if((Fv(a+8|0)|0)<0){_b(a)}}function fF(){var a=0,b=0;a=Fd(462552),b=70292,x[a>>2]=b}function f3(a,b,c){a=a|0;b=b|0;c=c|0;return xd(D(b,c))|0}function ena(a,b,c){a=a|0;b=b|0;c=c|0;return hV(a,b,c)|0}function eF(){var a=0,b=0;a=Fd(462560),b=70456,x[a>>2]=b}function e6(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,xE(c,b,Bf(b)))}function dF(){var a=0,b=0;a=Fd(462632),b=70620,x[a>>2]=b}function VW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Hv(a,b,c,d)}function QG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;_g(a,-1,-1)}function PE(a){a=a|0;x[a>>2]=66296;xb(a+12|0);return a|0}function OE(a){a=a|0;x[a>>2]=66336;xb(a+16|0);return a|0}function JX(a,b,c){a=a|0;b=b|0;c=c|0;Hv(a,b,x[b+8>>2],c)}function CT(a){a=a|0;if(!y[a|0]){return 1}return Ff(a)|0}function Bo(a,b,c){if(!b){return 0}return Yq(a,v[c|0],b)}function Bm(a,b,c){a=tqa(x[a>>2],x[a+4>>2],b,c);return a}function $E(a,b){Km(x[b>>2]);Jm(x[a>>2]);x[a>>2]=x[b>>2]}function zr(a){a=a|0;x[a>>2]=75036;gE(a+4|0);return a|0}function yP(a){a=a|0;x[a>>2]=75576;yh(a+4|0);return a|0}function oB(a,b,c){a=a|0;b=b|0;c=c|0;return QU(a,b,c)|0}function o7(a,b,c){a=a|0;b=b|0;c=c|0;return dO(a,b,c)|0}function kp(a){a=a|0;x[a>>2]=59240;Ob(a+4|0);return a|0}function iE(a){a=a|0;x[a>>2]=75016;gE(a+4|0);return a|0}function bF(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Jm(b)}}function _da(a,b){a=a|0;b=b|0;return A[a+12>>2]>b>>>0|0}function Y8(a){a=a|0;RJ(a);v[a+4202|0]=1;x[a+4224>>2]=0}function Wr(a,b,c){return QF(Rb(a),Cb(a),Rb(b),c,Cb(b))}function WC(a){a=a|0;x[a>>2]=76140;Ab(a+4|0);return a|0}function TN(a,b,c){a=a|0;b=b|0;c=c|0;return Xp(a,b,c)|0}function TH(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function So(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function OJ(a){return E(E(B[a+4208>>2]*E(1e4))+E(-1e4))}function NJ(a){return E(E(B[a+4252>>2]*E(19980))+E(20))}function Md(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function LA(a,b,c){a=a|0;b=b|0;c=c|0;return lV(a,b,c)|0}function Ks(a){a=a|0;x[a>>2]=82568;Ex(a+4|0);return a|0}function Hc(a){if(we(a)){a=Di(a)-1|0}else{a=10}return a}function El(a){a=a|0;x[a>>2]=59080;Ob(a+4|0);return a|0}function AE(a,b,c,d){a=SF(a,b,c,0,-2147483648);return a}function $oa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hB(b,c,d)}function zg(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+20>>2]](a,b)}function uj(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function rp(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function qc(a,b){a=a|0;b=b|0;return x[a>>2]!=x[b>>2]|0}function kh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+24>>2]](a,b)}function k1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Fi(a,c,d)}function jh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+28>>2]](a,b)}function h5(a,b){a=a|0;b=b|0;x[x[a+24>>2]+480272>>2]=b}function aK(a){a=a|0;return Si(E(B[a+4224>>2]*E(4)))|0}function Ze(a,b){a=sqa(x[a>>2],x[a+4>>2],b,0);return a}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Wg(a){var b=0;b=us(a);x[a+1396>>2]=0;return b}function Vm(a){if(we(a)){a=Di(a)-1|0}else{a=1}return a}function V1(a){a=a|0;return ae(x[x[a>>2]-12>>2]+a|0)|0}function T1(a){a=a|0;return Pf(x[x[a>>2]-12>>2]+a|0)|0}function NG(a){a=a|0;return hs(x[x[a>>2]-12>>2]+a|0)|0}function Kna(a,b){a=a|0;b=b|0;return Vb(a,b?b:17381)|0}function JG(a){a=a|0;return fs(x[x[a>>2]-12>>2]+a|0)|0}function Iaa(a,b,c){a=a|0;b=b|0;c=c|0;fm(a,b+4260|0,8)}function Cb(a){if(we(a)){return x[a+4>>2]}return Io(a)}function xb(a){if(we(a)){fg(a,x[a>>2],Di(a))}return a}function ti(a){a=a|0;return mb[x[x[a>>2]+12>>2]](a)|0}function so(a,b){a=a|0;b=b|0;return Ne(a)>>>0>b>>>0|0}function si(a){a=a|0;return mb[x[x[a>>2]+16>>2]](a)|0}function saa(a){a=a|0;v[a+4202|0]=1;Ss(a);Sx(a);xK(a)}function mD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function jba(a,b,c){a=a|0;b=b|0;c=c|0;B[b>>2]=B[c>>2]}function jO(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+24}function gf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function fA(a,b){return mb[x[x[a>>2]+36>>2]](a,0,b)|0}function cY(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+48}function Ym(a,b){return mb[x[x[a>>2]+36>>2]](a,b,0)|0}function Xm(a,b){return mb[x[x[a>>2]+52>>2]](a,b,0)|0}function XS(a){var b=0;b=hb-16|0;hb=b;pB(a);hb=b+16|0}function Woa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Uca(a){a=a|0;B[a+12>>2]=1;ZL(a,4);return a|0}function UX(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+36}function UL(){if(!y[455896]){UM(87192,1);v[455896]=1}}function Rz(a){var b=0;b=hb-16|0;hb=b;yb(a);hb=b+16|0}function Ofa(a,b,c){a=a|0;b=b|0;c=c|0;C[b>>3]=C[c>>3]}function Lm(a,b){a=hf(a,b);Sb(a+16|0,0,1040);return a}function K4(a){a=a|0;return lL(x[a+24>>2]+484344|0)|0}function Id(a,b,c){a=a|0;b=b|0;c=c|0;return rd(a,b)|0}function H3(a,b){a=a|0;b=b|0;WN(x[a>>2],b);return a|0}function Cn(a){a=a|0;return mb[x[x[a>>2]+24>>2]](a)|0}function BO(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+12}function $C(a){var b=0;b=hb-16|0;hb=b;Cm(a);hb=b+16|0}function to(a,b,c){a=a|0;b=b|0;c=c|0;w[b>>1]=z[c>>1]}function rqa(a){if(a){return 31-G(a-1^a)|0}return 32}function roa(a){a=a|0;return yL(y[a+3|0],y[a+5|0])|0}function qr(a,b,c){x[a>>2]=x[b>>2];x[a+4>>2]=x[c>>2]}function mla(a,b){a=a|0;b=b|0;return XG(a,b,Bf(b))|0}function cK(a){a=a|0;return E(E(B[a+4216>>2]*E(10)))}function _O(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function X4(a){a=a|0;return x[x[a+24>>2]+1074416>>2]}function Wba(a,b){a=a|0;b=b|0;a=a+24|0;vL(a,b);Gy(a)}function T4(a){a=a|0;return x[x[a+24>>2]+1074424>>2]}function Ql(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2]}function G9(a){a=a|0;return E(E(B[a+4232>>2]*E(20)))}function yc(a,b,c){a=a|0;b=b|0;c=c|0;return Zc(a)|0}function xn(a,b,c){if(!c){return 0}return dd(a,b,c)}function up(a){a=a|0;return z[x[a+24>>2]+480188>>1]}function rt(a){a=a|0;return ot(y[a+3|0],y[a+5|0])|0}function qY(a){a=a|0;a=mb[a|0]()|0;ib=lb;return a|0}function pz(a,b){a=a|0;b=b|0;return ir(a,b,Bf(b))|0}function pO(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function oe(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function ns(a){if(!a){return 0}x[114232]=a;return-1}function m3(a,b,c){a=a|0;b=b|0;c=c|0;aI(a-88|0,b,c)}function lH(a){return mH(a,E(15845632502852868e13))}function kH(a){return mH(a,E(2524354896707238e-44))}function k3(a,b,c){a=a|0;b=b|0;c=c|0;_H(a-88|0,b,c)}function i6(a){a=a|0;a=x[a+4>>2];return(a?a:1518)|0}function g5(a){a=a|0;return x[x[a+24>>2]+480272>>2]}function fm(a,b,c){x[a>>2]=b;x[a+4>>2]=b+c;return a}function dp(a,b){b=x[b>>2];x[a>>2]=b;Km(b);return a}function c9(a){a=a|0;return E(E(B[a+4232>>2]*E(4)))}function _ba(a,b){a=a|0;b=b|0;pj(a+36|0,b);return 1}function Zy(a){a=a|0;return ot(y[a+2|0],y[a+4|0])|0}function Wca(a){a=a|0;kg(83960);_y(83952);xb(83940)}function Ufa(a,b){a=a|0;b=b|0;x[b>>2]=0;x[b+4>>2]=0}function S4(a){a=a|0;return z[x[a+24>>2]+480214>>1]}function Rc(a,b){a=a|0;b=b|0;return dO(a,b,Bf(b))|0}function Pc(a){if(we(a)){ap(x[a>>2],Di(a))}return a}function Oo(a){a=a|0;a=hc(a);mb[x[x[a>>2]>>2]](a)|0}function NC(a,b,c){Hd(a,(c>>>3&536870908)+b|0,1<<c)}function Kl(a){a=a|0;return z[x[a+24>>2]+480192>>1]}function Gs(a){a=a|0;return z[x[a+24>>2]+480190>>1]}function tka(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,24,b)}function o3(a,b,c){a=a|0;b=b|0;c=+c;cI(a-88|0,b,c)}function l3(a,b){a=a|0;b=b|0;return $H(a-88|0,b)|0}function kA(a,b,c){fm(a,x[b+28>>2]+(c<<12)|0,4096)}function j3(a,b){a=a|0;b=b|0;return ZH(a-88|0,b)|0}function cP(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,pz(b,c))}function Wl(a){Oi(a+724|0);Oi(a+736|0);Oi(a+748|0)}function Wi(a,b,c){x[a>>2]=x[b>>2];v[a+4|0]=y[c|0]}function VP(a){a=a|0;return mg(44325e5/+(a>>>0))|0}function Rm(a,b,c){a=a|0;b=b|0;c=c|0;v[b|0]=y[c|0]}function Pq(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,WO(b,c))}function IN(a){return x[a+16>>2]!=(0-x[a+20>>2]|0)}function IH(a,b){wH(a,74);x[a+4>>2]=x[a+4>>2]|b&74}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,33,b)}function Bq(a){return(x[a+480180>>2]&740327453)!=0}function $ma(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,16,b)}function xg(a){return(x[yb(a)>>2]-x[a>>2]|0)/12|0}function wD(a){x[a+4>>2]=0;x[a>>2]=71784;return a}function sja(a,b){a=a|0;b=b|0;return mb[b|0](a)|0}function rm(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,22,b)}function re(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function qv(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,26,b)}function oq(a){return(x[yb(a)>>2]-x[a>>2]|0)/20|0}function mo(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,20,b)}function mh(a,b){a=a|0;b=b|0;return wG(a)^wG(b)^1}function jm(a){return(x[hc(a)>>2]-x[a>>2]|0)/24|0}function jH(a){return(a<<1)+16777216>>>0<16777217}function im(a){return(x[yb(a)>>2]-x[a>>2]|0)/48|0}function hp(a){return(x[hc(a)>>2]-x[a>>2]|0)/12|0}function gm(a){return(x[yb(a)>>2]-x[a>>2]|0)/33|0}function ff(a){return(x[yb(a)>>2]-x[a>>2]|0)/24|0}function ch(a,b){if(we(a)){ee(a,b);return}Ie(a,b)}function bg(a,b){return QF(Rb(a),Cb(a),b,0,Bf(b))}function bC(a){return!dd(a,23298,25)&y[a+34|0]<65}function _l(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function Yma(a,b){a=a|0;b=b|0;return $s(a,b,17)|0}function YG(a,b){if(!a){return 0}return ms(a,b,0)}function XU(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,30,b)}function WH(a,b){ax(x[x[a>>2]-12>>2]+a|0,x[b>>2])}function VG(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function Un(a){return(x[yb(a)>>2]-x[a>>2]|0)/56|0}function Qu(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,64,b)}function Ng(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,32,b)}function NT(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,40,b)}function Kka(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,9,b)}function Ib(a){return(x[a+4>>2]&x[x[a>>2]>>2])!=0}function Hd(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function Du(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,28,b)}function Cg(a,b){a=a|0;b=b|0;return xG(a)^xG(b)^1}function CD(a,b){a=yE(a,b);x[a>>2]=75276;return a}function Bj(a){return(x[yb(a)>>2]-x[a>>2]|0)/52|0}function $k(a,b,c){a=a|0;b=b|0;c=c|0;gf(a,c,12,b)}function zla(a,b){a=a|0;b=b|0;return um(a,b,2)|0}function wz(a,b,c){v[a|0]=y[b|0];v[a+1|0]=y[c|0]}function uq(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function tK(a){a=a|0;yh(a+4208|0);return Cf(a)|0}function oT(a,b){a=a|0;b=b|0;return $s(a,b,32)|0}function nz(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function n3(a,b){a=a|0;b=b|0;return+bI(a-88|0,b)}function koa(a,b){a=a|0;b=b|0;return um(a,b,3)|0}function kD(a,b,c){b=jD(c);x[a+4>>2]=c;x[a>>2]=b}function jB(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0]}function fp(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function bpa(a,b,c){a=a|0;b=b|0;c=c|0;sc(b,c,48)}function ZJ(a){a=a|0;lg(a+4256|0);return Cf(a)|0}function Wx(a){a=a|0;lg(a+4208|0);return Cf(a)|0}function VD(a,b,c){b=TD(c);x[a+4>>2]=c;x[a>>2]=b}function Rb(a){if(we(a)){return x[a>>2]}return a}function Mba(a,b){a=a|0;b=b|0;return $s(a,b,1)|0}function FV(a,b){a=a|0;b=b|0;return $s(a,b,11)|0}function Eh(a){return(xf(a)|0)!=(0-xf(a+12|0)|0)}function Cy(a){x[a+4>>2]=0;x[a+8>>2]=-1;v[a|0]=0}function $i(a){return(x[yb(a)>>2]-x[a>>2]|0)/6|0}function x$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460832))}function w$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460840))}function vt(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function vd(a){return(x[a+4>>2]-x[a>>2]|0)/24|0}function u$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461036))}function tm(a,b){a=a|0;b=b|0;return Hf(a,b,0)|0}function tk(a){a=a|0;return LG(x[a>>2])<<24>>24}function t$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461028))}function sW(a,b){a=a|0;b=b|0;$o(a,b);return a|0}function s$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461044))}function q$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461052))}function p$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461060))}function o$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461076))}function n$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461068))}function m$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461084))}function k$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461092))}function i$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(461100))}function hw(a,b,c,d){a=SF(a,b,c,-1,-1);return a}function h$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460848))}function g$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460856))}function fk(a){return mb[x[x[a>>2]+36>>2]](a)|0}function f$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460864))}function ex(a){var b=0;b=x[a>>2];gg(a);return b}function en(a){return mb[x[x[a>>2]+28>>2]](a)|0}function ej(a,b){a=a|0;b=b|0;return um(a,b,4)|0}function e9(a){a=a|0;return B[a+4212>>2]<E(1)|0}function e$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460872))}function c$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460912))}function b$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460920))}function aj(a){return(x[a+4>>2]-x[a>>2]|0)/48|0}function a$(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460928))}function Z_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460944))}function X_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460952))}function Vk(a){return(x[a+4>>2]-x[a>>2]|0)/33|0}function VQ(a,b){a=a|0;b=b|0;return um(a,b,8)|0}function U_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460960))}function Tn(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function S_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460968))}function Rk(a){return(x[a+4>>2]-x[a>>2]|0)/56|0}function R_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460880))}function Q_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460888))}function O_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460896))}function Mg(a,b){a=a|0;b=b|0;uG(a,x[a+16>>2]|b)}function M_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460904))}function Lg(a){return(x[a+4>>2]-x[a>>2]|0)/52|0}function K_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460976))}function J_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460984))}function I9(a){a=a|0;return B[a+4220>>2]<E(1)|0}function Ac(a){return(x[a+4>>2]-x[a>>2]|0)/12|0}function $_(a,b){a=a|0;b=b|0;Kd(a,b,Ed(460936))}function yk(a){return(x[a+4>>2]+x[a>>2]|0)-1|0}function xO(a){wO(a);Sb(a+27|0,0,255);return a}function s9(a){a=a|0;v[a+4202|0]=1;WJ(a);VJ(a)}function rT(a){a=a|0;return(y[a+1|0]==1?1:2)|0}function ng(a){return(x[a+4>>2]-x[a>>2]|0)/6|0}function mq(a,b){return(D(b,104)+a|0)+484380|0}function jc(a,b,c){a=a|0;b=b|0;c=c|0;fm(a,b,c)}function fZ(a,b,c){a=a|0;b=b|0;c=c|0;Hd(a,c,b)}function bt(a,b){return(x[a>>2]-x[b>>2]|0)/6|0}function af(a,b,c){if(!(y[a|0]&32)){Ww(b,c,a)}}function Zh(a){return(x[a+8>>2]|x[a+12>>2])!=0}function YT(a){return x[a>>2]+(x[a+4>>2]<<2)|0}function Xk(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function O8(a){a=a|0;PJ(a);Mx(a);v[a+4202|0]=1}function He(a){return x[a+20>>2]!=0&x[a>>2]!=0}function Ft(a){return(a>>>0<9?a:a-9|256)&65535}function A9(a){a=a|0;v[a+4202|0]=1;_J(a);$J(a)}function zc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function vqa(a,b,c,d){a=qqa(a,b,c,d);return a}function vD(a){a=a|0;x[a>>2]=75892;return a|0}function uU(a){v[a+12|0]=y[a+12|0]|2;return a}function qG(a){a=vI(a);x[a>>2]=59740;return a}function qF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function oC(a,b){a=a|0;b=b|0;return ev(a,b)|0}function nD(a){a=a|0;x[a>>2]=75996;return a|0}function iB(a,b){a=a|0;b=b|0;return Av(a,b)|0}function dj(a,b){a=a|0;b=b|0;return qU(a,b)|0}function dg(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function bk(a){a=un(a);x[a>>2]=74868;return a}function Yi(a,b){a=a|0;b=b|0;return Hb(a,b)|0}function Yaa(a,b,c){a=a|0;b=b|0;c=c|0;yq(b,c)}function XC(a){a=a|0;x[a>>2]=76100;return a|0}function VN(a,b){a=a|0;b=b|0;return ud(a,b)|0}function U1(a){a=a|0;zG(x[x[a>>2]-12>>2]+a|0)}function S1(a){a=a|0;yG(x[x[a>>2]-12>>2]+a|0)}function Ria(a){a=a|0;Ez(a+288|0);jq(a+800|0)}function Ri(a){return(y[a+31|0]-1&255)>>>0<17}function Pv(a,b){a=a|0;b=b|0;return pz(a,b)|0}function Po(a){x[a>>2]=0;x[a+4>>2]=0;return a}function PN(a,b){if(!(B[a>>2]<=b)){B[a>>2]=b}}function Mka(a){a=a|0;XQ(a);return x[a+16>>2]}function MS(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function MG(a){a=a|0;Qw(x[x[a>>2]-12>>2]+a|0)}function Jt(a,b){a=a|0;b=b|0;return Zf(a,b)|0}function IG(a){a=a|0;Ow(x[x[a>>2]-12>>2]+a|0)}function Hx(a){a=a|0;x[a>>2]=82436;return a|0}function Hb(a,b){a=a|0;b=b|0;return Zs(a,b)^1}function HI(a){a=a|0;x[a>>2]=82696;return a|0}function Fh(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function Fd(a){a=wD(a);x[a>>2]=66624;return a}function FN(a){EN(a+20|0);dN(a+8|0);kg(a+4|0)}function FI(a){a=a|0;x[a>>2]=82736;return a|0}function Et(a,b){a=a|0;b=b|0;return WO(a,b)|0}function Es(a){a=vI(a);x[a>>2]=59464;return a}function Eoa(a,b,c){a=a|0;b=b|0;c=c|0;hf(b,c)}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;Jz(b,c)}function Coa(a,b,c){a=a|0;b=b|0;c=c|0;Dm(b,c)}function Bk(a){return x[yb(a)>>2]-x[a>>2]>>11}function sd(a){return x[yb(a)>>2]-x[a>>2]>>2}function pna(a,b){a=a|0;b=b|0;Hq(Sb(b,0,48))}function pE(a,b,c){a=a|0;b=b|0;c=c|0;qE(a,c)}function lk(a){return Rg(Rb(a)+(Cb(a)<<2)|0)}function lj(a){return x[yb(a)>>2]-x[a>>2]>>3}function li(a){return x[yb(a)>>2]-x[a>>2]>>4}function gy(a,b){return D((b-a|0)/6|0,6)+a|0}function _f(a){return x[yb(a)>>2]-x[a>>2]>>1}function V4(a){a=a|0;return QI(x[a+24>>2])|0}function Ux(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function U2(a){a=a|0;return Ta(x[a+60>>2])|0}function Ska(a){a=a|0;XQ(a);return x[a+4>>2]}function Qv(a){return x[hc(a)>>2]-x[a>>2]>>4}function Qi(a,b,c){a=a|0;b=b|0;c=c|0;At(a,c)}function PF(a,b,c){a=a|0;b=b|0;c=c|0;Jd(b,c)}function Nx(a){return E(E(a*E(7900))+E(100))}function MA(a,b,c){a=a|0;b=b|0;c=c|0;eJ(a,c)}function Hg(a){return x[x[a+8>>2]>>2]==(a|0)}function Gh(a){return x[yb(a)>>2]-x[a>>2]>>5}function Ev(a){return x[hc(a)>>2]-x[a>>2]>>5}function Eg(a){return x[hc(a)>>2]-x[a>>2]>>2}function EA(a,b,c){a=a|0;b=b|0;c=c|0;Zf(b,c)}function Co(a){return x[hc(a)>>2]-x[a>>2]>>1}function xf(a){return x[a+4>>2]-x[a>>2]>>11}function wH(a,b){x[a+4>>2]=x[a+4>>2]&(b^-1)}function tf(a){return x[yb(a)>>2]-x[a>>2]|0}function gn(a){a=a|0;DG(x[a>>2]);return a|0}function fK(a){a=a|0;mb[x[x[a>>2]+4>>2]](a)}function eK(a){a=a|0;return E(B[a+4208>>2])}function df(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function d9(a){a=a|0;return E(B[a+4220>>2])}function cg(a,b,c){return Ia(a|0,b|0,c|0)|0}function b3(a){a=a|0;wH(a,16384);return a|0}function a3(a){a=a|0;ax(a,16384);return a|0}function VF(){return(x[x[114276]>>2]?4:1)|0}function Q2(a,b){a=a|0;b=b|0;return nh(a)|0}function PA(a){return x[hc(a)>>2]-x[a>>2]|0}function Ji(a,b){a=a|0;b=b|0;return E(E(0))}function H9(a){a=a|0;return E(B[a+4212>>2])}function Eaa(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function Dl(a){a=a|0;Pw(x[a>>2]);return a|0}function BJ(a){return _h(E(DJ(a)*E(32768)))}function AM(a){return a>>>0<=255&a>>>0>=251}function ze(a){return x[a+4>>2]-x[a>>2]>>5}function yaa(a,b){a=a|0;b=b|0;Sb(b,0,2048)}function xB(a){return y[a+1|0]==2&y[a|0]<3}function tw(a){a=a|0;return ih(a,461092)|0}function sf(a){x[a>>2]=x[a>>2]+16;return a}function s4(a,b){a=a|0;b=b|0;return b-a>>3}function rc(a){return x[a+4>>2]-x[a>>2]>>1}function qw(a){a=a|0;return ih(a,461100)|0}function qd(a){return x[a+4>>2]-x[a>>2]>>4}function pr(a){rr(a+28|0);Ab(a+12|0);xb(a)}function n2(a){a=a|0;return ih(a,460864)|0}function mu(a,b){return x[a>>2]-x[b>>2]>>2}function mH(a,b){return E(_w(a?E(-b):b)*b)}function kQ(a){x[a>>2]=x[a>>2]+56;return a}function ida(a,b){a=a|0;b=b|0;pj(a+40|0,b)}function hk(a,b){mb[x[x[b>>2]+44>>2]](a,b)}function gw(){da(bk(ec(4))|0,74984,26);p()}function gk(a,b){mb[x[x[b>>2]+32>>2]](a,b)}function dm(a){x[a>>2]=x[a>>2]+52;return a}function dk(a){x[a>>2]=x[a>>2]+12;return a}function cqa(a,b){a=a|0;b=b|0;pj(a+12|0,b)}function bj(a){x[a>>2]=x[a>>2]+24;return a}function _9(a,b,c){a=a|0;b=b|0;c=c|0;Po(a)}function Zt(a){ge(a+24|0);de(a+12|0);de(a)}function YI(a,b){a=a|0;b=b|0;Nw(a,x[b>>2])}function Y4(a){a=a|0;return+EM(x[a+24>>2])}function Wu(a){a=a|0;return ih(a,461036)|0}function Tg(a){return x[a+4>>2]-x[a>>2]>>3}function N5(a,b){a=a|0;b=b|0;Nw(a,z[b>>1])}function Mo(a){x[a>>2]=x[a>>2]+32;return a}function Lw(a){a=a|0;return ih(a,461028)|0}function Lba(a,b){a=a|0;b=b|0;Zf(a,b+36|0)}function Lb(a){return x[a+4>>2]-x[a>>2]>>2}function Jw(a){a=a|0;return ih(a,461044)|0}function Jr(a,b){mb[x[x[b>>2]+40>>2]](a,b)}function Jq(a,b){return x[a>>2]-x[b>>2]>>1}function Ik(a){xb(a+36|0);Me(a+24|0);hm(a)}function HJ(a){return E(E(a*E(96))+E(-96))}function Fs(a){return(a|0)<=65535&(a|0)>=0}function Di(a){return x[a+8>>2]&2147483647}function Cw(a){a=a|0;return ih(a,461052)|0}function B2(a){a=a|0;return ih(a,460848)|0}function AX(a){a=a|0;return x[a+4>>2]!=0|0}function zm(a,b){return x[a>>2]-x[b>>2]|0}function xc(a){return x[a+4>>2]-x[a>>2]|0}function x3(a,b){a=a|0;b=b|0;kI(a-88|0,b)}function v3(a,b){a=a|0;b=b|0;jI(a-88|0,b)}function ud(a,b){return x[a>>2]+D(b,12)|0}function sx(a){a=a|0;Js(a+8|0);return a|0}function rd(a,b){x[a>>2]=x[b>>2];return a}function ke(a){x[a>>2]=x[a>>2]+2;return a}function je(a){x[a>>2]=x[a>>2]+4;return a}function iA(a,b){return x[a>>2]+D(b,20)|0}function hs(a){a=a|0;lh(a+8|0);return a|0}function ho(a){return z[a+480190>>1]<3999}function hg(a){x[a>>2]=x[a>>2]-4;return a}function h3(a,b){a=a|0;b=b|0;XH(a-88|0,b)}function fs(a){a=a|0;lh(a+4|0);return a|0}function dE(a){a=Aa(a|0)|0;lb=ib;return a}function am(a,b){return x[a>>2]+D(b,56)|0}function _s(a,b,c){return w[b>>1]<w[c>>1]}function Ye(a,b){return x[a>>2]+D(b,52)|0}function X5(a,b){a=a|0;b=b|0;Nw(a,y[b|0])}function WZ(a,b){a=a|0;b=b|0;Zf(a,b+16|0)}function WO(a,b){return ir(a,Rb(b),Cb(b))}function Vc(a,b){return x[a>>2]+D(b,24)|0}function Saa(a){a=a|0;SU(a,80,150,80,255)}function QL(a,b){_l(a,C[b>>3],-C[b+8>>3])}function PI(a,b){a=a|0;b=b|0;Zf(a,b+12|0)}function MC(a){return(y[a+24|0]&16)>>>4|0}function KS(a,b){return x[a>>2]+D(b,33)|0}function Ho(a,b,c){return z[b>>1]<z[c>>1]}function GJ(a){a=a|0;Sb(a+4296|0,0,81928)}function Fc(a,b){a=a|0;b=b|0;dp(a,b+28|0)}function Ch(a){x[a>>2]=x[a>>2]-2;return a}function Bl(a){a=a|0;return EG(x[a>>2])|0}function An(a){return x[x[a+48>>2]+12>>2]}function Am(a,b){return x[a>>2]+(b<<11)|0}function $2(a){a=a|0;if(a){MH(a);ie(a,a)}}function wc(a,b){return x[a>>2]+(b<<4)|0}function vc(a,b){return x[a>>2]+(b<<1)|0}function u3(a,b){a=a|0;b=+b;iI(a-88|0,b)}function s3(a,b){a=a|0;b=+b;gI(a-88|0,b)}function qk(a){return(a|0)==32|a-9>>>0<5}function q3(a,b){a=a|0;b=+b;eI(a-88|0,b)}function pu(a){a=a|0;return x[a>>2]+14|0}function ol(a,b){return x[a>>2]+(b<<3)|0}function nK(a){return(y[a+24|0]&8)>>>3|0}function kqa(a,b){a=a|0;b=b|0;Hd(a,b,11)}function kd(a){return x[a>>2]==x[a+4>>2]}function iJ(a){return(Rb(a)+Cb(a)|0)-1|0}function dv(a,b){return x[a>>2]+(b<<5)|0}function ds(a,b){x[a+24>>2]=x[a+24>>2]+b}function cn(a){return a-97>>>0<26?a&95:a}function bw(a){return a-462912>>>2&65535}function _F(a){return a-65>>>0<26?a|32:a}function Zs(a,b){return x[a>>2]==x[b>>2]}function UZ(a,b){a=a|0;b=b|0;Um(a,66368)}function Sc(a,b){return x[a>>2]+D(b,6)|0}function SZ(a,b){a=a|0;b=b|0;Um(a,66388)}function Pb(a,b){return x[a>>2]+(b<<2)|0}function Nf(a){a=a|0;return!x[a+16>>2]|0}function M8(a){a=a|0;return x[a+4260>>2]}function Ko(a){return D(cr(a),Qe(a))&255}function Kma(a,b){a=a|0;b=b|0;Hd(a,b,17)}function Jpa(a,b){a=a|0;b=b|0;Hd(a,b,44)}function Jka(a,b){a=a|0;b=b|0;Hd(a,b,10)}function Jb(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function Hn(a){a=a|0;return DN(y[a|0])|0}function Fk(a){return z[An(a)+480188>>1]}function Ff(a){a=a|0;return be(y[a|0])|0}function Daa(a){a=a|0;return y[a+4201|0]}function Caa(a){a=a|0;return y[a+4202|0]}function B3(a){a=a|0;return sx(a-88|0)|0}function AD(a,b){Ub(a,b);Ub(a+4|0,b+4|0)}function zN(a,b){return(Pk(a,b)|0)!=255}function w3(a){a=a|0;IH(a,8);return a|0}function uu(a,b){return B[a>>2]<B[b>>2]}function uT(a,b){x[a>>2]=x[a>>2]+D(b,6)}function q8(a){a=a|0;return(a|0)==277|0}function oka(a,b){a=a|0;b=b|0;Hd(a,b,5)}function nf(a){return Rg(Rb(a)+Cb(a)|0)}function kE(a){return(z[a+2>>1]<<2)+a|0}function ie(a,b){if(!x[a+80>>2]){_b(b)}}function cV(a,b){a=a|0;b=b|0;return b|0}function bz(a,b,c){return a<b?b:a>c?c:a}function bS(a,b){x[a>>2]=x[a>>2]+(b<<2)}function az(a,b,c){return a<b?b:a>c?c:a}function ZY(a){a=a|0;if(a){nE(dw(a),1)}}function Xw(a){return(q(a),j(2))>>>20|0}function Xq(a,b){a=a|0;b=b|0;Hd(a,b,32)}function VZ(a,b){a=a|0;b=b|0;Vb(a,7160)}function Tt(a,b){return C[a>>3]<C[b>>3]}function TZ(a,b){a=a|0;b=b|0;Vb(a,7277)}function Sm(a,b,c){return Fi(a,b,b+c|0)}function Qfa(a,b){a=a|0;b=b|0;_l(b,0,0)}function Oi(a){x[a+4>>2]=0;x[a+8>>2]=-1}function Nu(a){a=a|0;return $A(rc(a))|0}function Nq(a,b){return x[a>>2]<x[b>>2]}function MO(a,b){x[a>>2]=x[a>>2]+(b<<1)}function Go(a,b){return A[a>>2]<A[b>>2]}function D3(a){a=a|0;IH(a,2);return a|0}function CF(a,b){a=a|0;b=b|0;Qj(a,1,45)}function BF(a,b){a=a|0;b=b|0;LF(a,1,45)}function yj(a,b){return Rb(a)+(b<<2)|0}function x8(a){a=a|0;return-2013527448}function t3(a){a=a|0;return+hI(a-88|0)}function sT(a,b){a=a|0;b=b|0;Os(a,0,b)}function r3(a){a=a|0;return+fI(a-88|0)}function p3(a){a=a|0;return+dI(a-88|0)}function jt(a){a=a|0;return 2147483647}function iv(a){yb(a);return 2147483647}function faa(a){a=a|0;return 542066252}function f5(a){a=a|0;return+C[a+16>>3]}function el(a){return D(x[a>>2],Ko(a))}function dX(a){a=a|0;return x[a+16>>2]}function be(a){return(a-1&255)>>>0<120}function bJ(a){x[a>>2]=82608;return a}
function ax(a,b){x[a+4>>2]=x[a+4>>2]|b}function _V(a){a=a|0;return x[a+12>>2]}function Sia(a){a=a|0;tP(a);return a|0}function Qe(a){return y[a+34|0]&64?2:1}function QV(a){a=a|0;return x[a+24>>2]}function Pja(a){a=a|0;return y[a+40|0]}function KI(a){return a?(a|0)==2?3:2:1}function H2(a){a=a|0;return x[a+20>>2]}function Fz(a,b){a=a|0;b=b|0;x[b>>2]=0}function EC(a,b){a=a|0;b=b|0;w[b>>1]=0}function Bc(a){x[x[a+8>>2]>>2]=x[a>>2]}function zJ(a,b){a=a|0;b=b|0;return 0}function z9(a){a=a|0;return-285139079}function z1(a){a=a|0;return lG(a,1)|0}function xw(a){a=a|0;if($F(a)){_b(a)}}function xu(a){return(y[a+16|0]&5)!=0}function xC(a){return y[a+22|0]>>>7|0}function we(a){return y[a+11|0]>>>7|0}function vu(a){a=a|0;return x[a+4>>2]}function vq(a){x[a>>2]=75808;return a}function vI(a){x[a>>2]=60512;return a}function un(a){x[a>>2]=74908;return a}function tq(a){a=a|0;ou(a);return a|0}function sA(a){a=a|0;return x[a+8>>2]}function r9(a){a=a|0;return-284078960}function pv(a){return y[a+21|0]>>>7|0}function o8(a,b){a=a|0;b=b|0;return 3}function nI(a){x[a>>2]=83360;return a}function nH(a){a=E(a-a);return E(a/a)}function n8(a,b){a=a|0;b=b|0;return 2}function mI(a){x[a>>2]=83384;return a}function mE(a,b){a=a|0;b=b|0;ra();p()}function ko(a,b){w[a+8>>1]=b;return a}function j9(a){a=a|0;return-281111764}function is(a,b){a=a|0;b=b|0;return-1}function f9(a){a=a|0;return-271958638}function cr(a){return v[a+34|0]&1?2:1}function bP(a){a=a|0;$Q(a);return a|0}function Yd(a,b){v[a+4|0]=0;x[a>>2]=b}function X8(a){a=a|0;return-620920304}function Wb(a){return dv(a,y[a+16|0])}function Vx(a,b){a=a|0;b=b|0;return 1}function Uh(a,b,c){Jd(Jd(a,b)+12|0,c)}function Sla(a){a=a|0;return y[a+8|0]}function SQ(a,b,c){ue(a,(b<<2)+a|0,c)}function QI(a){return z[a+1074438>>1]}function Oe(a,b){x[a+4>>2]=b;return a}function N8(a){a=a|0;return-275227023}function Ku(a){return(a|0)>=120?120:a}function J9(a){a=a|0;return-270114148}function I1(a){a=a|0;return oG(a,0)|0}function HA(a){return x[a+1304496>>2]}function H1(a){a=a|0;return oG(a,1)|0}function Epa(a,b){a=a|0;b=b|0;Dr(a,b)}function E8(a){a=a|0;return 302837129}function Ds(a){x[a>>2]=82888;return a}function B1(a){a=a|0;return lG(a,0)|0}function AA(a){a=a|0;return Qb(a,1)^1}function $D(a,b){return y[a|0]<y[b|0]}function vo(a,b){rc(a);cC(a,b);uo(a)}function uv(a,b){xc(a);HC(a,b);iq(a)}function rv(a,b){Lb(a);sC(a,b);sg(a)}function rM(a,b){Lb(a);NL(a,b);sg(a)}function pL(a,b){Lg(a);sM(a,b);nL(a)}function oA(a,b){xc(a);_T(a,b);iq(a)}function mfa(a){a=a|0;return oj(a)|0}function lt(a){return(a|0)<0?0-a|0:a}function ld(a,b){return Am(a+12|0,b)}function kV(a,b){a=a|0;b=b|0;jV(a,b)}function ep(a,b){a=a|0;b=b|0;mw(a,b)}function eh(a){return x[a+4>>2]-32|0}function cw(a){return(a<<2)+462912|0}function cka(a){a=a|0;return Kz(a)|0}function aqa(a){a=a|0;return xv(a)|0}function _x(a,b){Lb(a);bT(a,b);sg(a)}function Z9(a,b,c){a=a|0;b=b|0;c=c|0}function YZ(a){a=a|0;return v[a+8|0]}function XZ(a){a=a|0;return v[a+9|0]}function T9(a,b){a=a|0;b=b|0;Jt(a,b)}function RI(a){return x[a+4>>2]-48|0}function OI(a){return x[a+4>>2]-12|0}function NO(a,b){ze(a);KO(a,b);Iv(a)}function Mu(a){return x[a+4>>2]-24|0}function Mfa(a){a=a|0;return Uz(a)|0}function Km(a){x[a+4>>2]=x[a+4>>2]+1}function Kca(a){a=a|0;return Xh(a)|0}function JA(a,b){ng(a);$S(a,b);QS(a)}function Ina(a){a=a|0;return HA(a)|0}function FQ(a){return x[a+4>>2]-56|0}function EJ(a){x[a>>2]=0;x[a+4>>2]=0}function DN(a){return(a+5&255)>>>0<2}function Cba(a){a=a|0;return $x(a)|0}function CK(a){return x[a>>2]-2048|0}function At(a,b){a=a|0;b=b|0;Zf(a,b)}function $t(a){return x[yb(a)>>2]<<5}function yt(a,b,c){return fz(a,b,c)}function yC(a){return y[a+22|0]&127}function wu(a){a=a|0;return vh(a)|0}function vG(a){a=a|0;return zr(a)|0}function tL(a){a=a|0;return Yg(a)|0}function rga(a,b){a=a|0;b=b|0;Qk(b)}function po(a){a=a|0;return cj(a)|0}function pQ(a){a=a|0;return NA(a)|0}function pC(a){v[a+2|0]=0;w[a>>1]=0}function mt(a){return Pp(a)<<24>>24}function lka(a,b){a=a|0;b=b|0;Zt(b)}function kS(a){a=a|0;return pu(a)|0}function hr(a){a=a|0;return te(a)|0}function hD(a){a=a|0;return Fm(a)|0}function hA(a,b){return Le(a,0-b|0)}function gx(a){return!dd(a,83460,6)}function eP(a,b){return Pn(a,0-b|0)}function dc(a){return Rg(x[a+4>>2])}function cf(a){return x[a+24620>>2]}function ada(a,b){a=a|0;b=b|0;Ik(b)}function _ca(a,b){a=a|0;b=b|0;Xf(b)}function _X(a){a=a|0;return tH(a)|0}function Zk(a){a=a|0;return Zc(a)|0}function ZD(a){a=a|0;return x[a>>2]}function Yq(a,b,c){return Zw(a,b,c)}function W8(a){a=a|0;x[a+4224>>2]=0}function V2(a){a=a|0;return xu(a)|0}function Ui(a,b){return D(b,12)+a|0}function TT(a){a=a|0;return Pm(a)|0}function SG(a){a=a|0;return lh(a)|0}function RP(a){if(!y[a+4|0]){QP(a)}}function Pma(a,b){a=a|0;b=b|0;ES(b)}function LC(a){a=a|0;return tg(a)|0}function KX(a){a=a|0;return Kf(a)|0}function Ir(a){a=a|0;return ek(a)|0}function Io(a){return y[a+11|0]&127}function Ifa(a,b){a=a|0;b=b|0;ge(b)}function IU(a){a=a|0;return Wj(a)|0}function Fj(a){return x[a+4>>2]-4|0}function Ffa(a,b){a=a|0;b=b|0;bu(b)}function Cc(a,b){return x[a>>2]+b|0}function Bb(a,b){x[a>>2]=b;return a}function BK(a){x[a>>2]=x[a>>2]-2048}function AC(a){return y[a+21|0]&127}function $n(a,b,c){return Ho(a,b,c)}function $X(a){a=a|0;return Re(a)|0}function yF(a){return ih(a,460920)}function xF(a){return ih(a,460912)}function wX(a,b){a=a|0;b=b|0;pr(b)}function vh(a){return x[a>>2]+16|0}function uW(a,b){a=a|0;b=b|0;pC(b)}function uF(a){return ih(a,460936)}function tF(a){return ih(a,460928)}function sn(a,b){x[a+1304560>>2]=b}function ru(a,b){a=a|0;b=b|0;pB(b)}function ro(a,b){a=a|0;b=b|0;qe(b)}function qM(a,b){x[a>>2]=x[a>>2]+b}function qH(a){C[(hb-16|0)+8>>3]=a}function px(a){a=a|0;v[a+6152|0]=0}function lq(a,b){zo(a,b,x[b+4>>2])}function jk(a,b){a=a|0;b=b|0;Xb(a)}function ji(a,b){return(b-a|0)+a|0}function jY(a,b){a=a|0;b=b|0;cE(b)}function iw(a,b){a=a|0;b=b|0;Zc(b)}function gU(a){return x[a>>2]-48|0}function ek(a){return x[a>>2]-12|0}function e3(a,b){a=a|0;b=b|0;_b(b)}function cj(a){return x[a>>2]-24|0}function bs(a){return re(a,-1)?0:a}function aD(a,b){a=a|0;b=b|0;Cm(b)}function Yu(a){v[a|0]=0;v[a+1|0]=0}function X3(a,b){a=a|0;b=b|0;Vi(b)}function Ug(a,b){x[a>>2]=x[a>>2]|b}function Pm(a){return x[a>>2]-16|0}function PV(a,b){a=a|0;b=b|0;ii(b)}function Kz(a){return x[a>>2]-56|0}function Kr(a,b){a=a|0;b=b|0;Dg(a)}function Jn(a,b){return(b<<13)+a|0}function Ii(a){a=a|0;v[a+4202|0]=0}function Fm(a){return x[a>>2]-32|0}function Ei(a,b){Hd(a,Rb(b),Cb(b))}function EB(a,b){a=a|0;b=b|0;Yu(b)}function DS(a){return x[a>>2]-33|0}function CB(a,b){a=a|0;b=b|0;Ab(b)}function Bz(a,b){a=a|0;b=b|0;qf(b)}function Bi(a){return kd(a+36|0)^1}function $x(a){return x[a>>2]-52|0}function yB(a,b){return um(a,b,7)}function xA(a){return x[a>>2]-6|0}function wda(a){a=a|0;Og(a,Jj(a))}function vv(a){return v[a+24|0]&1}function uR(a,b){return(b<<4)+a|0}function ql(a){x[a>>2]=x[a>>2]-16}function pc(a,b){return Rb(a)+b|0}function pK(a){return a+1074332|0}function nh(a){return a-48>>>0<10}function nQ(a){x[a>>2]=x[a>>2]-56}function lo(a){x[a>>2]=2;return a}function gi(a){x[a>>2]=1;return a}function gL(a){x[a>>2]=x[a>>2]-52}function fd(a,b){return(b<<1)+a|0}function fU(a){x[a>>2]=x[a>>2]-48}function ef(a,b){return(b<<2)+a|0}function bc(a){return Rg(x[a>>2])}function aY(a){a=a|0;go(a,1,9299)}function _v(a,b){return x[a+b>>2]}function Zc(a){x[a>>2]=0;return a}function Yl(a){w[a>>1]=0;return a}function Yg(a){return x[a>>2]-4|0}function Wj(a){return x[a>>2]-2|0}function Ve(a){return x[mc(a)>>2]}function Uz(a){return x[a>>2]-8|0}function RA(a,b){return Rd(a,b)^1}function Ne(a){return Lg(a)&65535}function NA(a){return x[a>>2]-1|0}function Kp(a){yh(a+4|0);return a}function Kh(a){x[a>>2]=x[a>>2]-12}function Jg(a){x[a>>2]=x[a>>2]-24}function Gx(a,b){return qy(a,b)^1}function Gka(a){a=a|0;mS(a,65535)}function En(a){return a+1074328|0}function Em(a){x[a>>2]=x[a>>2]-32}function CS(a){x[a>>2]=x[a>>2]-33}function CR(a,b){return um(a,b,5)}function BB(a,b){return oV(a,b,7)}function Ax(a){return a+1304500|0}function AB(a){return y[a+1|0]==1}function yd(a){return x[a>>2]!=0}function wg(a,b){x[a>>2]=x[b>>2]}function wA(a){x[a>>2]=x[a>>2]-6}function vQ(a){Un(a);Rk(a);Un(a)}function ut(a){xc(a);eU(a);iq(a)}function uM(a){Bj(a);Lg(a);Bj(a)}function sr(a){ze(a);FD(a);Iv(a)}function rl(a){li(a);qd(a);li(a)}function ri(a){xg(a);Ac(a);xg(a)}function q_(a){a=a|0;ZE(a);_b(a)}function og(a){ff(a);vd(a);ff(a)}function nS(a,b){sc(a,b+4|0,256)}function jz(a){x[a>>2]=x[a>>2]+8}function jr(a){lj(a);Tg(a);lj(a)}function io(a){tf(a);xc(a);tf(a)}function ij(a){_f(a);rc(a);_f(a)}function iU(a){im(a);aj(a);im(a)}function i2(a){a=a|0;kp(a);_b(a)}function h_(a){a=a|0;pF(a);_b(a)}function gg(a){x[a>>2]=x[a>>2]+1}function dy(a){Lg(a);tM(a);nL(a)}function cz(a){v[a|0]=0;return a}function ct(a){return AM(y[a|0])}function cZ(a){a=a|0;return 9007}function bZ(a){a=a|0;return 6267}function bB(a){aj(a);zU(a);yU(a)}function aQ(a){return y[a|0]<129}function _r(a){a=a|0;zr(a);_b(a)}function _Z(a){a=a|0;PE(a);_b(a)}function ZZ(a){a=a|0;OE(a);_b(a)}function We(a,b){Bb(Zc(a)+4|0,b)}function WU(a){rc(a);PU(a);uo(a)}function Tz(a){x[a>>2]=x[a>>2]-8}function Sw(a){a=a|0;lh(a);_b(a)}function Sj(a){x[a>>2]=x[a>>2]+6}function R1(a){a=a|0;return 6387}function PK(a){xf(a);JK(a);IK(a)}function NK(a){Lb(a);GK(a);sg(a)}function Kq(a){rc(a);LB(a);uo(a)}function Ki(a){Lb(a);cT(a);sg(a)}function JY(a){a=a|0;return 5757}function Iu(a){$i(a);ng(a);$i(a)}function IY(a){a=a|0;return 8893}function Hq(a){return Sb(a,0,48)}function HY(a){a=a|0;return 6749}function Gm(a){Gh(a);ze(a);Gh(a)}function Ge(a){sd(a);Lb(a);sd(a)}function GY(a){a=a|0;return 2206}function GS(a){gm(a);Vk(a);gm(a)}function G2(a){a=a|0;El(a);_b(a)}function F_(a){a=a|0;aF(a);_b(a)}function EK(a){Bk(a);xf(a);Bk(a)}function Bt(a){Lb(a);YL(a);sg(a)}function Au(a){x[a>>2]=x[a>>2]-1}function Ar(a){a=a|0;iE(a);_b(a)}function AS(a){Lb(a);zS(a);sg(a)}function yZ(a){a=a|0;Pc(461204)}function wZ(a){a=a|0;xb(461220)}function ve(a){a=a|0;return a|0}function uZ(a){a=a|0;Pc(461236)}function td(a){return Rg(Rb(a))}function sZ(a){a=a|0;xb(461252)}function rL(a,b){return gy(a,b)}function qZ(a){a=a|0;Pc(461268)}function pt(a){Me(a+12|0);hO(a)}function od(a){uJ(a,0);return a}function ni(a,b){return a>>>b&1}function nC(a,b){return kC(a,b)}function km(a,b){return hf(a,b)}function kg(a){nt(a,0);return a}function ju(a,b){return _R(a,b)}function jf(a){xb(a+20|0);xb(a)}function hv(a,b){return lC(a,b)}function gT(a,b){return Bb(a,b)}function eM(a,b){return bM(a,b)}function ai(a){return ze(a)&255}function _D(a,b,c){Hd(a,b,1<<c)}function Zl(a){xb(a+12|0);xb(a)}function Zb(a,b){return Ye(a,b)}function Xx(a,b){return WK(a,b)}function Wv(a,b){return Df(a,b)}function Wo(a,b){return ji(a,b)}function Uia(a){a=a|0;_b(AP(a))}function Ue(a,b){return ag(a,b)}function Ti(a,b){return dv(a,b)}function TQ(a,b){return Sk(b,a)}function Qk(a){xb(a+12|0);vf(a)}function Qd(a,b){return Am(a,b)}function Pia(a){a=a|0;_b(yP(a))}function Mn(a){return Kj(Td(a))}function Lr(a){a=a|0;return 127}function Hw(a,b){return Wo(a,b)}function Gt(a,b){return Jd(a,b)}function Gp(a){w[a+480214>>1]=0}function EZ(a){a=a|0;xb(461156)}function Dj(a){return!x[a+4>>2]}function CZ(a){a=a|0;Pc(461172)}function Bh(a,b,c){gf(a,c,13,b)}function AZ(a){a=a|0;xb(461188)}function A3(a){a=a|0;lI(a-88|0)}function zG(a){a=a|0;_b(ae(a))}function zC(a,b){kv(a,Rb(a),b)}function yG(a){a=a|0;_b(Pf(a))}function tT(a){return a+2466|0}function sX(a){a=a|0;_b(nD(a))}function sP(a){return a+4896|0}function sK(a){a=a|0;_b(tK(a))}function pG(a){a=a|0;_b(El(a))}function ot(a,b){return a<<8|b}function ml(a){return a>>>0<11}function mG(a){a=a|0;_b(kp(a))}function m6(a){a=a|0;_b(Hx(a))}function lI(a){a=a|0;_b(sx(a))}function kX(a){a=a|0;_b(XC(a))}function iX(a){a=a|0;_b(WC(a))}function i4(a){a=a|0;_b(Ks(a))}function gz(a,b){return b-a>>1}function gc(a,b){x[a+100>>2]=b}function e4(a){a=a|0;_b(HI(a))}function dM(a,b,c){hz(a,b,c,1)}function a4(a){a=a|0;_b(FI(a))}function _R(a,b){return b-a>>2}function YJ(a){a=a|0;_b(ZJ(a))}function Y1(a){a=a|0;_b(xs(a))}function Xs(a){return a>>>27^a}function Ws(a){a=a|0;_b(Wx(a))}function TG(){return(Ra()|0)>0}function Qw(a){a=a|0;_b(hs(a))}function Ox(a){a=a|0;_b(gK(a))}function Ow(a){a=a|0;_b(fs(a))}function NE(a){a=a|0;_b(jw(a))}function LJ(a){a=a|0;_b(MJ(a))}function L8(a){a=a|0;return 13}function Ix(a){a=a|0;_b(pJ(a))}function Cja(a){a=a|0;return 9}function CX(a){a=a|0;_b(vD(a))}function BD(a){a=a|0;_b(zr(a))}function Ak(a){a=a|0;_b(Cf(a))}function $d(a,b){v[a|0]=y[b|0]}function ye(a){a=a|0;return 1}function y9(a){a=a|0;return 6}function xo(a){return a>>>0<5}function xe(a){a=a|0;return 2}function ss(a){return sH(a)*a}function qU(a,b){return b-a|0}function oS(a){a=a|0;return 7}function oF(a){return _d(a,1)}function nP(a,b){Sb(a,0,b<<2)}function kc(a){a=a|0;return 0}function hl(a){return!x[a>>2]}function g6(){return 19469602}function fc(a,b){return a+b|0}function bp(a){return a>>>0<2}function Xr(a,b){x[a+72>>2]=b}function XY(){mE(13233,0);p()}function WR(a){return UR(a,1)}function St(a){return a+256|0}function Sl(a,b){x[a+32>>2]=b}function QD(a){return a>>>0>8}function Pe(a,b){w[a+28>>1]=b}function PG(a){a=a|0;return-1}function NX(a){a=a|0;return 3}function Mm(a){a=a|0;return 4}function Kn(a,b){x[a+36>>2]=b}function KL(a){a=a|0;return 5}function Ij(a){return yd(a)^1}function Ah(a){return kd(a)^1}function zU(a){mU(a,x[a>>2])}function zS(a){sC(a,x[a>>2])}function yr(a,b,c){Hd(a,b,c)}function wM(a){return a+24|0}function uy(a,b){v[a+37|0]=b}function ul(a){return a+16|0}function ty(a,b){v[a+38|0]=b}function tl(a,b,c){_D(a,b,c)}function tM(a){sM(a,x[a>>2])}function mr(a,b){Gh(a);Gh(a)}function kl(a,b,c){vk(a,b,c)}function jF(a){FE(a,x[a>>2])}function iL(a,b){Bj(a);Bj(a)}function ht(a,b){nt(a,oe(b))}function hc(a){return a+12|0}function fh(a){return a+20|0}function ee(a,b){x[a+4>>2]=b}function eU(a){_T(a,x[a>>2])}function dw(a){return a-24|0}function cs(a,b){dp(a,b+4|0)}function cT(a){bT(a,x[a>>2])}function cN(a){bN(a,x[a>>2])}function al(a,b){ff(a);ff(a)}function aT(a){$S(a,x[a>>2])}function aO(a){$N(a,x[a>>2])}function _n(a,b){x[a+8>>2]=b}function ZA(a,b){$i(a);$i(a)}function YL(a){NL(a,x[a>>2])}function Xo(a,b){li(a);li(a)}function Wm(a,b){xg(a);xg(a)}function Wh(a,b){sd(a);sd(a)}function QA(a,b){tf(a);tf(a)}function OR(a,b,c){Bx(a,b,c)}function Mv(a,b){ED(a,oe(b))}function LO(a){KO(a,x[a>>2])}function LE(a){return a+3&-4}function LB(a){cC(a,x[a>>2])}function Kb(a,b,c){NC(a,b,c)}function JK(a){FK(a,x[a>>2])}function Ic(a,b){a=a|0;b=b|0}function IC(a){HC(a,x[a>>2])}function GM(a){return a+80|0}function GK(a){AK(a,x[a>>2])}function Fp(a,b){B[a+8>>2]=b}function Dp(a,b){B[a+4>>2]=b}function Do(a,b){_f(a);_f(a)}function Dc(a,b,c){qr(a,b,c)}function Cv(a,b){lj(a);lj(a)}function Cp(a,b){v[a+36|0]=b}function BQ(a,b){gf(a,b,8,2)}function $l(a,b){yb(b);yb(a)}function yb(a){return a+8|0}function wf(a){return a+2|0}function vm(a,b){v[a+3|0]=b}function uC(a,b){Hd(a,b,22)}function mc(a){return a+4|0}function jq(a){Sb(a,0,4096)}function h6(){return 327705}function gC(a,b){Hd(a,b,20)}function fi(a){return a+3|0}function ed(a){return a+1|0}function cpa(){return 65535}function Yc(a){return!Cb(a)}function RM(a){Sb(a,0,1024)}function Qh(a){return a&255}function Lp(a){Sb(a,0,8192)}function JB(a){x[a+12>>2]=0}function Hka(){return 65534}function yU(a){im(a);aj(a)}function wm(){gj(6974);p()}function ur(a){a=a|0;vr(a)}function uo(a){_f(a);rc(a)}function sq(a){mA(a,Ve(a))}function sg(a){sd(a);Lb(a)}function o1(){return 61800}function nL(a){Bj(a);Lg(a)}function n1(){return 63344}function lT(a){v[a+31|0]=0}function ku(a){lA(a,Ve(a))}function kq(a){ff(a);vd(a)}function iq(a){tf(a);xc(a)}function hT(a){DA(a,Ve(a))}function dT(a){FA(a,Ve(a))}function dN(a){it(a,Ve(a))}function dC(){gj(3950);p()}function cm(a,b){zo(a,b,0)}function _e(a,b){x[a>>2]=b}function Xc(){Sv(3950);p()}function WL(a){py(a,Ve(a))}function WD(a){li(a);qd(a)}function Vt(a){xg(a);Ac(a)}function Qc(a){a=a|0;_b(a)}function QS(a){$i(a);ng(a)}function Ob(a){Jm(x[a>>2])}function Nd(a){v[a+12|0]=1}function Nc(a){x[a+8>>2]=0}function Mk(a){ez(a,Ve(a))}function MB(a,b){$h(a,2,b)}function Iv(a){Gh(a);ze(a)}function If(){Sv(6974);p()}function IK(a){Bk(a);xf(a)}function Ez(a){Sb(a,0,512)}function Ep(a,b){B[a>>2]=b}function AN(a){Ny(a,Ve(a))}function tC(a){v[a+1|0]=3}function sG(a){ax(a,8192)}function Xd(a){v[a+4|0]=1}function OG(a){Sb(a,0,44)}function L2(a){a=a|0;ib=a}function G5(){return 2048}function FY(){return hb|0}function EY(a){a=a|0;hb=a}function ES(a){Sb(a,0,33)}function uh(a){a=a|0;p()}function tV(a,b){TI(a,b)}function qe(a){Ab(a+8|0)}function eR(a,b){Jx(a,b)}function bo(a,b){uG(a,b)}function ap(a,b){KE(a,b)}function XA(a){v[a|0]=16}function Vi(a){xb(a+4|0)}function Jh(a,b){gh(a,b)}function Jc(a){yh(a+8|0)}function IO(a,b){Ef(a,b)}function qf(a){v[a|0]=0}function rr(a){ED(a,0)}function mw(a,b){xb(b)}function lM(a){VL(a,0)}function _y(a){nt(a,0)}function Xf(a){jT(a,0)}function Ly(a){NM(a,0)}function Lc(a){Ce(a,0)}function Ky(a){MM(a,0)}function Ai(a){jJ(a,0)}function oo(a){bj(a)}function gD(a){Mo(a)}function RT(a){sf(a)}function Ke(a){a=a|0}function Hr(a){dk(a)}function Gb(a){xb(a)}function v$(){_E()}function d$(){iF()}function __(){hF()}function Y_(){gF()}function W_(){fF()}function T_(){eF()}function L_(){dF()}
// EMSCRIPTEN_END_FUNCS
e=y;var mb=c([null,Tn,Vb,Pq,Zf,Mpa,go,Zla,mla,zj,ska,sja,Vha,Os,Tn,o2,mW,sm,Mg,M1,_,Wu,fl,_Y,mY,iE,ve,DX,re,qW,QV,om,dj,Mh,yc,jpa,Mb,Ic,dj,kna,Yn,BS,Bz,ci,dB,oia,AP,uh,ye,ye,Sla,Pla,vu,Kla,PP,rja,kja,XY,yP,uh,ye,kc,ye,Ska,Mka,Eka,Aka,rka,Uia,$ja,Pia,Pja,Jja,ve,uh,BO,gga,vfa,VN,Et,TN,mO,jO,vt,$h,gea,xa,Xda,yc,yc,Uda,Ry,Pda,Lda,nZ,Id,yc,zda,tda,oda,zM,Ql,zn,Id,mZ,dda,Wca,Ke,Aaa,Ic,zM,$o,Dr,gZ,iZ,Tn,raa,m9,vn,nqa,qJ,Zf,Vb,S7,o7,cF,B6,q6,j6,b4,V3,N1,P3,X5,S5,N5,YI,YI,z5,p5,Is,Pq,Hs,E4,x4,Hs,D3,w3,b3,a3,Hs,Hs,w2,V2,R2,P2,z2,t2,s2,rx,v2,b2,Tn,C2,Et,y2,q2,p1,Vr,At,A1,u1,s1,yc,PF,H0,qc,V_,Ir,Er,ep,yc,yc,dB,Rm,lY,kY,iY,Ic,jY,Ic,Bz,Lga,hY,gY,fY,eY,Qi,cY,d2,X1,bY,ND,MD,aY,Vr,_X,YX,Pv,ur,pj,Rc,VX,Om,UX,TX,WX,SX,RX,ZX,Gga,XX,LD,QX,PX,KD,OX,Mf,oj,Tc,Lv,Qb,JX,Zj,Lv,IX,HX,GX,zr,FX,vX,uX,Id,aD,ZD,EX,wX,ii,yc,tX,qc,qX,pX,hD,Id,fD,oX,Ic,nX,mX,lX,dj,BD,vu,vD,CX,Oo,zJ,BX,Qc,AX,ye,ye,vu,sA,zX,PP,yX,xX,nD,sX,Oo,rX,Qc,kc,ye,ye,kc,kc,mD,XC,kX,Oo,jX,WC,iX,hX,gX,fX,eX,dX,cX,bX,aX,Tv,zf,Mb,XW,Hca,WW,Gca,VW,xv,cc,Kca,pD,Ad,UW,yc,zn,jZ,TW,SW,Ql,ep,Ic,TC,PW,OW,BD,yc,yc,NW,MW,LW,LC,JW,IW,Ic,Ic,Ic,HW,dB,Bz,EC,Rm,wW,vW,EW,CW,AW,uW,Ic,LC,oC,tW,fv,sW,nW,lW,kW,to,Ic,fW,XB,eW,dW,cW,bW,Ng,Kc,aW,$V,ZV,YV,XV,Fg,ig,Zg,WV,yc,_u,WB,yc,VB,UB,VV,UV,TV,SV,Ql,PV,EC,Ic,RV,GB,EB,CB,MV,LV,KV,JV,IV,Pg,HV,GV,FV,EV,jx,bK,Db,qP,DV,KX,pg,CV,$u,vB,id,Pd,pj,Cj,zV,yV,jj,hr,ah,vM,xV,wV,Tu,tc,Ec,Vo,pqa,uV,fe,Xu,eq,Db,lm,Db,Db,Yn,FW,mqa,Db,hC,lqa,kqa,Wq,Hf,av,fqa,ZU,HD,Ni,Gf,Nb,Kg,eqa,oB,dqa,Rc,nB,Fga,cqa,bqa,cq,aqa,YU,XU,zd,$pa,mB,_pa,_ba,tm,wo,Pl,iy,yL,Zpa,TU,kK,Ypa,Xpa,Wpa,Uk,lB,Vpa,Upa,Xq,RU,Tpa,Spa,Qg,yc,Rpa,Qpa,Ppa,BO,Opa,Npa,Jpa,gB,Ipa,gB,Epa,VN,Et,TN,ro,yc,Iq,Lpa,qc,Kpa,po,no,Ic,qc,Hpa,Fpa,IU,Gpa,vt,Bpa,Apa,zpa,wpa,iB,vpa,aB,upa,tpa,spa,Nu,rpa,dq,Cz,qpa,ppa,opa,npa,Yf,Ff,mpa,lpa,kpa,ipa,bpa,apa,yc,$oa,_oa,_A,fpa,Yn,Fq,dpa,sU,gpa,epa,Ic,Rm,ro,Ic,qc,Iq,Zoa,po,no,Mj,Eq,Voa,Du,Uoa,Roa,ZU,Dq,mg,Qoa,Eu,Dz,YU,Poa,rm,Ooa,Noa,ZT,Moa,Loa,vH,qm,fu,Koa,_fa,RU,Joa,Ioa,Hoa,yc,qg,Aoa,ro,yc,Iq,Goa,qc,Foa,po,no,Eoa,Doa,qc,Coa,Boa,TT,QT,zoa,HT,CL,eca,zL,CT,soa,roa,ej,ooa,noa,hda,koa,joa,ioa,qv,hoa,goa,foa,Mf,yW,eoa,Qia,Ria,doa,coa,qoa,fo,BW,boa,fq,zW,xT,aoa,$na,Cda,$c,_na,Zna,wT,Yna,rW,Xna,Wna,Vna,vT,Una,Iz,Tna,Sna,xW,BU,poa,Rna,sT,yc,Qna,MA,jO,GC,Tq,Pna,Ona,mn,cda,Nna,Mna,qT,LA,qT,_A,KA,Lna,vl,Kna,nY,Jna,Ina,Hna,Gna,wh,Dga,wh,Jba,Fna,gba,nT,Ena,qna,nj,Cd,eo,zna,GA,ona,kV,Yo,Fi,zA,nna,mna,mT,Dna,Cna,Ef,Bna,Yi,wu,hba,jda,Zaa,Ana,Pq,yna,xna,wna,vna,Id,Zk,Id,EA,ve,fT,Wk,tna,ve,Ic,Ic,Ic,rna,su,ru,pna,hna,gna,fna,mo,ena,dna,GD,cna,id,ll,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,yc,Vma,Uma,Tma,Sma,Lma,Kma,Rma,Qma,Pma,Ic,xS,ro,yc,Oma,Nma,qc,Mma,po,no,pS,fo,Hma,Gma,Fma,Ema,Sga,Mf,Dma,Cma,Bma,Ama,NT,aP,Hb,pu,rA,TA,fv,zma,yma,mS,xma,Xq,Vq,yu,$A,wma,lS,Qj,vma,Pq,Mf,Vu,Mf,yv,Sq,uma,Yi,kS,Kga,by,jS,tq,yc,yc,tma,sma,Zk,Id,rma,Ic,qma,su,ru,rq,ve,Ic,pma,GB,EB,oma,Wk,lma,kma,nj,jma,ima,jA,iu,hma,gma,fma,ema,dma,cma,ZB,bma,ama,Db,$la,_la,Yla,Xla,Oia,Afa,mD,Wla,Db,hu,Y2,IA,Z2,hu,Vla,Ula,_2,$2,eda,Tla,pT,oT,zz,Qi,NR,Rla,Qla,Ola,Nla,Mla,Lla,ru,Jla,Rm,dj,Ic,CB,Lu,gu,_k,Fi,Gla,Mf,Eq,zla,yla,Hla,AA,Ic,vla,vB,rV,ula,fda,tla,sla,mL,eo,rla,hR,qla,pla,ov,nv,du,cea,ola,nla,Lt,lla,so,kla,jla,cu,Rq,yc,ila,Ic,hla,gla,aD,tm,Mf,bla,Og,ala,Id,$ka,_ka,UQ,Id,Uq,Zka,Wka,Vka,$k,Nn,du,$c,Uka,dca,NR,NQ,Tka,ru,Ic,Rka,su,Oka,Nka,aB,VQ,GQ,Xu,Lka,Kka,Jka,Ika,cpa,Hka,Gka,Fka,_t,Dka,Cka,_t,Bka,dV,DQ,zka,yka,yc,DW,xka,yc,pka,kka,jka,Eq,uka,tka,qka,ro,oka,Iq,nka,qc,mka,po,no,lka,tQ,sQ,ika,hka,Rm,gka,pQ,qc,fka,eka,cka,yc,bka,Zja,fo,Yja,Uja,tP,hR,fo,Cfa,Bfa,Rja,Lja,Kja,GU,Vo,Ija,Hja,Gja,Fja,Eja,VP,lu,Dja,Bja,Aja,yc,zja,yja,xja,vja,uja,oja,LP,wja,Ic,tja,qc,qja,yc,pja,Ir,yc,Er,cP,lja,Sz,jja,ija,Mga,fja,eja,Dca,dja,cja,bja,Bca,aja,Cca,Eca,$ia,_ia,Zia,dY,RD,Pga,aA,yc,pda,mda,Gz,Yia,Xia,Wia,Fz,Via,su,Ic,Tia,Nia,Hj,Gj,Zp,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Fia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,nia,mia,lia,kia,jia,iia,hia,gia,fia,eia,dia,cia,bia,aia,$ha,_ha,Zha,Yha,Xha,Wha,Uha,Tha,Sha,Rha,Qha,Pha,Oha,Nha,Mha,Lha,Kha,Jha,Iha,Hha,Gha,Fha,Eha,Dha,Cha,Bha,Aha,zha,yha,xha,wha,vha,uha,tha,sha,rha,qha,pha,oha,nha,mha,lha,kha,jha,iha,hha,gha,fha,eha,dha,cha,bha,aha,$ga,_ga,Zga,Yga,Xga,Wga,Vga,Rga,bP,yc,Uga,Zk,Id,to,Wk,tga,il,Nga,Oga,KB,OO,yc,Iga,Hga,qga,Ega,nga,mga,Cga,Bga,Aga,zga,yga,qz,xga,wga,vga,uga,mT,Jt,kga,sga,rga,pga,oga,to,yc,qc,lga,hD,fD,DO,yc,jga,Id,hga,fga,ega,vO,dga,jV,cga,ZD,sO,Pca,bga,aga,dt,Nca,$fa,Mca,Lca,Zfa,Yfa,Xfa,Wfa,Vfa,Tfa,Sfa,Rfa,yc,Pfa,Ufa,Ic,Qfa,Ic,Ofa,Nfa,Mfa,Nk,yc,Kfa,Hfa,Gfa,Ifa,Ffa,qc,Efa,Dfa,Ir,Er,zfa,px,yfa,xfa,gl,wfa,kda,uz,Qga,XO,cu,GW,ufa,tfa,Id,sfa,to,to,rfa,IU,Et,KD,Zk,Id,yc,PF,pfa,ve,Wk,qc,ofa,Ir,Er,rT,Wd,YB,KW,uf,jc,oqa,nfa,mfa,hpa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,Kea,Jea,Iea,Hea,Gea,Fea,Eea,Dea,Cea,Bea,Aea,zea,yea,xea,wea,vea,uea,tea,sea,rea,qea,pea,oea,nea,mea,lea,kea,jea,iea,hea,fea,eea,dea,bea,Lfa,aea,$da,_da,cO,bO,Zda,Yda,Hn,rt,Zy,Wda,ON,iP,Nt,Vp,NN,Mb,iM,xM,yy,Up,qt,Tp,Vda,HN,fP,kP,Tda,Sda,Yi,wu,tq,CO,lz,Pi,Yi,kS,Rda,tq,Jfa,yc,yc,Qda,Oda,Nda,Zk,Id,Id,Zk,Id,Ic,ve,$M,Mda,Wk,ve,Kda,Wk,Ida,Jga,Sia,Hda,hM,TM,Uca,Gda,Fda,Re,yc,yc,yc,Eda,yc,yc,bda,Dda,$ca,Bda,MX,$W,ZW,RW,yda,QW,_W,LX,YW,Qn,xda,Tga,HM,Hp,wda,W9,vda,Jy,Fca,yc,uda,yc,sda,iga,Ql,zn,Id,nda,lda,vba,Aba,ida,xba,uba,Id,yc,pz,Xp,dP,ada,_ca,Zca,Yca,Rm,Xca,pQ,Ic,hja,gja,moa,loa,Xja,Wja,Qja,Oja,Jma,Ima,fla,ela,jna,ina,hqa,gqa,yoa,xoa,OV,NV,BV,AV,dla,cla,aka,_ja,nja,mja,ypa,xpa,Yoa,Xoa,jW,iW,hW,gW,Qka,Pka,wka,vka,xla,wla,lna,MS,woa,voa,uoa,toa,Dpa,Cpa,Toa,Soa,Yka,Xka,Aca,zca,ica,hca,Bla,Ala,Tja,Sja,Nja,Mja,Ila,Dla,Cla,pW,oW,jqa,iqa,nma,mma,Fla,Ela,Sca,yc,Rca,Ql,zn,Qca,Zk,Id,Ic,EA,Wk,Oca,oy,Xp,Ica,Jca,WN,yca,xca,aB,wca,Qu,vca,GQ,uca,tca,sca,Eq,rca,qca,Mf,pca,oca,nca,mca,lca,DQ,kca,jca,yc,g3,d3,c3,ro,Iq,gca,qc,fca,po,no,cca,bca,aca,zA,Uba,wh,Yba,Xba,wh,Wba,Nf,gh,Cl,Vba,Pba,Tba,Ql,Sba,tL,Rba,zA,Qba,Oba,Iba,yc,Nba,$ba,Mba,Gba,Fba,Kba,Zba,Hba,fy,hy,qc,Eba,Dba,Cba,yc,yc,Bba,eL,yc,Zk,Id,kba,yba,iba,Zx,Yi,wu,wba,R8,jba,sba,rba,wh,qba,pba,oba,$K,cL,zba,Bp,qz,nba,Ef,bL,lba,$j,kw,gh,Fz,fT,Wk,fba,eba,dba,cba,bba,aba,qj,$aa,_aa,mba,tba,Yaa,Xaa,qc,Waa,tL,Vaa,Taa,Saa,Raa,eaa,Qaa,Paa,HK,Baa,Rf,zn,aL,zaa,xaa,yaa,Ic,Fz,Ic,Wx,Ws,Ws,Gaa,kc,Ke,kc,kc,kc,Ic,Mm,Kaa,Laa,Naa,Maa,Oaa,Ji,Vx,Vx,Ux,Ux,Ux,Woa,Ke,MS,Faa,Eaa,Daa,Caa,Jaa,Ii,KK,daa,kc,kc,ye,Tx,xe,xe,ye,Iaa,Haa,Ic,Ke,Ic,Ke,vaa,rq,gaa,tK,sK,sK,faa,kc,Ke,kc,kc,kc,Ic,Cja,yK,taa,iaa,haa,uaa,Ji,qaa,paa,oaa,naa,maa,laa,kaa,jaa,saa,Ii,xK,kc,kc,ye,xe,xe,ye,wK,uK,yc,yc,Y9,X9,aaa,$9,mK,Cf,uh,baa,lK,caa,kc,_9,Z9,V9,At,U9,T9,S9,R9,Id,yc,zn,Jt,Q9,Ql,Ic,P9,F9,x9,q9,i9,b9,U8,K8,D8,Uaa,waa,hK,gK,Ox,fK,J9,kc,Ke,kc,kc,kc,Ic,oS,M9,N9,O9,Ji,L9,Ii,K9,kc,kc,ye,xe,xe,Ic,Ke,eK,I9,H9,dK,G9,cK,aK,E9,ZJ,YJ,YJ,z9,kc,Ke,kc,kc,kc,Ic,y9,B9,C9,D9,Ji,A9,Ii,_J,kc,kc,ye,xe,xe,w9,Ak,Ak,r9,kc,Ke,kc,kc,kc,Ic,KL,t9,u9,v9,Ji,s9,Ii,VJ,kc,kc,ye,xe,xe,p9,Wx,Ws,Ws,j9,kc,Ke,kc,kc,kc,Ic,KL,l9,n9,o9,Ji,k9,Ii,TJ,kc,kc,ye,xe,xe,h9,Ox,Ox,f9,oS,g9,eK,e9,d9,dK,c9,cK,aK,a9,Ak,Ak,X8,kc,Ke,kc,kc,kc,Ic,xe,Z8,_8,$8,Ji,Y8,Ii,W8,kc,kc,ye,xe,xe,T8,V8,MJ,LJ,LJ,N8,kc,Ke,kc,kc,M8,Ic,L8,P8,Q8,S8,Ji,O8,Ii,Mx,kc,kc,ye,xe,xe,Ic,Ke,J8,Ak,Ak,E8,kc,Ke,kc,kc,kc,Ic,NX,G8,H8,I8,Ji,F8,Ii,JJ,kc,kc,ye,xe,xe,C8,Ak,Ak,x8,kc,Ke,kc,kc,kc,Ic,Mm,z8,A8,B8,Ji,y8,Ii,GJ,kc,kc,ye,xe,xe,h6,v8,o6,$5,g6,f6,L5,Pv,J5,Ns,vJ,F5,l8,k8,Id,Id,G5,D5,C5,B5,da,h8,g8,vJ,A5,x5,rJ,d8,pJ,UI,sA,h5,g5,k5,e5,f5,i5,Lx,w5,O7,nJ,v5,u5,t5,s5,r5,q5,o5,n5,m5,l5,d5,Lx,Z4,Y4,X4,W4,V4,U4,T4,S4,R4,Q4,P4,O4,N4,M4,up,L4,K4,Kl,Gs,J4,yE,I4,G4,F4,D4,C4,B4,A4,zx,z4,y4,v4,u4,t4,r4,q4,o4,m4,k4,R5,gJ,fJ,dJ,cJ,E3,C3,rJ,Lx,I6,H6,G6,F6,E6,D6,C6,A6,z6,y6,x6,w6,v6,u6,t6,s6,r6,p6,n6,k6,Hx,m6,l6,Ix,i6,Ix,Ix,qD,Ls,e6,qfa,tr,VB,c6,_3,O5,a6,W3,U3,st,W5,yc,V5,$M,S3,Jda,Q5,rE,cP,Id,Id,Id,p4,j4,n4,l4,Ada,U5,d6,_5,wv,Yi,wu,tq,yc,mv,M5,Vca,Tca,K5,lJ,kJ,H5,E5,I5,Id,T5,P5,Y5,yc,yc,yc,Db,jc,y5,j5,yc,yc,Id,DM,c5,b5,a5,G3,qda,rda,Z5,gda,$4,_4,tn,PI,Lba,H4,Jj,lL,w4,Hf,yM,BL,AL,s4,f4,c4,dka,Vja,Z3,Y3,TT,X3,qc,T3,QT,Ic,H3,EA,F3,uh,Ks,i4,b6,ve,uh,ve,Qc,h4,g4,uh,HI,e4,Oo,d4,FI,a4,Oo,$3,Qc,R3,ve,Qc,Q3,O3,Qc,xI,wI,uh,Qc,N3,M3,Qc,uI,tI,Qc,L3,K3,Qc,sI,rI,Qc,J3,I3,Qc,qI,pI,sx,lI,z3,y3,kI,jI,iI,hI,gI,fI,eI,dI,cI,bI,aI,$H,_H,ZH,YH,XH,B3,A3,x3,v3,u3,t3,s3,r3,q3,p3,o3,n3,m3,l3,k3,j3,i3,h3,ve,uh,ve,uh,f3,e3,X2,W2,Gl,U2,T2,S2,O2,N2,K2,J2,Cn,Fc,B2,x2,H2,A2,u2,k2,r2,Pw,p2,una,sna,iT,n2,m2,l2,k2,j2,HG,g2,c2,Cn,Mg,ve,El,G2,Ic,Tn,RG,QG,kc,kc,F2,PG,E2,is,D2,is,hs,Qw,NG,MG,fs,Ow,JG,IG,kp,i2,Ic,Tn,RG,QG,kc,kc,h2,PG,f2,is,e2,is,hs,Qw,NG,MG,fs,Ow,JG,IG,xs,Y1,Z1,W1,a2,$1,_1,SG,Sw,SG,Sw,ae,zG,V1,U1,Pf,yG,T1,S1,Ke,O1,P1,vG,ve,Qc,R1,fZ,eZ,dZ,Q1,_r,lh,Sw,I2,kc,L1,Ke,ys,Jw,ys,Cw,gs,FG,K1,pG,J1,I1,H1,G1,pG,F1,nG,E1,D1,mG,C1,B1,z1,y1,mG,x1,nG,w1,v1,t1,r1,tw,kh,jh,Tr,_b,gw,Cg,tk,sw,Dl,gp,pk,d1,Je,si,zg,b1,$0,OF,OF,X0,Sr,V0,NF,ti,T0,R0,me,P0,vw,Lw,qw,kh,jh,Rr,mh,Bl,fl,gn,nk,si,zg,Qr,MF,ti,A0,kk,v0,u0,gp,q1,zw,Q2,BG,p0,$r,ip,om,k0,Zm,gp,ww,Ke,U$,Mr,T$,Bg,S$,AF,R$,zF,gp,P$,ir,N$,M$,rk,L$,vF,zF,J$,hZ,H$,G$,D$,C$,xw,y$,x$,w$,v$,u$,t$,s$,r$,q$,p$,o$,n$,m$,l$,k$,j$,i$,h$,g$,f$,e$,d$,c$,b$,a$,$_,__,Z_,Y_,X_,W_,U_,T_,S_,R_,Q_,P_,O_,N_,M_,L_,K_,J_,I_,lF,H_,iw,D_,G_,oZ,pZ,EE,E_,C_,o1,n1,m1,ms,XF,jp,c_,b_,WF,VF,UF,QZ,OZ,MZ,KZ,IZ,GZ,EZ,CZ,AZ,yZ,wZ,uZ,sZ,qZ,Ic,aF,F_,fK,ZE,q_,p_,o_,n_,m_,cV,l_,k_,j_,pF,h_,g_,f_,e_,d_,kc,a_,$Z,PE,_Z,YZ,XZ,PI,VZ,TZ,OE,ZZ,sA,_V,WZ,UZ,SZ,ve,Qc,Qc,B_,A_,z_,y_,x_,w_,v_,u_,cV,t_,s_,r_,Qc,YE,YE,cp,ye,ye,i_,ye,Qc,WE,VE,cp,kc,kc,UE,Mm,Qc,WE,VE,cp,kc,kc,UE,Mm,Qc,TE,SE,cp,kc,kc,QE,Mm,Qc,TE,SE,cp,kc,kc,QE,Mm,ve,Qc,l1,k1,j1,ve,Qc,i1,h1,g1,Qc,f1,e1,c1,a1,_0,Z0,Y0,W0,U0,S0,Q0,Qc,O0,N0,M0,L0,K0,J0,I0,G0,F0,E0,D0,Qc,C0,B0,z0,y0,x0,w0,t0,s0,Qc,r0,q0,o0,n0,m0,l0,j0,i0,ve,Qc,xe,h0,g0,f0,e0,d0,c0,RZ,NZ,JZ,xZ,tZ,FZ,BZ,ve,Qc,xe,b0,a0,$$,_$,Z$,Y$,PZ,LZ,HZ,vZ,rZ,DZ,zZ,jw,NE,X$,jw,NE,W$,Qc,Lr,Lr,jk,jk,jk,CF,kc,ik,ik,Qc,Lr,Lr,jk,jk,jk,CF,kc,ik,ik,Qc,jt,jt,jk,Kr,Kr,BF,kc,ik,ik,Qc,jt,jt,jk,Kr,Kr,BF,kc,ik,ik,Qc,V$,Q$,Qc,O$,K$,Qc,I$,F$,Qc,E$,B$,Qc,qF,A$,Ic,Qc,qF,z$,Ic,ve,uh,uh,kc,kc,kc,$X,Qc,Cr,lZ,sE,ck,$Y,kZ,oE,vG,Qc,cZ,pE,Qc,bZ,aZ,pE,_r,WY,lE,ra,mE,ve,Qc,Ke,Ke,VY,MY,PY,UY,Qc,NY,QY,TY,Qc,OY,RY,SY,Qc,IY,Qc,HY,Qc,JY,Ar,vu,_r,Ar,Ar,Ar,_r,Qc,GY]);function nb(){return u.byteLength/65536|0}function sb(tb){tb=tb|0;var ob=nb()|0;var pb=ob+tb|0;if(ob<pb&&pb<65536){var qb=new ArrayBuffer(D(pb,65536));var rb=new Int8Array(qb);rb.set(v);v=new Int8Array(qb);w=new Int16Array(qb);x=new Int32Array(qb);y=new Uint8Array(qb);z=new Uint16Array(qb);A=new Uint32Array(qb);B=new Float32Array(qb);C=new Float64Array(qb);u=qb;t.buffer=u;e=y}return ob}return{"xa":vV,"ya":mb,"za":w8,"Aa":u8,"Ba":Qc,"Ca":t8,"Da":s8,"Ea":r8,"Fa":Ns,"Ga":Ic,"Ha":q8,"Ia":p8,"Ja":o8,"Ka":Vx,"La":n8,"Ma":zJ,"Na":m8,"Oa":ve,"Pa":xJ,"Qa":wJ,"Ra":xJ,"Sa":j8,"Ta":DY,"Ua":CY,"Va":BY,"Wa":i8,"Xa":tJ,"Ya":f8,"Za":sJ,"_a":e8,"$a":c8,"ab":b8,"bb":a8,"cb":$7,"db":_7,"eb":Z7,"fb":Y7,"gb":X7,"hb":W7,"ib":V7,"jb":U7,"kb":T7,"lb":R7,"mb":Q7,"nb":P7,"ob":N7,"pb":M7,"qb":L7,"rb":K7,"sb":J7,"tb":I7,"ub":H7,"vb":G7,"wb":F7,"xb":E7,"yb":D7,"zb":C7,"Ab":B7,"Bb":A7,"Cb":z7,"Db":y7,"Eb":x7,"Fb":w7,"Gb":v7,"Hb":u7,"Ib":t7,"Jb":s7,"Kb":r7,"Lb":q7,"Mb":p7,"Nb":n7,"Ob":m7,"Pb":l7,"Qb":k7,"Rb":j7,"Sb":i7,"Tb":h7,"Ub":g7,"Vb":f7,"Wb":e7,"Xb":d7,"Yb":c7,"Zb":b7,"_b":a7,"$b":$6,"ac":_6,"bc":Z6,"cc":Y6,"dc":X6,"ec":W6,"fc":V6,"gc":U6,"hc":AY,"ic":T6,"jc":S6,"kc":R6,"lc":Q6,"mc":zY,"nc":P6,"oc":O6,"pc":N6,"qc":M6,"rc":L6,"sc":K6,"tc":J6,"uc":M2,"vc":L2,"wc":FY,"xc":EY,"yc":YY,"zc":ZY,"Ac":LY,"Bc":KY,"Cc":yY,"Dc":xY,"Ec":wY,"Fc":vY,"Gc":uY,"Hc":tY,"Ic":sY,"Jc":rY,"Kc":qY,"Lc":pY,"Mc":oY}}return ub(wb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


